/*!
 * jQuery JavaScript Library v2.2.3
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2016-04-05T19:26Z
 */
/*!
 * Bootstrap v3.3.6 (http://getbootstrap.com)
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under the MIT license
 */
if(function(t,e){"object"==typeof module&&"object"==typeof module.exports?module.exports=t.document?e(t,!0):function(t){if(!t.document)throw new Error("jQuery requires a window with a document");return e(t)}:e(t)}("undefined"!=typeof window?window:this,function(t,e){function n(t){var e=!!t&&"length"in t&&t.length,n=ot.type(t);return"function"===n||ot.isWindow(t)?!1:"array"===n||0===e||"number"==typeof e&&e>0&&e-1 in t}function i(t,e,n){if(ot.isFunction(e))return ot.grep(t,function(t,i){return!!e.call(t,i,t)!==n});if(e.nodeType)return ot.grep(t,function(t){return t===e!==n});if("string"==typeof e){if(gt.test(e))return ot.filter(e,t,n);e=ot.filter(e,t)}return ot.grep(t,function(t){return J.call(e,t)>-1!==n})}function r(t,e){for(;(t=t[e])&&1!==t.nodeType;);return t}function o(t){var e={};return ot.each(t.match(wt)||[],function(t,n){e[n]=!0}),e}function a(){X.removeEventListener("DOMContentLoaded",a),t.removeEventListener("load",a),ot.ready()}function s(){this.expando=ot.expando+s.uid++}function u(t,e,n){var i;if(void 0===n&&1===t.nodeType)if(i="data-"+e.replace(St,"-$&").toLowerCase(),n=t.getAttribute(i),"string"==typeof n){try{n="true"===n?!0:"false"===n?!1:"null"===n?null:+n+""===n?+n:Dt.test(n)?ot.parseJSON(n):n}catch(r){}Mt.set(t,e,n)}else n=void 0;return n}function l(t,e,n,i){var r,o=1,a=20,s=i?function(){return i.cur()}:function(){return ot.css(t,e,"")},u=s(),l=n&&n[3]||(ot.cssNumber[e]?"":"px"),c=(ot.cssNumber[e]||"px"!==l&&+u)&&At.exec(ot.css(t,e));if(c&&c[3]!==l){l=l||c[3],n=n||[],c=+u||1;do o=o||".5",c/=o,ot.style(t,e,c+l);while(o!==(o=s()/u)&&1!==o&&--a)}return n&&(c=+c||+u||0,r=n[1]?c+(n[1]+1)*n[2]:+n[2],i&&(i.unit=l,i.start=c,i.end=r)),r}function c(t,e){var n="undefined"!=typeof t.getElementsByTagName?t.getElementsByTagName(e||"*"):"undefined"!=typeof t.querySelectorAll?t.querySelectorAll(e||"*"):[];return void 0===e||e&&ot.nodeName(t,e)?ot.merge([t],n):n}function d(t,e){for(var n=0,i=t.length;i>n;n++)Ct.set(t[n],"globalEval",!e||Ct.get(e[n],"globalEval"))}function h(t,e,n,i,r){for(var o,a,s,u,l,h,f=e.createDocumentFragment(),p=[],g=0,m=t.length;m>g;g++)if(o=t[g],o||0===o)if("object"===ot.type(o))ot.merge(p,o.nodeType?[o]:o);else if(Wt.test(o)){for(a=a||f.appendChild(e.createElement("div")),s=(It.exec(o)||["",""])[1].toLowerCase(),u=Ft[s]||Ft._default,a.innerHTML=u[1]+ot.htmlPrefilter(o)+u[2],h=u[0];h--;)a=a.lastChild;ot.merge(p,a.childNodes),a=f.firstChild,a.textContent=""}else p.push(e.createTextNode(o));for(f.textContent="",g=0;o=p[g++];)if(i&&ot.inArray(o,i)>-1)r&&r.push(o);else if(l=ot.contains(o.ownerDocument,o),a=c(f.appendChild(o),"script"),l&&d(a),n)for(h=0;o=a[h++];)Pt.test(o.type||"")&&n.push(o);return f}function f(){return!0}function p(){return!1}function g(){try{return X.activeElement}catch(t){}}function m(t,e,n,i,r,o){var a,s;if("object"==typeof e){"string"!=typeof n&&(i=i||n,n=void 0);for(s in e)m(t,s,n,i,e[s],o);return t}if(null==i&&null==r?(r=n,i=n=void 0):null==r&&("string"==typeof n?(r=i,i=void 0):(r=i,i=n,n=void 0)),r===!1)r=p;else if(!r)return t;return 1===o&&(a=r,r=function(t){return ot().off(t),a.apply(this,arguments)},r.guid=a.guid||(a.guid=ot.guid++)),t.each(function(){ot.event.add(this,e,r,i,n)})}function v(t,e){return ot.nodeName(t,"table")&&ot.nodeName(11!==e.nodeType?e:e.firstChild,"tr")?t.getElementsByTagName("tbody")[0]||t.appendChild(t.ownerDocument.createElement("tbody")):t}function y(t){return t.type=(null!==t.getAttribute("type"))+"/"+t.type,t}function b(t){var e=qt.exec(t.type);return e?t.type=e[1]:t.removeAttribute("type"),t}function x(t,e){var n,i,r,o,a,s,u,l;if(1===e.nodeType){if(Ct.hasData(t)&&(o=Ct.access(t),a=Ct.set(e,o),l=o.events)){delete a.handle,a.events={};for(r in l)for(n=0,i=l[r].length;i>n;n++)ot.event.add(e,r,l[r][n])}Mt.hasData(t)&&(s=Mt.access(t),u=ot.extend({},s),Mt.set(e,u))}}function w(t,e){var n=e.nodeName.toLowerCase();"input"===n&&Nt.test(t.type)?e.checked=t.checked:("input"===n||"textarea"===n)&&(e.defaultValue=t.defaultValue)}function _(t,e,n,i){e=Z.apply([],e);var r,o,a,s,u,l,d=0,f=t.length,p=f-1,g=e[0],m=ot.isFunction(g);if(m||f>1&&"string"==typeof g&&!it.checkClone&&Ut.test(g))return t.each(function(r){var o=t.eq(r);m&&(e[0]=g.call(this,r,o.html())),_(o,e,n,i)});if(f&&(r=h(e,t[0].ownerDocument,!1,t,i),o=r.firstChild,1===r.childNodes.length&&(r=o),o||i)){for(a=ot.map(c(r,"script"),y),s=a.length;f>d;d++)u=r,d!==p&&(u=ot.clone(u,!0,!0),s&&ot.merge(a,c(u,"script"))),n.call(t[d],u,d);if(s)for(l=a[a.length-1].ownerDocument,ot.map(a,b),d=0;s>d;d++)u=a[d],Pt.test(u.type||"")&&!Ct.access(u,"globalEval")&&ot.contains(l,u)&&(u.src?ot._evalUrl&&ot._evalUrl(u.src):ot.globalEval(u.textContent.replace(Bt,"")))}return t}function $(t,e,n){for(var i,r=e?ot.filter(e,t):t,o=0;null!=(i=r[o]);o++)n||1!==i.nodeType||ot.cleanData(c(i)),i.parentNode&&(n&&ot.contains(i.ownerDocument,i)&&d(c(i,"script")),i.parentNode.removeChild(i));return t}function k(t,e){var n=ot(e.createElement(t)).appendTo(e.body),i=ot.css(n[0],"display");return n.detach(),i}function C(t){var e=X,n=Yt[t];return n||(n=k(t,e),"none"!==n&&n||(Vt=(Vt||ot("<iframe frameborder='0' width='0' height='0'/>")).appendTo(e.documentElement),e=Vt[0].contentDocument,e.write(),e.close(),n=k(t,e),Vt.detach()),Yt[t]=n),n}function M(t,e,n){var i,r,o,a,s=t.style;return n=n||Kt(t),a=n?n.getPropertyValue(e)||n[e]:void 0,""!==a&&void 0!==a||ot.contains(t.ownerDocument,t)||(a=ot.style(t,e)),n&&!it.pixelMarginRight()&&Xt.test(a)&&Gt.test(e)&&(i=s.width,r=s.minWidth,o=s.maxWidth,s.minWidth=s.maxWidth=s.width=a,a=n.width,s.width=i,s.minWidth=r,s.maxWidth=o),void 0!==a?a+"":a}function D(t,e){return{get:function(){return t()?void delete this.get:(this.get=e).apply(this,arguments)}}}function S(t){if(t in ie)return t;for(var e=t[0].toUpperCase()+t.slice(1),n=ne.length;n--;)if(t=ne[n]+e,t in ie)return t}function T(t,e,n){var i=At.exec(e);return i?Math.max(0,i[2]-(n||0))+(i[3]||"px"):e}function A(t,e,n,i,r){for(var o=n===(i?"border":"content")?4:"width"===e?1:0,a=0;4>o;o+=2)"margin"===n&&(a+=ot.css(t,n+Et[o],!0,r)),i?("content"===n&&(a-=ot.css(t,"padding"+Et[o],!0,r)),"margin"!==n&&(a-=ot.css(t,"border"+Et[o]+"Width",!0,r))):(a+=ot.css(t,"padding"+Et[o],!0,r),"padding"!==n&&(a+=ot.css(t,"border"+Et[o]+"Width",!0,r)));return a}function E(e,n,i){var r=!0,o="width"===n?e.offsetWidth:e.offsetHeight,a=Kt(e),s="border-box"===ot.css(e,"boxSizing",!1,a);if(X.msFullscreenElement&&t.top!==t&&e.getClientRects().length&&(o=Math.round(100*e.getBoundingClientRect()[n])),0>=o||null==o){if(o=M(e,n,a),(0>o||null==o)&&(o=e.style[n]),Xt.test(o))return o;r=s&&(it.boxSizingReliable()||o===e.style[n]),o=parseFloat(o)||0}return o+A(e,n,i||(s?"border":"content"),r,a)+"px"}function O(t,e){for(var n,i,r,o=[],a=0,s=t.length;s>a;a++)i=t[a],i.style&&(o[a]=Ct.get(i,"olddisplay"),n=i.style.display,e?(o[a]||"none"!==n||(i.style.display=""),""===i.style.display&&Ot(i)&&(o[a]=Ct.access(i,"olddisplay",C(i.nodeName)))):(r=Ot(i),"none"===n&&r||Ct.set(i,"olddisplay",r?n:ot.css(i,"display"))));for(a=0;s>a;a++)i=t[a],i.style&&(e&&"none"!==i.style.display&&""!==i.style.display||(i.style.display=e?o[a]||"":"none"));return t}function N(t,e,n,i,r){return new N.prototype.init(t,e,n,i,r)}function I(){return t.setTimeout(function(){re=void 0}),re=ot.now()}function P(t,e){var n,i=0,r={height:t};for(e=e?1:0;4>i;i+=2-e)n=Et[i],r["margin"+n]=r["padding"+n]=t;return e&&(r.opacity=r.width=t),r}function F(t,e,n){for(var i,r=(L.tweeners[e]||[]).concat(L.tweeners["*"]),o=0,a=r.length;a>o;o++)if(i=r[o].call(n,e,t))return i}function W(t,e,n){var i,r,o,a,s,u,l,c,d=this,h={},f=t.style,p=t.nodeType&&Ot(t),g=Ct.get(t,"fxshow");n.queue||(s=ot._queueHooks(t,"fx"),null==s.unqueued&&(s.unqueued=0,u=s.empty.fire,s.empty.fire=function(){s.unqueued||u()}),s.unqueued++,d.always(function(){d.always(function(){s.unqueued--,ot.queue(t,"fx").length||s.empty.fire()})})),1===t.nodeType&&("height"in e||"width"in e)&&(n.overflow=[f.overflow,f.overflowX,f.overflowY],l=ot.css(t,"display"),c="none"===l?Ct.get(t,"olddisplay")||C(t.nodeName):l,"inline"===c&&"none"===ot.css(t,"float")&&(f.display="inline-block")),n.overflow&&(f.overflow="hidden",d.always(function(){f.overflow=n.overflow[0],f.overflowX=n.overflow[1],f.overflowY=n.overflow[2]}));for(i in e)if(r=e[i],ae.exec(r)){if(delete e[i],o=o||"toggle"===r,r===(p?"hide":"show")){if("show"!==r||!g||void 0===g[i])continue;p=!0}h[i]=g&&g[i]||ot.style(t,i)}else l=void 0;if(ot.isEmptyObject(h))"inline"===("none"===l?C(t.nodeName):l)&&(f.display=l);else{g?"hidden"in g&&(p=g.hidden):g=Ct.access(t,"fxshow",{}),o&&(g.hidden=!p),p?ot(t).show():d.done(function(){ot(t).hide()}),d.done(function(){var e;Ct.remove(t,"fxshow");for(e in h)ot.style(t,e,h[e])});for(i in h)a=F(p?g[i]:0,i,d),i in g||(g[i]=a.start,p&&(a.end=a.start,a.start="width"===i||"height"===i?1:0))}}function H(t,e){var n,i,r,o,a;for(n in t)if(i=ot.camelCase(n),r=e[i],o=t[n],ot.isArray(o)&&(r=o[1],o=t[n]=o[0]),n!==i&&(t[i]=o,delete t[n]),a=ot.cssHooks[i],a&&"expand"in a){o=a.expand(o),delete t[i];for(n in o)n in t||(t[n]=o[n],e[n]=r)}else e[i]=r}function L(t,e,n){var i,r,o=0,a=L.prefilters.length,s=ot.Deferred().always(function(){delete u.elem}),u=function(){if(r)return!1;for(var e=re||I(),n=Math.max(0,l.startTime+l.duration-e),i=n/l.duration||0,o=1-i,a=0,u=l.tweens.length;u>a;a++)l.tweens[a].run(o);return s.notifyWith(t,[l,o,n]),1>o&&u?n:(s.resolveWith(t,[l]),!1)},l=s.promise({elem:t,props:ot.extend({},e),opts:ot.extend(!0,{specialEasing:{},easing:ot.easing._default},n),originalProperties:e,originalOptions:n,startTime:re||I(),duration:n.duration,tweens:[],createTween:function(e,n){var i=ot.Tween(t,l.opts,e,n,l.opts.specialEasing[e]||l.opts.easing);return l.tweens.push(i),i},stop:function(e){var n=0,i=e?l.tweens.length:0;if(r)return this;for(r=!0;i>n;n++)l.tweens[n].run(1);return e?(s.notifyWith(t,[l,1,0]),s.resolveWith(t,[l,e])):s.rejectWith(t,[l,e]),this}}),c=l.props;for(H(c,l.opts.specialEasing);a>o;o++)if(i=L.prefilters[o].call(l,t,c,l.opts))return ot.isFunction(i.stop)&&(ot._queueHooks(l.elem,l.opts.queue).stop=ot.proxy(i.stop,i)),i;return ot.map(c,F,l),ot.isFunction(l.opts.start)&&l.opts.start.call(t,l),ot.fx.timer(ot.extend(u,{elem:t,anim:l,queue:l.opts.queue})),l.progress(l.opts.progress).done(l.opts.done,l.opts.complete).fail(l.opts.fail).always(l.opts.always)}function z(t){return t.getAttribute&&t.getAttribute("class")||""}function j(t){return function(e,n){"string"!=typeof e&&(n=e,e="*");var i,r=0,o=e.toLowerCase().match(wt)||[];if(ot.isFunction(n))for(;i=o[r++];)"+"===i[0]?(i=i.slice(1)||"*",(t[i]=t[i]||[]).unshift(n)):(t[i]=t[i]||[]).push(n)}}function R(t,e,n,i){function r(s){var u;return o[s]=!0,ot.each(t[s]||[],function(t,s){var l=s(e,n,i);return"string"!=typeof l||a||o[l]?a?!(u=l):void 0:(e.dataTypes.unshift(l),r(l),!1)}),u}var o={},a=t===Me;return r(e.dataTypes[0])||!o["*"]&&r("*")}function U(t,e){var n,i,r=ot.ajaxSettings.flatOptions||{};for(n in e)void 0!==e[n]&&((r[n]?t:i||(i={}))[n]=e[n]);return i&&ot.extend(!0,t,i),t}function q(t,e,n){for(var i,r,o,a,s=t.contents,u=t.dataTypes;"*"===u[0];)u.shift(),void 0===i&&(i=t.mimeType||e.getResponseHeader("Content-Type"));if(i)for(r in s)if(s[r]&&s[r].test(i)){u.unshift(r);break}if(u[0]in n)o=u[0];else{for(r in n){if(!u[0]||t.converters[r+" "+u[0]]){o=r;break}a||(a=r)}o=o||a}return o?(o!==u[0]&&u.unshift(o),n[o]):void 0}function B(t,e,n,i){var r,o,a,s,u,l={},c=t.dataTypes.slice();if(c[1])for(a in t.converters)l[a.toLowerCase()]=t.converters[a];for(o=c.shift();o;)if(t.responseFields[o]&&(n[t.responseFields[o]]=e),!u&&i&&t.dataFilter&&(e=t.dataFilter(e,t.dataType)),u=o,o=c.shift())if("*"===o)o=u;else if("*"!==u&&u!==o){if(a=l[u+" "+o]||l["* "+o],!a)for(r in l)if(s=r.split(" "),s[1]===o&&(a=l[u+" "+s[0]]||l["* "+s[0]])){a===!0?a=l[r]:l[r]!==!0&&(o=s[0],c.unshift(s[1]));break}if(a!==!0)if(a&&t["throws"])e=a(e);else try{e=a(e)}catch(d){return{state:"parsererror",error:a?d:"No conversion from "+u+" to "+o}}}return{state:"success",data:e}}function V(t,e,n,i){var r;if(ot.isArray(e))ot.each(e,function(e,r){n||Ae.test(t)?i(t,r):V(t+"["+("object"==typeof r&&null!=r?e:"")+"]",r,n,i)});else if(n||"object"!==ot.type(e))i(t,e);else for(r in e)V(t+"["+r+"]",e[r],n,i)}function Y(t){return ot.isWindow(t)?t:9===t.nodeType&&t.defaultView}var G=[],X=t.document,K=G.slice,Z=G.concat,Q=G.push,J=G.indexOf,tt={},et=tt.toString,nt=tt.hasOwnProperty,it={},rt="2.2.3",ot=function(t,e){return new ot.fn.init(t,e)},at=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,st=/^-ms-/,ut=/-([\da-z])/gi,lt=function(t,e){return e.toUpperCase()};ot.fn=ot.prototype={jquery:rt,constructor:ot,selector:"",length:0,toArray:function(){return K.call(this)},get:function(t){return null!=t?0>t?this[t+this.length]:this[t]:K.call(this)},pushStack:function(t){var e=ot.merge(this.constructor(),t);return e.prevObject=this,e.context=this.context,e},each:function(t){return ot.each(this,t)},map:function(t){return this.pushStack(ot.map(this,function(e,n){return t.call(e,n,e)}))},slice:function(){return this.pushStack(K.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(t){var e=this.length,n=+t+(0>t?e:0);return this.pushStack(n>=0&&e>n?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:Q,sort:G.sort,splice:G.splice},ot.extend=ot.fn.extend=function(){var t,e,n,i,r,o,a=arguments[0]||{},s=1,u=arguments.length,l=!1;for("boolean"==typeof a&&(l=a,a=arguments[s]||{},s++),"object"==typeof a||ot.isFunction(a)||(a={}),s===u&&(a=this,s--);u>s;s++)if(null!=(t=arguments[s]))for(e in t)n=a[e],i=t[e],a!==i&&(l&&i&&(ot.isPlainObject(i)||(r=ot.isArray(i)))?(r?(r=!1,o=n&&ot.isArray(n)?n:[]):o=n&&ot.isPlainObject(n)?n:{},a[e]=ot.extend(l,o,i)):void 0!==i&&(a[e]=i));return a},ot.extend({expando:"jQuery"+(rt+Math.random()).replace(/\D/g,""),isReady:!0,error:function(t){throw new Error(t)},noop:function(){},isFunction:function(t){return"function"===ot.type(t)},isArray:Array.isArray,isWindow:function(t){return null!=t&&t===t.window},isNumeric:function(t){var e=t&&t.toString();return!ot.isArray(t)&&e-parseFloat(e)+1>=0},isPlainObject:function(t){var e;if("object"!==ot.type(t)||t.nodeType||ot.isWindow(t))return!1;if(t.constructor&&!nt.call(t,"constructor")&&!nt.call(t.constructor.prototype||{},"isPrototypeOf"))return!1;for(e in t);return void 0===e||nt.call(t,e)},isEmptyObject:function(t){var e;for(e in t)return!1;return!0},type:function(t){return null==t?t+"":"object"==typeof t||"function"==typeof t?tt[et.call(t)]||"object":typeof t},globalEval:function(t){var e,n=eval;t=ot.trim(t),t&&(1===t.indexOf("use strict")?(e=X.createElement("script"),e.text=t,X.head.appendChild(e).parentNode.removeChild(e)):n(t))},camelCase:function(t){return t.replace(st,"ms-").replace(ut,lt)},nodeName:function(t,e){return t.nodeName&&t.nodeName.toLowerCase()===e.toLowerCase()},each:function(t,e){var i,r=0;if(n(t))for(i=t.length;i>r&&e.call(t[r],r,t[r])!==!1;r++);else for(r in t)if(e.call(t[r],r,t[r])===!1)break;return t},trim:function(t){return null==t?"":(t+"").replace(at,"")},makeArray:function(t,e){var i=e||[];return null!=t&&(n(Object(t))?ot.merge(i,"string"==typeof t?[t]:t):Q.call(i,t)),i},inArray:function(t,e,n){return null==e?-1:J.call(e,t,n)},merge:function(t,e){for(var n=+e.length,i=0,r=t.length;n>i;i++)t[r++]=e[i];return t.length=r,t},grep:function(t,e,n){for(var i,r=[],o=0,a=t.length,s=!n;a>o;o++)i=!e(t[o],o),i!==s&&r.push(t[o]);return r},map:function(t,e,i){var r,o,a=0,s=[];if(n(t))for(r=t.length;r>a;a++)o=e(t[a],a,i),null!=o&&s.push(o);else for(a in t)o=e(t[a],a,i),null!=o&&s.push(o);return Z.apply([],s)},guid:1,proxy:function(t,e){var n,i,r;return"string"==typeof e&&(n=t[e],e=t,t=n),ot.isFunction(t)?(i=K.call(arguments,2),r=function(){return t.apply(e||this,i.concat(K.call(arguments)))},r.guid=t.guid=t.guid||ot.guid++,r):void 0},now:Date.now,support:it}),"function"==typeof Symbol&&(ot.fn[Symbol.iterator]=G[Symbol.iterator]),ot.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(t,e){tt["[object "+e+"]"]=e.toLowerCase()});var ct=/*!
 * Sizzle CSS Selector Engine v2.2.1
 * http://sizzlejs.com/
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2015-10-17
 */
function(t){function e(t,e,n,i){var r,o,a,s,u,l,d,f,p=e&&e.ownerDocument,g=e?e.nodeType:9;if(n=n||[],"string"!=typeof t||!t||1!==g&&9!==g&&11!==g)return n;if(!i&&((e?e.ownerDocument||e:z)!==O&&E(e),e=e||O,I)){if(11!==g&&(l=vt.exec(t)))if(r=l[1]){if(9===g){if(!(a=e.getElementById(r)))return n;if(a.id===r)return n.push(a),n}else if(p&&(a=p.getElementById(r))&&H(e,a)&&a.id===r)return n.push(a),n}else{if(l[2])return Q.apply(n,e.getElementsByTagName(t)),n;if((r=l[3])&&w.getElementsByClassName&&e.getElementsByClassName)return Q.apply(n,e.getElementsByClassName(r)),n}if(w.qsa&&!B[t+" "]&&(!P||!P.test(t))){if(1!==g)p=e,f=t;else if("object"!==e.nodeName.toLowerCase()){for((s=e.getAttribute("id"))?s=s.replace(bt,"\\$&"):e.setAttribute("id",s=L),d=C(t),o=d.length,u=ht.test(s)?"#"+s:"[id='"+s+"']";o--;)d[o]=u+" "+h(d[o]);f=d.join(","),p=yt.test(t)&&c(e.parentNode)||e}if(f)try{return Q.apply(n,p.querySelectorAll(f)),n}catch(m){}finally{s===L&&e.removeAttribute("id")}}}return D(t.replace(st,"$1"),e,n,i)}function n(){function t(n,i){return e.push(n+" ")>_.cacheLength&&delete t[e.shift()],t[n+" "]=i}var e=[];return t}function i(t){return t[L]=!0,t}function r(t){var e=O.createElement("div");try{return!!t(e)}catch(n){return!1}finally{e.parentNode&&e.parentNode.removeChild(e),e=null}}function o(t,e){for(var n=t.split("|"),i=n.length;i--;)_.attrHandle[n[i]]=e}function a(t,e){var n=e&&t,i=n&&1===t.nodeType&&1===e.nodeType&&(~e.sourceIndex||Y)-(~t.sourceIndex||Y);if(i)return i;if(n)for(;n=n.nextSibling;)if(n===e)return-1;return t?1:-1}function s(t){return function(e){var n=e.nodeName.toLowerCase();return"input"===n&&e.type===t}}function u(t){return function(e){var n=e.nodeName.toLowerCase();return("input"===n||"button"===n)&&e.type===t}}function l(t){return i(function(e){return e=+e,i(function(n,i){for(var r,o=t([],n.length,e),a=o.length;a--;)n[r=o[a]]&&(n[r]=!(i[r]=n[r]))})})}function c(t){return t&&"undefined"!=typeof t.getElementsByTagName&&t}function d(){}function h(t){for(var e=0,n=t.length,i="";n>e;e++)i+=t[e].value;return i}function f(t,e,n){var i=e.dir,r=n&&"parentNode"===i,o=R++;return e.first?function(e,n,o){for(;e=e[i];)if(1===e.nodeType||r)return t(e,n,o)}:function(e,n,a){var s,u,l,c=[j,o];if(a){for(;e=e[i];)if((1===e.nodeType||r)&&t(e,n,a))return!0}else for(;e=e[i];)if(1===e.nodeType||r){if(l=e[L]||(e[L]={}),u=l[e.uniqueID]||(l[e.uniqueID]={}),(s=u[i])&&s[0]===j&&s[1]===o)return c[2]=s[2];if(u[i]=c,c[2]=t(e,n,a))return!0}}}function p(t){return t.length>1?function(e,n,i){for(var r=t.length;r--;)if(!t[r](e,n,i))return!1;return!0}:t[0]}function g(t,n,i){for(var r=0,o=n.length;o>r;r++)e(t,n[r],i);return i}function m(t,e,n,i,r){for(var o,a=[],s=0,u=t.length,l=null!=e;u>s;s++)(o=t[s])&&(!n||n(o,i,r))&&(a.push(o),l&&e.push(s));return a}function v(t,e,n,r,o,a){return r&&!r[L]&&(r=v(r)),o&&!o[L]&&(o=v(o,a)),i(function(i,a,s,u){var l,c,d,h=[],f=[],p=a.length,v=i||g(e||"*",s.nodeType?[s]:s,[]),y=!t||!i&&e?v:m(v,h,t,s,u),b=n?o||(i?t:p||r)?[]:a:y;if(n&&n(y,b,s,u),r)for(l=m(b,f),r(l,[],s,u),c=l.length;c--;)(d=l[c])&&(b[f[c]]=!(y[f[c]]=d));if(i){if(o||t){if(o){for(l=[],c=b.length;c--;)(d=b[c])&&l.push(y[c]=d);o(null,b=[],l,u)}for(c=b.length;c--;)(d=b[c])&&(l=o?tt(i,d):h[c])>-1&&(i[l]=!(a[l]=d))}}else b=m(b===a?b.splice(p,b.length):b),o?o(null,a,b,u):Q.apply(a,b)})}function y(t){for(var e,n,i,r=t.length,o=_.relative[t[0].type],a=o||_.relative[" "],s=o?1:0,u=f(function(t){return t===e},a,!0),l=f(function(t){return tt(e,t)>-1},a,!0),c=[function(t,n,i){var r=!o&&(i||n!==S)||((e=n).nodeType?u(t,n,i):l(t,n,i));return e=null,r}];r>s;s++)if(n=_.relative[t[s].type])c=[f(p(c),n)];else{if(n=_.filter[t[s].type].apply(null,t[s].matches),n[L]){for(i=++s;r>i&&!_.relative[t[i].type];i++);return v(s>1&&p(c),s>1&&h(t.slice(0,s-1).concat({value:" "===t[s-2].type?"*":""})).replace(st,"$1"),n,i>s&&y(t.slice(s,i)),r>i&&y(t=t.slice(i)),r>i&&h(t))}c.push(n)}return p(c)}function b(t,n){var r=n.length>0,o=t.length>0,a=function(i,a,s,u,l){var c,d,h,f=0,p="0",g=i&&[],v=[],y=S,b=i||o&&_.find.TAG("*",l),x=j+=null==y?1:Math.random()||.1,w=b.length;for(l&&(S=a===O||a||l);p!==w&&null!=(c=b[p]);p++){if(o&&c){for(d=0,a||c.ownerDocument===O||(E(c),s=!I);h=t[d++];)if(h(c,a||O,s)){u.push(c);break}l&&(j=x)}r&&((c=!h&&c)&&f--,i&&g.push(c))}if(f+=p,r&&p!==f){for(d=0;h=n[d++];)h(g,v,a,s);if(i){if(f>0)for(;p--;)g[p]||v[p]||(v[p]=K.call(u));v=m(v)}Q.apply(u,v),l&&!i&&v.length>0&&f+n.length>1&&e.uniqueSort(u)}return l&&(j=x,S=y),g};return r?i(a):a}var x,w,_,$,k,C,M,D,S,T,A,E,O,N,I,P,F,W,H,L="sizzle"+1*new Date,z=t.document,j=0,R=0,U=n(),q=n(),B=n(),V=function(t,e){return t===e&&(A=!0),0},Y=1<<31,G={}.hasOwnProperty,X=[],K=X.pop,Z=X.push,Q=X.push,J=X.slice,tt=function(t,e){for(var n=0,i=t.length;i>n;n++)if(t[n]===e)return n;return-1},et="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",nt="[\\x20\\t\\r\\n\\f]",it="(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",rt="\\["+nt+"*("+it+")(?:"+nt+"*([*^$|!~]?=)"+nt+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+it+"))|)"+nt+"*\\]",ot=":("+it+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+rt+")*)|.*)\\)|)",at=new RegExp(nt+"+","g"),st=new RegExp("^"+nt+"+|((?:^|[^\\\\])(?:\\\\.)*)"+nt+"+$","g"),ut=new RegExp("^"+nt+"*,"+nt+"*"),lt=new RegExp("^"+nt+"*([>+~]|"+nt+")"+nt+"*"),ct=new RegExp("="+nt+"*([^\\]'\"]*?)"+nt+"*\\]","g"),dt=new RegExp(ot),ht=new RegExp("^"+it+"$"),ft={ID:new RegExp("^#("+it+")"),CLASS:new RegExp("^\\.("+it+")"),TAG:new RegExp("^("+it+"|[*])"),ATTR:new RegExp("^"+rt),PSEUDO:new RegExp("^"+ot),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+nt+"*(even|odd|(([+-]|)(\\d*)n|)"+nt+"*(?:([+-]|)"+nt+"*(\\d+)|))"+nt+"*\\)|)","i"),bool:new RegExp("^(?:"+et+")$","i"),needsContext:new RegExp("^"+nt+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+nt+"*((?:-\\d)?\\d*)"+nt+"*\\)|)(?=[^-]|$)","i")},pt=/^(?:input|select|textarea|button)$/i,gt=/^h\d$/i,mt=/^[^{]+\{\s*\[native \w/,vt=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,yt=/[+~]/,bt=/'|\\/g,xt=new RegExp("\\\\([\\da-f]{1,6}"+nt+"?|("+nt+")|.)","ig"),wt=function(t,e,n){var i="0x"+e-65536;return i!==i||n?e:0>i?String.fromCharCode(i+65536):String.fromCharCode(i>>10|55296,1023&i|56320)},_t=function(){E()};try{Q.apply(X=J.call(z.childNodes),z.childNodes),X[z.childNodes.length].nodeType}catch($t){Q={apply:X.length?function(t,e){Z.apply(t,J.call(e))}:function(t,e){for(var n=t.length,i=0;t[n++]=e[i++];);t.length=n-1}}}w=e.support={},k=e.isXML=function(t){var e=t&&(t.ownerDocument||t).documentElement;return e?"HTML"!==e.nodeName:!1},E=e.setDocument=function(t){var e,n,i=t?t.ownerDocument||t:z;return i!==O&&9===i.nodeType&&i.documentElement?(O=i,N=O.documentElement,I=!k(O),(n=O.defaultView)&&n.top!==n&&(n.addEventListener?n.addEventListener("unload",_t,!1):n.attachEvent&&n.attachEvent("onunload",_t)),w.attributes=r(function(t){return t.className="i",!t.getAttribute("className")}),w.getElementsByTagName=r(function(t){return t.appendChild(O.createComment("")),!t.getElementsByTagName("*").length}),w.getElementsByClassName=mt.test(O.getElementsByClassName),w.getById=r(function(t){return N.appendChild(t).id=L,!O.getElementsByName||!O.getElementsByName(L).length}),w.getById?(_.find.ID=function(t,e){if("undefined"!=typeof e.getElementById&&I){var n=e.getElementById(t);return n?[n]:[]}},_.filter.ID=function(t){var e=t.replace(xt,wt);return function(t){return t.getAttribute("id")===e}}):(delete _.find.ID,_.filter.ID=function(t){var e=t.replace(xt,wt);return function(t){var n="undefined"!=typeof t.getAttributeNode&&t.getAttributeNode("id");return n&&n.value===e}}),_.find.TAG=w.getElementsByTagName?function(t,e){return"undefined"!=typeof e.getElementsByTagName?e.getElementsByTagName(t):w.qsa?e.querySelectorAll(t):void 0}:function(t,e){var n,i=[],r=0,o=e.getElementsByTagName(t);if("*"===t){for(;n=o[r++];)1===n.nodeType&&i.push(n);return i}return o},_.find.CLASS=w.getElementsByClassName&&function(t,e){return"undefined"!=typeof e.getElementsByClassName&&I?e.getElementsByClassName(t):void 0},F=[],P=[],(w.qsa=mt.test(O.querySelectorAll))&&(r(function(t){N.appendChild(t).innerHTML="<a id='"+L+"'></a><select id='"+L+"-\r\\' msallowcapture=''><option selected=''></option></select>",t.querySelectorAll("[msallowcapture^='']").length&&P.push("[*^$]="+nt+"*(?:''|\"\")"),t.querySelectorAll("[selected]").length||P.push("\\["+nt+"*(?:value|"+et+")"),t.querySelectorAll("[id~="+L+"-]").length||P.push("~="),t.querySelectorAll(":checked").length||P.push(":checked"),t.querySelectorAll("a#"+L+"+*").length||P.push(".#.+[+~]")}),r(function(t){var e=O.createElement("input");e.setAttribute("type","hidden"),t.appendChild(e).setAttribute("name","D"),t.querySelectorAll("[name=d]").length&&P.push("name"+nt+"*[*^$|!~]?="),t.querySelectorAll(":enabled").length||P.push(":enabled",":disabled"),t.querySelectorAll("*,:x"),P.push(",.*:")})),(w.matchesSelector=mt.test(W=N.matches||N.webkitMatchesSelector||N.mozMatchesSelector||N.oMatchesSelector||N.msMatchesSelector))&&r(function(t){w.disconnectedMatch=W.call(t,"div"),W.call(t,"[s!='']:x"),F.push("!=",ot)}),P=P.length&&new RegExp(P.join("|")),F=F.length&&new RegExp(F.join("|")),e=mt.test(N.compareDocumentPosition),H=e||mt.test(N.contains)?function(t,e){var n=9===t.nodeType?t.documentElement:t,i=e&&e.parentNode;return t===i||!(!i||1!==i.nodeType||!(n.contains?n.contains(i):t.compareDocumentPosition&&16&t.compareDocumentPosition(i)))}:function(t,e){if(e)for(;e=e.parentNode;)if(e===t)return!0;return!1},V=e?function(t,e){if(t===e)return A=!0,0;var n=!t.compareDocumentPosition-!e.compareDocumentPosition;return n?n:(n=(t.ownerDocument||t)===(e.ownerDocument||e)?t.compareDocumentPosition(e):1,1&n||!w.sortDetached&&e.compareDocumentPosition(t)===n?t===O||t.ownerDocument===z&&H(z,t)?-1:e===O||e.ownerDocument===z&&H(z,e)?1:T?tt(T,t)-tt(T,e):0:4&n?-1:1)}:function(t,e){if(t===e)return A=!0,0;var n,i=0,r=t.parentNode,o=e.parentNode,s=[t],u=[e];if(!r||!o)return t===O?-1:e===O?1:r?-1:o?1:T?tt(T,t)-tt(T,e):0;if(r===o)return a(t,e);for(n=t;n=n.parentNode;)s.unshift(n);for(n=e;n=n.parentNode;)u.unshift(n);for(;s[i]===u[i];)i++;return i?a(s[i],u[i]):s[i]===z?-1:u[i]===z?1:0},O):O},e.matches=function(t,n){return e(t,null,null,n)},e.matchesSelector=function(t,n){if((t.ownerDocument||t)!==O&&E(t),n=n.replace(ct,"='$1']"),w.matchesSelector&&I&&!B[n+" "]&&(!F||!F.test(n))&&(!P||!P.test(n)))try{var i=W.call(t,n);if(i||w.disconnectedMatch||t.document&&11!==t.document.nodeType)return i}catch(r){}return e(n,O,null,[t]).length>0},e.contains=function(t,e){return(t.ownerDocument||t)!==O&&E(t),H(t,e)},e.attr=function(t,e){(t.ownerDocument||t)!==O&&E(t);var n=_.attrHandle[e.toLowerCase()],i=n&&G.call(_.attrHandle,e.toLowerCase())?n(t,e,!I):void 0;return void 0!==i?i:w.attributes||!I?t.getAttribute(e):(i=t.getAttributeNode(e))&&i.specified?i.value:null},e.error=function(t){throw new Error("Syntax error, unrecognized expression: "+t)},e.uniqueSort=function(t){var e,n=[],i=0,r=0;if(A=!w.detectDuplicates,T=!w.sortStable&&t.slice(0),t.sort(V),A){for(;e=t[r++];)e===t[r]&&(i=n.push(r));for(;i--;)t.splice(n[i],1)}return T=null,t},$=e.getText=function(t){var e,n="",i=0,r=t.nodeType;if(r){if(1===r||9===r||11===r){if("string"==typeof t.textContent)return t.textContent;for(t=t.firstChild;t;t=t.nextSibling)n+=$(t)}else if(3===r||4===r)return t.nodeValue}else for(;e=t[i++];)n+=$(e);return n},_=e.selectors={cacheLength:50,createPseudo:i,match:ft,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(t){return t[1]=t[1].replace(xt,wt),t[3]=(t[3]||t[4]||t[5]||"").replace(xt,wt),"~="===t[2]&&(t[3]=" "+t[3]+" "),t.slice(0,4)},CHILD:function(t){return t[1]=t[1].toLowerCase(),"nth"===t[1].slice(0,3)?(t[3]||e.error(t[0]),t[4]=+(t[4]?t[5]+(t[6]||1):2*("even"===t[3]||"odd"===t[3])),t[5]=+(t[7]+t[8]||"odd"===t[3])):t[3]&&e.error(t[0]),t},PSEUDO:function(t){var e,n=!t[6]&&t[2];return ft.CHILD.test(t[0])?null:(t[3]?t[2]=t[4]||t[5]||"":n&&dt.test(n)&&(e=C(n,!0))&&(e=n.indexOf(")",n.length-e)-n.length)&&(t[0]=t[0].slice(0,e),t[2]=n.slice(0,e)),t.slice(0,3))}},filter:{TAG:function(t){var e=t.replace(xt,wt).toLowerCase();return"*"===t?function(){return!0}:function(t){return t.nodeName&&t.nodeName.toLowerCase()===e}},CLASS:function(t){var e=U[t+" "];return e||(e=new RegExp("(^|"+nt+")"+t+"("+nt+"|$)"))&&U(t,function(t){return e.test("string"==typeof t.className&&t.className||"undefined"!=typeof t.getAttribute&&t.getAttribute("class")||"")})},ATTR:function(t,n,i){return function(r){var o=e.attr(r,t);return null==o?"!="===n:n?(o+="","="===n?o===i:"!="===n?o!==i:"^="===n?i&&0===o.indexOf(i):"*="===n?i&&o.indexOf(i)>-1:"$="===n?i&&o.slice(-i.length)===i:"~="===n?(" "+o.replace(at," ")+" ").indexOf(i)>-1:"|="===n?o===i||o.slice(0,i.length+1)===i+"-":!1):!0}},CHILD:function(t,e,n,i,r){var o="nth"!==t.slice(0,3),a="last"!==t.slice(-4),s="of-type"===e;return 1===i&&0===r?function(t){return!!t.parentNode}:function(e,n,u){var l,c,d,h,f,p,g=o!==a?"nextSibling":"previousSibling",m=e.parentNode,v=s&&e.nodeName.toLowerCase(),y=!u&&!s,b=!1;if(m){if(o){for(;g;){for(h=e;h=h[g];)if(s?h.nodeName.toLowerCase()===v:1===h.nodeType)return!1;p=g="only"===t&&!p&&"nextSibling"}return!0}if(p=[a?m.firstChild:m.lastChild],a&&y){for(h=m,d=h[L]||(h[L]={}),c=d[h.uniqueID]||(d[h.uniqueID]={}),l=c[t]||[],f=l[0]===j&&l[1],b=f&&l[2],h=f&&m.childNodes[f];h=++f&&h&&h[g]||(b=f=0)||p.pop();)if(1===h.nodeType&&++b&&h===e){c[t]=[j,f,b];break}}else if(y&&(h=e,d=h[L]||(h[L]={}),c=d[h.uniqueID]||(d[h.uniqueID]={}),l=c[t]||[],f=l[0]===j&&l[1],b=f),b===!1)for(;(h=++f&&h&&h[g]||(b=f=0)||p.pop())&&((s?h.nodeName.toLowerCase()!==v:1!==h.nodeType)||!++b||(y&&(d=h[L]||(h[L]={}),c=d[h.uniqueID]||(d[h.uniqueID]={}),c[t]=[j,b]),h!==e)););return b-=r,b===i||b%i===0&&b/i>=0}}},PSEUDO:function(t,n){var r,o=_.pseudos[t]||_.setFilters[t.toLowerCase()]||e.error("unsupported pseudo: "+t);return o[L]?o(n):o.length>1?(r=[t,t,"",n],_.setFilters.hasOwnProperty(t.toLowerCase())?i(function(t,e){for(var i,r=o(t,n),a=r.length;a--;)i=tt(t,r[a]),t[i]=!(e[i]=r[a])}):function(t){return o(t,0,r)}):o}},pseudos:{not:i(function(t){var e=[],n=[],r=M(t.replace(st,"$1"));return r[L]?i(function(t,e,n,i){for(var o,a=r(t,null,i,[]),s=t.length;s--;)(o=a[s])&&(t[s]=!(e[s]=o))}):function(t,i,o){return e[0]=t,r(e,null,o,n),e[0]=null,!n.pop()}}),has:i(function(t){return function(n){return e(t,n).length>0}}),contains:i(function(t){return t=t.replace(xt,wt),function(e){return(e.textContent||e.innerText||$(e)).indexOf(t)>-1}}),lang:i(function(t){return ht.test(t||"")||e.error("unsupported lang: "+t),t=t.replace(xt,wt).toLowerCase(),function(e){var n;do if(n=I?e.lang:e.getAttribute("xml:lang")||e.getAttribute("lang"))return n=n.toLowerCase(),n===t||0===n.indexOf(t+"-");while((e=e.parentNode)&&1===e.nodeType);return!1}}),target:function(e){var n=t.location&&t.location.hash;return n&&n.slice(1)===e.id},root:function(t){return t===N},focus:function(t){return t===O.activeElement&&(!O.hasFocus||O.hasFocus())&&!!(t.type||t.href||~t.tabIndex)},enabled:function(t){return t.disabled===!1},disabled:function(t){return t.disabled===!0},checked:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&!!t.checked||"option"===e&&!!t.selected},selected:function(t){return t.parentNode&&t.parentNode.selectedIndex,t.selected===!0},empty:function(t){for(t=t.firstChild;t;t=t.nextSibling)if(t.nodeType<6)return!1;return!0},parent:function(t){return!_.pseudos.empty(t)},header:function(t){return gt.test(t.nodeName)},input:function(t){return pt.test(t.nodeName)},button:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&"button"===t.type||"button"===e},text:function(t){var e;return"input"===t.nodeName.toLowerCase()&&"text"===t.type&&(null==(e=t.getAttribute("type"))||"text"===e.toLowerCase())},first:l(function(){return[0]}),last:l(function(t,e){return[e-1]}),eq:l(function(t,e,n){return[0>n?n+e:n]}),even:l(function(t,e){for(var n=0;e>n;n+=2)t.push(n);return t}),odd:l(function(t,e){for(var n=1;e>n;n+=2)t.push(n);return t}),lt:l(function(t,e,n){for(var i=0>n?n+e:n;--i>=0;)t.push(i);return t}),gt:l(function(t,e,n){for(var i=0>n?n+e:n;++i<e;)t.push(i);return t})}},_.pseudos.nth=_.pseudos.eq;for(x in{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})_.pseudos[x]=s(x);for(x in{submit:!0,reset:!0})_.pseudos[x]=u(x);return d.prototype=_.filters=_.pseudos,_.setFilters=new d,C=e.tokenize=function(t,n){var i,r,o,a,s,u,l,c=q[t+" "];if(c)return n?0:c.slice(0);for(s=t,u=[],l=_.preFilter;s;){(!i||(r=ut.exec(s)))&&(r&&(s=s.slice(r[0].length)||s),u.push(o=[])),i=!1,(r=lt.exec(s))&&(i=r.shift(),o.push({value:i,type:r[0].replace(st," ")}),s=s.slice(i.length));for(a in _.filter)!(r=ft[a].exec(s))||l[a]&&!(r=l[a](r))||(i=r.shift(),o.push({value:i,type:a,matches:r}),s=s.slice(i.length));if(!i)break}return n?s.length:s?e.error(t):q(t,u).slice(0)},M=e.compile=function(t,e){var n,i=[],r=[],o=B[t+" "];if(!o){for(e||(e=C(t)),n=e.length;n--;)o=y(e[n]),o[L]?i.push(o):r.push(o);o=B(t,b(r,i)),o.selector=t}return o},D=e.select=function(t,e,n,i){var r,o,a,s,u,l="function"==typeof t&&t,d=!i&&C(t=l.selector||t);if(n=n||[],1===d.length){if(o=d[0]=d[0].slice(0),o.length>2&&"ID"===(a=o[0]).type&&w.getById&&9===e.nodeType&&I&&_.relative[o[1].type]){if(e=(_.find.ID(a.matches[0].replace(xt,wt),e)||[])[0],!e)return n;l&&(e=e.parentNode),t=t.slice(o.shift().value.length)}for(r=ft.needsContext.test(t)?0:o.length;r--&&(a=o[r],!_.relative[s=a.type]);)if((u=_.find[s])&&(i=u(a.matches[0].replace(xt,wt),yt.test(o[0].type)&&c(e.parentNode)||e))){if(o.splice(r,1),t=i.length&&h(o),!t)return Q.apply(n,i),n;break}}return(l||M(t,d))(i,e,!I,n,!e||yt.test(t)&&c(e.parentNode)||e),n},w.sortStable=L.split("").sort(V).join("")===L,w.detectDuplicates=!!A,E(),w.sortDetached=r(function(t){return 1&t.compareDocumentPosition(O.createElement("div"))}),r(function(t){return t.innerHTML="<a href='#'></a>","#"===t.firstChild.getAttribute("href")})||o("type|href|height|width",function(t,e,n){return n?void 0:t.getAttribute(e,"type"===e.toLowerCase()?1:2)}),w.attributes&&r(function(t){return t.innerHTML="<input/>",t.firstChild.setAttribute("value",""),""===t.firstChild.getAttribute("value")})||o("value",function(t,e,n){return n||"input"!==t.nodeName.toLowerCase()?void 0:t.defaultValue}),r(function(t){return null==t.getAttribute("disabled")})||o(et,function(t,e,n){var i;return n?void 0:t[e]===!0?e.toLowerCase():(i=t.getAttributeNode(e))&&i.specified?i.value:null}),e}(t);ot.find=ct,ot.expr=ct.selectors,ot.expr[":"]=ot.expr.pseudos,ot.uniqueSort=ot.unique=ct.uniqueSort,ot.text=ct.getText,ot.isXMLDoc=ct.isXML,ot.contains=ct.contains;var dt=function(t,e,n){for(var i=[],r=void 0!==n;(t=t[e])&&9!==t.nodeType;)if(1===t.nodeType){if(r&&ot(t).is(n))break;i.push(t)}return i},ht=function(t,e){for(var n=[];t;t=t.nextSibling)1===t.nodeType&&t!==e&&n.push(t);return n},ft=ot.expr.match.needsContext,pt=/^<([\w-]+)\s*\/?>(?:<\/\1>|)$/,gt=/^.[^:#\[\.,]*$/;ot.filter=function(t,e,n){var i=e[0];return n&&(t=":not("+t+")"),1===e.length&&1===i.nodeType?ot.find.matchesSelector(i,t)?[i]:[]:ot.find.matches(t,ot.grep(e,function(t){return 1===t.nodeType}))},ot.fn.extend({find:function(t){var e,n=this.length,i=[],r=this;if("string"!=typeof t)return this.pushStack(ot(t).filter(function(){for(e=0;n>e;e++)if(ot.contains(r[e],this))return!0}));for(e=0;n>e;e++)ot.find(t,r[e],i);return i=this.pushStack(n>1?ot.unique(i):i),i.selector=this.selector?this.selector+" "+t:t,i},filter:function(t){return this.pushStack(i(this,t||[],!1))},not:function(t){return this.pushStack(i(this,t||[],!0))},is:function(t){return!!i(this,"string"==typeof t&&ft.test(t)?ot(t):t||[],!1).length}});var mt,vt=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,yt=ot.fn.init=function(t,e,n){var i,r;if(!t)return this;if(n=n||mt,"string"==typeof t){if(i="<"===t[0]&&">"===t[t.length-1]&&t.length>=3?[null,t,null]:vt.exec(t),!i||!i[1]&&e)return!e||e.jquery?(e||n).find(t):this.constructor(e).find(t);if(i[1]){if(e=e instanceof ot?e[0]:e,ot.merge(this,ot.parseHTML(i[1],e&&e.nodeType?e.ownerDocument||e:X,!0)),pt.test(i[1])&&ot.isPlainObject(e))for(i in e)ot.isFunction(this[i])?this[i](e[i]):this.attr(i,e[i]);return this}return r=X.getElementById(i[2]),r&&r.parentNode&&(this.length=1,this[0]=r),this.context=X,this.selector=t,this}return t.nodeType?(this.context=this[0]=t,this.length=1,this):ot.isFunction(t)?void 0!==n.ready?n.ready(t):t(ot):(void 0!==t.selector&&(this.selector=t.selector,this.context=t.context),ot.makeArray(t,this))};yt.prototype=ot.fn,mt=ot(X);var bt=/^(?:parents|prev(?:Until|All))/,xt={children:!0,contents:!0,next:!0,prev:!0};ot.fn.extend({has:function(t){var e=ot(t,this),n=e.length;return this.filter(function(){for(var t=0;n>t;t++)if(ot.contains(this,e[t]))return!0})},closest:function(t,e){for(var n,i=0,r=this.length,o=[],a=ft.test(t)||"string"!=typeof t?ot(t,e||this.context):0;r>i;i++)for(n=this[i];n&&n!==e;n=n.parentNode)if(n.nodeType<11&&(a?a.index(n)>-1:1===n.nodeType&&ot.find.matchesSelector(n,t))){o.push(n);break}return this.pushStack(o.length>1?ot.uniqueSort(o):o)},index:function(t){return t?"string"==typeof t?J.call(ot(t),this[0]):J.call(this,t.jquery?t[0]:t):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(t,e){return this.pushStack(ot.uniqueSort(ot.merge(this.get(),ot(t,e))))},addBack:function(t){return this.add(null==t?this.prevObject:this.prevObject.filter(t))}}),ot.each({parent:function(t){var e=t.parentNode;return e&&11!==e.nodeType?e:null},parents:function(t){return dt(t,"parentNode")},parentsUntil:function(t,e,n){return dt(t,"parentNode",n)},next:function(t){return r(t,"nextSibling")},prev:function(t){return r(t,"previousSibling")},nextAll:function(t){return dt(t,"nextSibling")},prevAll:function(t){return dt(t,"previousSibling")},nextUntil:function(t,e,n){return dt(t,"nextSibling",n)},prevUntil:function(t,e,n){return dt(t,"previousSibling",n)},siblings:function(t){return ht((t.parentNode||{}).firstChild,t)},children:function(t){return ht(t.firstChild)},contents:function(t){return t.contentDocument||ot.merge([],t.childNodes)}},function(t,e){ot.fn[t]=function(n,i){var r=ot.map(this,e,n);return"Until"!==t.slice(-5)&&(i=n),i&&"string"==typeof i&&(r=ot.filter(i,r)),this.length>1&&(xt[t]||ot.uniqueSort(r),bt.test(t)&&r.reverse()),this.pushStack(r)}});var wt=/\S+/g;ot.Callbacks=function(t){t="string"==typeof t?o(t):ot.extend({},t);var e,n,i,r,a=[],s=[],u=-1,l=function(){for(r=t.once,i=e=!0;s.length;u=-1)for(n=s.shift();++u<a.length;)a[u].apply(n[0],n[1])===!1&&t.stopOnFalse&&(u=a.length,n=!1);t.memory||(n=!1),e=!1,r&&(a=n?[]:"")},c={add:function(){return a&&(n&&!e&&(u=a.length-1,s.push(n)),function i(e){ot.each(e,function(e,n){ot.isFunction(n)?t.unique&&c.has(n)||a.push(n):n&&n.length&&"string"!==ot.type(n)&&i(n)})}(arguments),n&&!e&&l()),this},remove:function(){return ot.each(arguments,function(t,e){for(var n;(n=ot.inArray(e,a,n))>-1;)a.splice(n,1),u>=n&&u--}),this},has:function(t){return t?ot.inArray(t,a)>-1:a.length>0},empty:function(){return a&&(a=[]),this},disable:function(){return r=s=[],a=n="",this},disabled:function(){return!a},lock:function(){return r=s=[],n||(a=n=""),this},locked:function(){return!!r},fireWith:function(t,n){return r||(n=n||[],n=[t,n.slice?n.slice():n],s.push(n),e||l()),this},fire:function(){return c.fireWith(this,arguments),this},fired:function(){return!!i}};return c},ot.extend({Deferred:function(t){var e=[["resolve","done",ot.Callbacks("once memory"),"resolved"],["reject","fail",ot.Callbacks("once memory"),"rejected"],["notify","progress",ot.Callbacks("memory")]],n="pending",i={state:function(){return n},always:function(){return r.done(arguments).fail(arguments),this},then:function(){var t=arguments;return ot.Deferred(function(n){ot.each(e,function(e,o){var a=ot.isFunction(t[e])&&t[e];r[o[1]](function(){var t=a&&a.apply(this,arguments);t&&ot.isFunction(t.promise)?t.promise().progress(n.notify).done(n.resolve).fail(n.reject):n[o[0]+"With"](this===i?n.promise():this,a?[t]:arguments)})}),t=null}).promise()},promise:function(t){return null!=t?ot.extend(t,i):i}},r={};return i.pipe=i.then,ot.each(e,function(t,o){var a=o[2],s=o[3];i[o[1]]=a.add,s&&a.add(function(){n=s},e[1^t][2].disable,e[2][2].lock),r[o[0]]=function(){return r[o[0]+"With"](this===r?i:this,arguments),this},r[o[0]+"With"]=a.fireWith}),i.promise(r),t&&t.call(r,r),r},when:function(t){var e,n,i,r=0,o=K.call(arguments),a=o.length,s=1!==a||t&&ot.isFunction(t.promise)?a:0,u=1===s?t:ot.Deferred(),l=function(t,n,i){return function(r){n[t]=this,i[t]=arguments.length>1?K.call(arguments):r,i===e?u.notifyWith(n,i):--s||u.resolveWith(n,i)}};if(a>1)for(e=new Array(a),n=new Array(a),i=new Array(a);a>r;r++)o[r]&&ot.isFunction(o[r].promise)?o[r].promise().progress(l(r,n,e)).done(l(r,i,o)).fail(u.reject):--s;return s||u.resolveWith(i,o),u.promise()}});var _t;ot.fn.ready=function(t){return ot.ready.promise().done(t),this},ot.extend({isReady:!1,readyWait:1,holdReady:function(t){t?ot.readyWait++:ot.ready(!0)},ready:function(t){(t===!0?--ot.readyWait:ot.isReady)||(ot.isReady=!0,t!==!0&&--ot.readyWait>0||(_t.resolveWith(X,[ot]),ot.fn.triggerHandler&&(ot(X).triggerHandler("ready"),ot(X).off("ready"))))}}),ot.ready.promise=function(e){return _t||(_t=ot.Deferred(),"complete"===X.readyState||"loading"!==X.readyState&&!X.documentElement.doScroll?t.setTimeout(ot.ready):(X.addEventListener("DOMContentLoaded",a),t.addEventListener("load",a))),_t.promise(e)},ot.ready.promise();var $t=function(t,e,n,i,r,o,a){var s=0,u=t.length,l=null==n;if("object"===ot.type(n)){r=!0;for(s in n)$t(t,e,s,n[s],!0,o,a)}else if(void 0!==i&&(r=!0,ot.isFunction(i)||(a=!0),l&&(a?(e.call(t,i),e=null):(l=e,e=function(t,e,n){return l.call(ot(t),n)})),e))for(;u>s;s++)e(t[s],n,a?i:i.call(t[s],s,e(t[s],n)));return r?t:l?e.call(t):u?e(t[0],n):o},kt=function(t){return 1===t.nodeType||9===t.nodeType||!+t.nodeType};s.uid=1,s.prototype={register:function(t,e){var n=e||{};return t.nodeType?t[this.expando]=n:Object.defineProperty(t,this.expando,{value:n,writable:!0,configurable:!0}),t[this.expando]},cache:function(t){if(!kt(t))return{};var e=t[this.expando];return e||(e={},kt(t)&&(t.nodeType?t[this.expando]=e:Object.defineProperty(t,this.expando,{value:e,configurable:!0}))),e},set:function(t,e,n){var i,r=this.cache(t);if("string"==typeof e)r[e]=n;else for(i in e)r[i]=e[i];return r},get:function(t,e){return void 0===e?this.cache(t):t[this.expando]&&t[this.expando][e]},access:function(t,e,n){var i;return void 0===e||e&&"string"==typeof e&&void 0===n?(i=this.get(t,e),void 0!==i?i:this.get(t,ot.camelCase(e))):(this.set(t,e,n),void 0!==n?n:e)},remove:function(t,e){var n,i,r,o=t[this.expando];if(void 0!==o){if(void 0===e)this.register(t);else{ot.isArray(e)?i=e.concat(e.map(ot.camelCase)):(r=ot.camelCase(e),e in o?i=[e,r]:(i=r,i=i in o?[i]:i.match(wt)||[])),n=i.length;for(;n--;)delete o[i[n]]}(void 0===e||ot.isEmptyObject(o))&&(t.nodeType?t[this.expando]=void 0:delete t[this.expando])}},hasData:function(t){var e=t[this.expando];return void 0!==e&&!ot.isEmptyObject(e)}};var Ct=new s,Mt=new s,Dt=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,St=/[A-Z]/g;ot.extend({hasData:function(t){return Mt.hasData(t)||Ct.hasData(t)},data:function(t,e,n){return Mt.access(t,e,n)},removeData:function(t,e){Mt.remove(t,e)},_data:function(t,e,n){return Ct.access(t,e,n)},_removeData:function(t,e){Ct.remove(t,e)}}),ot.fn.extend({data:function(t,e){var n,i,r,o=this[0],a=o&&o.attributes;if(void 0===t){if(this.length&&(r=Mt.get(o),1===o.nodeType&&!Ct.get(o,"hasDataAttrs"))){for(n=a.length;n--;)a[n]&&(i=a[n].name,0===i.indexOf("data-")&&(i=ot.camelCase(i.slice(5)),u(o,i,r[i])));Ct.set(o,"hasDataAttrs",!0)}return r}return"object"==typeof t?this.each(function(){Mt.set(this,t)}):$t(this,function(e){var n,i;if(o&&void 0===e){if(n=Mt.get(o,t)||Mt.get(o,t.replace(St,"-$&").toLowerCase()),void 0!==n)return n;if(i=ot.camelCase(t),n=Mt.get(o,i),void 0!==n)return n;if(n=u(o,i,void 0),void 0!==n)return n}else i=ot.camelCase(t),this.each(function(){var n=Mt.get(this,i);Mt.set(this,i,e),t.indexOf("-")>-1&&void 0!==n&&Mt.set(this,t,e)})},null,e,arguments.length>1,null,!0)},removeData:function(t){return this.each(function(){Mt.remove(this,t)})}}),ot.extend({queue:function(t,e,n){var i;return t?(e=(e||"fx")+"queue",i=Ct.get(t,e),n&&(!i||ot.isArray(n)?i=Ct.access(t,e,ot.makeArray(n)):i.push(n)),i||[]):void 0},dequeue:function(t,e){e=e||"fx";var n=ot.queue(t,e),i=n.length,r=n.shift(),o=ot._queueHooks(t,e),a=function(){ot.dequeue(t,e)};"inprogress"===r&&(r=n.shift(),i--),r&&("fx"===e&&n.unshift("inprogress"),delete o.stop,r.call(t,a,o)),!i&&o&&o.empty.fire()},_queueHooks:function(t,e){var n=e+"queueHooks";return Ct.get(t,n)||Ct.access(t,n,{empty:ot.Callbacks("once memory").add(function(){Ct.remove(t,[e+"queue",n])})})}}),ot.fn.extend({queue:function(t,e){var n=2;return"string"!=typeof t&&(e=t,t="fx",n--),arguments.length<n?ot.queue(this[0],t):void 0===e?this:this.each(function(){var n=ot.queue(this,t,e);ot._queueHooks(this,t),"fx"===t&&"inprogress"!==n[0]&&ot.dequeue(this,t)})},dequeue:function(t){return this.each(function(){ot.dequeue(this,t)})},clearQueue:function(t){return this.queue(t||"fx",[])},promise:function(t,e){var n,i=1,r=ot.Deferred(),o=this,a=this.length,s=function(){--i||r.resolveWith(o,[o])};for("string"!=typeof t&&(e=t,t=void 0),t=t||"fx";a--;)n=Ct.get(o[a],t+"queueHooks"),n&&n.empty&&(i++,n.empty.add(s));return s(),r.promise(e)}});var Tt=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,At=new RegExp("^(?:([+-])=|)("+Tt+")([a-z%]*)$","i"),Et=["Top","Right","Bottom","Left"],Ot=function(t,e){return t=e||t,"none"===ot.css(t,"display")||!ot.contains(t.ownerDocument,t)},Nt=/^(?:checkbox|radio)$/i,It=/<([\w:-]+)/,Pt=/^$|\/(?:java|ecma)script/i,Ft={option:[1,"<select multiple='multiple'>","</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};Ft.optgroup=Ft.option,Ft.tbody=Ft.tfoot=Ft.colgroup=Ft.caption=Ft.thead,Ft.th=Ft.td;var Wt=/<|&#?\w+;/;!function(){var t=X.createDocumentFragment(),e=t.appendChild(X.createElement("div")),n=X.createElement("input");n.setAttribute("type","radio"),n.setAttribute("checked","checked"),n.setAttribute("name","t"),e.appendChild(n),it.checkClone=e.cloneNode(!0).cloneNode(!0).lastChild.checked,e.innerHTML="<textarea>x</textarea>",it.noCloneChecked=!!e.cloneNode(!0).lastChild.defaultValue}();var Ht=/^key/,Lt=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,zt=/^([^.]*)(?:\.(.+)|)/;ot.event={global:{},add:function(t,e,n,i,r){var o,a,s,u,l,c,d,h,f,p,g,m=Ct.get(t);if(m)for(n.handler&&(o=n,n=o.handler,r=o.selector),n.guid||(n.guid=ot.guid++),(u=m.events)||(u=m.events={}),(a=m.handle)||(a=m.handle=function(e){return"undefined"!=typeof ot&&ot.event.triggered!==e.type?ot.event.dispatch.apply(t,arguments):void 0}),e=(e||"").match(wt)||[""],l=e.length;l--;)s=zt.exec(e[l])||[],f=g=s[1],p=(s[2]||"").split(".").sort(),f&&(d=ot.event.special[f]||{},f=(r?d.delegateType:d.bindType)||f,d=ot.event.special[f]||{},c=ot.extend({type:f,origType:g,data:i,handler:n,guid:n.guid,selector:r,needsContext:r&&ot.expr.match.needsContext.test(r),namespace:p.join(".")},o),(h=u[f])||(h=u[f]=[],h.delegateCount=0,d.setup&&d.setup.call(t,i,p,a)!==!1||t.addEventListener&&t.addEventListener(f,a)),d.add&&(d.add.call(t,c),c.handler.guid||(c.handler.guid=n.guid)),r?h.splice(h.delegateCount++,0,c):h.push(c),ot.event.global[f]=!0)},remove:function(t,e,n,i,r){var o,a,s,u,l,c,d,h,f,p,g,m=Ct.hasData(t)&&Ct.get(t);if(m&&(u=m.events)){for(e=(e||"").match(wt)||[""],l=e.length;l--;)if(s=zt.exec(e[l])||[],f=g=s[1],p=(s[2]||"").split(".").sort(),f){for(d=ot.event.special[f]||{},f=(i?d.delegateType:d.bindType)||f,h=u[f]||[],s=s[2]&&new RegExp("(^|\\.)"+p.join("\\.(?:.*\\.|)")+"(\\.|$)"),a=o=h.length;o--;)c=h[o],!r&&g!==c.origType||n&&n.guid!==c.guid||s&&!s.test(c.namespace)||i&&i!==c.selector&&("**"!==i||!c.selector)||(h.splice(o,1),
c.selector&&h.delegateCount--,d.remove&&d.remove.call(t,c));a&&!h.length&&(d.teardown&&d.teardown.call(t,p,m.handle)!==!1||ot.removeEvent(t,f,m.handle),delete u[f])}else for(f in u)ot.event.remove(t,f+e[l],n,i,!0);ot.isEmptyObject(u)&&Ct.remove(t,"handle events")}},dispatch:function(t){t=ot.event.fix(t);var e,n,i,r,o,a=[],s=K.call(arguments),u=(Ct.get(this,"events")||{})[t.type]||[],l=ot.event.special[t.type]||{};if(s[0]=t,t.delegateTarget=this,!l.preDispatch||l.preDispatch.call(this,t)!==!1){for(a=ot.event.handlers.call(this,t,u),e=0;(r=a[e++])&&!t.isPropagationStopped();)for(t.currentTarget=r.elem,n=0;(o=r.handlers[n++])&&!t.isImmediatePropagationStopped();)(!t.rnamespace||t.rnamespace.test(o.namespace))&&(t.handleObj=o,t.data=o.data,i=((ot.event.special[o.origType]||{}).handle||o.handler).apply(r.elem,s),void 0!==i&&(t.result=i)===!1&&(t.preventDefault(),t.stopPropagation()));return l.postDispatch&&l.postDispatch.call(this,t),t.result}},handlers:function(t,e){var n,i,r,o,a=[],s=e.delegateCount,u=t.target;if(s&&u.nodeType&&("click"!==t.type||isNaN(t.button)||t.button<1))for(;u!==this;u=u.parentNode||this)if(1===u.nodeType&&(u.disabled!==!0||"click"!==t.type)){for(i=[],n=0;s>n;n++)o=e[n],r=o.selector+" ",void 0===i[r]&&(i[r]=o.needsContext?ot(r,this).index(u)>-1:ot.find(r,this,null,[u]).length),i[r]&&i.push(o);i.length&&a.push({elem:u,handlers:i})}return s<e.length&&a.push({elem:this,handlers:e.slice(s)}),a},props:"altKey bubbles cancelable ctrlKey currentTarget detail eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),fixHooks:{},keyHooks:{props:"char charCode key keyCode".split(" "),filter:function(t,e){return null==t.which&&(t.which=null!=e.charCode?e.charCode:e.keyCode),t}},mouseHooks:{props:"button buttons clientX clientY offsetX offsetY pageX pageY screenX screenY toElement".split(" "),filter:function(t,e){var n,i,r,o=e.button;return null==t.pageX&&null!=e.clientX&&(n=t.target.ownerDocument||X,i=n.documentElement,r=n.body,t.pageX=e.clientX+(i&&i.scrollLeft||r&&r.scrollLeft||0)-(i&&i.clientLeft||r&&r.clientLeft||0),t.pageY=e.clientY+(i&&i.scrollTop||r&&r.scrollTop||0)-(i&&i.clientTop||r&&r.clientTop||0)),t.which||void 0===o||(t.which=1&o?1:2&o?3:4&o?2:0),t}},fix:function(t){if(t[ot.expando])return t;var e,n,i,r=t.type,o=t,a=this.fixHooks[r];for(a||(this.fixHooks[r]=a=Lt.test(r)?this.mouseHooks:Ht.test(r)?this.keyHooks:{}),i=a.props?this.props.concat(a.props):this.props,t=new ot.Event(o),e=i.length;e--;)n=i[e],t[n]=o[n];return t.target||(t.target=X),3===t.target.nodeType&&(t.target=t.target.parentNode),a.filter?a.filter(t,o):t},special:{load:{noBubble:!0},focus:{trigger:function(){return this!==g()&&this.focus?(this.focus(),!1):void 0},delegateType:"focusin"},blur:{trigger:function(){return this===g()&&this.blur?(this.blur(),!1):void 0},delegateType:"focusout"},click:{trigger:function(){return"checkbox"===this.type&&this.click&&ot.nodeName(this,"input")?(this.click(),!1):void 0},_default:function(t){return ot.nodeName(t.target,"a")}},beforeunload:{postDispatch:function(t){void 0!==t.result&&t.originalEvent&&(t.originalEvent.returnValue=t.result)}}}},ot.removeEvent=function(t,e,n){t.removeEventListener&&t.removeEventListener(e,n)},ot.Event=function(t,e){return this instanceof ot.Event?(t&&t.type?(this.originalEvent=t,this.type=t.type,this.isDefaultPrevented=t.defaultPrevented||void 0===t.defaultPrevented&&t.returnValue===!1?f:p):this.type=t,e&&ot.extend(this,e),this.timeStamp=t&&t.timeStamp||ot.now(),void(this[ot.expando]=!0)):new ot.Event(t,e)},ot.Event.prototype={constructor:ot.Event,isDefaultPrevented:p,isPropagationStopped:p,isImmediatePropagationStopped:p,preventDefault:function(){var t=this.originalEvent;this.isDefaultPrevented=f,t&&t.preventDefault()},stopPropagation:function(){var t=this.originalEvent;this.isPropagationStopped=f,t&&t.stopPropagation()},stopImmediatePropagation:function(){var t=this.originalEvent;this.isImmediatePropagationStopped=f,t&&t.stopImmediatePropagation(),this.stopPropagation()}},ot.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},function(t,e){ot.event.special[t]={delegateType:e,bindType:e,handle:function(t){var n,i=this,r=t.relatedTarget,o=t.handleObj;return(!r||r!==i&&!ot.contains(i,r))&&(t.type=o.origType,n=o.handler.apply(this,arguments),t.type=e),n}}}),ot.fn.extend({on:function(t,e,n,i){return m(this,t,e,n,i)},one:function(t,e,n,i){return m(this,t,e,n,i,1)},off:function(t,e,n){var i,r;if(t&&t.preventDefault&&t.handleObj)return i=t.handleObj,ot(t.delegateTarget).off(i.namespace?i.origType+"."+i.namespace:i.origType,i.selector,i.handler),this;if("object"==typeof t){for(r in t)this.off(r,e,t[r]);return this}return(e===!1||"function"==typeof e)&&(n=e,e=void 0),n===!1&&(n=p),this.each(function(){ot.event.remove(this,t,n,e)})}});var jt=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:-]+)[^>]*)\/>/gi,Rt=/<script|<style|<link/i,Ut=/checked\s*(?:[^=]|=\s*.checked.)/i,qt=/^true\/(.*)/,Bt=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;ot.extend({htmlPrefilter:function(t){return t.replace(jt,"<$1></$2>")},clone:function(t,e,n){var i,r,o,a,s=t.cloneNode(!0),u=ot.contains(t.ownerDocument,t);if(!(it.noCloneChecked||1!==t.nodeType&&11!==t.nodeType||ot.isXMLDoc(t)))for(a=c(s),o=c(t),i=0,r=o.length;r>i;i++)w(o[i],a[i]);if(e)if(n)for(o=o||c(t),a=a||c(s),i=0,r=o.length;r>i;i++)x(o[i],a[i]);else x(t,s);return a=c(s,"script"),a.length>0&&d(a,!u&&c(t,"script")),s},cleanData:function(t){for(var e,n,i,r=ot.event.special,o=0;void 0!==(n=t[o]);o++)if(kt(n)){if(e=n[Ct.expando]){if(e.events)for(i in e.events)r[i]?ot.event.remove(n,i):ot.removeEvent(n,i,e.handle);n[Ct.expando]=void 0}n[Mt.expando]&&(n[Mt.expando]=void 0)}}}),ot.fn.extend({domManip:_,detach:function(t){return $(this,t,!0)},remove:function(t){return $(this,t)},text:function(t){return $t(this,function(t){return void 0===t?ot.text(this):this.empty().each(function(){(1===this.nodeType||11===this.nodeType||9===this.nodeType)&&(this.textContent=t)})},null,t,arguments.length)},append:function(){return _(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var e=v(this,t);e.appendChild(t)}})},prepend:function(){return _(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var e=v(this,t);e.insertBefore(t,e.firstChild)}})},before:function(){return _(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this)})},after:function(){return _(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this.nextSibling)})},empty:function(){for(var t,e=0;null!=(t=this[e]);e++)1===t.nodeType&&(ot.cleanData(c(t,!1)),t.textContent="");return this},clone:function(t,e){return t=null==t?!1:t,e=null==e?t:e,this.map(function(){return ot.clone(this,t,e)})},html:function(t){return $t(this,function(t){var e=this[0]||{},n=0,i=this.length;if(void 0===t&&1===e.nodeType)return e.innerHTML;if("string"==typeof t&&!Rt.test(t)&&!Ft[(It.exec(t)||["",""])[1].toLowerCase()]){t=ot.htmlPrefilter(t);try{for(;i>n;n++)e=this[n]||{},1===e.nodeType&&(ot.cleanData(c(e,!1)),e.innerHTML=t);e=0}catch(r){}}e&&this.empty().append(t)},null,t,arguments.length)},replaceWith:function(){var t=[];return _(this,arguments,function(e){var n=this.parentNode;ot.inArray(this,t)<0&&(ot.cleanData(c(this)),n&&n.replaceChild(e,this))},t)}}),ot.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(t,e){ot.fn[t]=function(t){for(var n,i=[],r=ot(t),o=r.length-1,a=0;o>=a;a++)n=a===o?this:this.clone(!0),ot(r[a])[e](n),Q.apply(i,n.get());return this.pushStack(i)}});var Vt,Yt={HTML:"block",BODY:"block"},Gt=/^margin/,Xt=new RegExp("^("+Tt+")(?!px)[a-z%]+$","i"),Kt=function(e){var n=e.ownerDocument.defaultView;return n&&n.opener||(n=t),n.getComputedStyle(e)},Zt=function(t,e,n,i){var r,o,a={};for(o in e)a[o]=t.style[o],t.style[o]=e[o];r=n.apply(t,i||[]);for(o in e)t.style[o]=a[o];return r},Qt=X.documentElement;!function(){function e(){s.style.cssText="-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box;position:relative;display:block;margin:auto;border:1px;padding:1px;top:1%;width:50%",s.innerHTML="",Qt.appendChild(a);var e=t.getComputedStyle(s);n="1%"!==e.top,o="2px"===e.marginLeft,i="4px"===e.width,s.style.marginRight="50%",r="4px"===e.marginRight,Qt.removeChild(a)}var n,i,r,o,a=X.createElement("div"),s=X.createElement("div");s.style&&(s.style.backgroundClip="content-box",s.cloneNode(!0).style.backgroundClip="",it.clearCloneStyle="content-box"===s.style.backgroundClip,a.style.cssText="border:0;width:8px;height:0;top:0;left:-9999px;padding:0;margin-top:1px;position:absolute",a.appendChild(s),ot.extend(it,{pixelPosition:function(){return e(),n},boxSizingReliable:function(){return null==i&&e(),i},pixelMarginRight:function(){return null==i&&e(),r},reliableMarginLeft:function(){return null==i&&e(),o},reliableMarginRight:function(){var e,n=s.appendChild(X.createElement("div"));return n.style.cssText=s.style.cssText="-webkit-box-sizing:content-box;box-sizing:content-box;display:block;margin:0;border:0;padding:0",n.style.marginRight=n.style.width="0",s.style.width="1px",Qt.appendChild(a),e=!parseFloat(t.getComputedStyle(n).marginRight),Qt.removeChild(a),s.removeChild(n),e}}))}();var Jt=/^(none|table(?!-c[ea]).+)/,te={position:"absolute",visibility:"hidden",display:"block"},ee={letterSpacing:"0",fontWeight:"400"},ne=["Webkit","O","Moz","ms"],ie=X.createElement("div").style;ot.extend({cssHooks:{opacity:{get:function(t,e){if(e){var n=M(t,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{"float":"cssFloat"},style:function(t,e,n,i){if(t&&3!==t.nodeType&&8!==t.nodeType&&t.style){var r,o,a,s=ot.camelCase(e),u=t.style;return e=ot.cssProps[s]||(ot.cssProps[s]=S(s)||s),a=ot.cssHooks[e]||ot.cssHooks[s],void 0===n?a&&"get"in a&&void 0!==(r=a.get(t,!1,i))?r:u[e]:(o=typeof n,"string"===o&&(r=At.exec(n))&&r[1]&&(n=l(t,e,r),o="number"),null!=n&&n===n&&("number"===o&&(n+=r&&r[3]||(ot.cssNumber[s]?"":"px")),it.clearCloneStyle||""!==n||0!==e.indexOf("background")||(u[e]="inherit"),a&&"set"in a&&void 0===(n=a.set(t,n,i))||(u[e]=n)),void 0)}},css:function(t,e,n,i){var r,o,a,s=ot.camelCase(e);return e=ot.cssProps[s]||(ot.cssProps[s]=S(s)||s),a=ot.cssHooks[e]||ot.cssHooks[s],a&&"get"in a&&(r=a.get(t,!0,n)),void 0===r&&(r=M(t,e,i)),"normal"===r&&e in ee&&(r=ee[e]),""===n||n?(o=parseFloat(r),n===!0||isFinite(o)?o||0:r):r}}),ot.each(["height","width"],function(t,e){ot.cssHooks[e]={get:function(t,n,i){return n?Jt.test(ot.css(t,"display"))&&0===t.offsetWidth?Zt(t,te,function(){return E(t,e,i)}):E(t,e,i):void 0},set:function(t,n,i){var r,o=i&&Kt(t),a=i&&A(t,e,i,"border-box"===ot.css(t,"boxSizing",!1,o),o);return a&&(r=At.exec(n))&&"px"!==(r[3]||"px")&&(t.style[e]=n,n=ot.css(t,e)),T(t,n,a)}}}),ot.cssHooks.marginLeft=D(it.reliableMarginLeft,function(t,e){return e?(parseFloat(M(t,"marginLeft"))||t.getBoundingClientRect().left-Zt(t,{marginLeft:0},function(){return t.getBoundingClientRect().left}))+"px":void 0}),ot.cssHooks.marginRight=D(it.reliableMarginRight,function(t,e){return e?Zt(t,{display:"inline-block"},M,[t,"marginRight"]):void 0}),ot.each({margin:"",padding:"",border:"Width"},function(t,e){ot.cssHooks[t+e]={expand:function(n){for(var i=0,r={},o="string"==typeof n?n.split(" "):[n];4>i;i++)r[t+Et[i]+e]=o[i]||o[i-2]||o[0];return r}},Gt.test(t)||(ot.cssHooks[t+e].set=T)}),ot.fn.extend({css:function(t,e){return $t(this,function(t,e,n){var i,r,o={},a=0;if(ot.isArray(e)){for(i=Kt(t),r=e.length;r>a;a++)o[e[a]]=ot.css(t,e[a],!1,i);return o}return void 0!==n?ot.style(t,e,n):ot.css(t,e)},t,e,arguments.length>1)},show:function(){return O(this,!0)},hide:function(){return O(this)},toggle:function(t){return"boolean"==typeof t?t?this.show():this.hide():this.each(function(){Ot(this)?ot(this).show():ot(this).hide()})}}),ot.Tween=N,N.prototype={constructor:N,init:function(t,e,n,i,r,o){this.elem=t,this.prop=n,this.easing=r||ot.easing._default,this.options=e,this.start=this.now=this.cur(),this.end=i,this.unit=o||(ot.cssNumber[n]?"":"px")},cur:function(){var t=N.propHooks[this.prop];return t&&t.get?t.get(this):N.propHooks._default.get(this)},run:function(t){var e,n=N.propHooks[this.prop];return this.options.duration?this.pos=e=ot.easing[this.easing](t,this.options.duration*t,0,1,this.options.duration):this.pos=e=t,this.now=(this.end-this.start)*e+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):N.propHooks._default.set(this),this}},N.prototype.init.prototype=N.prototype,N.propHooks={_default:{get:function(t){var e;return 1!==t.elem.nodeType||null!=t.elem[t.prop]&&null==t.elem.style[t.prop]?t.elem[t.prop]:(e=ot.css(t.elem,t.prop,""),e&&"auto"!==e?e:0)},set:function(t){ot.fx.step[t.prop]?ot.fx.step[t.prop](t):1!==t.elem.nodeType||null==t.elem.style[ot.cssProps[t.prop]]&&!ot.cssHooks[t.prop]?t.elem[t.prop]=t.now:ot.style(t.elem,t.prop,t.now+t.unit)}}},N.propHooks.scrollTop=N.propHooks.scrollLeft={set:function(t){t.elem.nodeType&&t.elem.parentNode&&(t.elem[t.prop]=t.now)}},ot.easing={linear:function(t){return t},swing:function(t){return.5-Math.cos(t*Math.PI)/2},_default:"swing"},ot.fx=N.prototype.init,ot.fx.step={};var re,oe,ae=/^(?:toggle|show|hide)$/,se=/queueHooks$/;ot.Animation=ot.extend(L,{tweeners:{"*":[function(t,e){var n=this.createTween(t,e);return l(n.elem,t,At.exec(e),n),n}]},tweener:function(t,e){ot.isFunction(t)?(e=t,t=["*"]):t=t.match(wt);for(var n,i=0,r=t.length;r>i;i++)n=t[i],L.tweeners[n]=L.tweeners[n]||[],L.tweeners[n].unshift(e)},prefilters:[W],prefilter:function(t,e){e?L.prefilters.unshift(t):L.prefilters.push(t)}}),ot.speed=function(t,e,n){var i=t&&"object"==typeof t?ot.extend({},t):{complete:n||!n&&e||ot.isFunction(t)&&t,duration:t,easing:n&&e||e&&!ot.isFunction(e)&&e};return i.duration=ot.fx.off?0:"number"==typeof i.duration?i.duration:i.duration in ot.fx.speeds?ot.fx.speeds[i.duration]:ot.fx.speeds._default,(null==i.queue||i.queue===!0)&&(i.queue="fx"),i.old=i.complete,i.complete=function(){ot.isFunction(i.old)&&i.old.call(this),i.queue&&ot.dequeue(this,i.queue)},i},ot.fn.extend({fadeTo:function(t,e,n,i){return this.filter(Ot).css("opacity",0).show().end().animate({opacity:e},t,n,i)},animate:function(t,e,n,i){var r=ot.isEmptyObject(t),o=ot.speed(e,n,i),a=function(){var e=L(this,ot.extend({},t),o);(r||Ct.get(this,"finish"))&&e.stop(!0)};return a.finish=a,r||o.queue===!1?this.each(a):this.queue(o.queue,a)},stop:function(t,e,n){var i=function(t){var e=t.stop;delete t.stop,e(n)};return"string"!=typeof t&&(n=e,e=t,t=void 0),e&&t!==!1&&this.queue(t||"fx",[]),this.each(function(){var e=!0,r=null!=t&&t+"queueHooks",o=ot.timers,a=Ct.get(this);if(r)a[r]&&a[r].stop&&i(a[r]);else for(r in a)a[r]&&a[r].stop&&se.test(r)&&i(a[r]);for(r=o.length;r--;)o[r].elem!==this||null!=t&&o[r].queue!==t||(o[r].anim.stop(n),e=!1,o.splice(r,1));(e||!n)&&ot.dequeue(this,t)})},finish:function(t){return t!==!1&&(t=t||"fx"),this.each(function(){var e,n=Ct.get(this),i=n[t+"queue"],r=n[t+"queueHooks"],o=ot.timers,a=i?i.length:0;for(n.finish=!0,ot.queue(this,t,[]),r&&r.stop&&r.stop.call(this,!0),e=o.length;e--;)o[e].elem===this&&o[e].queue===t&&(o[e].anim.stop(!0),o.splice(e,1));for(e=0;a>e;e++)i[e]&&i[e].finish&&i[e].finish.call(this);delete n.finish})}}),ot.each(["toggle","show","hide"],function(t,e){var n=ot.fn[e];ot.fn[e]=function(t,i,r){return null==t||"boolean"==typeof t?n.apply(this,arguments):this.animate(P(e,!0),t,i,r)}}),ot.each({slideDown:P("show"),slideUp:P("hide"),slideToggle:P("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(t,e){ot.fn[t]=function(t,n,i){return this.animate(e,t,n,i)}}),ot.timers=[],ot.fx.tick=function(){var t,e=0,n=ot.timers;for(re=ot.now();e<n.length;e++)t=n[e],t()||n[e]!==t||n.splice(e--,1);n.length||ot.fx.stop(),re=void 0},ot.fx.timer=function(t){ot.timers.push(t),t()?ot.fx.start():ot.timers.pop()},ot.fx.interval=13,ot.fx.start=function(){oe||(oe=t.setInterval(ot.fx.tick,ot.fx.interval))},ot.fx.stop=function(){t.clearInterval(oe),oe=null},ot.fx.speeds={slow:600,fast:200,_default:400},ot.fn.delay=function(e,n){return e=ot.fx?ot.fx.speeds[e]||e:e,n=n||"fx",this.queue(n,function(n,i){var r=t.setTimeout(n,e);i.stop=function(){t.clearTimeout(r)}})},function(){var t=X.createElement("input"),e=X.createElement("select"),n=e.appendChild(X.createElement("option"));t.type="checkbox",it.checkOn=""!==t.value,it.optSelected=n.selected,e.disabled=!0,it.optDisabled=!n.disabled,t=X.createElement("input"),t.value="t",t.type="radio",it.radioValue="t"===t.value}();var ue,le=ot.expr.attrHandle;ot.fn.extend({attr:function(t,e){return $t(this,ot.attr,t,e,arguments.length>1)},removeAttr:function(t){return this.each(function(){ot.removeAttr(this,t)})}}),ot.extend({attr:function(t,e,n){var i,r,o=t.nodeType;if(3!==o&&8!==o&&2!==o)return"undefined"==typeof t.getAttribute?ot.prop(t,e,n):(1===o&&ot.isXMLDoc(t)||(e=e.toLowerCase(),r=ot.attrHooks[e]||(ot.expr.match.bool.test(e)?ue:void 0)),void 0!==n?null===n?void ot.removeAttr(t,e):r&&"set"in r&&void 0!==(i=r.set(t,n,e))?i:(t.setAttribute(e,n+""),n):r&&"get"in r&&null!==(i=r.get(t,e))?i:(i=ot.find.attr(t,e),null==i?void 0:i))},attrHooks:{type:{set:function(t,e){if(!it.radioValue&&"radio"===e&&ot.nodeName(t,"input")){var n=t.value;return t.setAttribute("type",e),n&&(t.value=n),e}}}},removeAttr:function(t,e){var n,i,r=0,o=e&&e.match(wt);if(o&&1===t.nodeType)for(;n=o[r++];)i=ot.propFix[n]||n,ot.expr.match.bool.test(n)&&(t[i]=!1),t.removeAttribute(n)}}),ue={set:function(t,e,n){return e===!1?ot.removeAttr(t,n):t.setAttribute(n,n),n}},ot.each(ot.expr.match.bool.source.match(/\w+/g),function(t,e){var n=le[e]||ot.find.attr;le[e]=function(t,e,i){var r,o;return i||(o=le[e],le[e]=r,r=null!=n(t,e,i)?e.toLowerCase():null,le[e]=o),r}});var ce=/^(?:input|select|textarea|button)$/i,de=/^(?:a|area)$/i;ot.fn.extend({prop:function(t,e){return $t(this,ot.prop,t,e,arguments.length>1)},removeProp:function(t){return this.each(function(){delete this[ot.propFix[t]||t]})}}),ot.extend({prop:function(t,e,n){var i,r,o=t.nodeType;if(3!==o&&8!==o&&2!==o)return 1===o&&ot.isXMLDoc(t)||(e=ot.propFix[e]||e,r=ot.propHooks[e]),void 0!==n?r&&"set"in r&&void 0!==(i=r.set(t,n,e))?i:t[e]=n:r&&"get"in r&&null!==(i=r.get(t,e))?i:t[e]},propHooks:{tabIndex:{get:function(t){var e=ot.find.attr(t,"tabindex");return e?parseInt(e,10):ce.test(t.nodeName)||de.test(t.nodeName)&&t.href?0:-1}}},propFix:{"for":"htmlFor","class":"className"}}),it.optSelected||(ot.propHooks.selected={get:function(t){var e=t.parentNode;return e&&e.parentNode&&e.parentNode.selectedIndex,null},set:function(t){var e=t.parentNode;e&&(e.selectedIndex,e.parentNode&&e.parentNode.selectedIndex)}}),ot.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],function(){ot.propFix[this.toLowerCase()]=this});var he=/[\t\r\n\f]/g;ot.fn.extend({addClass:function(t){var e,n,i,r,o,a,s,u=0;if(ot.isFunction(t))return this.each(function(e){ot(this).addClass(t.call(this,e,z(this)))});if("string"==typeof t&&t)for(e=t.match(wt)||[];n=this[u++];)if(r=z(n),i=1===n.nodeType&&(" "+r+" ").replace(he," ")){for(a=0;o=e[a++];)i.indexOf(" "+o+" ")<0&&(i+=o+" ");s=ot.trim(i),r!==s&&n.setAttribute("class",s)}return this},removeClass:function(t){var e,n,i,r,o,a,s,u=0;if(ot.isFunction(t))return this.each(function(e){ot(this).removeClass(t.call(this,e,z(this)))});if(!arguments.length)return this.attr("class","");if("string"==typeof t&&t)for(e=t.match(wt)||[];n=this[u++];)if(r=z(n),i=1===n.nodeType&&(" "+r+" ").replace(he," ")){for(a=0;o=e[a++];)for(;i.indexOf(" "+o+" ")>-1;)i=i.replace(" "+o+" "," ");s=ot.trim(i),r!==s&&n.setAttribute("class",s)}return this},toggleClass:function(t,e){var n=typeof t;return"boolean"==typeof e&&"string"===n?e?this.addClass(t):this.removeClass(t):ot.isFunction(t)?this.each(function(n){ot(this).toggleClass(t.call(this,n,z(this),e),e)}):this.each(function(){var e,i,r,o;if("string"===n)for(i=0,r=ot(this),o=t.match(wt)||[];e=o[i++];)r.hasClass(e)?r.removeClass(e):r.addClass(e);else(void 0===t||"boolean"===n)&&(e=z(this),e&&Ct.set(this,"__className__",e),this.setAttribute&&this.setAttribute("class",e||t===!1?"":Ct.get(this,"__className__")||""))})},hasClass:function(t){var e,n,i=0;for(e=" "+t+" ";n=this[i++];)if(1===n.nodeType&&(" "+z(n)+" ").replace(he," ").indexOf(e)>-1)return!0;return!1}});var fe=/\r/g,pe=/[\x20\t\r\n\f]+/g;ot.fn.extend({val:function(t){var e,n,i,r=this[0];{if(arguments.length)return i=ot.isFunction(t),this.each(function(n){var r;1===this.nodeType&&(r=i?t.call(this,n,ot(this).val()):t,null==r?r="":"number"==typeof r?r+="":ot.isArray(r)&&(r=ot.map(r,function(t){return null==t?"":t+""})),e=ot.valHooks[this.type]||ot.valHooks[this.nodeName.toLowerCase()],e&&"set"in e&&void 0!==e.set(this,r,"value")||(this.value=r))});if(r)return e=ot.valHooks[r.type]||ot.valHooks[r.nodeName.toLowerCase()],e&&"get"in e&&void 0!==(n=e.get(r,"value"))?n:(n=r.value,"string"==typeof n?n.replace(fe,""):null==n?"":n)}}}),ot.extend({valHooks:{option:{get:function(t){var e=ot.find.attr(t,"value");return null!=e?e:ot.trim(ot.text(t)).replace(pe," ")}},select:{get:function(t){for(var e,n,i=t.options,r=t.selectedIndex,o="select-one"===t.type||0>r,a=o?null:[],s=o?r+1:i.length,u=0>r?s:o?r:0;s>u;u++)if(n=i[u],(n.selected||u===r)&&(it.optDisabled?!n.disabled:null===n.getAttribute("disabled"))&&(!n.parentNode.disabled||!ot.nodeName(n.parentNode,"optgroup"))){if(e=ot(n).val(),o)return e;a.push(e)}return a},set:function(t,e){for(var n,i,r=t.options,o=ot.makeArray(e),a=r.length;a--;)i=r[a],(i.selected=ot.inArray(ot.valHooks.option.get(i),o)>-1)&&(n=!0);return n||(t.selectedIndex=-1),o}}}}),ot.each(["radio","checkbox"],function(){ot.valHooks[this]={set:function(t,e){return ot.isArray(e)?t.checked=ot.inArray(ot(t).val(),e)>-1:void 0}},it.checkOn||(ot.valHooks[this].get=function(t){return null===t.getAttribute("value")?"on":t.value})});var ge=/^(?:focusinfocus|focusoutblur)$/;ot.extend(ot.event,{trigger:function(e,n,i,r){var o,a,s,u,l,c,d,h=[i||X],f=nt.call(e,"type")?e.type:e,p=nt.call(e,"namespace")?e.namespace.split("."):[];if(a=s=i=i||X,3!==i.nodeType&&8!==i.nodeType&&!ge.test(f+ot.event.triggered)&&(f.indexOf(".")>-1&&(p=f.split("."),f=p.shift(),p.sort()),l=f.indexOf(":")<0&&"on"+f,e=e[ot.expando]?e:new ot.Event(f,"object"==typeof e&&e),e.isTrigger=r?2:3,e.namespace=p.join("."),e.rnamespace=e.namespace?new RegExp("(^|\\.)"+p.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,e.result=void 0,e.target||(e.target=i),n=null==n?[e]:ot.makeArray(n,[e]),d=ot.event.special[f]||{},r||!d.trigger||d.trigger.apply(i,n)!==!1)){if(!r&&!d.noBubble&&!ot.isWindow(i)){for(u=d.delegateType||f,ge.test(u+f)||(a=a.parentNode);a;a=a.parentNode)h.push(a),s=a;s===(i.ownerDocument||X)&&h.push(s.defaultView||s.parentWindow||t)}for(o=0;(a=h[o++])&&!e.isPropagationStopped();)e.type=o>1?u:d.bindType||f,c=(Ct.get(a,"events")||{})[e.type]&&Ct.get(a,"handle"),c&&c.apply(a,n),c=l&&a[l],c&&c.apply&&kt(a)&&(e.result=c.apply(a,n),e.result===!1&&e.preventDefault());return e.type=f,r||e.isDefaultPrevented()||d._default&&d._default.apply(h.pop(),n)!==!1||!kt(i)||l&&ot.isFunction(i[f])&&!ot.isWindow(i)&&(s=i[l],s&&(i[l]=null),ot.event.triggered=f,i[f](),ot.event.triggered=void 0,s&&(i[l]=s)),e.result}},simulate:function(t,e,n){var i=ot.extend(new ot.Event,n,{type:t,isSimulated:!0});ot.event.trigger(i,null,e),i.isDefaultPrevented()&&n.preventDefault()}}),ot.fn.extend({trigger:function(t,e){return this.each(function(){ot.event.trigger(t,e,this)})},triggerHandler:function(t,e){var n=this[0];return n?ot.event.trigger(t,e,n,!0):void 0}}),ot.each("blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error contextmenu".split(" "),function(t,e){ot.fn[e]=function(t,n){return arguments.length>0?this.on(e,null,t,n):this.trigger(e)}}),ot.fn.extend({hover:function(t,e){return this.mouseenter(t).mouseleave(e||t)}}),it.focusin="onfocusin"in t,it.focusin||ot.each({focus:"focusin",blur:"focusout"},function(t,e){var n=function(t){ot.event.simulate(e,t.target,ot.event.fix(t))};ot.event.special[e]={setup:function(){var i=this.ownerDocument||this,r=Ct.access(i,e);r||i.addEventListener(t,n,!0),Ct.access(i,e,(r||0)+1)},teardown:function(){var i=this.ownerDocument||this,r=Ct.access(i,e)-1;r?Ct.access(i,e,r):(i.removeEventListener(t,n,!0),Ct.remove(i,e))}}});var me=t.location,ve=ot.now(),ye=/\?/;ot.parseJSON=function(t){return JSON.parse(t+"")},ot.parseXML=function(e){var n;if(!e||"string"!=typeof e)return null;try{n=(new t.DOMParser).parseFromString(e,"text/xml")}catch(i){n=void 0}return(!n||n.getElementsByTagName("parsererror").length)&&ot.error("Invalid XML: "+e),n};var be=/#.*$/,xe=/([?&])_=[^&]*/,we=/^(.*?):[ \t]*([^\r\n]*)$/gm,_e=/^(?:about|app|app-storage|.+-extension|file|res|widget):$/,$e=/^(?:GET|HEAD)$/,ke=/^\/\//,Ce={},Me={},De="*/".concat("*"),Se=X.createElement("a");Se.href=me.href,ot.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:me.href,type:"GET",isLocal:_e.test(me.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":De,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":ot.parseJSON,"text xml":ot.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(t,e){return e?U(U(t,ot.ajaxSettings),e):U(ot.ajaxSettings,t)},ajaxPrefilter:j(Ce),ajaxTransport:j(Me),ajax:function(e,n){function i(e,n,i,s){var l,d,y,b,w,$=n;2!==x&&(x=2,u&&t.clearTimeout(u),r=void 0,a=s||"",_.readyState=e>0?4:0,l=e>=200&&300>e||304===e,i&&(b=q(h,_,i)),b=B(h,b,_,l),l?(h.ifModified&&(w=_.getResponseHeader("Last-Modified"),w&&(ot.lastModified[o]=w),w=_.getResponseHeader("etag"),w&&(ot.etag[o]=w)),204===e||"HEAD"===h.type?$="nocontent":304===e?$="notmodified":($=b.state,d=b.data,y=b.error,l=!y)):(y=$,(e||!$)&&($="error",0>e&&(e=0))),_.status=e,_.statusText=(n||$)+"",l?g.resolveWith(f,[d,$,_]):g.rejectWith(f,[_,$,y]),_.statusCode(v),v=void 0,c&&p.trigger(l?"ajaxSuccess":"ajaxError",[_,h,l?d:y]),m.fireWith(f,[_,$]),c&&(p.trigger("ajaxComplete",[_,h]),--ot.active||ot.event.trigger("ajaxStop")))}"object"==typeof e&&(n=e,e=void 0),n=n||{};var r,o,a,s,u,l,c,d,h=ot.ajaxSetup({},n),f=h.context||h,p=h.context&&(f.nodeType||f.jquery)?ot(f):ot.event,g=ot.Deferred(),m=ot.Callbacks("once memory"),v=h.statusCode||{},y={},b={},x=0,w="canceled",_={readyState:0,getResponseHeader:function(t){var e;if(2===x){if(!s)for(s={};e=we.exec(a);)s[e[1].toLowerCase()]=e[2];e=s[t.toLowerCase()]}return null==e?null:e},getAllResponseHeaders:function(){return 2===x?a:null},setRequestHeader:function(t,e){var n=t.toLowerCase();return x||(t=b[n]=b[n]||t,y[t]=e),this},overrideMimeType:function(t){return x||(h.mimeType=t),this},statusCode:function(t){var e;if(t)if(2>x)for(e in t)v[e]=[v[e],t[e]];else _.always(t[_.status]);return this},abort:function(t){var e=t||w;return r&&r.abort(e),i(0,e),this}};if(g.promise(_).complete=m.add,_.success=_.done,_.error=_.fail,h.url=((e||h.url||me.href)+"").replace(be,"").replace(ke,me.protocol+"//"),h.type=n.method||n.type||h.method||h.type,h.dataTypes=ot.trim(h.dataType||"*").toLowerCase().match(wt)||[""],null==h.crossDomain){l=X.createElement("a");try{l.href=h.url,l.href=l.href,h.crossDomain=Se.protocol+"//"+Se.host!=l.protocol+"//"+l.host}catch($){h.crossDomain=!0}}if(h.data&&h.processData&&"string"!=typeof h.data&&(h.data=ot.param(h.data,h.traditional)),R(Ce,h,n,_),2===x)return _;c=ot.event&&h.global,c&&0===ot.active++&&ot.event.trigger("ajaxStart"),h.type=h.type.toUpperCase(),h.hasContent=!$e.test(h.type),o=h.url,h.hasContent||(h.data&&(o=h.url+=(ye.test(o)?"&":"?")+h.data,delete h.data),h.cache===!1&&(h.url=xe.test(o)?o.replace(xe,"$1_="+ve++):o+(ye.test(o)?"&":"?")+"_="+ve++)),h.ifModified&&(ot.lastModified[o]&&_.setRequestHeader("If-Modified-Since",ot.lastModified[o]),ot.etag[o]&&_.setRequestHeader("If-None-Match",ot.etag[o])),(h.data&&h.hasContent&&h.contentType!==!1||n.contentType)&&_.setRequestHeader("Content-Type",h.contentType),_.setRequestHeader("Accept",h.dataTypes[0]&&h.accepts[h.dataTypes[0]]?h.accepts[h.dataTypes[0]]+("*"!==h.dataTypes[0]?", "+De+"; q=0.01":""):h.accepts["*"]);for(d in h.headers)_.setRequestHeader(d,h.headers[d]);if(h.beforeSend&&(h.beforeSend.call(f,_,h)===!1||2===x))return _.abort();w="abort";for(d in{success:1,error:1,complete:1})_[d](h[d]);if(r=R(Me,h,n,_)){if(_.readyState=1,c&&p.trigger("ajaxSend",[_,h]),2===x)return _;h.async&&h.timeout>0&&(u=t.setTimeout(function(){_.abort("timeout")},h.timeout));try{x=1,r.send(y,i)}catch($){if(!(2>x))throw $;i(-1,$)}}else i(-1,"No Transport");return _},getJSON:function(t,e,n){return ot.get(t,e,n,"json")},getScript:function(t,e){return ot.get(t,void 0,e,"script")}}),ot.each(["get","post"],function(t,e){ot[e]=function(t,n,i,r){return ot.isFunction(n)&&(r=r||i,i=n,n=void 0),ot.ajax(ot.extend({url:t,type:e,dataType:r,data:n,success:i},ot.isPlainObject(t)&&t))}}),ot._evalUrl=function(t){return ot.ajax({url:t,type:"GET",dataType:"script",async:!1,global:!1,"throws":!0})},ot.fn.extend({wrapAll:function(t){var e;return ot.isFunction(t)?this.each(function(e){ot(this).wrapAll(t.call(this,e))}):(this[0]&&(e=ot(t,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&e.insertBefore(this[0]),e.map(function(){for(var t=this;t.firstElementChild;)t=t.firstElementChild;return t}).append(this)),this)},wrapInner:function(t){return ot.isFunction(t)?this.each(function(e){ot(this).wrapInner(t.call(this,e))}):this.each(function(){var e=ot(this),n=e.contents();n.length?n.wrapAll(t):e.append(t)})},wrap:function(t){var e=ot.isFunction(t);return this.each(function(n){ot(this).wrapAll(e?t.call(this,n):t)})},unwrap:function(){return this.parent().each(function(){ot.nodeName(this,"body")||ot(this).replaceWith(this.childNodes)}).end()}}),ot.expr.filters.hidden=function(t){return!ot.expr.filters.visible(t)},ot.expr.filters.visible=function(t){return t.offsetWidth>0||t.offsetHeight>0||t.getClientRects().length>0};var Te=/%20/g,Ae=/\[\]$/,Ee=/\r?\n/g,Oe=/^(?:submit|button|image|reset|file)$/i,Ne=/^(?:input|select|textarea|keygen)/i;ot.param=function(t,e){var n,i=[],r=function(t,e){e=ot.isFunction(e)?e():null==e?"":e,i[i.length]=encodeURIComponent(t)+"="+encodeURIComponent(e)};if(void 0===e&&(e=ot.ajaxSettings&&ot.ajaxSettings.traditional),ot.isArray(t)||t.jquery&&!ot.isPlainObject(t))ot.each(t,function(){r(this.name,this.value)});else for(n in t)V(n,t[n],e,r);return i.join("&").replace(Te,"+")},ot.fn.extend({serialize:function(){return ot.param(this.serializeArray())},serializeArray:function(){return this.map(function(){var t=ot.prop(this,"elements");return t?ot.makeArray(t):this}).filter(function(){var t=this.type;return this.name&&!ot(this).is(":disabled")&&Ne.test(this.nodeName)&&!Oe.test(t)&&(this.checked||!Nt.test(t))}).map(function(t,e){var n=ot(this).val();return null==n?null:ot.isArray(n)?ot.map(n,function(t){return{name:e.name,value:t.replace(Ee,"\r\n")}}):{name:e.name,value:n.replace(Ee,"\r\n")}}).get()}}),ot.ajaxSettings.xhr=function(){try{return new t.XMLHttpRequest}catch(e){}};var Ie={0:200,1223:204},Pe=ot.ajaxSettings.xhr();it.cors=!!Pe&&"withCredentials"in Pe,it.ajax=Pe=!!Pe,ot.ajaxTransport(function(e){var n,i;return it.cors||Pe&&!e.crossDomain?{send:function(r,o){var a,s=e.xhr();if(s.open(e.type,e.url,e.async,e.username,e.password),e.xhrFields)for(a in e.xhrFields)s[a]=e.xhrFields[a];e.mimeType&&s.overrideMimeType&&s.overrideMimeType(e.mimeType),e.crossDomain||r["X-Requested-With"]||(r["X-Requested-With"]="XMLHttpRequest");
for(a in r)s.setRequestHeader(a,r[a]);n=function(t){return function(){n&&(n=i=s.onload=s.onerror=s.onabort=s.onreadystatechange=null,"abort"===t?s.abort():"error"===t?"number"!=typeof s.status?o(0,"error"):o(s.status,s.statusText):o(Ie[s.status]||s.status,s.statusText,"text"!==(s.responseType||"text")||"string"!=typeof s.responseText?{binary:s.response}:{text:s.responseText},s.getAllResponseHeaders()))}},s.onload=n(),i=s.onerror=n("error"),void 0!==s.onabort?s.onabort=i:s.onreadystatechange=function(){4===s.readyState&&t.setTimeout(function(){n&&i()})},n=n("abort");try{s.send(e.hasContent&&e.data||null)}catch(u){if(n)throw u}},abort:function(){n&&n()}}:void 0}),ot.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(t){return ot.globalEval(t),t}}}),ot.ajaxPrefilter("script",function(t){void 0===t.cache&&(t.cache=!1),t.crossDomain&&(t.type="GET")}),ot.ajaxTransport("script",function(t){if(t.crossDomain){var e,n;return{send:function(i,r){e=ot("<script>").prop({charset:t.scriptCharset,src:t.url}).on("load error",n=function(t){e.remove(),n=null,t&&r("error"===t.type?404:200,t.type)}),X.head.appendChild(e[0])},abort:function(){n&&n()}}}});var Fe=[],We=/(=)\?(?=&|$)|\?\?/;ot.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var t=Fe.pop()||ot.expando+"_"+ve++;return this[t]=!0,t}}),ot.ajaxPrefilter("json jsonp",function(e,n,i){var r,o,a,s=e.jsonp!==!1&&(We.test(e.url)?"url":"string"==typeof e.data&&0===(e.contentType||"").indexOf("application/x-www-form-urlencoded")&&We.test(e.data)&&"data");return s||"jsonp"===e.dataTypes[0]?(r=e.jsonpCallback=ot.isFunction(e.jsonpCallback)?e.jsonpCallback():e.jsonpCallback,s?e[s]=e[s].replace(We,"$1"+r):e.jsonp!==!1&&(e.url+=(ye.test(e.url)?"&":"?")+e.jsonp+"="+r),e.converters["script json"]=function(){return a||ot.error(r+" was not called"),a[0]},e.dataTypes[0]="json",o=t[r],t[r]=function(){a=arguments},i.always(function(){void 0===o?ot(t).removeProp(r):t[r]=o,e[r]&&(e.jsonpCallback=n.jsonpCallback,Fe.push(r)),a&&ot.isFunction(o)&&o(a[0]),a=o=void 0}),"script"):void 0}),ot.parseHTML=function(t,e,n){if(!t||"string"!=typeof t)return null;"boolean"==typeof e&&(n=e,e=!1),e=e||X;var i=pt.exec(t),r=!n&&[];return i?[e.createElement(i[1])]:(i=h([t],e,r),r&&r.length&&ot(r).remove(),ot.merge([],i.childNodes))};var He=ot.fn.load;ot.fn.load=function(t,e,n){if("string"!=typeof t&&He)return He.apply(this,arguments);var i,r,o,a=this,s=t.indexOf(" ");return s>-1&&(i=ot.trim(t.slice(s)),t=t.slice(0,s)),ot.isFunction(e)?(n=e,e=void 0):e&&"object"==typeof e&&(r="POST"),a.length>0&&ot.ajax({url:t,type:r||"GET",dataType:"html",data:e}).done(function(t){o=arguments,a.html(i?ot("<div>").append(ot.parseHTML(t)).find(i):t)}).always(n&&function(t,e){a.each(function(){n.apply(this,o||[t.responseText,e,t])})}),this},ot.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],function(t,e){ot.fn[e]=function(t){return this.on(e,t)}}),ot.expr.filters.animated=function(t){return ot.grep(ot.timers,function(e){return t===e.elem}).length},ot.offset={setOffset:function(t,e,n){var i,r,o,a,s,u,l,c=ot.css(t,"position"),d=ot(t),h={};"static"===c&&(t.style.position="relative"),s=d.offset(),o=ot.css(t,"top"),u=ot.css(t,"left"),l=("absolute"===c||"fixed"===c)&&(o+u).indexOf("auto")>-1,l?(i=d.position(),a=i.top,r=i.left):(a=parseFloat(o)||0,r=parseFloat(u)||0),ot.isFunction(e)&&(e=e.call(t,n,ot.extend({},s))),null!=e.top&&(h.top=e.top-s.top+a),null!=e.left&&(h.left=e.left-s.left+r),"using"in e?e.using.call(t,h):d.css(h)}},ot.fn.extend({offset:function(t){if(arguments.length)return void 0===t?this:this.each(function(e){ot.offset.setOffset(this,t,e)});var e,n,i=this[0],r={top:0,left:0},o=i&&i.ownerDocument;if(o)return e=o.documentElement,ot.contains(e,i)?(r=i.getBoundingClientRect(),n=Y(o),{top:r.top+n.pageYOffset-e.clientTop,left:r.left+n.pageXOffset-e.clientLeft}):r},position:function(){if(this[0]){var t,e,n=this[0],i={top:0,left:0};return"fixed"===ot.css(n,"position")?e=n.getBoundingClientRect():(t=this.offsetParent(),e=this.offset(),ot.nodeName(t[0],"html")||(i=t.offset()),i.top+=ot.css(t[0],"borderTopWidth",!0),i.left+=ot.css(t[0],"borderLeftWidth",!0)),{top:e.top-i.top-ot.css(n,"marginTop",!0),left:e.left-i.left-ot.css(n,"marginLeft",!0)}}},offsetParent:function(){return this.map(function(){for(var t=this.offsetParent;t&&"static"===ot.css(t,"position");)t=t.offsetParent;return t||Qt})}}),ot.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(t,e){var n="pageYOffset"===e;ot.fn[t]=function(i){return $t(this,function(t,i,r){var o=Y(t);return void 0===r?o?o[e]:t[i]:void(o?o.scrollTo(n?o.pageXOffset:r,n?r:o.pageYOffset):t[i]=r)},t,i,arguments.length)}}),ot.each(["top","left"],function(t,e){ot.cssHooks[e]=D(it.pixelPosition,function(t,n){return n?(n=M(t,e),Xt.test(n)?ot(t).position()[e]+"px":n):void 0})}),ot.each({Height:"height",Width:"width"},function(t,e){ot.each({padding:"inner"+t,content:e,"":"outer"+t},function(n,i){ot.fn[i]=function(i,r){var o=arguments.length&&(n||"boolean"!=typeof i),a=n||(i===!0||r===!0?"margin":"border");return $t(this,function(e,n,i){var r;return ot.isWindow(e)?e.document.documentElement["client"+t]:9===e.nodeType?(r=e.documentElement,Math.max(e.body["scroll"+t],r["scroll"+t],e.body["offset"+t],r["offset"+t],r["client"+t])):void 0===i?ot.css(e,n,a):ot.style(e,n,i,a)},e,o?i:void 0,o,null)}})}),ot.fn.extend({bind:function(t,e,n){return this.on(t,null,e,n)},unbind:function(t,e){return this.off(t,null,e)},delegate:function(t,e,n,i){return this.on(e,t,n,i)},undelegate:function(t,e,n){return 1===arguments.length?this.off(t,"**"):this.off(e,t||"**",n)},size:function(){return this.length}}),ot.fn.andSelf=ot.fn.addBack,"function"==typeof define&&define.amd&&define("jquery",[],function(){return ot});var Le=t.jQuery,ze=t.$;return ot.noConflict=function(e){return t.$===ot&&(t.$=ze),e&&t.jQuery===ot&&(t.jQuery=Le),ot},e||(t.jQuery=t.$=ot),ot}),/**
 * @license AngularJS v1.4.11
 * (c) 2010-2015 Google, Inc. http://angularjs.org
 * License: MIT
 */
function(t,e,n){"use strict";function i(t,e){return e=e||Error,function(){var n,i,r=2,o=arguments,a=o[0],s="["+(t?t+":":"")+a+"] ",u=o[1];for(s+=u.replace(/\{\d+\}/g,function(t){var e=+t.slice(1,-1),n=e+r;return n<o.length?bt(o[n]):t}),s+="\nhttp://errors.angularjs.org/1.4.11/"+(t?t+"/":"")+a,i=r,n="?";i<o.length;i++,n="&")s+=n+"p"+(i-r)+"="+encodeURIComponent(bt(o[i]));return new e(s)}}function r(t){if(null==t||S(t))return!1;if(qi(t)||$(t)||Oi&&t instanceof Oi)return!0;var e="length"in Object(t)&&t.length;return k(e)&&(e>=0&&(e-1 in t||t instanceof Array)||"function"==typeof t.item)}function o(t,e,n){var i,a;if(t)if(M(t))for(i in t)"prototype"==i||"length"==i||"name"==i||t.hasOwnProperty&&!t.hasOwnProperty(i)||e.call(n,t[i],i,t);else if(qi(t)||r(t)){var s="object"!=typeof t;for(i=0,a=t.length;a>i;i++)(s||i in t)&&e.call(n,t[i],i,t)}else if(t.forEach&&t.forEach!==o)t.forEach(e,n,t);else if(_(t))for(i in t)e.call(n,t[i],i,t);else if("function"==typeof t.hasOwnProperty)for(i in t)t.hasOwnProperty(i)&&e.call(n,t[i],i,t);else for(i in t)Di.call(t,i)&&e.call(n,t[i],i,t);return t}function a(t,e,n){for(var i=Object.keys(t).sort(),r=0;r<i.length;r++)e.call(n,t[i[r]],i[r]);return i}function s(t){return function(e,n){t(n,e)}}function u(){return++Ri}function l(t,e){e?t.$$hashKey=e:delete t.$$hashKey}function c(t,e,n){for(var i=t.$$hashKey,r=0,o=e.length;o>r;++r){var a=e[r];if(w(a)||M(a))for(var s=Object.keys(a),u=0,d=s.length;d>u;u++){var h=s[u],f=a[h];n&&w(f)?C(f)?t[h]=new Date(f.valueOf()):D(f)?t[h]=new RegExp(f):f.nodeName?t[h]=f.cloneNode(!0):F(f)?t[h]=f.clone():(w(t[h])||(t[h]=qi(f)?[]:{}),c(t[h],[f],!0)):t[h]=f}}return l(t,i),t}function d(t){return c(t,Pi.call(arguments,1),!1)}function h(t){return c(t,Pi.call(arguments,1),!0)}function f(t){return parseInt(t,10)}function p(t,e){return d(Object.create(t),e)}function g(){}function m(t){return t}function v(t){return function(){return t}}function y(t){return M(t.toString)&&t.toString!==Hi}function b(t){return"undefined"==typeof t}function x(t){return"undefined"!=typeof t}function w(t){return null!==t&&"object"==typeof t}function _(t){return null!==t&&"object"==typeof t&&!Li(t)}function $(t){return"string"==typeof t}function k(t){return"number"==typeof t}function C(t){return"[object Date]"===Hi.call(t)}function M(t){return"function"==typeof t}function D(t){return"[object RegExp]"===Hi.call(t)}function S(t){return t&&t.window===t}function T(t){return t&&t.$evalAsync&&t.$watch}function A(t){return"[object File]"===Hi.call(t)}function E(t){return"[object FormData]"===Hi.call(t)}function O(t){return"[object Blob]"===Hi.call(t)}function N(t){return"boolean"==typeof t}function I(t){return t&&M(t.then)}function P(t){return t&&k(t.length)&&Bi.test(Hi.call(t))}function F(t){return!(!t||!(t.nodeName||t.prop&&t.attr&&t.find))}function W(t){var e,n={},i=t.split(",");for(e=0;e<i.length;e++)n[i[e]]=!0;return n}function H(t){return Mi(t.nodeName||t[0]&&t[0].nodeName)}function L(t,e){var n=t.indexOf(e);return n>=0&&t.splice(n,1),n}function z(t,e){function n(t,e){var n,r=e.$$hashKey;if(qi(t))for(var o=0,a=t.length;a>o;o++)e.push(i(t[o]));else if(_(t))for(n in t)e[n]=i(t[n]);else if(t&&"function"==typeof t.hasOwnProperty)for(n in t)t.hasOwnProperty(n)&&(e[n]=i(t[n]));else for(n in t)Di.call(t,n)&&(e[n]=i(t[n]));return l(e,r),e}function i(t){if(!w(t))return t;var e=r.indexOf(t);if(-1!==e)return a[e];if(S(t)||T(t))throw zi("cpws","Can't copy! Making copies of Window or Scope instances is not supported.");var i,o=!1;return qi(t)?(i=[],o=!0):P(t)?i=new t.constructor(t):C(t)?i=new Date(t.getTime()):D(t)?(i=new RegExp(t.source,t.toString().match(/[^\/]*$/)[0]),i.lastIndex=t.lastIndex):O(t)?i=new t.constructor([t],{type:t.type}):M(t.cloneNode)?i=t.cloneNode(!0):(i=Object.create(Li(t)),o=!0),r.push(t),a.push(i),o?n(t,i):i}var r=[],a=[];if(e){if(P(e))throw zi("cpta","Can't copy! TypedArray destination cannot be mutated.");if(t===e)throw zi("cpi","Can't copy! Source and destination are identical.");return qi(e)?e.length=0:o(e,function(t,n){"$$hashKey"!==n&&delete e[n]}),r.push(t),a.push(e),n(t,e)}return i(t)}function j(t,e){if(qi(t)){e=e||[];for(var n=0,i=t.length;i>n;n++)e[n]=t[n]}else if(w(t)){e=e||{};for(var r in t)("$"!==r.charAt(0)||"$"!==r.charAt(1))&&(e[r]=t[r])}return e||t}function R(t,e){if(t===e)return!0;if(null===t||null===e)return!1;if(t!==t&&e!==e)return!0;var n,i,r,o=typeof t,a=typeof e;if(o==a&&"object"==o){if(!qi(t)){if(C(t))return C(e)?R(t.getTime(),e.getTime()):!1;if(D(t))return D(e)?t.toString()==e.toString():!1;if(T(t)||T(e)||S(t)||S(e)||qi(e)||C(e)||D(e))return!1;r=mt();for(i in t)if("$"!==i.charAt(0)&&!M(t[i])){if(!R(t[i],e[i]))return!1;r[i]=!0}for(i in e)if(!(i in r)&&"$"!==i.charAt(0)&&x(e[i])&&!M(e[i]))return!1;return!0}if(!qi(e))return!1;if((n=t.length)==e.length){for(i=0;n>i;i++)if(!R(t[i],e[i]))return!1;return!0}}return!1}function U(t,e,n){return t.concat(Pi.call(e,n))}function q(t,e){return Pi.call(t,e||0)}function B(t,e){var n=arguments.length>2?q(arguments,2):[];return!M(e)||e instanceof RegExp?e:n.length?function(){return arguments.length?e.apply(t,U(n,arguments,0)):e.apply(t,n)}:function(){return arguments.length?e.apply(t,arguments):e.call(t)}}function V(t,i){var r=i;return"string"==typeof t&&"$"===t.charAt(0)&&"$"===t.charAt(1)?r=n:S(i)?r="$WINDOW":i&&e===i?r="$DOCUMENT":T(i)&&(r="$SCOPE"),r}function Y(t,e){return b(t)?n:(k(e)||(e=e?2:null),JSON.stringify(t,V,e))}function G(t){return $(t)?JSON.parse(t):t}function X(t,e){t=t.replace(Ki,"");var n=Date.parse("Jan 01, 1970 00:00:00 "+t)/6e4;return isNaN(n)?e:n}function K(t,e){return t=new Date(t.getTime()),t.setMinutes(t.getMinutes()+e),t}function Z(t,e,n){n=n?-1:1;var i=t.getTimezoneOffset(),r=X(e,i);return K(t,n*(r-i))}function Q(t){t=Oi(t).clone();try{t.empty()}catch(e){}var n=Oi("<div>").append(t).html();try{return t[0].nodeType===nr?Mi(n):n.match(/^(<[^>]+>)/)[1].replace(/^<([\w\-]+)/,function(t,e){return"<"+Mi(e)})}catch(e){return Mi(n)}}function J(t){try{return decodeURIComponent(t)}catch(e){}}function tt(t){var e={};return o((t||"").split("&"),function(t){var n,i,r;t&&(i=t=t.replace(/\+/g,"%20"),n=t.indexOf("="),-1!==n&&(i=t.substring(0,n),r=t.substring(n+1)),i=J(i),x(i)&&(r=x(r)?J(r):!0,Di.call(e,i)?qi(e[i])?e[i].push(r):e[i]=[e[i],r]:e[i]=r))}),e}function et(t){var e=[];return o(t,function(t,n){qi(t)?o(t,function(t){e.push(it(n,!0)+(t===!0?"":"="+it(t,!0)))}):e.push(it(n,!0)+(t===!0?"":"="+it(t,!0)))}),e.length?e.join("&"):""}function nt(t){return it(t,!0).replace(/%26/gi,"&").replace(/%3D/gi,"=").replace(/%2B/gi,"+")}function it(t,e){return encodeURIComponent(t).replace(/%40/gi,"@").replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%3B/gi,";").replace(/%20/g,e?"%20":"+")}function rt(t,e){var n,i,r=Zi.length;for(i=0;r>i;++i)if(n=Zi[i]+e,$(n=t.getAttribute(n)))return n;return null}function ot(t,e){var n,i,r={};o(Zi,function(e){var r=e+"app";!n&&t.hasAttribute&&t.hasAttribute(r)&&(n=t,i=t.getAttribute(r))}),o(Zi,function(e){var r,o=e+"app";!n&&(r=t.querySelector("["+o.replace(":","\\:")+"]"))&&(n=r,i=r.getAttribute(o))}),n&&(r.strictDi=null!==rt(n,"strict-di"),e(n,i?[i]:[],r))}function at(n,i,r){w(r)||(r={});var a={strictDi:!1};r=d(a,r);var s=function(){if(n=Oi(n),n.injector()){var t=n[0]===e?"document":Q(n);throw zi("btstrpd","App already bootstrapped with this element '{0}'",t.replace(/</,"&lt;").replace(/>/,"&gt;"))}i=i||[],i.unshift(["$provide",function(t){t.value("$rootElement",n)}]),r.debugInfoEnabled&&i.push(["$compileProvider",function(t){t.debugInfoEnabled(!0)}]),i.unshift("ng");var o=ee(i,r.strictDi);return o.invoke(["$rootScope","$rootElement","$compile","$injector",function(t,e,n,i){t.$apply(function(){e.data("$injector",i),n(e)(t)})}]),o},u=/^NG_ENABLE_DEBUG_INFO!/,l=/^NG_DEFER_BOOTSTRAP!/;return t&&u.test(t.name)&&(r.debugInfoEnabled=!0,t.name=t.name.replace(u,"")),t&&!l.test(t.name)?s():(t.name=t.name.replace(l,""),ji.resumeBootstrap=function(t){return o(t,function(t){i.push(t)}),s()},void(M(ji.resumeDeferredBootstrap)&&ji.resumeDeferredBootstrap()))}function st(){t.name="NG_ENABLE_DEBUG_INFO!"+t.name,t.location.reload()}function ut(t){var e=ji.element(t).injector();if(!e)throw zi("test","no injector found for element argument to getTestability");return e.get("$$testability")}function lt(t,e){return e=e||"_",t.replace(Qi,function(t,n){return(n?e:"")+t.toLowerCase()})}function ct(){var e;if(!Ji){var i=Xi();Ni=b(i)?t.jQuery:i?t[i]:n,Ni&&Ni.fn.on?(Oi=Ni,d(Ni.fn,{scope:wr.scope,isolateScope:wr.isolateScope,controller:wr.controller,injector:wr.injector,inheritedData:wr.inheritedData}),e=Ni.cleanData,Ni.cleanData=function(t){var n;if(Ui)Ui=!1;else for(var i,r=0;null!=(i=t[r]);r++)n=Ni._data(i,"events"),n&&n.$destroy&&Ni(i).triggerHandler("$destroy");e(t)}):Oi=Tt,ji.element=Oi,Ji=!0}}function dt(t,e,n){if(!t)throw zi("areq","Argument '{0}' is {1}",e||"?",n||"required");return t}function ht(t,e,n){return n&&qi(t)&&(t=t[t.length-1]),dt(M(t),e,"not a function, got "+(t&&"object"==typeof t?t.constructor.name||"Object":typeof t)),t}function ft(t,e){if("hasOwnProperty"===t)throw zi("badname","hasOwnProperty is not a valid {0} name",e)}function pt(t,e,n){if(!e)return t;for(var i,r=e.split("."),o=t,a=r.length,s=0;a>s;s++)i=r[s],t&&(t=(o=t)[i]);return!n&&M(t)?B(o,t):t}function gt(t){for(var e,n=t[0],i=t[t.length-1],r=1;n!==i&&(n=n.nextSibling);r++)(e||t[r]!==n)&&(e||(e=Oi(Pi.call(t,0,r))),e.push(n));return e||t}function mt(){return Object.create(null)}function vt(t){function e(t,e,n){return t[e]||(t[e]=n())}var n=i("$injector"),r=i("ng"),o=e(t,"angular",Object);return o.$$minErr=o.$$minErr||i,e(o,"module",function(){var t={};return function(i,o,a){var s=function(t,e){if("hasOwnProperty"===t)throw r("badname","hasOwnProperty is not a valid {0} name",e)};return s(i,"module"),o&&t.hasOwnProperty(i)&&(t[i]=null),e(t,i,function(){function t(t,e,n,i){return i||(i=r),function(){return i[n||"push"]([t,e,arguments]),c}}function e(t,e){return function(n,o){return o&&M(o)&&(o.$$moduleName=i),r.push([t,e,arguments]),c}}if(!o)throw n("nomod","Module '{0}' is not available! You either misspelled the module name or forgot to load it. If registering a module ensure that you specify the dependencies as the second argument.",i);var r=[],s=[],u=[],l=t("$injector","invoke","push",s),c={_invokeQueue:r,_configBlocks:s,_runBlocks:u,requires:o,name:i,provider:e("$provide","provider"),factory:e("$provide","factory"),service:e("$provide","service"),value:t("$provide","value"),constant:t("$provide","constant","unshift"),decorator:e("$provide","decorator"),animation:e("$animateProvider","register"),filter:e("$filterProvider","register"),controller:e("$controllerProvider","register"),directive:e("$compileProvider","directive"),config:l,run:function(t){return u.push(t),this}};return a&&l(a),c})}})}function yt(t){var e=[];return JSON.stringify(t,function(t,n){if(n=V(t,n),w(n)){if(e.indexOf(n)>=0)return"...";e.push(n)}return n})}function bt(t){return"function"==typeof t?t.toString().replace(/ \{[\s\S]*$/,""):b(t)?"undefined":"string"!=typeof t?yt(t):t}function xt(e){d(e,{bootstrap:at,copy:z,extend:d,merge:h,equals:R,element:Oi,forEach:o,injector:ee,noop:g,bind:B,toJson:Y,fromJson:G,identity:m,isUndefined:b,isDefined:x,isString:$,isFunction:M,isObject:w,isNumber:k,isElement:F,isArray:qi,version:ar,isDate:C,lowercase:Mi,uppercase:Si,callbacks:{counter:0},getTestability:ut,$$minErr:i,$$csp:Gi,reloadWithDebugInfo:st}),(Ii=vt(t))("ng",["ngLocale"],["$provide",function(t){t.provider({$$sanitizeUri:xn}),t.provider("$compile",de).directive({a:Mo,input:Bo,textarea:Bo,form:Eo,script:Wa,select:za,style:Ra,option:ja,ngBind:Go,ngBindHtml:Ko,ngBindTemplate:Xo,ngClass:Qo,ngClassEven:ta,ngClassOdd:Jo,ngCloak:ea,ngController:na,ngForm:Oo,ngHide:Ea,ngIf:oa,ngInclude:aa,ngInit:ua,ngNonBindable:_a,ngPluralize:Ma,ngRepeat:Da,ngShow:Aa,ngStyle:Oa,ngSwitch:Na,ngSwitchWhen:Ia,ngSwitchDefault:Pa,ngOptions:Ca,ngTransclude:Fa,ngModel:ba,ngList:la,ngChange:Zo,pattern:qa,ngPattern:qa,required:Ua,ngRequired:Ua,minlength:Va,ngMinlength:Va,maxlength:Ba,ngMaxlength:Ba,ngValue:Yo,ngModelOptions:wa}).directive({ngInclude:sa}).directive(Do).directive(ia),t.provider({$anchorScroll:ne,$animate:Fr,$animateCss:Lr,$$animateJs:Ir,$$animateQueue:Pr,$$AnimateRunner:Hr,$$animateAsyncRun:Wr,$browser:ue,$cacheFactory:le,$controller:me,$document:ve,$exceptionHandler:ye,$filter:In,$$forceReflow:qr,$interpolate:Oe,$interval:Ne,$http:Se,$httpParamSerializer:xe,$httpParamSerializerJQLike:we,$httpBackend:Ae,$xhrFactory:Te,$location:Ye,$log:Ge,$parse:pn,$rootScope:bn,$q:gn,$$q:mn,$sce:kn,$sceDelegate:$n,$sniffer:Cn,$templateCache:ce,$templateRequest:Mn,$$testability:Dn,$timeout:Sn,$window:En,$$rAF:yn,$$jqLite:Kt,$$HashMap:Cr,$$cookieReader:Nn})}])}function wt(){return++ur}function _t(t){return t.replace(dr,function(t,e,n,i){return i?n.toUpperCase():n}).replace(hr,"Moz$1")}function $t(t){return!mr.test(t)}function kt(t){var e=t.nodeType;return e===tr||!e||e===rr}function Ct(t){for(var e in sr[t.ng339])return!0;return!1}function Mt(t,e){var n,i,r,a,s=e.createDocumentFragment(),u=[];if($t(t))u.push(e.createTextNode(t));else{for(n=n||s.appendChild(e.createElement("div")),i=(vr.exec(t)||["",""])[1].toLowerCase(),r=br[i]||br._default,n.innerHTML=r[1]+t.replace(yr,"<$1></$2>")+r[2],a=r[0];a--;)n=n.lastChild;u=U(u,n.childNodes),n=s.firstChild,n.textContent=""}return s.textContent="",s.innerHTML="",o(u,function(t){s.appendChild(t)}),s}function Dt(t,n){n=n||e;var i;return(i=gr.exec(t))?[n.createElement(i[1])]:(i=Mt(t,n))?i.childNodes:[]}function St(t,e){var n=t.parentNode;n&&n.replaceChild(e,t),e.appendChild(t)}function Tt(t){if(t instanceof Tt)return t;var e;if($(t)&&(t=Vi(t),e=!0),!(this instanceof Tt)){if(e&&"<"!=t.charAt(0))throw pr("nosel","Looking up elements via selectors is not supported by jqLite! See: http://docs.angularjs.org/api/angular.element");return new Tt(t)}e?Lt(this,Dt(t)):Lt(this,t)}function At(t){return t.cloneNode(!0)}function Et(t,e){if(e||Nt(t),t.querySelectorAll)for(var n=t.querySelectorAll("*"),i=0,r=n.length;r>i;i++)Nt(n[i])}function Ot(t,e,n,i){if(x(i))throw pr("offargs","jqLite#off() does not support the `selector` argument");var r=It(t),a=r&&r.events,s=r&&r.handle;if(s)if(e){var u=function(e){var i=a[e];x(n)&&L(i||[],n),x(n)&&i&&i.length>0||(cr(t,e,s),delete a[e])};o(e.split(" "),function(t){u(t),fr[t]&&u(fr[t])})}else for(e in a)"$destroy"!==e&&cr(t,e,s),delete a[e]}function Nt(t,e){var i=t.ng339,r=i&&sr[i];if(r){if(e)return void delete r.data[e];r.handle&&(r.events.$destroy&&r.handle({},"$destroy"),Ot(t)),delete sr[i],t.ng339=n}}function It(t,e){var i=t.ng339,r=i&&sr[i];return e&&!r&&(t.ng339=i=wt(),r=sr[i]={events:{},data:{},handle:n}),r}function Pt(t,e,n){if(kt(t)){var i=x(n),r=!i&&e&&!w(e),o=!e,a=It(t,!r),s=a&&a.data;if(i)s[e]=n;else{if(o)return s;if(r)return s&&s[e];d(s,e)}}}function Ft(t,e){return t.getAttribute?(" "+(t.getAttribute("class")||"")+" ").replace(/[\n\t]/g," ").indexOf(" "+e+" ")>-1:!1}function Wt(t,e){e&&t.setAttribute&&o(e.split(" "),function(e){t.setAttribute("class",Vi((" "+(t.getAttribute("class")||"")+" ").replace(/[\n\t]/g," ").replace(" "+Vi(e)+" "," ")))})}function Ht(t,e){if(e&&t.setAttribute){var n=(" "+(t.getAttribute("class")||"")+" ").replace(/[\n\t]/g," ");o(e.split(" "),function(t){t=Vi(t),-1===n.indexOf(" "+t+" ")&&(n+=t+" ")}),t.setAttribute("class",Vi(n))}}function Lt(t,e){if(e)if(e.nodeType)t[t.length++]=e;else{var n=e.length;if("number"==typeof n&&e.window!==e){if(n)for(var i=0;n>i;i++)t[t.length++]=e[i]}else t[t.length++]=e}}function zt(t,e){return jt(t,"$"+(e||"ngController")+"Controller")}function jt(t,e,n){t.nodeType==rr&&(t=t.documentElement);for(var i=qi(e)?e:[e];t;){for(var r=0,o=i.length;o>r;r++)if(x(n=Oi.data(t,i[r])))return n;t=t.parentNode||t.nodeType===or&&t.host}}function Rt(t){for(Et(t,!0);t.firstChild;)t.removeChild(t.firstChild)}function Ut(t,e){e||Et(t);var n=t.parentNode;n&&n.removeChild(t)}function qt(e,n){n=n||t,"complete"===n.document.readyState?n.setTimeout(e):Oi(n).on("load",e)}function Bt(t,e){var n=_r[e.toLowerCase()];return n&&$r[H(t)]&&n}function Vt(t){return kr[t]}function Yt(t,e){var n=function(n,i){n.isDefaultPrevented=function(){return n.defaultPrevented};var r=e[i||n.type],o=r?r.length:0;if(o){if(b(n.immediatePropagationStopped)){var a=n.stopImmediatePropagation;n.stopImmediatePropagation=function(){n.immediatePropagationStopped=!0,n.stopPropagation&&n.stopPropagation(),a&&a.call(n)}}n.isImmediatePropagationStopped=function(){return n.immediatePropagationStopped===!0};var s=r.specialHandlerWrapper||Gt;o>1&&(r=j(r));for(var u=0;o>u;u++)n.isImmediatePropagationStopped()||s(t,n,r[u])}};return n.elem=t,n}function Gt(t,e,n){n.call(t,e)}function Xt(t,e,n){var i=e.relatedTarget;(!i||i!==t&&!xr.call(t,i))&&n.call(t,e)}function Kt(){this.$get=function(){return d(Tt,{hasClass:function(t,e){return t.attr&&(t=t[0]),Ft(t,e)},addClass:function(t,e){return t.attr&&(t=t[0]),Ht(t,e)},removeClass:function(t,e){return t.attr&&(t=t[0]),Wt(t,e)}})}}function Zt(t,e){var n=t&&t.$$hashKey;if(n)return"function"==typeof n&&(n=t.$$hashKey()),n;var i=typeof t;return n="function"==i||"object"==i&&null!==t?t.$$hashKey=i+":"+(e||u)():i+":"+t}function Qt(t,e){if(e){var n=0;this.nextUid=function(){return++n}}o(t,this.put,this)}function Jt(t){var e=t.toString().replace(Tr,""),n=e.match(Mr);return n?"function("+(n[1]||"").replace(/[\s\r\n]+/," ")+")":"fn"}function te(t,e,n){var i,r,a,s;if("function"==typeof t){if(!(i=t.$inject)){if(i=[],t.length){if(e)throw $(n)&&n||(n=t.name||Jt(t)),Ar("strictdi","{0} is not using explicit annotation and cannot be invoked in strict mode",n);r=t.toString().replace(Tr,""),a=r.match(Mr),o(a[1].split(Dr),function(t){t.replace(Sr,function(t,e,n){i.push(n)})})}t.$inject=i}}else qi(t)?(s=t.length-1,ht(t[s],"fn"),i=t.slice(0,s)):ht(t,"fn",!0);return i}function ee(t,e){function i(t){return function(e,n){return w(e)?void o(e,s(t)):t(e,n)}}function r(t,e){if(ft(t,"service"),(M(e)||qi(e))&&(e=k.instantiate(e)),!e.$get)throw Ar("pget","Provider '{0}' must define $get factory method.",t);return _[t+m]=e}function a(t,e){return function(){var n=D.invoke(e,this);if(b(n))throw Ar("undef","Provider '{0}' must return a value from $get factory method.",t);return n}}function u(t,e,n){return r(t,{$get:n!==!1?a(t,e):e})}function l(t,e){return u(t,["$injector",function(t){return t.instantiate(e)}])}function c(t,e){return u(t,v(e),!1)}function d(t,e){ft(t,"constant"),_[t]=e,C[t]=e}function h(t,e){var n=k.get(t+m),i=n.$get;n.$get=function(){var t=D.invoke(i,n);return D.invoke(e,null,{$delegate:t})}}function f(t){dt(b(t)||qi(t),"modulesToLoad","not an array");var e,n=[];return o(t,function(t){function i(t){var e,n;for(e=0,n=t.length;n>e;e++){var i=t[e],r=k.get(i[0]);r[i[1]].apply(r,i[2])}}if(!x.get(t)){x.put(t,!0);try{$(t)?(e=Ii(t),n=n.concat(f(e.requires)).concat(e._runBlocks),i(e._invokeQueue),i(e._configBlocks)):M(t)?n.push(k.invoke(t)):qi(t)?n.push(k.invoke(t)):ht(t,"module")}catch(r){throw qi(t)&&(t=t[t.length-1]),r.message&&r.stack&&-1==r.stack.indexOf(r.message)&&(r=r.message+"\n"+r.stack),Ar("modulerr","Failed to instantiate module {0} due to:\n{1}",t,r.stack||r.message||r)}}}),n}function p(t,n){function i(e,i){if(t.hasOwnProperty(e)){if(t[e]===g)throw Ar("cdep","Circular dependency found: {0}",e+" <- "+y.join(" <- "));return t[e]}try{return y.unshift(e),t[e]=g,t[e]=n(e,i)}catch(r){throw t[e]===g&&delete t[e],r}finally{y.shift()}}function r(t,n,r,o){"string"==typeof r&&(o=r,r=null);var a,s,u,l=[],c=ee.$$annotate(t,e,o);for(s=0,a=c.length;a>s;s++){if(u=c[s],"string"!=typeof u)throw Ar("itkn","Incorrect injection token! Expected service name as string, got {0}",u);l.push(r&&r.hasOwnProperty(u)?r[u]:i(u,o))}return qi(t)&&(t=t[a]),t.apply(n,l)}function o(t,e,n){var i=Object.create((qi(t)?t[t.length-1]:t).prototype||null),o=r(t,i,e,n);return w(o)||M(o)?o:i}return{invoke:r,instantiate:o,get:i,annotate:ee.$$annotate,has:function(e){return _.hasOwnProperty(e+m)||t.hasOwnProperty(e)}}}e=e===!0;var g={},m="Provider",y=[],x=new Qt([],!0),_={$provide:{provider:i(r),factory:i(u),service:i(l),value:i(c),constant:i(d),decorator:h}},k=_.$injector=p(_,function(t,e){throw ji.isString(e)&&y.push(e),Ar("unpr","Unknown provider: {0}",y.join(" <- "))}),C={},D=C.$injector=p(C,function(t,e){var i=k.get(t+m,e);return D.invoke(i.$get,i,n,t)});return o(f(t),function(t){t&&D.invoke(t)}),D}function ne(){var t=!0;this.disableAutoScrolling=function(){t=!1},this.$get=["$window","$location","$rootScope",function(e,n,i){function r(t){var e=null;return Array.prototype.some.call(t,function(t){return"a"===H(t)?(e=t,!0):void 0}),e}function o(){var t=s.yOffset;if(M(t))t=t();else if(F(t)){var n=t[0],i=e.getComputedStyle(n);t="fixed"!==i.position?0:n.getBoundingClientRect().bottom}else k(t)||(t=0);return t}function a(t){if(t){t.scrollIntoView();var n=o();if(n){var i=t.getBoundingClientRect().top;e.scrollBy(0,i-n)}}else e.scrollTo(0,0)}function s(t){t=$(t)?t:n.hash();var e;t?(e=u.getElementById(t))?a(e):(e=r(u.getElementsByName(t)))?a(e):"top"===t&&a(null):a(null)}var u=e.document;return t&&i.$watch(function(){return n.hash()},function(t,e){(t!==e||""!==t)&&qt(function(){i.$evalAsync(s)})}),s}]}function ie(t,e){return t||e?t?e?(qi(t)&&(t=t.join(" ")),qi(e)&&(e=e.join(" ")),t+" "+e):t:e:""}function re(t){for(var e=0;e<t.length;e++){var n=t[e];if(n.nodeType===Or)return n}}function oe(t){$(t)&&(t=t.split(" "));var e=mt();return o(t,function(t){t.length&&(e[t]=!0)}),e}function ae(t){return w(t)?t:{}}function se(t,e,n,i){function r(t){try{t.apply(null,q(arguments,1))}finally{if(y--,0===y)for(;x.length;)try{x.pop()()}catch(e){n.error(e)}}}function a(t){var e=t.indexOf("#");return-1===e?"":t.substr(e)}function s(){C=null,l(),c()}function u(){try{return f.state}catch(t){}}function l(){w=u(),w=b(w)?null:w,R(w,S)&&(w=S),S=w}function c(){($!==d.url()||_!==w)&&($=d.url(),_=w,o(M,function(t){t(d.url(),w)}))}var d=this,h=(e[0],t.location),f=t.history,p=t.setTimeout,m=t.clearTimeout,v={};d.isMock=!1;var y=0,x=[];d.$$completeOutstandingRequest=r,d.$$incOutstandingRequestCount=function(){y++},d.notifyWhenNoOutstandingRequests=function(t){0===y?t():x.push(t)};var w,_,$=h.href,k=e.find("base"),C=null;l(),_=w,d.url=function(e,n,r){if(b(r)&&(r=null),h!==t.location&&(h=t.location),f!==t.history&&(f=t.history),e){var o=_===r;if($===e&&(!i.history||o))return d;var s=$&&He($)===He(e);return $=e,_=r,!i.history||s&&o?((!s||C)&&(C=e),n?h.replace(e):s?h.hash=a(e):h.href=e,h.href!==e&&(C=e)):(f[n?"replaceState":"pushState"](r,"",e),l(),_=w),d}return C||h.href.replace(/%27/g,"'")},d.state=function(){return w};var M=[],D=!1,S=null;d.onUrlChange=function(e){return D||(i.history&&Oi(t).on("popstate",s),Oi(t).on("hashchange",s),D=!0),M.push(e),e},d.$$applicationDestroyed=function(){Oi(t).off("hashchange popstate",s)},d.$$checkUrlChange=c,d.baseHref=function(){var t=k.attr("href");return t?t.replace(/^(https?\:)?\/\/[^\/]*/,""):""},d.defer=function(t,e){var n;return y++,n=p(function(){delete v[n],r(t)},e||0),v[n]=!0,n},d.defer.cancel=function(t){return v[t]?(delete v[t],m(t),r(g),!0):!1}}function ue(){this.$get=["$window","$log","$sniffer","$document",function(t,e,n,i){return new se(t,i,e,n)}]}function le(){this.$get=function(){function t(t,n){function r(t){t!=h&&(f?f==t&&(f=t.n):f=t,o(t.n,t.p),o(t,h),h=t,h.n=null)}function o(t,e){t!=e&&(t&&(t.p=e),e&&(e.n=t))}if(t in e)throw i("$cacheFactory")("iid","CacheId '{0}' is already taken!",t);var a=0,s=d({},n,{id:t}),u=mt(),l=n&&n.capacity||Number.MAX_VALUE,c=mt(),h=null,f=null;return e[t]={put:function(t,e){if(!b(e)){if(l<Number.MAX_VALUE){var n=c[t]||(c[t]={key:t});r(n)}return t in u||a++,u[t]=e,a>l&&this.remove(f.key),e}},get:function(t){if(l<Number.MAX_VALUE){var e=c[t];if(!e)return;r(e)}return u[t]},remove:function(t){if(l<Number.MAX_VALUE){var e=c[t];if(!e)return;e==h&&(h=e.p),e==f&&(f=e.n),o(e.n,e.p),delete c[t]}t in u&&(delete u[t],a--)},removeAll:function(){u=mt(),a=0,c=mt(),h=f=null},destroy:function(){u=null,s=null,c=null,delete e[t]},info:function(){return d({},s,{size:a})}}}var e={};return t.info=function(){var t={};return o(e,function(e,n){t[n]=e.info()}),t},t.get=function(t){return e[t]},t}}function ce(){this.$get=["$cacheFactory",function(t){return t("templates")}]}function de(t,i){function r(t,e,n){var i=/^\s*([@&]|=(\*?))(\??)\s*(\w*)\s*$/,r=mt();return o(t,function(t,o){if(t in C)return void(r[o]=C[t]);var a=t.match(i);if(!a)throw zr("iscp","Invalid {3} for directive '{0}'. Definition: {... {1}: '{2}' ...}",e,o,t,n?"controller bindings definition":"isolate scope definition");r[o]={mode:a[1][0],collection:"*"===a[2],optional:"?"===a[3],attrName:a[4]||o},a[4]&&(C[t]=r[o])}),r}function a(t,e){var n={isolateScope:null,bindToController:null};if(w(t.scope)&&(t.bindToController===!0?(n.bindToController=r(t.scope,e,!0),n.isolateScope={}):n.isolateScope=r(t.scope,e,!1)),w(t.bindToController)&&(n.bindToController=r(t.bindToController,e,!0)),w(n.bindToController)){var i=t.controller,o=t.controllerAs;if(!i)throw zr("noctrl","Cannot bind to controller without directive '{0}'s controller.",e);if(!ge(i,o))throw zr("noident","Cannot bind to controller without identifier for directive '{0}'.",e)}return n}function u(t){var e=t.charAt(0);if(!e||e!==Mi(e))throw zr("baddir","Directive name '{0}' is invalid. The first character must be a lowercase letter",t);if(t!==t.trim())throw zr("baddir","Directive name '{0}' is invalid. The name should not contain leading or trailing whitespaces",t)}var l={},c="Directive",h=/^\s*directive\:\s*([\w\-]+)\s+(.*)$/,f=/(([\w\-]+)(?:\:([^;]+))?;?)/,y=W("ngSrc,ngSrcset,src,srcset"),_=/^(?:(\^\^?)?(\?)?(\^\^?)?)?/,k=/^(on[a-z]+|formaction)$/,C=mt();this.directive=function S(e,n){return ft(e,"directive"),$(e)?(u(e),dt(n,"directiveFactory"),l.hasOwnProperty(e)||(l[e]=[],t.factory(e+c,["$injector","$exceptionHandler",function(t,n){var i=[];return o(l[e],function(r,o){try{var a=t.invoke(r);M(a)?a={compile:v(a)}:!a.compile&&a.link&&(a.compile=v(a.link)),a.priority=a.priority||0,a.index=o,a.name=a.name||e,a.require=a.require||a.controller&&a.name,a.restrict=a.restrict||"EA",a.$$moduleName=r.$$moduleName,i.push(a)}catch(s){n(s)}}),i}])),l[e].push(n)):o(e,s(S)),this},this.aHrefSanitizationWhitelist=function(t){return x(t)?(i.aHrefSanitizationWhitelist(t),this):i.aHrefSanitizationWhitelist()},this.imgSrcSanitizationWhitelist=function(t){return x(t)?(i.imgSrcSanitizationWhitelist(t),this):i.imgSrcSanitizationWhitelist()};var D=!0;this.debugInfoEnabled=function(t){return x(t)?(D=t,this):D},this.$get=["$injector","$interpolate","$exceptionHandler","$templateRequest","$parse","$controller","$rootScope","$sce","$animate","$$sanitizeUri",function(t,i,r,s,u,v,C,S,A,E){function O(t,e){try{t.addClass(e)}catch(n){}}function I(t,n,i,r,o){t instanceof Oi||(t=Oi(t));for(var a=/\S+/,s=0,u=t.length;u>s;s++){var l=t[s];l.nodeType===nr&&l.nodeValue.match(a)&&St(l,t[s]=e.createElement("span"))}var c=F(t,n,t,i,r,o);I.$$addScopeClass(t);var d=null;return function(e,n,i){dt(e,"scope"),o&&o.needsNewScope&&(e=e.$parent.$new()),i=i||{};var r=i.parentBoundTranscludeFn,a=i.transcludeControllers,s=i.futureParentElement;r&&r.$$boundTransclude&&(r=r.$$boundTransclude),d||(d=P(s));var u;if(u="html"!==d?Oi(et(d,Oi("<div>").append(t).html())):n?wr.clone.call(t):t,a)for(var l in a)u.data("$"+l+"Controller",a[l].instance);return I.$$addScopeInfo(u,e),n&&n(u,e),c&&c(e,u,u,r),u}}function P(t){var e=t&&t[0];return e&&"foreignobject"!==H(e)&&e.toString().match(/SVG/)?"svg":"html"}function F(t,e,i,r,o,a){function s(t,i,r,o){var a,s,u,l,c,d,h,f,m;if(p){var v=i.length;for(m=new Array(v),c=0;c<g.length;c+=3)h=g[c],m[h]=i[h]}else m=i;for(c=0,d=g.length;d>c;)u=m[g[c++]],a=g[c++],s=g[c++],a?(a.scope?(l=t.$new(),I.$$addScopeInfo(Oi(u),l)):l=t,f=a.transcludeOnThisElement?W(t,a.transclude,o):!a.templateOnThisElement&&o?o:!o&&e?W(t,e):null,a(s,l,u,r,f)):s&&s(t,u.childNodes,n,o)}for(var u,l,c,d,h,f,p,g=[],m=0;m<t.length;m++)u=new ut,l=z(t[m],[],u,0===m?r:n,o),c=l.length?B(l,t[m],u,e,i,null,[],[],a):null,c&&c.scope&&I.$$addScopeClass(u.$$element),h=c&&c.terminal||!(d=t[m].childNodes)||!d.length?null:F(d,c?(c.transcludeOnThisElement||!c.templateOnThisElement)&&c.transclude:e),(c||h)&&(g.push(m,c,h),f=!0,p=p||c),a=null;return f?s:null}function W(t,e,n){var i=function(i,r,o,a,s){return i||(i=t.$new(!1,s),i.$$transcluded=!0),e(i,r,{parentBoundTranscludeFn:n,transcludeControllers:o,futureParentElement:a})};return i}function z(t,e,n,i,r){var o,a,s=t.nodeType,u=n.$attr;switch(s){case tr:Y(e,he(H(t)),"E",i,r);for(var l,c,d,p,g,m,v=t.attributes,y=0,b=v&&v.length;b>y;y++){var x=!1,_=!1;l=v[y],c=l.name,g=Vi(l.value),p=he(c),(m=pt.test(p))&&(c=c.replace(jr,"").substr(8).replace(/_(.)/g,function(t,e){return e.toUpperCase()}));var k=p.match(gt);k&&G(k[1])&&(x=c,_=c.substr(0,c.length-5)+"end",c=c.substr(0,c.length-6)),d=he(c.toLowerCase()),u[d]=c,(m||!n.hasOwnProperty(d))&&(n[d]=g,Bt(t,d)&&(n[d]=!0)),it(t,e,g,d,m),Y(e,d,"A",i,r,x,_)}if(a=t.className,w(a)&&(a=a.animVal),$(a)&&""!==a)for(;o=f.exec(a);)d=he(o[2]),Y(e,d,"C",i,r)&&(n[d]=Vi(o[3])),a=a.substr(o.index+o[0].length);break;case nr:if(11===Ei)for(;t.parentNode&&t.nextSibling&&t.nextSibling.nodeType===nr;)t.nodeValue=t.nodeValue+t.nextSibling.nodeValue,t.parentNode.removeChild(t.nextSibling);tt(e,t.nodeValue);break;case ir:try{o=h.exec(t.nodeValue),o&&(d=he(o[1]),Y(e,d,"M",i,r)&&(n[d]=Vi(o[2])))}catch(C){}}return e.sort(Z),e}function j(t,e,n){var i=[],r=0;if(e&&t.hasAttribute&&t.hasAttribute(e)){do{if(!t)throw zr("uterdir","Unterminated attribute, found '{0}' but no matching '{1}' found.",e,n);t.nodeType==tr&&(t.hasAttribute(e)&&r++,t.hasAttribute(n)&&r--),i.push(t),t=t.nextSibling}while(r>0)}else i.push(t);return Oi(i)}function U(t,e,n){return function(i,r,o,a,s){return r=j(r[0],e,n),t(i,r,o,a,s)}}function B(t,i,o,a,s,u,l,c,d){function h(t,e,n,i){t&&(n&&(t=U(t,n,i)),t.require=m.require,t.directiveName=y,(A===m||m.$$isolateScope)&&(t=ot(t,{isolateScope:!0})),l.push(t)),e&&(n&&(e=U(e,n,i)),e.require=m.require,e.directiveName=y,(A===m||m.$$isolateScope)&&(e=ot(e,{isolateScope:!0})),c.push(e))}function f(t,e,n,i){var r;if($(e)){var o=e.match(_),a=e.substring(o[0].length),s=o[1]||o[3],u="?"===o[2];if("^^"===s?n=n.parent():(r=i&&i[a],r=r&&r.instance),!r){var l="$"+a+"Controller";r=s?n.inheritedData(l):n.data(l)}if(!r&&!u)throw zr("ctreq","Controller '{0}', required by directive '{1}', can't be found!",a,t)}else if(qi(e)){r=[];for(var c=0,d=e.length;d>c;c++)r[c]=f(t,e[c],n,i)}return r||null}function p(t,e,n,i,r,o){var a=mt();for(var s in i){var u=i[s],l={$scope:u===A||u.$$isolateScope?r:o,$element:t,$attrs:e,$transclude:n},c=u.controller;"@"==c&&(c=e[u.name]);var d=v(c,l,!0,u.controllerAs);a[u.name]=d,t.data("$"+u.name+"Controller",d.instance)}return a}function g(t,e,r,a,s){function u(t,e,i){var r;return T(t)||(i=e,e=t,t=n),F&&(r=m),i||(i=F?y.parent():y),s(t,e,r,i,O)}var d,h,g,m,v,y,b,x,w;i===r?(b=o,y=o.$$element):(y=Oi(r),b=new ut(y,o)),g=e,A?h=e.$new(!0):D&&(g=e.$parent),s&&(v=u,v.$$boundTransclude=s),S&&(m=p(y,b,v,S,h,e)),A&&(I.$$addScopeInfo(y,h,!0,!(E&&(E===A||E===A.$$originalDirective))),I.$$addScopeClass(y,!0),h.$$isolateBindings=A.$$isolateBindings,x=st(e,b,h,h.$$isolateBindings,A),x&&h.$on("$destroy",x));for(var _ in m){var $=S[_],k=m[_],C=$.$$bindings.bindToController;k.identifier&&C&&(w=st(g,b,k.instance,C,$));var M=k();M!==k.instance&&(k.instance=M,y.data("$"+$.name+"Controller",M),w&&w(),w=st(g,b,k.instance,C,$))}for(R=0,B=l.length;B>R;R++)d=l[R],at(d,d.isolateScope?h:e,y,b,d.require&&f(d.directiveName,d.require,y,m),v);var O=e;for(A&&(A.template||null===A.templateUrl)&&(O=h),t&&t(O,r.childNodes,n,s),R=c.length-1;R>=0;R--)d=c[R],at(d,d.isolateScope?h:e,y,b,d.require&&f(d.directiveName,d.require,y,m),v)}d=d||{};for(var m,y,b,x,k,C=-Number.MAX_VALUE,D=d.newScopeDirective,S=d.controllerDirectives,A=d.newIsolateScopeDirective,E=d.templateDirective,O=d.nonTlbTranscludeDirective,N=!1,P=!1,F=d.hasElementTranscludeDirective,W=o.$$element=Oi(i),H=u,L=a,R=0,B=t.length;B>R;R++){m=t[R];var Y=m.$$start,G=m.$$end;
if(Y&&(W=j(i,Y,G)),b=n,C>m.priority)break;if((k=m.scope)&&(m.templateUrl||(w(k)?(J("new/isolated scope",A||D,m,W),A=m):J("new/isolated scope",A,m,W)),D=D||m),y=m.name,!m.templateUrl&&m.controller&&(k=m.controller,S=S||mt(),J("'"+y+"' controller",S[y],m,W),S[y]=m),(k=m.transclude)&&(N=!0,m.$$tlb||(J("transclusion",O,m,W),O=m),"element"==k?(F=!0,C=m.priority,b=W,W=o.$$element=Oi(e.createComment(" "+y+": "+o[y]+" ")),i=W[0],rt(s,q(b),i),L=I(b,a,C,H&&H.name,{nonTlbTranscludeDirective:O})):(b=Oi(At(i)).contents(),W.empty(),L=I(b,a,n,n,{needsNewScope:m.$$isolateScope||m.$$newScope}))),m.template)if(P=!0,J("template",E,m,W),E=m,k=M(m.template)?m.template(W,o):m.template,k=ft(k),m.replace){if(H=m,b=$t(k)?[]:pe(et(m.templateNamespace,Vi(k))),i=b[0],1!=b.length||i.nodeType!==tr)throw zr("tplrt","Template for directive '{0}' must have exactly one root element. {1}",y,"");rt(s,W,i);var Z={$attr:{}},tt=z(i,[],Z),nt=t.splice(R+1,t.length-(R+1));(A||D)&&V(tt,A,D),t=t.concat(tt).concat(nt),X(o,Z),B=t.length}else W.html(k);if(m.templateUrl)P=!0,J("template",E,m,W),E=m,m.replace&&(H=m),g=K(t.splice(R,t.length-R),W,o,s,N&&L,l,c,{controllerDirectives:S,newScopeDirective:D!==m&&D,newIsolateScopeDirective:A,templateDirective:E,nonTlbTranscludeDirective:O}),B=t.length;else if(m.compile)try{x=m.compile(W,o,L),M(x)?h(null,x,Y,G):x&&h(x.pre,x.post,Y,G)}catch(it){r(it,Q(W))}m.terminal&&(g.terminal=!0,C=Math.max(C,m.priority))}return g.scope=D&&D.scope===!0,g.transcludeOnThisElement=N,g.templateOnThisElement=P,g.transclude=L,d.hasElementTranscludeDirective=F,g}function V(t,e,n){for(var i=0,r=t.length;r>i;i++)t[i]=p(t[i],{$$isolateScope:e,$$newScope:n})}function Y(e,n,i,o,s,u,d){if(n===s)return null;var h=null;if(l.hasOwnProperty(n))for(var f,g=t.get(n+c),m=0,v=g.length;v>m;m++)try{if(f=g[m],(b(o)||o>f.priority)&&-1!=f.restrict.indexOf(i)){if(u&&(f=p(f,{$$start:u,$$end:d})),!f.$$bindings){var y=f.$$bindings=a(f,f.name);w(y.isolateScope)&&(f.$$isolateBindings=y.isolateScope)}e.push(f),h=f}}catch(x){r(x)}return h}function G(e){if(l.hasOwnProperty(e))for(var n,i=t.get(e+c),r=0,o=i.length;o>r;r++)if(n=i[r],n.multiElement)return!0;return!1}function X(t,e){var n=e.$attr,i=t.$attr,r=t.$$element;o(t,function(i,r){"$"!=r.charAt(0)&&(e[r]&&e[r]!==i&&(i+=("style"===r?";":" ")+e[r]),t.$set(r,i,!0,n[r]))}),o(e,function(e,o){"class"==o?(O(r,e),t["class"]=(t["class"]?t["class"]+" ":"")+e):"style"==o?(r.attr("style",r.attr("style")+";"+e),t.style=(t.style?t.style+";":"")+e):"$"==o.charAt(0)||t.hasOwnProperty(o)||(t[o]=e,i[o]=n[o])})}function K(t,e,n,i,r,a,u,l){var c,d,h=[],f=e[0],g=t.shift(),m=p(g,{templateUrl:null,transclude:null,replace:null,$$originalDirective:g}),v=M(g.templateUrl)?g.templateUrl(e,n):g.templateUrl,y=g.templateNamespace;return e.empty(),s(v).then(function(s){var p,b,x,_;if(s=ft(s),g.replace){if(x=$t(s)?[]:pe(et(y,Vi(s))),p=x[0],1!=x.length||p.nodeType!==tr)throw zr("tplrt","Template for directive '{0}' must have exactly one root element. {1}",g.name,v);b={$attr:{}},rt(i,e,p);var $=z(p,[],b);w(g.scope)&&V($,!0),t=$.concat(t),X(n,b)}else p=f,e.html(s);for(t.unshift(m),c=B(t,p,n,r,e,g,a,u,l),o(i,function(t,n){t==p&&(i[n]=e[0])}),d=F(e[0].childNodes,r);h.length;){var k=h.shift(),C=h.shift(),M=h.shift(),D=h.shift(),S=e[0];if(!k.$$destroyed){if(C!==f){var T=C.className;l.hasElementTranscludeDirective&&g.replace||(S=At(p)),rt(M,Oi(C),S),O(Oi(S),T)}_=c.transcludeOnThisElement?W(k,c.transclude,D):D,c(d,k,S,i,_)}}h=null}),function(t,e,n,i,r){var o=r;e.$$destroyed||(h?h.push(e,n,i,o):(c.transcludeOnThisElement&&(o=W(e,c.transclude,r)),c(d,e,n,i,o)))}}function Z(t,e){var n=e.priority-t.priority;return 0!==n?n:t.name!==e.name?t.name<e.name?-1:1:t.index-e.index}function J(t,e,n,i){function r(t){return t?" (module: "+t+")":""}if(e)throw zr("multidir","Multiple directives [{0}{1}, {2}{3}] asking for {4} on: {5}",e.name,r(e.$$moduleName),n.name,r(n.$$moduleName),t,Q(i))}function tt(t,e){var n=i(e,!0);n&&t.push({priority:0,compile:function(t){var e=t.parent(),i=!!e.length;return i&&I.$$addBindingClass(e),function(t,e){var r=e.parent();i||I.$$addBindingClass(r),I.$$addBindingInfo(r,n.expressions),t.$watch(n,function(t){e[0].nodeValue=t})}}})}function et(t,n){switch(t=Mi(t||"html")){case"svg":case"math":var i=e.createElement("div");return i.innerHTML="<"+t+">"+n+"</"+t+">",i.childNodes[0].childNodes;default:return n}}function nt(t,e){if("srcdoc"==e)return S.HTML;var n=H(t);return"xlinkHref"==e||"form"==n&&"action"==e||"img"!=n&&("src"==e||"ngSrc"==e)?S.RESOURCE_URL:void 0}function it(t,e,n,r,o){var a=nt(t,r);o=y[r]||o;var s=i(n,!0,a,o);if(s){if("multiple"===r&&"select"===H(t))throw zr("selmulti","Binding to the 'multiple' attribute is not supported. Element: {0}",Q(t));e.push({priority:100,compile:function(){return{pre:function(t,e,u){var l=u.$$observers||(u.$$observers=mt());if(k.test(r))throw zr("nodomevents","Interpolations for HTML DOM event attributes are disallowed.  Please use the ng- versions (such as ng-click instead of onclick) instead.");var c=u[r];c!==n&&(s=c&&i(c,!0,a,o),n=c),s&&(u[r]=s(t),(l[r]||(l[r]=[])).$$inter=!0,(u.$$observers&&u.$$observers[r].$$scope||t).$watch(s,function(t,e){"class"===r&&t!=e?u.$updateClass(t,e):u.$set(r,t)}))}}}})}}function rt(t,n,i){var r,o,a=n[0],s=n.length,u=a.parentNode;if(t)for(r=0,o=t.length;o>r;r++)if(t[r]==a){t[r++]=i;for(var l=r,c=l+s-1,d=t.length;d>l;l++,c++)d>c?t[l]=t[c]:delete t[l];t.length-=s-1,t.context===a&&(t.context=i);break}u&&u.replaceChild(i,a);var h=e.createDocumentFragment();h.appendChild(a),Oi.hasData(a)&&(Oi.data(i,Oi.data(a)),Ni?(Ui=!0,Ni.cleanData([a])):delete Oi.cache[a[Oi.expando]]);for(var f=1,p=n.length;p>f;f++){var g=n[f];Oi(g).remove(),h.appendChild(g),delete n[f]}n[0]=i,n.length=1}function ot(t,e){return d(function(){return t.apply(null,arguments)},t,e)}function at(t,e,n,i,o,a){try{t(e,n,i,o,a)}catch(s){r(s,Q(n))}}function st(t,e,n,r,a){var s=[];return o(r,function(r,o){var l,c,d,h,f=r.attrName,p=r.optional,m=r.mode;switch(m){case"@":p||Di.call(e,f)||(n[o]=e[f]=void 0),e.$observe(f,function(t){$(t)&&(n[o]=t)}),e.$$observers[f].$$scope=t,l=e[f],$(l)?n[o]=i(l)(t):N(l)&&(n[o]=l);break;case"=":if(!Di.call(e,f)){if(p)break;e[f]=void 0}if(p&&!e[f])break;c=u(e[f]),h=c.literal?R:function(t,e){return t===e||t!==t&&e!==e},d=c.assign||function(){throw l=n[o]=c(t),zr("nonassign","Expression '{0}' in attribute '{1}' used with directive '{2}' is non-assignable!",e[f],f,a.name)},l=n[o]=c(t);var v=function(e){return h(e,n[o])||(h(e,l)?d(t,e=n[o]):n[o]=e),l=e};v.$stateful=!0;var y;y=r.collection?t.$watchCollection(e[f],v):t.$watch(u(e[f],v),null,c.literal),s.push(y);break;case"&":if(c=e.hasOwnProperty(f)?u(e[f]):g,c===g&&p)break;n[o]=function(e){return c(t,e)}}}),s.length&&function(){for(var t=0,e=s.length;e>t;++t)s[t]()}}var ut=function(t,e){if(e){var n,i,r,o=Object.keys(e);for(n=0,i=o.length;i>n;n++)r=o[n],this[r]=e[r]}else this.$attr={};this.$$element=t};ut.prototype={$normalize:he,$addClass:function(t){t&&t.length>0&&A.addClass(this.$$element,t)},$removeClass:function(t){t&&t.length>0&&A.removeClass(this.$$element,t)},$updateClass:function(t,e){var n=fe(t,e);n&&n.length&&A.addClass(this.$$element,n);var i=fe(e,t);i&&i.length&&A.removeClass(this.$$element,i)},$set:function(t,e,n,i){var a,s=this.$$element[0],u=Bt(s,t),l=Vt(t),c=t;if(u?(this.$$element.prop(t,e),i=u):l&&(this[l]=e,c=l),this[t]=e,i?this.$attr[t]=i:(i=this.$attr[t],i||(this.$attr[t]=i=lt(t,"-"))),a=H(this.$$element),"a"===a&&"href"===t||"img"===a&&"src"===t)this[t]=e=E(e,"src"===t);else if("img"===a&&"srcset"===t&&x(e)){for(var d="",h=Vi(e),f=/(\s+\d+x\s*,|\s+\d+w\s*,|\s+,|,\s+)/,p=/\s/.test(h)?f:/(,)/,g=h.split(p),m=Math.floor(g.length/2),v=0;m>v;v++){var y=2*v;d+=E(Vi(g[y]),!0),d+=" "+Vi(g[y+1])}var w=Vi(g[2*v]).split(/\s/);d+=E(Vi(w[0]),!0),2===w.length&&(d+=" "+Vi(w[1])),this[t]=e=d}n!==!1&&(null===e||b(e)?this.$$element.removeAttr(i):this.$$element.attr(i,e));var _=this.$$observers;_&&o(_[c],function(t){try{t(e)}catch(n){r(n)}})},$observe:function(t,e){var n=this,i=n.$$observers||(n.$$observers=mt()),r=i[t]||(i[t]=[]);return r.push(e),C.$evalAsync(function(){r.$$inter||!n.hasOwnProperty(t)||b(n[t])||e(n[t])}),function(){L(r,e)}}};var ct=i.startSymbol(),ht=i.endSymbol(),ft="{{"==ct&&"}}"==ht?m:function(t){return t.replace(/\{\{/g,ct).replace(/}}/g,ht)},pt=/^ngAttr[A-Z]/,gt=/^(.+)Start$/;return I.$$addBindingInfo=D?function(t,e){var n=t.data("$binding")||[];qi(e)?n=n.concat(e):n.push(e),t.data("$binding",n)}:g,I.$$addBindingClass=D?function(t){O(t,"ng-binding")}:g,I.$$addScopeInfo=D?function(t,e,n,i){var r=n?i?"$isolateScopeNoTemplate":"$isolateScope":"$scope";t.data(r,e)}:g,I.$$addScopeClass=D?function(t,e){O(t,e?"ng-isolate-scope":"ng-scope")}:g,I}]}function he(t){return _t(t.replace(jr,""))}function fe(t,e){var n="",i=t.split(/\s+/),r=e.split(/\s+/);t:for(var o=0;o<i.length;o++){for(var a=i[o],s=0;s<r.length;s++)if(a==r[s])continue t;n+=(n.length>0?" ":"")+a}return n}function pe(t){t=Oi(t);var e=t.length;if(1>=e)return t;for(;e--;){var n=t[e];n.nodeType===ir&&Fi.call(t,e,1)}return t}function ge(t,e){if(e&&$(e))return e;if($(t)){var n=Ur.exec(t);if(n)return n[3]}}function me(){var t={},e=!1;this.register=function(e,n){ft(e,"controller"),w(e)?d(t,e):t[e]=n},this.allowGlobals=function(){e=!0},this.$get=["$injector","$window",function(r,o){function a(t,e,n,r){if(!t||!w(t.$scope))throw i("$controller")("noscp","Cannot export controller '{0}' as '{1}'! No $scope object provided via `locals`.",r,e);t.$scope[e]=n}return function(i,s,u,l){var c,h,f,p;if(u=u===!0,l&&$(l)&&(p=l),$(i)){if(h=i.match(Ur),!h)throw Rr("ctrlfmt","Badly formed controller string '{0}'. Must match `__name__ as __id__` or `__name__`.",i);f=h[1],p=p||h[3],i=t.hasOwnProperty(f)?t[f]:pt(s.$scope,f,!0)||(e?pt(o,f,!0):n),ht(i,f,!0)}if(u){var g=(qi(i)?i[i.length-1]:i).prototype;c=Object.create(g||null),p&&a(s,p,c,f||i.name);var m;return m=d(function(){var t=r.invoke(i,c,s,f);return t!==c&&(w(t)||M(t))&&(c=t,p&&a(s,p,c,f||i.name)),c},{instance:c,identifier:p})}return c=r.instantiate(i,s,f),p&&a(s,p,c,f||i.name),c}}]}function ve(){this.$get=["$window",function(t){return Oi(t.document)}]}function ye(){this.$get=["$log",function(t){return function(e,n){t.error.apply(t,arguments)}}]}function be(t){return w(t)?C(t)?t.toISOString():Y(t):t}function xe(){this.$get=function(){return function(t){if(!t)return"";var e=[];return a(t,function(t,n){null===t||b(t)||(qi(t)?o(t,function(t,i){e.push(it(n)+"="+it(be(t)))}):e.push(it(n)+"="+it(be(t))))}),e.join("&")}}}function we(){this.$get=function(){return function(t){function e(t,i,r){null===t||b(t)||(qi(t)?o(t,function(t,n){e(t,i+"["+(w(t)?n:"")+"]")}):w(t)&&!C(t)?a(t,function(t,n){e(t,i+(r?"":"[")+n+(r?"":"]"))}):n.push(it(i)+"="+it(be(t))))}if(!t)return"";var n=[];return e(t,"",!0),n.join("&")}}}function _e(t,e){if($(t)){var n=t.replace(Xr,"").trim();if(n){var i=e("Content-Type");(i&&0===i.indexOf(Br)||$e(n))&&(t=G(n))}}return t}function $e(t){var e=t.match(Yr);return e&&Gr[e[0]].test(t)}function ke(t){function e(t,e){t&&(i[t]=i[t]?i[t]+", "+e:e)}var n,i=mt();return $(t)?o(t.split("\n"),function(t){n=t.indexOf(":"),e(Mi(Vi(t.substr(0,n))),Vi(t.substr(n+1)))}):w(t)&&o(t,function(t,n){e(Mi(n),Vi(t))}),i}function Ce(t){var e;return function(n){if(e||(e=ke(t)),n){var i=e[Mi(n)];return void 0===i&&(i=null),i}return e}}function Me(t,e,n,i){return M(i)?i(t,e,n):(o(i,function(i){t=i(t,e,n)}),t)}function De(t){return t>=200&&300>t}function Se(){var t=this.defaults={transformResponse:[_e],transformRequest:[function(t){return!w(t)||A(t)||O(t)||E(t)?t:Y(t)}],headers:{common:{Accept:"application/json, text/plain, */*"},post:j(Vr),put:j(Vr),patch:j(Vr)},xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",paramSerializer:"$httpParamSerializer"},e=!1;this.useApplyAsync=function(t){return x(t)?(e=!!t,this):e};var r=!0;this.useLegacyPromiseExtensions=function(t){return x(t)?(r=!!t,this):r};var a=this.interceptors=[];this.$get=["$httpBackend","$$cookieReader","$cacheFactory","$rootScope","$q","$injector",function(s,u,l,c,h,f){function p(e){function a(t){var e=d({},t);return e.data=Me(t.data,t.headers,t.status,l.transformResponse),De(t.status)?e:h.reject(e)}function s(t,e){var n,i={};return o(t,function(t,r){M(t)?(n=t(e),null!=n&&(i[r]=n)):i[r]=t}),i}function u(e){var n,i,r,o=t.headers,a=d({},e.headers);o=d({},o.common,o[Mi(e.method)]);t:for(n in o){i=Mi(n);for(r in a)if(Mi(r)===i)continue t;a[n]=o[n]}return s(a,j(e))}if(!ji.isObject(e))throw i("$http")("badreq","Http request configuration must be an object.  Received: {0}",e);if(!$(e.url))throw i("$http")("badreq","Http request configuration url must be a string.  Received: {0}",e.url);var l=d({method:"get",transformRequest:t.transformRequest,transformResponse:t.transformResponse,paramSerializer:t.paramSerializer},e);l.headers=u(e),l.method=Si(l.method),l.paramSerializer=$(l.paramSerializer)?f.get(l.paramSerializer):l.paramSerializer;var c=function(e){var i=e.headers,r=Me(e.data,Ce(i),n,e.transformRequest);return b(r)&&o(i,function(t,e){"content-type"===Mi(e)&&delete i[e]}),b(e.withCredentials)&&!b(t.withCredentials)&&(e.withCredentials=t.withCredentials),v(e,r).then(a,a)},p=[c,n],g=h.when(l);for(o(k,function(t){(t.request||t.requestError)&&p.unshift(t.request,t.requestError),(t.response||t.responseError)&&p.push(t.response,t.responseError)});p.length;){var m=p.shift(),y=p.shift();g=g.then(m,y)}return r?(g.success=function(t){return ht(t,"fn"),g.then(function(e){t(e.data,e.status,e.headers,l)}),g},g.error=function(t){return ht(t,"fn"),g.then(null,function(e){t(e.data,e.status,e.headers,l)}),g}):(g.success=Zr("success"),g.error=Zr("error")),g}function g(t){o(arguments,function(t){p[t]=function(e,n){return p(d({},n||{},{method:t,url:e}))}})}function m(t){o(arguments,function(t){p[t]=function(e,n,i){return p(d({},i||{},{method:t,url:e,data:n}))}})}function v(i,r){function o(t,n,i,r){function o(){a(n,t,i,r)}f&&(De(t)?f.put(k,[t,n,ke(i),r]):f.remove(k)),e?c.$applyAsync(o):(o(),c.$$phase||c.$apply())}function a(t,e,n,r){e=e>=-1?e:0,(De(e)?m.resolve:m.reject)({data:t,status:e,headers:Ce(n),config:i,statusText:r})}function l(t){a(t.data,t.status,j(t.headers()),t.statusText)}function d(){var t=p.pendingRequests.indexOf(i);-1!==t&&p.pendingRequests.splice(t,1)}var f,g,m=h.defer(),v=m.promise,$=i.headers,k=y(i.url,i.paramSerializer(i.params));if(p.pendingRequests.push(i),v.then(d,d),!i.cache&&!t.cache||i.cache===!1||"GET"!==i.method&&"JSONP"!==i.method||(f=w(i.cache)?i.cache:w(t.cache)?t.cache:_),f&&(g=f.get(k),x(g)?I(g)?g.then(l,l):qi(g)?a(g[1],g[0],j(g[2]),g[3]):a(g,200,{},"OK"):f.put(k,v)),b(g)){var C=An(i.url)?u()[i.xsrfCookieName||t.xsrfCookieName]:n;C&&($[i.xsrfHeaderName||t.xsrfHeaderName]=C),s(i.method,k,r,o,$,i.timeout,i.withCredentials,i.responseType)}return v}function y(t,e){return e.length>0&&(t+=(-1==t.indexOf("?")?"?":"&")+e),t}var _=l("$http");t.paramSerializer=$(t.paramSerializer)?f.get(t.paramSerializer):t.paramSerializer;var k=[];return o(a,function(t){k.unshift($(t)?f.get(t):f.invoke(t))}),p.pendingRequests=[],g("get","delete","head","jsonp"),m("post","put","patch"),p.defaults=t,p}]}function Te(){this.$get=function(){return function(){return new t.XMLHttpRequest}}}function Ae(){this.$get=["$browser","$window","$document","$xhrFactory",function(t,e,n,i){return Ee(t,i,t.defer,e.angular.callbacks,n[0])}]}function Ee(t,e,n,i,r){function a(t,e,n){var o=r.createElement("script"),a=null;return o.type="text/javascript",o.src=t,o.async=!0,a=function(t){cr(o,"load",a),cr(o,"error",a),r.body.removeChild(o),o=null;var s=-1,u="unknown";t&&("load"!==t.type||i[e].called||(t={type:"error"}),u=t.type,s="error"===t.type?404:200),n&&n(s,u)},lr(o,"load",a),lr(o,"error",a),r.body.appendChild(o),a}return function(r,s,u,l,c,d,h,f){function p(){y&&y(),w&&w.abort()}function m(e,i,r,o,a){x(k)&&n.cancel(k),y=w=null,e(i,r,o,a),t.$$completeOutstandingRequest(g)}if(t.$$incOutstandingRequestCount(),s=s||t.url(),"jsonp"==Mi(r)){var v="_"+(i.counter++).toString(36);i[v]=function(t){i[v].data=t,i[v].called=!0};var y=a(s.replace("JSON_CALLBACK","angular.callbacks."+v),v,function(t,e){m(l,t,i[v].data,"",e),i[v]=g})}else{var w=e(r,s);w.open(r,s,!0),o(c,function(t,e){x(t)&&w.setRequestHeader(e,t)}),w.onload=function(){var t=w.statusText||"",e="response"in w?w.response:w.responseText,n=1223===w.status?204:w.status;0===n&&(n=e?200:"file"==Tn(s).protocol?404:0),m(l,n,e,w.getAllResponseHeaders(),t)};var _=function(){m(l,-1,null,null,"")};if(w.onerror=_,w.onabort=_,h&&(w.withCredentials=!0),f)try{w.responseType=f}catch($){if("json"!==f)throw $}w.send(b(u)?null:u)}if(d>0)var k=n(p,d);else I(d)&&d.then(p)}}function Oe(){var t="{{",e="}}";this.startSymbol=function(e){return e?(t=e,this):t},this.endSymbol=function(t){return t?(e=t,this):e},this.$get=["$parse","$exceptionHandler","$sce",function(n,i,r){function o(t){return"\\\\\\"+t}function a(n){return n.replace(h,t).replace(f,e)}function s(t){if(null==t)return"";switch(typeof t){case"string":break;case"number":t=""+t;break;default:t=Y(t)}return t}function u(o,u,h,f){function p(t){try{return t=S(t),f&&!x(t)?t:s(t)}catch(e){i(Qr.interr(o,e))}}f=!!f;for(var g,m,v,y=0,w=[],_=[],$=o.length,k=[],C=[];$>y;){if(-1==(g=o.indexOf(t,y))||-1==(m=o.indexOf(e,g+l))){y!==$&&k.push(a(o.substring(y)));break}y!==g&&k.push(a(o.substring(y,g))),v=o.substring(g+l,m),w.push(v),_.push(n(v,p)),y=m+c,C.push(k.length),k.push("")}if(h&&k.length>1&&Qr.throwNoconcat(o),!u||w.length){var D=function(t){for(var e=0,n=w.length;n>e;e++){if(f&&b(t[e]))return;k[C[e]]=t[e]}return k.join("")},S=function(t){return h?r.getTrusted(h,t):r.valueOf(t)};return d(function(t){var e=0,n=w.length,r=new Array(n);try{for(;n>e;e++)r[e]=_[e](t);return D(r)}catch(a){i(Qr.interr(o,a))}},{exp:o,expressions:w,$$watchDelegate:function(t,e){var n;return t.$watchGroup(_,function(i,r){var o=D(i);M(e)&&e.call(this,o,i!==r?n:o,t),n=o})}})}}var l=t.length,c=e.length,h=new RegExp(t.replace(/./g,o),"g"),f=new RegExp(e.replace(/./g,o),"g");return u.startSymbol=function(){return t},u.endSymbol=function(){return e},u}]}function Ne(){this.$get=["$rootScope","$window","$q","$$q",function(t,e,n,i){function r(r,a,s,u){var l=arguments.length>4,c=l?q(arguments,4):[],d=e.setInterval,h=e.clearInterval,f=0,p=x(u)&&!u,g=(p?i:n).defer(),m=g.promise;return s=x(s)?s:0,m.then(null,null,l?function(){r.apply(null,c)}:r),m.$$intervalId=d(function(){g.notify(f++),s>0&&f>=s&&(g.resolve(f),h(m.$$intervalId),delete o[m.$$intervalId]),p||t.$apply()},a),o[m.$$intervalId]=g,m}var o={};return r.cancel=function(t){return t&&t.$$intervalId in o?(o[t.$$intervalId].reject("canceled"),e.clearInterval(t.$$intervalId),delete o[t.$$intervalId],!0):!1},r}]}function Ie(t){for(var e=t.split("/"),n=e.length;n--;)e[n]=nt(e[n]);return e.join("/")}function Pe(t,e){var n=Tn(t);e.$$protocol=n.protocol,e.$$host=n.hostname,e.$$port=f(n.port)||to[n.protocol]||null}function Fe(t,e){var n="/"!==t.charAt(0);n&&(t="/"+t);var i=Tn(t);e.$$path=decodeURIComponent(n&&"/"===i.pathname.charAt(0)?i.pathname.substring(1):i.pathname),e.$$search=tt(i.search),e.$$hash=decodeURIComponent(i.hash),e.$$path&&"/"!=e.$$path.charAt(0)&&(e.$$path="/"+e.$$path)}function We(t,e){return 0===e.indexOf(t)?e.substr(t.length):void 0}function He(t){var e=t.indexOf("#");return-1==e?t:t.substr(0,e)}function Le(t){return t.replace(/(#.+)|#$/,"$1")}function ze(t){return t.substr(0,He(t).lastIndexOf("/")+1)}function je(t){return t.substring(0,t.indexOf("/",t.indexOf("//")+2))}function Re(t,e,n){this.$$html5=!0,n=n||"",Pe(t,this),this.$$parse=function(t){var n=We(e,t);if(!$(n))throw eo("ipthprfx",'Invalid url "{0}", missing path prefix "{1}".',t,e);Fe(n,this),this.$$path||(this.$$path="/"),this.$$compose()},this.$$compose=function(){var t=et(this.$$search),n=this.$$hash?"#"+nt(this.$$hash):"";this.$$url=Ie(this.$$path)+(t?"?"+t:"")+n,this.$$absUrl=e+this.$$url.substr(1)},this.$$parseLinkUrl=function(i,r){if(r&&"#"===r[0])return this.hash(r.slice(1)),!0;var o,a,s;return x(o=We(t,i))?(a=o,s=x(o=We(n,o))?e+(We("/",o)||o):t+a):x(o=We(e,i))?s=e+o:e==i+"/"&&(s=e),s&&this.$$parse(s),!!s}}function Ue(t,e,n){Pe(t,this),this.$$parse=function(i){function r(t,e,n){var i,r=/^\/[A-Z]:(\/.*)/;return 0===e.indexOf(n)&&(e=e.replace(n,"")),r.exec(e)?t:(i=r.exec(t),i?i[1]:t)}var o,a=We(t,i)||We(e,i);b(a)||"#"!==a.charAt(0)?this.$$html5?o=a:(o="",b(a)&&(t=i,this.replace())):(o=We(n,a),b(o)&&(o=a)),Fe(o,this),this.$$path=r(this.$$path,o,t),this.$$compose()},this.$$compose=function(){var e=et(this.$$search),i=this.$$hash?"#"+nt(this.$$hash):"";this.$$url=Ie(this.$$path)+(e?"?"+e:"")+i,this.$$absUrl=t+(this.$$url?n+this.$$url:"")},this.$$parseLinkUrl=function(e,n){return He(t)==He(e)?(this.$$parse(e),!0):!1}}function qe(t,e,n){this.$$html5=!0,Ue.apply(this,arguments),this.$$parseLinkUrl=function(i,r){if(r&&"#"===r[0])return this.hash(r.slice(1)),!0;var o,a;return t==He(i)?o=i:(a=We(e,i))?o=t+n+a:e===i+"/"&&(o=e),o&&this.$$parse(o),!!o},this.$$compose=function(){var e=et(this.$$search),i=this.$$hash?"#"+nt(this.$$hash):"";this.$$url=Ie(this.$$path)+(e?"?"+e:"")+i,this.$$absUrl=t+n+this.$$url}}function Be(t){return function(){return this[t]}}function Ve(t,e){return function(n){return b(n)?this[t]:(this[t]=e(n),this.$$compose(),this)}}function Ye(){var t="",e={enabled:!1,requireBase:!0,rewriteLinks:!0};this.hashPrefix=function(e){return x(e)?(t=e,this):t},this.html5Mode=function(t){return N(t)?(e.enabled=t,this):w(t)?(N(t.enabled)&&(e.enabled=t.enabled),N(t.requireBase)&&(e.requireBase=t.requireBase),N(t.rewriteLinks)&&(e.rewriteLinks=t.rewriteLinks),this):e},this.$get=["$rootScope","$browser","$sniffer","$rootElement","$window",function(n,i,r,o,a){function s(t,e,n){var r=l.url(),o=l.$$state;try{i.url(t,e,n),l.$$state=i.state()}catch(a){throw l.url(r),l.$$state=o,a}}function u(t,e){n.$broadcast("$locationChangeSuccess",l.absUrl(),t,l.$$state,e)}var l,c,d,h=i.baseHref(),f=i.url();if(e.enabled){if(!h&&e.requireBase)throw eo("nobase","$location in HTML5 mode requires a <base> tag to be present!");d=je(f)+(h||"/"),c=r.history?Re:qe}else d=He(f),c=Ue;var p=ze(d);l=new c(d,p,"#"+t),l.$$parseLinkUrl(f,f),l.$$state=i.state();var g=/^\s*(javascript|mailto):/i;o.on("click",function(t){if(e.rewriteLinks&&!t.ctrlKey&&!t.metaKey&&!t.shiftKey&&2!=t.which&&2!=t.button){for(var r=Oi(t.target);"a"!==H(r[0]);)if(r[0]===o[0]||!(r=r.parent())[0])return;var s=r.prop("href"),u=r.attr("href")||r.attr("xlink:href");w(s)&&"[object SVGAnimatedString]"===s.toString()&&(s=Tn(s.animVal).href),g.test(s)||!s||r.attr("target")||t.isDefaultPrevented()||l.$$parseLinkUrl(s,u)&&(t.preventDefault(),l.absUrl()!=i.url()&&(n.$apply(),a.angular["ff-684208-preventDefault"]=!0))}}),Le(l.absUrl())!=Le(f)&&i.url(l.absUrl(),!0);var m=!0;return i.onUrlChange(function(t,e){return b(We(p,t))?void(a.location.href=t):(n.$evalAsync(function(){var i,r=l.absUrl(),o=l.$$state;t=Le(t),l.$$parse(t),l.$$state=e,i=n.$broadcast("$locationChangeStart",t,r,e,o).defaultPrevented,l.absUrl()===t&&(i?(l.$$parse(r),l.$$state=o,s(r,!1,o)):(m=!1,u(r,o)))}),void(n.$$phase||n.$digest()))}),n.$watch(function(){var t=Le(i.url()),e=Le(l.absUrl()),o=i.state(),a=l.$$replace,c=t!==e||l.$$html5&&r.history&&o!==l.$$state;(m||c)&&(m=!1,n.$evalAsync(function(){var e=l.absUrl(),i=n.$broadcast("$locationChangeStart",e,t,l.$$state,o).defaultPrevented;l.absUrl()===e&&(i?(l.$$parse(t),l.$$state=o):(c&&s(e,a,o===l.$$state?null:l.$$state),u(t,o)))})),l.$$replace=!1}),l}]}function Ge(){var t=!0,e=this;this.debugEnabled=function(e){return x(e)?(t=e,this):t},this.$get=["$window",function(n){function i(t){return t instanceof Error&&(t.stack?t=t.message&&-1===t.stack.indexOf(t.message)?"Error: "+t.message+"\n"+t.stack:t.stack:t.sourceURL&&(t=t.message+"\n"+t.sourceURL+":"+t.line)),t}function r(t){var e=n.console||{},r=e[t]||e.log||g,a=!1;try{a=!!r.apply}catch(s){}return a?function(){var t=[];return o(arguments,function(e){t.push(i(e))}),r.apply(e,t)}:function(t,e){r(t,null==e?"":e)}}return{log:r("log"),info:r("info"),warn:r("warn"),error:r("error"),debug:function(){var n=r("debug");return function(){t&&n.apply(e,arguments)}}()}}]}function Xe(t,e){if("__defineGetter__"===t||"__defineSetter__"===t||"__lookupGetter__"===t||"__lookupSetter__"===t||"__proto__"===t)throw io("isecfld","Attempting to access a disallowed field in Angular expressions! Expression: {0}",e);return t}function Ke(t,e){if(t+="",!$(t))throw io("iseccst","Cannot convert object to primitive value! Expression: {0}",e);return t}function Ze(t,e){if(t){if(t.constructor===t)throw io("isecfn","Referencing Function in Angular expressions is disallowed! Expression: {0}",e);if(t.window===t)throw io("isecwindow","Referencing the Window in Angular expressions is disallowed! Expression: {0}",e);if(t.children&&(t.nodeName||t.prop&&t.attr&&t.find))throw io("isecdom","Referencing DOM nodes in Angular expressions is disallowed! Expression: {0}",e);if(t===Object)throw io("isecobj","Referencing Object in Angular expressions is disallowed! Expression: {0}",e)}return t}function Qe(t,e){if(t){if(t.constructor===t)throw io("isecfn","Referencing Function in Angular expressions is disallowed! Expression: {0}",e);if(t===ro||t===oo||t===ao)throw io("isecff","Referencing call, apply or bind in Angular expressions is disallowed! Expression: {0}",e)}}function Je(t,e){if(t&&(t===0..constructor||t===(!1).constructor||t==="".constructor||t==={}.constructor||t===[].constructor||t===Function.constructor))throw io("isecaf","Assigning to a constructor is disallowed! Expression: {0}",e)}function tn(t,e){return"undefined"!=typeof t?t:e}function en(t,e){return"undefined"==typeof t?e:"undefined"==typeof e?t:t+e}function nn(t,e){var n=t(e);return!n.$stateful}function rn(t,e){var n,i;switch(t.type){case co.Program:n=!0,o(t.body,function(t){rn(t.expression,e),n=n&&t.expression.constant}),t.constant=n;break;case co.Literal:t.constant=!0,t.toWatch=[];break;case co.UnaryExpression:rn(t.argument,e),t.constant=t.argument.constant,t.toWatch=t.argument.toWatch;break;case co.BinaryExpression:rn(t.left,e),rn(t.right,e),t.constant=t.left.constant&&t.right.constant,t.toWatch=t.left.toWatch.concat(t.right.toWatch);break;case co.LogicalExpression:rn(t.left,e),rn(t.right,e),t.constant=t.left.constant&&t.right.constant,t.toWatch=t.constant?[]:[t];break;case co.ConditionalExpression:rn(t.test,e),rn(t.alternate,e),rn(t.consequent,e),t.constant=t.test.constant&&t.alternate.constant&&t.consequent.constant,t.toWatch=t.constant?[]:[t];break;case co.Identifier:t.constant=!1,t.toWatch=[t];break;case co.MemberExpression:rn(t.object,e),t.computed&&rn(t.property,e),t.constant=t.object.constant&&(!t.computed||t.property.constant),t.toWatch=[t];break;case co.CallExpression:n=t.filter?nn(e,t.callee.name):!1,i=[],o(t.arguments,function(t){rn(t,e),n=n&&t.constant,t.constant||i.push.apply(i,t.toWatch)}),t.constant=n,t.toWatch=t.filter&&nn(e,t.callee.name)?i:[t];break;case co.AssignmentExpression:rn(t.left,e),rn(t.right,e),t.constant=t.left.constant&&t.right.constant,t.toWatch=[t];break;case co.ArrayExpression:n=!0,i=[],o(t.elements,function(t){rn(t,e),n=n&&t.constant,t.constant||i.push.apply(i,t.toWatch)}),t.constant=n,t.toWatch=i;break;case co.ObjectExpression:n=!0,i=[],o(t.properties,function(t){rn(t.value,e),n=n&&t.value.constant,t.value.constant||i.push.apply(i,t.value.toWatch)}),t.constant=n,t.toWatch=i;break;case co.ThisExpression:t.constant=!1,t.toWatch=[]}}function on(t){if(1==t.length){var e=t[0].expression,i=e.toWatch;return 1!==i.length?i:i[0]!==e?i:n}}function an(t){return t.type===co.Identifier||t.type===co.MemberExpression}function sn(t){return 1===t.body.length&&an(t.body[0].expression)?{type:co.AssignmentExpression,left:t.body[0].expression,right:{type:co.NGValueParameter},operator:"="}:void 0}function un(t){return 0===t.body.length||1===t.body.length&&(t.body[0].expression.type===co.Literal||t.body[0].expression.type===co.ArrayExpression||t.body[0].expression.type===co.ObjectExpression)}function ln(t){return t.constant}function cn(t,e){this.astBuilder=t,this.$filter=e}function dn(t,e){this.astBuilder=t,this.$filter=e}function hn(t){return"constructor"==t}function fn(t){return M(t.valueOf)?t.valueOf():fo.call(t)}function pn(){var t=mt(),e=mt();this.$get=["$filter",function(i){function r(n,r,o){var s,f,y;switch(o=o||v,typeof n){case"string":n=n.trim(),y=n;var b=o?e:t;if(s=b[y],!s){":"===n.charAt(0)&&":"===n.charAt(1)&&(f=!0,n=n.substring(2));var x=o?m:p,w=new lo(x),_=new ho(w,i,x);s=_.parse(n),s.constant?s.$$watchDelegate=d:f?s.$$watchDelegate=s.literal?c:l:s.inputs&&(s.$$watchDelegate=u),o&&(s=a(s)),b[y]=s}return h(s,r);case"function":return h(n,r);default:return h(g,r)}}function a(t){function e(e,n,i,r){var o=v;v=!0;try{return t(e,n,i,r)}finally{v=o}}if(!t)return t;e.$$watchDelegate=t.$$watchDelegate,e.assign=a(t.assign),e.constant=t.constant,e.literal=t.literal;for(var n=0;t.inputs&&n<t.inputs.length;++n)t.inputs[n]=a(t.inputs[n]);return e.inputs=t.inputs,e}function s(t,e){return null==t||null==e?t===e:"object"==typeof t&&(t=fn(t),"object"==typeof t)?!1:t===e||t!==t&&e!==e}function u(t,e,i,r,o){var a,u=r.inputs;if(1===u.length){var l=s;return u=u[0],t.$watch(function(t){var e=u(t);return s(e,l)||(a=r(t,n,n,[e]),l=e&&fn(e)),a},e,i,o)}for(var c=[],d=[],h=0,f=u.length;f>h;h++)c[h]=s,d[h]=null;return t.$watch(function(t){for(var e=!1,i=0,o=u.length;o>i;i++){var l=u[i](t);(e||(e=!s(l,c[i])))&&(d[i]=l,c[i]=l&&fn(l))}return e&&(a=r(t,n,n,d)),a},e,i,o)}function l(t,e,n,i){var r,o;return r=t.$watch(function(t){return i(t)},function(t,n,i){o=t,M(e)&&e.apply(this,arguments),x(t)&&i.$$postDigest(function(){x(o)&&r()})},n)}function c(t,e,n,i){function r(t){var e=!0;return o(t,function(t){x(t)||(e=!1)}),e}var a,s;return a=t.$watch(function(t){return i(t)},function(t,n,i){s=t,M(e)&&e.call(this,t,n,i),r(t)&&i.$$postDigest(function(){r(s)&&a()})},n)}function d(t,e,n,i){var r;return r=t.$watch(function(t){return i(t)},function(t,n,i){M(e)&&e.apply(this,arguments),r()},n)}function h(t,e){if(!e)return t;var n=t.$$watchDelegate,i=!1,r=n!==c&&n!==l,o=r?function(n,r,o,a){var s=i&&a?a[0]:t(n,r,o,a);return e(s,n,r)}:function(n,i,r,o){var a=t(n,i,r,o),s=e(a,n,i);return x(a)?s:a};return t.$$watchDelegate&&t.$$watchDelegate!==u?o.$$watchDelegate=t.$$watchDelegate:e.$stateful||(o.$$watchDelegate=u,i=!t.inputs,o.inputs=t.inputs?t.inputs:[t]),o}var f=Gi().noUnsafeEval,p={csp:f,expensiveChecks:!1},m={csp:f,expensiveChecks:!0},v=!1;return r.$$runningExpensiveChecks=function(){return v},r}]}function gn(){this.$get=["$rootScope","$exceptionHandler",function(t,e){return vn(function(e){t.$evalAsync(e)},e)}]}function mn(){this.$get=["$browser","$exceptionHandler",function(t,e){return vn(function(e){t.defer(e)},e)}]}function vn(t,e){function r(t,e,n){function i(e){return function(n){r||(r=!0,e.call(t,n))}}var r=!1;return[i(e),i(n)]}function a(){this.$$state={status:0}}function s(t,e){return function(n){e.call(t,n)}}function u(t){var i,r,o;o=t.pending,t.processScheduled=!1,t.pending=n;for(var a=0,s=o.length;s>a;++a){r=o[a][0],i=o[a][t.status];try{M(i)?r.resolve(i(t.value)):1===t.status?r.resolve(t.value):r.reject(t.value)}catch(u){r.reject(u),e(u)}}}function l(e){!e.processScheduled&&e.pending&&(e.processScheduled=!0,t(function(){u(e)}))}function c(){this.promise=new a,this.resolve=s(this,this.resolve),this.reject=s(this,this.reject),this.notify=s(this,this.notify)}function h(t){var e=new c,n=0,i=qi(t)?[]:{};return o(t,function(t,r){n++,y(t).then(function(t){i.hasOwnProperty(r)||(i[r]=t,--n||e.resolve(i))},function(t){i.hasOwnProperty(r)||e.reject(t)})}),0===n&&e.resolve(i),e.promise}var f=i("$q",TypeError),p=function(){return new c};d(a.prototype,{then:function(t,e,n){if(b(t)&&b(e)&&b(n))return this;var i=new c;return this.$$state.pending=this.$$state.pending||[],this.$$state.pending.push([i,t,e,n]),this.$$state.status>0&&l(this.$$state),i.promise},"catch":function(t){return this.then(null,t)},"finally":function(t,e){return this.then(function(e){return v(e,!0,t)},function(e){return v(e,!1,t)},e)}}),d(c.prototype,{resolve:function(t){this.promise.$$state.status||(t===this.promise?this.$$reject(f("qcycle","Expected promise to be resolved with value other than itself '{0}'",t)):this.$$resolve(t));
},$$resolve:function(t){var n,i;i=r(this,this.$$resolve,this.$$reject);try{(w(t)||M(t))&&(n=t&&t.then),M(n)?(this.promise.$$state.status=-1,n.call(t,i[0],i[1],this.notify)):(this.promise.$$state.value=t,this.promise.$$state.status=1,l(this.promise.$$state))}catch(o){i[1](o),e(o)}},reject:function(t){this.promise.$$state.status||this.$$reject(t)},$$reject:function(t){this.promise.$$state.value=t,this.promise.$$state.status=2,l(this.promise.$$state)},notify:function(n){var i=this.promise.$$state.pending;this.promise.$$state.status<=0&&i&&i.length&&t(function(){for(var t,r,o=0,a=i.length;a>o;o++){r=i[o][0],t=i[o][3];try{r.notify(M(t)?t(n):n)}catch(s){e(s)}}})}});var g=function(t){var e=new c;return e.reject(t),e.promise},m=function(t,e){var n=new c;return e?n.resolve(t):n.reject(t),n.promise},v=function(t,e,n){var i=null;try{M(n)&&(i=n())}catch(r){return m(r,!1)}return I(i)?i.then(function(){return m(t,e)},function(t){return m(t,!1)}):m(t,e)},y=function(t,e,n,i){var r=new c;return r.resolve(t),r.promise.then(e,n,i)},x=y,_=function $(t){function e(t){i.resolve(t)}function n(t){i.reject(t)}if(!M(t))throw f("norslvr","Expected resolverFn, got '{0}'",t);if(!(this instanceof $))return new $(t);var i=new c;return t(e,n),i.promise};return _.defer=p,_.reject=g,_.when=y,_.resolve=x,_.all=h,_}function yn(){this.$get=["$window","$timeout",function(t,e){var n=t.requestAnimationFrame||t.webkitRequestAnimationFrame,i=t.cancelAnimationFrame||t.webkitCancelAnimationFrame||t.webkitCancelRequestAnimationFrame,r=!!n,o=r?function(t){var e=n(t);return function(){i(e)}}:function(t){var n=e(t,16.66,!1);return function(){e.cancel(n)}};return o.supported=r,o}]}function bn(){function t(t){function e(){this.$$watchers=this.$$nextSibling=this.$$childHead=this.$$childTail=null,this.$$listeners={},this.$$listenerCount={},this.$$watchersCount=0,this.$id=u(),this.$$ChildScope=null}return e.prototype=t,e}var e=10,n=i("$rootScope"),a=null,s=null;this.digestTtl=function(t){return arguments.length&&(e=t),e},this.$get=["$injector","$exceptionHandler","$parse","$browser",function(i,l,c,d){function h(t){t.currentScope.$$destroyed=!0}function f(t){9===Ei&&(t.$$childHead&&f(t.$$childHead),t.$$nextSibling&&f(t.$$nextSibling)),t.$parent=t.$$nextSibling=t.$$prevSibling=t.$$childHead=t.$$childTail=t.$root=t.$$watchers=null}function p(){this.$id=u(),this.$$phase=this.$parent=this.$$watchers=this.$$nextSibling=this.$$prevSibling=this.$$childHead=this.$$childTail=null,this.$root=this,this.$$destroyed=!1,this.$$listeners={},this.$$listenerCount={},this.$$watchersCount=0,this.$$isolateBindings=null}function m(t){if(C.$$phase)throw n("inprog","{0} already in progress",C.$$phase);C.$$phase=t}function v(){C.$$phase=null}function y(t,e){do t.$$watchersCount+=e;while(t=t.$parent)}function x(t,e,n){do t.$$listenerCount[n]-=e,0===t.$$listenerCount[n]&&delete t.$$listenerCount[n];while(t=t.$parent)}function _(){}function $(){for(;T.length;)try{T.shift()()}catch(t){l(t)}s=null}function k(){null===s&&(s=d.defer(function(){C.$apply($)}))}p.prototype={constructor:p,$new:function(e,n){var i;return n=n||this,e?(i=new p,i.$root=this.$root):(this.$$ChildScope||(this.$$ChildScope=t(this)),i=new this.$$ChildScope),i.$parent=n,i.$$prevSibling=n.$$childTail,n.$$childHead?(n.$$childTail.$$nextSibling=i,n.$$childTail=i):n.$$childHead=n.$$childTail=i,(e||n!=this)&&i.$on("$destroy",h),i},$watch:function(t,e,n,i){var r=c(t);if(r.$$watchDelegate)return r.$$watchDelegate(this,e,n,r,t);var o=this,s=o.$$watchers,u={fn:e,last:_,get:r,exp:i||t,eq:!!n};return a=null,M(e)||(u.fn=g),s||(s=o.$$watchers=[]),s.unshift(u),y(this,1),function(){L(s,u)>=0&&y(o,-1),a=null}},$watchGroup:function(t,e){function n(){u=!1,l?(l=!1,e(r,r,s)):e(r,i,s)}var i=new Array(t.length),r=new Array(t.length),a=[],s=this,u=!1,l=!0;if(!t.length){var c=!0;return s.$evalAsync(function(){c&&e(r,r,s)}),function(){c=!1}}return 1===t.length?this.$watch(t[0],function(t,n,o){r[0]=t,i[0]=n,e(r,t===n?r:i,o)}):(o(t,function(t,e){var o=s.$watch(t,function(t,o){r[e]=t,i[e]=o,u||(u=!0,s.$evalAsync(n))});a.push(o)}),function(){for(;a.length;)a.shift()()})},$watchCollection:function(t,e){function n(t){o=t;var e,n,i,s,u;if(!b(o)){if(w(o))if(r(o)){a!==f&&(a=f,m=a.length=0,d++),e=o.length,m!==e&&(d++,a.length=m=e);for(var l=0;e>l;l++)u=a[l],s=o[l],i=u!==u&&s!==s,i||u===s||(d++,a[l]=s)}else{a!==p&&(a=p={},m=0,d++),e=0;for(n in o)Di.call(o,n)&&(e++,s=o[n],u=a[n],n in a?(i=u!==u&&s!==s,i||u===s||(d++,a[n]=s)):(m++,a[n]=s,d++));if(m>e){d++;for(n in a)Di.call(o,n)||(m--,delete a[n])}}else a!==o&&(a=o,d++);return d}}function i(){if(g?(g=!1,e(o,o,u)):e(o,s,u),l)if(w(o))if(r(o)){s=new Array(o.length);for(var t=0;t<o.length;t++)s[t]=o[t]}else{s={};for(var n in o)Di.call(o,n)&&(s[n]=o[n])}else s=o}n.$stateful=!0;var o,a,s,u=this,l=e.length>1,d=0,h=c(t,n),f=[],p={},g=!0,m=0;return this.$watch(h,i)},$digest:function(){var t,i,r,o,u,c,h,f,p,g,y,b,x=e,w=this,k=[];m("$digest"),d.$$checkUrlChange(),this===C&&null!==s&&(d.defer.cancel(s),$()),a=null;do{for(f=!1,g=w;D.length;){try{b=D.shift(),b.scope.$eval(b.expression,b.locals)}catch(T){l(T)}a=null}t:do{if(c=g.$$watchers)for(h=c.length;h--;)try{if(t=c[h])if(u=t.get,(i=u(g))===(r=t.last)||(t.eq?R(i,r):"number"==typeof i&&"number"==typeof r&&isNaN(i)&&isNaN(r))){if(t===a){f=!1;break t}}else f=!0,a=t,t.last=t.eq?z(i,null):i,o=t.fn,o(i,r===_?i:r,g),5>x&&(y=4-x,k[y]||(k[y]=[]),k[y].push({msg:M(t.exp)?"fn: "+(t.exp.name||t.exp.toString()):t.exp,newVal:i,oldVal:r}))}catch(T){l(T)}if(!(p=g.$$watchersCount&&g.$$childHead||g!==w&&g.$$nextSibling))for(;g!==w&&!(p=g.$$nextSibling);)g=g.$parent}while(g=p);if((f||D.length)&&!x--)throw v(),n("infdig","{0} $digest() iterations reached. Aborting!\nWatchers fired in the last 5 iterations: {1}",e,k)}while(f||D.length);for(v();S.length;)try{S.shift()()}catch(T){l(T)}},$destroy:function(){if(!this.$$destroyed){var t=this.$parent;this.$broadcast("$destroy"),this.$$destroyed=!0,this===C&&d.$$applicationDestroyed(),y(this,-this.$$watchersCount);for(var e in this.$$listenerCount)x(this,this.$$listenerCount[e],e);t&&t.$$childHead==this&&(t.$$childHead=this.$$nextSibling),t&&t.$$childTail==this&&(t.$$childTail=this.$$prevSibling),this.$$prevSibling&&(this.$$prevSibling.$$nextSibling=this.$$nextSibling),this.$$nextSibling&&(this.$$nextSibling.$$prevSibling=this.$$prevSibling),this.$destroy=this.$digest=this.$apply=this.$evalAsync=this.$applyAsync=g,this.$on=this.$watch=this.$watchGroup=function(){return g},this.$$listeners={},this.$$nextSibling=null,f(this)}},$eval:function(t,e){return c(t)(this,e)},$evalAsync:function(t,e){C.$$phase||D.length||d.defer(function(){D.length&&C.$digest()}),D.push({scope:this,expression:c(t),locals:e})},$$postDigest:function(t){S.push(t)},$apply:function(t){try{m("$apply");try{return this.$eval(t)}finally{v()}}catch(e){l(e)}finally{try{C.$digest()}catch(e){throw l(e),e}}},$applyAsync:function(t){function e(){n.$eval(t)}var n=this;t&&T.push(e),t=c(t),k()},$on:function(t,e){var n=this.$$listeners[t];n||(this.$$listeners[t]=n=[]),n.push(e);var i=this;do i.$$listenerCount[t]||(i.$$listenerCount[t]=0),i.$$listenerCount[t]++;while(i=i.$parent);var r=this;return function(){var i=n.indexOf(e);-1!==i&&(n[i]=null,x(r,1,t))}},$emit:function(t,e){var n,i,r,o=[],a=this,s=!1,u={name:t,targetScope:a,stopPropagation:function(){s=!0},preventDefault:function(){u.defaultPrevented=!0},defaultPrevented:!1},c=U([u],arguments,1);do{for(n=a.$$listeners[t]||o,u.currentScope=a,i=0,r=n.length;r>i;i++)if(n[i])try{n[i].apply(null,c)}catch(d){l(d)}else n.splice(i,1),i--,r--;if(s)return u.currentScope=null,u;a=a.$parent}while(a);return u.currentScope=null,u},$broadcast:function(t,e){var n=this,i=n,r=n,o={name:t,targetScope:n,preventDefault:function(){o.defaultPrevented=!0},defaultPrevented:!1};if(!n.$$listenerCount[t])return o;for(var a,s,u,c=U([o],arguments,1);i=r;){for(o.currentScope=i,a=i.$$listeners[t]||[],s=0,u=a.length;u>s;s++)if(a[s])try{a[s].apply(null,c)}catch(d){l(d)}else a.splice(s,1),s--,u--;if(!(r=i.$$listenerCount[t]&&i.$$childHead||i!==n&&i.$$nextSibling))for(;i!==n&&!(r=i.$$nextSibling);)i=i.$parent}return o.currentScope=null,o}};var C=new p,D=C.$$asyncQueue=[],S=C.$$postDigestQueue=[],T=C.$$applyAsyncQueue=[];return C}]}function xn(){var t=/^\s*(https?|ftp|mailto|tel|file):/,e=/^\s*((https?|ftp|file|blob):|data:image\/)/;this.aHrefSanitizationWhitelist=function(e){return x(e)?(t=e,this):t},this.imgSrcSanitizationWhitelist=function(t){return x(t)?(e=t,this):e},this.$get=function(){return function(n,i){var r,o=i?e:t;return r=Tn(n).href,""===r||r.match(o)?n:"unsafe:"+r}}}function wn(t){if("self"===t)return t;if($(t)){if(t.indexOf("***")>-1)throw po("iwcard","Illegal sequence *** in string matcher.  String: {0}",t);return t=Yi(t).replace("\\*\\*",".*").replace("\\*","[^:/.?&;]*"),new RegExp("^"+t+"$")}if(D(t))return new RegExp("^"+t.source+"$");throw po("imatcher",'Matchers may only be "self", string patterns or RegExp objects')}function _n(t){var e=[];return x(t)&&o(t,function(t){e.push(wn(t))}),e}function $n(){this.SCE_CONTEXTS=go;var t=["self"],e=[];this.resourceUrlWhitelist=function(e){return arguments.length&&(t=_n(e)),t},this.resourceUrlBlacklist=function(t){return arguments.length&&(e=_n(t)),e},this.$get=["$injector",function(n){function i(t,e){return"self"===t?An(e):!!t.exec(e.href)}function r(n){var r,o,a=Tn(n.toString()),s=!1;for(r=0,o=t.length;o>r;r++)if(i(t[r],a)){s=!0;break}if(s)for(r=0,o=e.length;o>r;r++)if(i(e[r],a)){s=!1;break}return s}function o(t){var e=function(t){this.$$unwrapTrustedValue=function(){return t}};return t&&(e.prototype=new t),e.prototype.valueOf=function(){return this.$$unwrapTrustedValue()},e.prototype.toString=function(){return this.$$unwrapTrustedValue().toString()},e}function a(t,e){var n=d.hasOwnProperty(t)?d[t]:null;if(!n)throw po("icontext","Attempted to trust a value in invalid context. Context: {0}; Value: {1}",t,e);if(null===e||b(e)||""===e)return e;if("string"!=typeof e)throw po("itype","Attempted to trust a non-string value in a content requiring a string: Context: {0}",t);return new n(e)}function s(t){return t instanceof c?t.$$unwrapTrustedValue():t}function u(t,e){if(null===e||b(e)||""===e)return e;var n=d.hasOwnProperty(t)?d[t]:null;if(n&&e instanceof n)return e.$$unwrapTrustedValue();if(t===go.RESOURCE_URL){if(r(e))return e;throw po("insecurl","Blocked loading resource from url not allowed by $sceDelegate policy.  URL: {0}",e.toString())}if(t===go.HTML)return l(e);throw po("unsafe","Attempting to use an unsafe value in a safe context.")}var l=function(t){throw po("unsafe","Attempting to use an unsafe value in a safe context.")};n.has("$sanitize")&&(l=n.get("$sanitize"));var c=o(),d={};return d[go.HTML]=o(c),d[go.CSS]=o(c),d[go.URL]=o(c),d[go.JS]=o(c),d[go.RESOURCE_URL]=o(d[go.URL]),{trustAs:a,getTrusted:u,valueOf:s}}]}function kn(){var t=!0;this.enabled=function(e){return arguments.length&&(t=!!e),t},this.$get=["$parse","$sceDelegate",function(e,n){if(t&&8>Ei)throw po("iequirks","Strict Contextual Escaping does not support Internet Explorer version < 11 in quirks mode.  You can fix this by adding the text <!doctype html> to the top of your HTML document.  See http://docs.angularjs.org/api/ng.$sce for more information.");var i=j(go);i.isEnabled=function(){return t},i.trustAs=n.trustAs,i.getTrusted=n.getTrusted,i.valueOf=n.valueOf,t||(i.trustAs=i.getTrusted=function(t,e){return e},i.valueOf=m),i.parseAs=function(t,n){var r=e(n);return r.literal&&r.constant?r:e(n,function(e){return i.getTrusted(t,e)})};var r=i.parseAs,a=i.getTrusted,s=i.trustAs;return o(go,function(t,e){var n=Mi(e);i[_t("parse_as_"+n)]=function(e){return r(t,e)},i[_t("get_trusted_"+n)]=function(e){return a(t,e)},i[_t("trust_as_"+n)]=function(e){return s(t,e)}}),i}]}function Cn(){this.$get=["$window","$document",function(t,e){var n,i,r={},o=f((/android (\d+)/.exec(Mi((t.navigator||{}).userAgent))||[])[1]),a=/Boxee/i.test((t.navigator||{}).userAgent),s=e[0]||{},u=/^(Moz|webkit|ms)(?=[A-Z])/,l=s.body&&s.body.style,c=!1,d=!1;if(l){for(var h in l)if(i=u.exec(h)){n=i[0],n=n.substr(0,1).toUpperCase()+n.substr(1);break}n||(n="WebkitOpacity"in l&&"webkit"),c=!!("transition"in l||n+"Transition"in l),d=!!("animation"in l||n+"Animation"in l),!o||c&&d||(c=$(l.webkitTransition),d=$(l.webkitAnimation))}return{history:!(!t.history||!t.history.pushState||4>o||a),hasEvent:function(t){if("input"===t&&11>=Ei)return!1;if(b(r[t])){var e=s.createElement("div");r[t]="on"+t in e}return r[t]},csp:Gi(),vendorPrefix:n,transitions:c,animations:d,android:o}}]}function Mn(){this.$get=["$templateCache","$http","$q","$sce",function(t,e,n,i){function r(o,a){function s(t){if(!a)throw zr("tpload","Failed to load template: {0} (HTTP status: {1} {2})",o,t.status,t.statusText);return n.reject(t)}r.totalPendingRequests++,(!$(o)||b(t.get(o)))&&(o=i.getTrustedResourceUrl(o));var u=e.defaults&&e.defaults.transformResponse;qi(u)?u=u.filter(function(t){return t!==_e}):u===_e&&(u=null);var l={cache:t,transformResponse:u};return e.get(o,l)["finally"](function(){r.totalPendingRequests--}).then(function(e){return t.put(o,e.data),e.data},s)}return r.totalPendingRequests=0,r}]}function Dn(){this.$get=["$rootScope","$browser","$location",function(t,e,n){var i={};return i.findBindings=function(t,e,n){var i=t.getElementsByClassName("ng-binding"),r=[];return o(i,function(t){var i=ji.element(t).data("$binding");i&&o(i,function(i){if(n){var o=new RegExp("(^|\\s)"+Yi(e)+"(\\s|\\||$)");o.test(i)&&r.push(t)}else-1!=i.indexOf(e)&&r.push(t)})}),r},i.findModels=function(t,e,n){for(var i=["ng-","data-ng-","ng\\:"],r=0;r<i.length;++r){var o=n?"=":"*=",a="["+i[r]+"model"+o+'"'+e+'"]',s=t.querySelectorAll(a);if(s.length)return s}},i.getLocation=function(){return n.url()},i.setLocation=function(e){e!==n.url()&&(n.url(e),t.$digest())},i.whenStable=function(t){e.notifyWhenNoOutstandingRequests(t)},i}]}function Sn(){this.$get=["$rootScope","$browser","$q","$$q","$exceptionHandler",function(t,e,n,i,r){function o(o,s,u){M(o)||(u=s,s=o,o=g);var l,c=q(arguments,3),d=x(u)&&!u,h=(d?i:n).defer(),f=h.promise;return l=e.defer(function(){try{h.resolve(o.apply(null,c))}catch(e){h.reject(e),r(e)}finally{delete a[f.$$timeoutId]}d||t.$apply()},s),f.$$timeoutId=l,a[l]=h,f}var a={};return o.cancel=function(t){return t&&t.$$timeoutId in a?(a[t.$$timeoutId].reject("canceled"),delete a[t.$$timeoutId],e.defer.cancel(t.$$timeoutId)):!1},o}]}function Tn(t){var e=t;return Ei&&(mo.setAttribute("href",e),e=mo.href),mo.setAttribute("href",e),{href:mo.href,protocol:mo.protocol?mo.protocol.replace(/:$/,""):"",host:mo.host,search:mo.search?mo.search.replace(/^\?/,""):"",hash:mo.hash?mo.hash.replace(/^#/,""):"",hostname:mo.hostname,port:mo.port,pathname:"/"===mo.pathname.charAt(0)?mo.pathname:"/"+mo.pathname}}function An(t){var e=$(t)?Tn(t):t;return e.protocol===vo.protocol&&e.host===vo.host}function En(){this.$get=v(t)}function On(t){function e(t){try{return decodeURIComponent(t)}catch(e){return t}}var n=t[0]||{},i={},r="";return function(){var t,o,a,s,u,l=n.cookie||"";if(l!==r)for(r=l,t=r.split("; "),i={},a=0;a<t.length;a++)o=t[a],s=o.indexOf("="),s>0&&(u=e(o.substring(0,s)),b(i[u])&&(i[u]=e(o.substring(s+1))));return i}}function Nn(){this.$get=On}function In(t){function e(i,r){if(w(i)){var a={};return o(i,function(t,n){a[n]=e(n,t)}),a}return t.factory(i+n,r)}var n="Filter";this.register=e,this.$get=["$injector",function(t){return function(e){return t.get(e+n)}}],e("currency",Ln),e("date",ti),e("filter",Pn),e("json",ei),e("limitTo",ni),e("lowercase",ko),e("number",zn),e("orderBy",ii),e("uppercase",Co)}function Pn(){return function(t,e,n){if(!r(t)){if(null==t)return t;throw i("filter")("notarray","Expected array but received: {0}",t)}var o,a,s=Hn(e);switch(s){case"function":o=e;break;case"boolean":case"null":case"number":case"string":a=!0;case"object":o=Fn(e,n,a);break;default:return t}return Array.prototype.filter.call(t,o)}}function Fn(t,e,n){var i,r=w(t)&&"$"in t;return e===!0?e=R:M(e)||(e=function(t,e){return b(t)?!1:null===t||null===e?t===e:w(e)||w(t)&&!y(t)?!1:(t=Mi(""+t),e=Mi(""+e),-1!==t.indexOf(e))}),i=function(i){return r&&!w(i)?Wn(i,t.$,e,!1):Wn(i,t,e,n)}}function Wn(t,e,n,i,r){var o=Hn(t),a=Hn(e);if("string"===a&&"!"===e.charAt(0))return!Wn(t,e.substring(1),n,i);if(qi(t))return t.some(function(t){return Wn(t,e,n,i)});switch(o){case"object":var s;if(i){for(s in t)if("$"!==s.charAt(0)&&Wn(t[s],e,n,!0))return!0;return r?!1:Wn(t,e,n,!1)}if("object"===a){for(s in e){var u=e[s];if(!M(u)&&!b(u)){var l="$"===s,c=l?t:t[s];if(!Wn(c,u,n,l,l))return!1}}return!0}return n(t,e);case"function":return!1;default:return n(t,e)}}function Hn(t){return null===t?"null":typeof t}function Ln(t){var e=t.NUMBER_FORMATS;return function(t,n,i){return b(n)&&(n=e.CURRENCY_SYM),b(i)&&(i=e.PATTERNS[1].maxFrac),null==t?t:Un(t,e.PATTERNS[1],e.GROUP_SEP,e.DECIMAL_SEP,i).replace(/\u00A4/g,n)}}function zn(t){var e=t.NUMBER_FORMATS;return function(t,n){return null==t?t:Un(t,e.PATTERNS[0],e.GROUP_SEP,e.DECIMAL_SEP,n)}}function jn(t){var e,n,i,r,o,a=0;for((n=t.indexOf(bo))>-1&&(t=t.replace(bo,"")),(i=t.search(/e/i))>0?(0>n&&(n=i),n+=+t.slice(i+1),t=t.substring(0,i)):0>n&&(n=t.length),i=0;t.charAt(i)==xo;i++);if(i==(o=t.length))e=[0],n=1;else{for(o--;t.charAt(o)==xo;)o--;for(n-=i,e=[],r=0;o>=i;i++,r++)e[r]=+t.charAt(i)}return n>yo&&(e=e.splice(0,yo-1),a=n-1,n=1),{d:e,e:a,i:n}}function Rn(t,e,n,i){var r=t.d,o=r.length-t.i;e=b(e)?Math.min(Math.max(n,o),i):+e;var a=e+t.i,s=r[a];if(a>0)r.splice(a);else{t.i=1,r.length=a=e+1;for(var u=0;a>u;u++)r[u]=0}for(s>=5&&r[a-1]++;e>o;o++)r.push(0);var l=r.reduceRight(function(t,e,n,i){return e+=t,i[n]=e%10,Math.floor(e/10)},0);l&&(r.unshift(l),t.i++)}function Un(t,e,n,i,r){if(!$(t)&&!k(t)||isNaN(t))return"";var o,a=!isFinite(t),s=!1,u=Math.abs(t)+"",l="";if(a)l="∞";else{o=jn(u),Rn(o,r,e.minFrac,e.maxFrac);var c=o.d,d=o.i,h=o.e,f=[];for(s=c.reduce(function(t,e){return t&&!e},!0);0>d;)c.unshift(0),d++;d>0?f=c.splice(d,c.length):(f=c,c=[0]);var p=[];for(c.length>=e.lgSize&&p.unshift(c.splice(-e.lgSize,c.length).join(""));c.length>e.gSize;)p.unshift(c.splice(-e.gSize,c.length).join(""));c.length&&p.unshift(c.join("")),l=p.join(n),f.length&&(l+=i+f.join("")),h&&(l+="e+"+h)}return 0>t&&!s?e.negPre+l+e.negSuf:e.posPre+l+e.posSuf}function qn(t,e,n){var i="";for(0>t&&(i="-",t=-t),t=""+t;t.length<e;)t=xo+t;return n&&(t=t.substr(t.length-e)),i+t}function Bn(t,e,n,i){return n=n||0,function(r){var o=r["get"+t]();return(n>0||o>-n)&&(o+=n),0===o&&-12==n&&(o=12),qn(o,e,i)}}function Vn(t,e){return function(n,i){var r=n["get"+t](),o=Si(e?"SHORT"+t:t);return i[o][r]}}function Yn(t,e,n){var i=-1*n,r=i>=0?"+":"";return r+=qn(Math[i>0?"floor":"ceil"](i/60),2)+qn(Math.abs(i%60),2)}function Gn(t){var e=new Date(t,0,1).getDay();return new Date(t,0,(4>=e?5:12)-e)}function Xn(t){return new Date(t.getFullYear(),t.getMonth(),t.getDate()+(4-t.getDay()))}function Kn(t){return function(e){var n=Gn(e.getFullYear()),i=Xn(e),r=+i-+n,o=1+Math.round(r/6048e5);return qn(o,t)}}function Zn(t,e){return t.getHours()<12?e.AMPMS[0]:e.AMPMS[1]}function Qn(t,e){return t.getFullYear()<=0?e.ERAS[0]:e.ERAS[1]}function Jn(t,e){return t.getFullYear()<=0?e.ERANAMES[0]:e.ERANAMES[1]}function ti(t){function e(t){var e;if(e=t.match(n)){var i=new Date(0),r=0,o=0,a=e[8]?i.setUTCFullYear:i.setFullYear,s=e[8]?i.setUTCHours:i.setHours;e[9]&&(r=f(e[9]+e[10]),o=f(e[9]+e[11])),a.call(i,f(e[1]),f(e[2])-1,f(e[3]));var u=f(e[4]||0)-r,l=f(e[5]||0)-o,c=f(e[6]||0),d=Math.round(1e3*parseFloat("0."+(e[7]||0)));return s.call(i,u,l,c,d),i}return t}var n=/^(\d{4})-?(\d\d)-?(\d\d)(?:T(\d\d)(?::?(\d\d)(?::?(\d\d)(?:\.(\d+))?)?)?(Z|([+-])(\d\d):?(\d\d))?)?$/;return function(n,i,r){var a,s,u="",l=[];if(i=i||"mediumDate",i=t.DATETIME_FORMATS[i]||i,$(n)&&(n=$o.test(n)?f(n):e(n)),k(n)&&(n=new Date(n)),!C(n)||!isFinite(n.getTime()))return n;for(;i;)s=_o.exec(i),s?(l=U(l,s,1),i=l.pop()):(l.push(i),i=null);var c=n.getTimezoneOffset();return r&&(c=X(r,c),n=Z(n,r,!0)),o(l,function(e){a=wo[e],u+=a?a(n,t.DATETIME_FORMATS,c):"''"===e?"'":e.replace(/(^'|'$)/g,"").replace(/''/g,"'")}),u}}function ei(){return function(t,e){return b(e)&&(e=2),Y(t,e)}}function ni(){return function(t,e,n){return e=Math.abs(Number(e))===1/0?Number(e):f(e),isNaN(e)?t:(k(t)&&(t=t.toString()),qi(t)||$(t)?(n=!n||isNaN(n)?0:f(n),n=0>n?Math.max(0,t.length+n):n,e>=0?t.slice(n,n+e):0===n?t.slice(e,t.length):t.slice(Math.max(0,n+e),n)):t)}}function ii(t){function e(e,n){return n=n?-1:1,e.map(function(e){var i=1,r=m;if(M(e))r=e;else if($(e)&&(("+"==e.charAt(0)||"-"==e.charAt(0))&&(i="-"==e.charAt(0)?-1:1,e=e.substring(1)),""!==e&&(r=t(e),r.constant))){var o=r();r=function(t){return t[o]}}return{get:r,descending:i*n}})}function n(t){switch(typeof t){case"number":case"boolean":case"string":return!0;default:return!1}}function i(t,e){return"function"==typeof t.valueOf&&(t=t.valueOf(),n(t))?t:y(t)&&(t=t.toString(),n(t))?t:e}function o(t,e){var n=typeof t;return null===t?(n="string",t="null"):"string"===n?t=t.toLowerCase():"object"===n&&(t=i(t,e)),{value:t,type:n}}function a(t,e){var n=0;return t.type===e.type?t.value!==e.value&&(n=t.value<e.value?-1:1):n=t.type<e.type?-1:1,n}return function(t,n,i){function s(t,e){return{value:t,predicateValues:l.map(function(n){return o(n.get(t),e)})}}function u(t,e){for(var n=0,i=0,r=l.length;r>i&&!(n=a(t.predicateValues[i],e.predicateValues[i])*l[i].descending);++i);return n}if(!r(t))return t;qi(n)||(n=[n]),0===n.length&&(n=["+"]);var l=e(n,i);l.push({get:function(){return{}},descending:i?-1:1});var c=Array.prototype.map.call(t,s);return c.sort(u),t=c.map(function(t){return t.value})}}function ri(t){return M(t)&&(t={link:t}),t.restrict=t.restrict||"AC",v(t)}function oi(t,e){t.$name=e}function ai(t,e,i,r,a){var s=this,u=[];s.$error={},s.$$success={},s.$pending=n,s.$name=a(e.name||e.ngForm||"")(i),s.$dirty=!1,s.$pristine=!0,s.$valid=!0,s.$invalid=!1,s.$submitted=!1,s.$$parentForm=So,s.$rollbackViewValue=function(){o(u,function(t){t.$rollbackViewValue()})},s.$commitViewValue=function(){o(u,function(t){t.$commitViewValue()})},s.$addControl=function(t){ft(t.$name,"input"),u.push(t),t.$name&&(s[t.$name]=t),t.$$parentForm=s},s.$$renameControl=function(t,e){var n=t.$name;s[n]===t&&delete s[n],s[e]=t,t.$name=e},s.$removeControl=function(t){t.$name&&s[t.$name]===t&&delete s[t.$name],o(s.$pending,function(e,n){s.$setValidity(n,null,t)}),o(s.$error,function(e,n){s.$setValidity(n,null,t)}),o(s.$$success,function(e,n){s.$setValidity(n,null,t)}),L(u,t),t.$$parentForm=So},wi({ctrl:this,$element:t,set:function(t,e,n){var i=t[e];if(i){var r=i.indexOf(n);-1===r&&i.push(n)}else t[e]=[n]},unset:function(t,e,n){var i=t[e];i&&(L(i,n),0===i.length&&delete t[e])},$animate:r}),s.$setDirty=function(){r.removeClass(t,ha),r.addClass(t,fa),s.$dirty=!0,s.$pristine=!1,s.$$parentForm.$setDirty()},s.$setPristine=function(){r.setClass(t,ha,fa+" "+To),s.$dirty=!1,s.$pristine=!0,s.$submitted=!1,o(u,function(t){t.$setPristine()})},s.$setUntouched=function(){o(u,function(t){t.$setUntouched()})},s.$setSubmitted=function(){r.addClass(t,To),s.$submitted=!0,s.$$parentForm.$setSubmitted()}}function si(t){t.$formatters.push(function(e){return t.$isEmpty(e)?e:e.toString()})}function ui(t,e,n,i,r,o){li(t,e,n,i,r,o),si(i)}function li(t,e,n,i,r,o){var a=Mi(e[0].type);if(!r.android){var s=!1;e.on("compositionstart",function(t){s=!0}),e.on("compositionend",function(){s=!1,l()})}var u,l=function(t){if(u&&(o.defer.cancel(u),u=null),!s){var r=e.val(),l=t&&t.type;"password"===a||n.ngTrim&&"false"===n.ngTrim||(r=Vi(r)),(i.$viewValue!==r||""===r&&i.$$hasNativeValidators)&&i.$setViewValue(r,l)}};if(r.hasEvent("input"))e.on("input",l);else{var c=function(t,e,n){u||(u=o.defer(function(){u=null,e&&e.value===n||l(t)}))};e.on("keydown",function(t){var e=t.keyCode;91===e||e>15&&19>e||e>=37&&40>=e||c(t,this,this.value)}),r.hasEvent("paste")&&e.on("paste cut",c)}e.on("change",l),Uo[a]&&i.$$hasNativeValidators&&a===n.type&&e.on(Ro,function(t){if(!u){var e=this[Ci],n=e.badInput,i=e.typeMismatch;u=o.defer(function(){u=null,(e.badInput!==n||e.typeMismatch!==i)&&l(t)})}}),i.$render=function(){var t=i.$isEmpty(i.$viewValue)?"":i.$viewValue;e.val()!==t&&e.val(t)}}function ci(t,e){if(C(t))return t;if($(t)){Lo.lastIndex=0;var n=Lo.exec(t);if(n){var i=+n[1],r=+n[2],o=0,a=0,s=0,u=0,l=Gn(i),c=7*(r-1);return e&&(o=e.getHours(),a=e.getMinutes(),s=e.getSeconds(),u=e.getMilliseconds()),new Date(i,0,l.getDate()+c,o,a,s,u)}}return NaN}function di(t,e){return function(n,i){var r,a;if(C(n))return n;if($(n)){if('"'==n.charAt(0)&&'"'==n.charAt(n.length-1)&&(n=n.substring(1,n.length-1)),No.test(n))return new Date(n);if(t.lastIndex=0,r=t.exec(n))return r.shift(),a=i?{yyyy:i.getFullYear(),MM:i.getMonth()+1,dd:i.getDate(),HH:i.getHours(),mm:i.getMinutes(),ss:i.getSeconds(),sss:i.getMilliseconds()/1e3}:{yyyy:1970,MM:1,dd:1,HH:0,mm:0,ss:0,sss:0},o(r,function(t,n){n<e.length&&(a[e[n]]=+t)}),new Date(a.yyyy,a.MM-1,a.dd,a.HH,a.mm,a.ss||0,1e3*a.sss||0)}return NaN}}function hi(t,e,i,r){return function(o,a,s,u,l,c,d){function h(t){return t&&!(t.getTime&&t.getTime()!==t.getTime())}function f(t){return x(t)&&!C(t)?i(t)||n:t}fi(o,a,s,u),li(o,a,s,u,l,c);var p,g=u&&u.$options&&u.$options.timezone;if(u.$$parserName=t,u.$parsers.push(function(t){if(u.$isEmpty(t))return null;if(e.test(t)){var r=i(t,p);return g&&(r=Z(r,g)),r}return n}),u.$formatters.push(function(t){if(t&&!C(t))throw va("datefmt","Expected `{0}` to be a date",t);return h(t)?(p=t,p&&g&&(p=Z(p,g,!0)),d("date")(t,r,g)):(p=null,"")}),x(s.min)||s.ngMin){var m;u.$validators.min=function(t){return!h(t)||b(m)||i(t)>=m},s.$observe("min",function(t){m=f(t),u.$validate()})}if(x(s.max)||s.ngMax){var v;u.$validators.max=function(t){return!h(t)||b(v)||i(t)<=v},s.$observe("max",function(t){v=f(t),u.$validate()})}}}function fi(t,e,i,r){var o=e[0],a=r.$$hasNativeValidators=w(o.validity);a&&r.$parsers.push(function(t){var i=e.prop(Ci)||{};return i.badInput&&!i.typeMismatch?n:t})}function pi(t,e,i,r,o,a){if(fi(t,e,i,r),li(t,e,i,r,o,a),r.$$parserName="number",r.$parsers.push(function(t){return r.$isEmpty(t)?null:Fo.test(t)?parseFloat(t):n}),r.$formatters.push(function(t){if(!r.$isEmpty(t)){if(!k(t))throw va("numfmt","Expected `{0}` to be a number",t);t=t.toString()}return t}),x(i.min)||i.ngMin){var s;r.$validators.min=function(t){return r.$isEmpty(t)||b(s)||t>=s},i.$observe("min",function(t){x(t)&&!k(t)&&(t=parseFloat(t,10)),s=k(t)&&!isNaN(t)?t:n,r.$validate()})}if(x(i.max)||i.ngMax){var u;r.$validators.max=function(t){return r.$isEmpty(t)||b(u)||u>=t},i.$observe("max",function(t){x(t)&&!k(t)&&(t=parseFloat(t,10)),u=k(t)&&!isNaN(t)?t:n,r.$validate()})}}function gi(t,e,n,i,r,o){li(t,e,n,i,r,o),si(i),i.$$parserName="url",i.$validators.url=function(t,e){var n=t||e;return i.$isEmpty(n)||Io.test(n)}}function mi(t,e,n,i,r,o){li(t,e,n,i,r,o),si(i),i.$$parserName="email",i.$validators.email=function(t,e){var n=t||e;return i.$isEmpty(n)||Po.test(n)}}function vi(t,e,n,i){b(n.name)&&e.attr("name",u());var r=function(t){e[0].checked&&i.$setViewValue(n.value,t&&t.type)};e.on("click",r),i.$render=function(){var t=n.value;e[0].checked=t==i.$viewValue},n.$observe("value",i.$render)}function yi(t,e,n,i,r){var o;if(x(i)){if(o=t(i),!o.constant)throw va("constexpr","Expected constant expression for `{0}`, but saw `{1}`.",n,i);return o(e)}return r}function bi(t,e,n,i,r,o,a,s){var u=yi(s,t,"ngTrueValue",n.ngTrueValue,!0),l=yi(s,t,"ngFalseValue",n.ngFalseValue,!1),c=function(t){i.$setViewValue(e[0].checked,t&&t.type)};e.on("click",c),i.$render=function(){e[0].checked=i.$viewValue},i.$isEmpty=function(t){return t===!1},i.$formatters.push(function(t){return R(t,u)}),i.$parsers.push(function(t){return t?u:l})}function xi(t,e){return t="ngClass"+t,["$animate",function(n){function i(t,e){var n=[];t:for(var i=0;i<t.length;i++){for(var r=t[i],o=0;o<e.length;o++)if(r==e[o])continue t;n.push(r)}return n}function r(t){var e=[];return qi(t)?(o(t,function(t){e=e.concat(r(t))}),e):$(t)?t.split(" "):w(t)?(o(t,function(t,n){t&&(e=e.concat(n.split(" ")))}),e):t}return{restrict:"AC",link:function(a,s,u){function l(t){var e=d(t,1);u.$addClass(e)}function c(t){var e=d(t,-1);u.$removeClass(e)}function d(t,e){var n=s.data("$classCounts")||mt(),i=[];return o(t,function(t){(e>0||n[t])&&(n[t]=(n[t]||0)+e,n[t]===+(e>0)&&i.push(t))}),s.data("$classCounts",n),i.join(" ")}function h(t,e){var r=i(e,t),o=i(t,e);r=d(r,1),o=d(o,-1),r&&r.length&&n.addClass(s,r),o&&o.length&&n.removeClass(s,o)}function f(t){if(e===!0||a.$index%2===e){var n=r(t||[]);if(p){if(!R(t,p)){var i=r(p);h(i,n)}}else l(n)}p=qi(t)?t.map(function(t){return j(t)}):j(t)}var p;a.$watch(u[t],f,!0),u.$observe("class",function(e){f(a.$eval(u[t]))}),"ngClass"!==t&&a.$watch("$index",function(n,i){var o=1&n;if(o!==(1&i)){var s=r(a.$eval(u[t]));o===e?l(s):c(s)}})}}}]}function wi(t){function e(t,e,u){b(e)?i("$pending",t,u):r("$pending",t,u),N(e)?e?(d(s.$error,t,u),c(s.$$success,t,u)):(c(s.$error,t,u),d(s.$$success,t,u)):(d(s.$error,t,u),d(s.$$success,t,u)),s.$pending?(o(ma,!0),s.$valid=s.$invalid=n,a("",null)):(o(ma,!1),s.$valid=_i(s.$error),s.$invalid=!s.$valid,a("",s.$valid));var l;l=s.$pending&&s.$pending[t]?n:s.$error[t]?!1:s.$$success[t]?!0:null,a(t,l),s.$$parentForm.$setValidity(t,l,s)}function i(t,e,n){s[t]||(s[t]={}),c(s[t],e,n)}function r(t,e,i){s[t]&&d(s[t],e,i),_i(s[t])&&(s[t]=n)}function o(t,e){e&&!l[t]?(h.addClass(u,t),l[t]=!0):!e&&l[t]&&(h.removeClass(u,t),l[t]=!1)}function a(t,e){t=t?"-"+lt(t,"-"):"",o(ca+t,e===!0),o(da+t,e===!1)}var s=t.ctrl,u=t.$element,l={},c=t.set,d=t.unset,h=t.$animate;l[da]=!(l[ca]=u.hasClass(ca)),s.$setValidity=e}function _i(t){if(t)for(var e in t)if(t.hasOwnProperty(e))return!1;return!0}function $i(t){t[0].hasAttribute("selected")&&(t[0].selected=!0)}var ki=/^\/(.+)\/([a-z]*)$/,Ci="validity",Mi=function(t){return $(t)?t.toLowerCase():t},Di=Object.prototype.hasOwnProperty,Si=function(t){return $(t)?t.toUpperCase():t},Ti=function(t){return $(t)?t.replace(/[A-Z]/g,function(t){return String.fromCharCode(32|t.charCodeAt(0))}):t},Ai=function(t){return $(t)?t.replace(/[a-z]/g,function(t){return String.fromCharCode(-33&t.charCodeAt(0))}):t};"i"!=="I".toLowerCase()&&(Mi=Ti,Si=Ai);var Ei,Oi,Ni,Ii,Pi=[].slice,Fi=[].splice,Wi=[].push,Hi=Object.prototype.toString,Li=Object.getPrototypeOf,zi=i("ng"),ji=t.angular||(t.angular={}),Ri=0;Ei=e.documentMode,g.$inject=[],m.$inject=[];var Ui,qi=Array.isArray,Bi=/^\[object (?:Uint8|Uint8Clamped|Uint16|Uint32|Int8|Int16|Int32|Float32|Float64)Array\]$/,Vi=function(t){return $(t)?t.trim():t},Yi=function(t){return t.replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g,"\\$1").replace(/\x08/g,"\\x08")},Gi=function(){function t(){try{return new Function(""),!1}catch(t){return!0}}if(!x(Gi.rules)){var n=e.querySelector("[ng-csp]")||e.querySelector("[data-ng-csp]");if(n){var i=n.getAttribute("ng-csp")||n.getAttribute("data-ng-csp");Gi.rules={noUnsafeEval:!i||-1!==i.indexOf("no-unsafe-eval"),noInlineStyle:!i||-1!==i.indexOf("no-inline-style")}}else Gi.rules={noUnsafeEval:t(),noInlineStyle:!1}}return Gi.rules},Xi=function(){if(x(Xi.name_))return Xi.name_;var t,n,i,r,o=Zi.length;for(n=0;o>n;++n)if(i=Zi[n],t=e.querySelector("["+i.replace(":","\\:")+"jq]")){r=t.getAttribute(i+"jq");break}return Xi.name_=r},Ki=/:/g,Zi=["ng-","data-ng-","ng:","x-ng-"],Qi=/[A-Z]/g,Ji=!1,tr=1,er=2,nr=3,ir=8,rr=9,or=11,ar={full:"1.4.11",major:1,minor:4,dot:11,codeName:"relentless-syncomania"};Tt.expando="ng339";var sr=Tt.cache={},ur=1,lr=function(t,e,n){t.addEventListener(e,n,!1)},cr=function(t,e,n){t.removeEventListener(e,n,!1)};Tt._data=function(t){return this.cache[t[this.expando]]||{}};var dr=/([\:\-\_]+(.))/g,hr=/^moz([A-Z])/,fr={mouseleave:"mouseout",mouseenter:"mouseover"},pr=i("jqLite"),gr=/^<([\w-]+)\s*\/?>(?:<\/\1>|)$/,mr=/<|&#?\w+;/,vr=/<([\w:-]+)/,yr=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:-]+)[^>]*)\/>/gi,br={option:[1,'<select multiple="multiple">',"</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],
_default:[0,"",""]};br.optgroup=br.option,br.tbody=br.tfoot=br.colgroup=br.caption=br.thead,br.th=br.td;var xr=Node.prototype.contains||function(t){return!!(16&this.compareDocumentPosition(t))},wr=Tt.prototype={ready:function(n){function i(){r||(r=!0,n())}var r=!1;"complete"===e.readyState?setTimeout(i):(this.on("DOMContentLoaded",i),Tt(t).on("load",i))},toString:function(){var t=[];return o(this,function(e){t.push(""+e)}),"["+t.join(", ")+"]"},eq:function(t){return Oi(t>=0?this[t]:this[this.length+t])},length:0,push:Wi,sort:[].sort,splice:[].splice},_r={};o("multiple,selected,checked,disabled,readOnly,required,open".split(","),function(t){_r[Mi(t)]=t});var $r={};o("input,select,option,textarea,button,form,details".split(","),function(t){$r[t]=!0});var kr={ngMinlength:"minlength",ngMaxlength:"maxlength",ngMin:"min",ngMax:"max",ngPattern:"pattern"};o({data:Pt,removeData:Nt,hasData:Ct},function(t,e){Tt[e]=t}),o({data:Pt,inheritedData:jt,scope:function(t){return Oi.data(t,"$scope")||jt(t.parentNode||t,["$isolateScope","$scope"])},isolateScope:function(t){return Oi.data(t,"$isolateScope")||Oi.data(t,"$isolateScopeNoTemplate")},controller:zt,injector:function(t){return jt(t,"$injector")},removeAttr:function(t,e){t.removeAttribute(e)},hasClass:Ft,css:function(t,e,n){return e=_t(e),x(n)?void(t.style[e]=n):t.style[e]},attr:function(t,e,i){var r=t.nodeType;if(r!==nr&&r!==er&&r!==ir){var o=Mi(e);if(_r[o]){if(!x(i))return t[e]||(t.attributes.getNamedItem(e)||g).specified?o:n;i?(t[e]=!0,t.setAttribute(e,o)):(t[e]=!1,t.removeAttribute(o))}else if(x(i))t.setAttribute(e,i);else if(t.getAttribute){var a=t.getAttribute(e,2);return null===a?n:a}}},prop:function(t,e,n){return x(n)?void(t[e]=n):t[e]},text:function(){function t(t,e){if(b(e)){var n=t.nodeType;return n===tr||n===nr?t.textContent:""}t.textContent=e}return t.$dv="",t}(),val:function(t,e){if(b(e)){if(t.multiple&&"select"===H(t)){var n=[];return o(t.options,function(t){t.selected&&n.push(t.value||t.text)}),0===n.length?null:n}return t.value}t.value=e},html:function(t,e){return b(e)?t.innerHTML:(Et(t,!0),void(t.innerHTML=e))},empty:Rt},function(t,e){Tt.prototype[e]=function(e,n){var i,r,o=this.length;if(t!==Rt&&b(2==t.length&&t!==Ft&&t!==zt?e:n)){if(w(e)){for(i=0;o>i;i++)if(t===Pt)t(this[i],e);else for(r in e)t(this[i],r,e[r]);return this}for(var a=t.$dv,s=b(a)?Math.min(o,1):o,u=0;s>u;u++){var l=t(this[u],e,n);a=a?a+l:l}return a}for(i=0;o>i;i++)t(this[i],e,n);return this}}),o({removeData:Nt,on:function(t,e,i,r){if(x(r))throw pr("onargs","jqLite#on() does not support the `selector` or `eventData` parameters");if(kt(t)){var o=It(t,!0),a=o.events,s=o.handle;s||(s=o.handle=Yt(t,a));for(var u=e.indexOf(" ")>=0?e.split(" "):[e],l=u.length,c=function(e,n,r){var o=a[e];o||(o=a[e]=[],o.specialHandlerWrapper=n,"$destroy"===e||r||lr(t,e,s)),o.push(i)};l--;)e=u[l],fr[e]?(c(fr[e],Xt),c(e,n,!0)):c(e)}},off:Ot,one:function(t,e,n){t=Oi(t),t.on(e,function i(){t.off(e,n),t.off(e,i)}),t.on(e,n)},replaceWith:function(t,e){var n,i=t.parentNode;Et(t),o(new Tt(e),function(e){n?i.insertBefore(e,n.nextSibling):i.replaceChild(e,t),n=e})},children:function(t){var e=[];return o(t.childNodes,function(t){t.nodeType===tr&&e.push(t)}),e},contents:function(t){return t.contentDocument||t.childNodes||[]},append:function(t,e){var n=t.nodeType;if(n===tr||n===or){e=new Tt(e);for(var i=0,r=e.length;r>i;i++){var o=e[i];t.appendChild(o)}}},prepend:function(t,e){if(t.nodeType===tr){var n=t.firstChild;o(new Tt(e),function(e){t.insertBefore(e,n)})}},wrap:function(t,e){St(t,Oi(e).eq(0).clone()[0])},remove:Ut,detach:function(t){Ut(t,!0)},after:function(t,e){var n=t,i=t.parentNode;e=new Tt(e);for(var r=0,o=e.length;o>r;r++){var a=e[r];i.insertBefore(a,n.nextSibling),n=a}},addClass:Ht,removeClass:Wt,toggleClass:function(t,e,n){e&&o(e.split(" "),function(e){var i=n;b(i)&&(i=!Ft(t,e)),(i?Ht:Wt)(t,e)})},parent:function(t){var e=t.parentNode;return e&&e.nodeType!==or?e:null},next:function(t){return t.nextElementSibling},find:function(t,e){return t.getElementsByTagName?t.getElementsByTagName(e):[]},clone:At,triggerHandler:function(t,e,n){var i,r,a,s=e.type||e,u=It(t),l=u&&u.events,c=l&&l[s];c&&(i={preventDefault:function(){this.defaultPrevented=!0},isDefaultPrevented:function(){return this.defaultPrevented===!0},stopImmediatePropagation:function(){this.immediatePropagationStopped=!0},isImmediatePropagationStopped:function(){return this.immediatePropagationStopped===!0},stopPropagation:g,type:s,target:t},e.type&&(i=d(i,e)),r=j(c),a=n?[i].concat(n):[i],o(r,function(e){i.isImmediatePropagationStopped()||e.apply(t,a)}))}},function(t,e){Tt.prototype[e]=function(e,n,i){for(var r,o=0,a=this.length;a>o;o++)b(r)?(r=t(this[o],e,n,i),x(r)&&(r=Oi(r))):Lt(r,t(this[o],e,n,i));return x(r)?r:this},Tt.prototype.bind=Tt.prototype.on,Tt.prototype.unbind=Tt.prototype.off}),Qt.prototype={put:function(t,e){this[Zt(t,this.nextUid)]=e},get:function(t){return this[Zt(t,this.nextUid)]},remove:function(t){var e=this[t=Zt(t,this.nextUid)];return delete this[t],e}};var Cr=[function(){this.$get=[function(){return Qt}]}],Mr=/^[^\(]*\(\s*([^\)]*)\)/m,Dr=/,/,Sr=/^\s*(_?)(\S+?)\1\s*$/,Tr=/((\/\/.*$)|(\/\*[\s\S]*?\*\/))/gm,Ar=i("$injector");ee.$$annotate=te;var Er=i("$animate"),Or=1,Nr="ng-animate",Ir=function(){this.$get=function(){}},Pr=function(){var t=new Qt,e=[];this.$get=["$$AnimateRunner","$rootScope",function(n,i){function r(t,e,n){var i=!1;return e&&(e=$(e)?e.split(" "):qi(e)?e:[],o(e,function(e){e&&(i=!0,t[e]=n)})),i}function a(){o(e,function(e){var n=t.get(e);if(n){var i=oe(e.attr("class")),r="",a="";o(n,function(t,e){var n=!!i[e];t!==n&&(t?r+=(r.length?" ":"")+e:a+=(a.length?" ":"")+e)}),o(e,function(t){r&&Ht(t,r),a&&Wt(t,a)}),t.remove(e)}}),e.length=0}function s(n,o,s){var u=t.get(n)||{},l=r(u,o,!0),c=r(u,s,!1);(l||c)&&(t.put(n,u),e.push(n),1===e.length&&i.$$postDigest(a))}return{enabled:g,on:g,off:g,pin:g,push:function(t,e,i,r){r&&r(),i=i||{},i.from&&t.css(i.from),i.to&&t.css(i.to),(i.addClass||i.removeClass)&&s(t,i.addClass,i.removeClass);var o=new n;return o.complete(),o}}}]},Fr=["$provide",function(t){var e=this;this.$$registeredAnimations=Object.create(null),this.register=function(n,i){if(n&&"."!==n.charAt(0))throw Er("notcsel","Expecting class selector starting with '.' got '{0}'.",n);var r=n+"-animation";e.$$registeredAnimations[n.substr(1)]=r,t.factory(r,i)},this.classNameFilter=function(t){if(1===arguments.length&&(this.$$classNameFilter=t instanceof RegExp?t:null,this.$$classNameFilter)){var e=new RegExp("(\\s+|\\/)"+Nr+"(\\s+|\\/)");if(e.test(this.$$classNameFilter.toString()))throw Er("nongcls",'$animateProvider.classNameFilter(regex) prohibits accepting a regex value which matches/contains the "{0}" CSS class.',Nr)}return this.$$classNameFilter},this.$get=["$$animateQueue",function(t){function e(t,e,n){if(n){var i=re(n);!i||i.parentNode||i.previousElementSibling||(n=null)}n?n.after(t):e.prepend(t)}return{on:t.on,off:t.off,pin:t.pin,enabled:t.enabled,cancel:function(t){t.end&&t.end()},enter:function(n,i,r,o){return i=i&&Oi(i),r=r&&Oi(r),i=i||r.parent(),e(n,i,r),t.push(n,"enter",ae(o))},move:function(n,i,r,o){return i=i&&Oi(i),r=r&&Oi(r),i=i||r.parent(),e(n,i,r),t.push(n,"move",ae(o))},leave:function(e,n){return t.push(e,"leave",ae(n),function(){e.remove()})},addClass:function(e,n,i){return i=ae(i),i.addClass=ie(i.addclass,n),t.push(e,"addClass",i)},removeClass:function(e,n,i){return i=ae(i),i.removeClass=ie(i.removeClass,n),t.push(e,"removeClass",i)},setClass:function(e,n,i,r){return r=ae(r),r.addClass=ie(r.addClass,n),r.removeClass=ie(r.removeClass,i),t.push(e,"setClass",r)},animate:function(e,n,i,r,o){return o=ae(o),o.from=o.from?d(o.from,n):n,o.to=o.to?d(o.to,i):i,r=r||"ng-inline-animate",o.tempClasses=ie(o.tempClasses,r),t.push(e,"animate",o)}}}]}],Wr=function(){this.$get=["$$rAF",function(t){function e(e){n.push(e),n.length>1||t(function(){for(var t=0;t<n.length;t++)n[t]();n=[]})}var n=[];return function(){var t=!1;return e(function(){t=!0}),function(n){t?n():e(n)}}}]},Hr=function(){this.$get=["$q","$sniffer","$$animateAsyncRun","$document","$timeout",function(t,e,n,i,r){function a(t){this.setHost(t);var e=n(),o=function(t){r(t,0,!1)};this._doneCallbacks=[],this._tick=function(t){var n=i[0];n&&n.hidden?o(t):e(t)},this._state=0}var s=0,u=1,l=2;return a.chain=function(t,e){function n(){return i===t.length?void e(!0):void t[i](function(t){return t===!1?void e(!1):(i++,void n())})}var i=0;n()},a.all=function(t,e){function n(n){r=r&&n,++i===t.length&&e(r)}var i=0,r=!0;o(t,function(t){t.done(n)})},a.prototype={setHost:function(t){this.host=t||{}},done:function(t){this._state===l?t():this._doneCallbacks.push(t)},progress:g,getPromise:function(){if(!this.promise){var e=this;this.promise=t(function(t,n){e.done(function(e){e===!1?n():t()})})}return this.promise},then:function(t,e){return this.getPromise().then(t,e)},"catch":function(t){return this.getPromise()["catch"](t)},"finally":function(t){return this.getPromise()["finally"](t)},pause:function(){this.host.pause&&this.host.pause()},resume:function(){this.host.resume&&this.host.resume()},end:function(){this.host.end&&this.host.end(),this._resolve(!0)},cancel:function(){this.host.cancel&&this.host.cancel(),this._resolve(!1)},complete:function(t){var e=this;e._state===s&&(e._state=u,e._tick(function(){e._resolve(t)}))},_resolve:function(t){this._state!==l&&(o(this._doneCallbacks,function(e){e(t)}),this._doneCallbacks.length=0,this._state=l)}},a}]},Lr=function(){this.$get=["$$rAF","$q","$$AnimateRunner",function(t,e,n){return function(e,i){function r(){return t(function(){o(),s||u.complete(),s=!0}),u}function o(){a.addClass&&(e.addClass(a.addClass),a.addClass=null),a.removeClass&&(e.removeClass(a.removeClass),a.removeClass=null),a.to&&(e.css(a.to),a.to=null)}var a=i||{};a.$$prepared||(a=z(a)),a.cleanupStyles&&(a.from=a.to=null),a.from&&(e.css(a.from),a.from=null);var s,u=new n;return{start:r,end:r}}}]},zr=i("$compile");de.$inject=["$provide","$$sanitizeUriProvider"];var jr=/^((?:x|data)[\:\-_])/i,Rr=i("$controller"),Ur=/^(\S+)(\s+as\s+([\w$]+))?$/,qr=function(){this.$get=["$document",function(t){return function(e){return e?!e.nodeType&&e instanceof Oi&&(e=e[0]):e=t[0].body,e.offsetWidth+1}}]},Br="application/json",Vr={"Content-Type":Br+";charset=utf-8"},Yr=/^\[|^\{(?!\{)/,Gr={"[":/]$/,"{":/}$/},Xr=/^\)\]\}',?\n/,Kr=i("$http"),Zr=function(t){return function(){throw Kr("legacy","The method `{0}` on the promise returned from `$http` has been disabled.",t)}},Qr=ji.$interpolateMinErr=i("$interpolate");Qr.throwNoconcat=function(t){throw Qr("noconcat","Error while interpolating: {0}\nStrict Contextual Escaping disallows interpolations that concatenate multiple expressions when a trusted value is required.  See http://docs.angularjs.org/api/ng.$sce",t)},Qr.interr=function(t,e){return Qr("interr","Can't interpolate: {0}\n{1}",t,e.toString())};var Jr=/^([^\?#]*)(\?([^#]*))?(#(.*))?$/,to={http:80,https:443,ftp:21},eo=i("$location"),no={$$html5:!1,$$replace:!1,absUrl:Be("$$absUrl"),url:function(t){if(b(t))return this.$$url;var e=Jr.exec(t);return(e[1]||""===t)&&this.path(decodeURIComponent(e[1])),(e[2]||e[1]||""===t)&&this.search(e[3]||""),this.hash(e[5]||""),this},protocol:Be("$$protocol"),host:Be("$$host"),port:Be("$$port"),path:Ve("$$path",function(t){return t=null!==t?t.toString():"","/"==t.charAt(0)?t:"/"+t}),search:function(t,e){switch(arguments.length){case 0:return this.$$search;case 1:if($(t)||k(t))t=t.toString(),this.$$search=tt(t);else{if(!w(t))throw eo("isrcharg","The first argument of the `$location#search()` call must be a string or an object.");t=z(t,{}),o(t,function(e,n){null==e&&delete t[n]}),this.$$search=t}break;default:b(e)||null===e?delete this.$$search[t]:this.$$search[t]=e}return this.$$compose(),this},hash:Ve("$$hash",function(t){return null!==t?t.toString():""}),replace:function(){return this.$$replace=!0,this}};o([qe,Ue,Re],function(t){t.prototype=Object.create(no),t.prototype.state=function(e){if(!arguments.length)return this.$$state;if(t!==Re||!this.$$html5)throw eo("nostate","History API state support is available only in HTML5 mode and only in browsers supporting HTML5 History API");return this.$$state=b(e)?null:e,this}});var io=i("$parse"),ro=Function.prototype.call,oo=Function.prototype.apply,ao=Function.prototype.bind,so=mt();o("+ - * / % === !== == != < > <= >= && || ! = |".split(" "),function(t){so[t]=!0});var uo={n:"\n",f:"\f",r:"\r",t:"	",v:"","'":"'",'"':'"'},lo=function(t){this.options=t};lo.prototype={constructor:lo,lex:function(t){for(this.text=t,this.index=0,this.tokens=[];this.index<this.text.length;){var e=this.text.charAt(this.index);if('"'===e||"'"===e)this.readString(e);else if(this.isNumber(e)||"."===e&&this.isNumber(this.peek()))this.readNumber();else if(this.isIdent(e))this.readIdent();else if(this.is(e,"(){}[].,;:?"))this.tokens.push({index:this.index,text:e}),this.index++;else if(this.isWhitespace(e))this.index++;else{var n=e+this.peek(),i=n+this.peek(2),r=so[e],o=so[n],a=so[i];if(r||o||a){var s=a?i:o?n:e;this.tokens.push({index:this.index,text:s,operator:!0}),this.index+=s.length}else this.throwError("Unexpected next character ",this.index,this.index+1)}}return this.tokens},is:function(t,e){return-1!==e.indexOf(t)},peek:function(t){var e=t||1;return this.index+e<this.text.length?this.text.charAt(this.index+e):!1},isNumber:function(t){return t>="0"&&"9">=t&&"string"==typeof t},isWhitespace:function(t){return" "===t||"\r"===t||"	"===t||"\n"===t||""===t||" "===t},isIdent:function(t){return t>="a"&&"z">=t||t>="A"&&"Z">=t||"_"===t||"$"===t},isExpOperator:function(t){return"-"===t||"+"===t||this.isNumber(t)},throwError:function(t,e,n){n=n||this.index;var i=x(e)?"s "+e+"-"+this.index+" ["+this.text.substring(e,n)+"]":" "+n;throw io("lexerr","Lexer Error: {0} at column{1} in expression [{2}].",t,i,this.text)},readNumber:function(){for(var t="",e=this.index;this.index<this.text.length;){var n=Mi(this.text.charAt(this.index));if("."==n||this.isNumber(n))t+=n;else{var i=this.peek();if("e"==n&&this.isExpOperator(i))t+=n;else if(this.isExpOperator(n)&&i&&this.isNumber(i)&&"e"==t.charAt(t.length-1))t+=n;else{if(!this.isExpOperator(n)||i&&this.isNumber(i)||"e"!=t.charAt(t.length-1))break;this.throwError("Invalid exponent")}}this.index++}this.tokens.push({index:e,text:t,constant:!0,value:Number(t)})},readIdent:function(){for(var t=this.index;this.index<this.text.length;){var e=this.text.charAt(this.index);if(!this.isIdent(e)&&!this.isNumber(e))break;this.index++}this.tokens.push({index:t,text:this.text.slice(t,this.index),identifier:!0})},readString:function(t){var e=this.index;this.index++;for(var n="",i=t,r=!1;this.index<this.text.length;){var o=this.text.charAt(this.index);if(i+=o,r){if("u"===o){var a=this.text.substring(this.index+1,this.index+5);a.match(/[\da-f]{4}/i)||this.throwError("Invalid unicode escape [\\u"+a+"]"),this.index+=4,n+=String.fromCharCode(parseInt(a,16))}else{var s=uo[o];n+=s||o}r=!1}else if("\\"===o)r=!0;else{if(o===t)return this.index++,void this.tokens.push({index:e,text:i,constant:!0,value:n});n+=o}this.index++}this.throwError("Unterminated quote",e)}};var co=function(t,e){this.lexer=t,this.options=e};co.Program="Program",co.ExpressionStatement="ExpressionStatement",co.AssignmentExpression="AssignmentExpression",co.ConditionalExpression="ConditionalExpression",co.LogicalExpression="LogicalExpression",co.BinaryExpression="BinaryExpression",co.UnaryExpression="UnaryExpression",co.CallExpression="CallExpression",co.MemberExpression="MemberExpression",co.Identifier="Identifier",co.Literal="Literal",co.ArrayExpression="ArrayExpression",co.Property="Property",co.ObjectExpression="ObjectExpression",co.ThisExpression="ThisExpression",co.NGValueParameter="NGValueParameter",co.prototype={ast:function(t){this.text=t,this.tokens=this.lexer.lex(t);var e=this.program();return 0!==this.tokens.length&&this.throwError("is an unexpected token",this.tokens[0]),e},program:function(){for(var t=[];;)if(this.tokens.length>0&&!this.peek("}",")",";","]")&&t.push(this.expressionStatement()),!this.expect(";"))return{type:co.Program,body:t}},expressionStatement:function(){return{type:co.ExpressionStatement,expression:this.filterChain()}},filterChain:function(){for(var t,e=this.expression();t=this.expect("|");)e=this.filter(e);return e},expression:function(){return this.assignment()},assignment:function(){var t=this.ternary();return this.expect("=")&&(t={type:co.AssignmentExpression,left:t,right:this.assignment(),operator:"="}),t},ternary:function(){var t,e,n=this.logicalOR();return this.expect("?")&&(t=this.expression(),this.consume(":"))?(e=this.expression(),{type:co.ConditionalExpression,test:n,alternate:t,consequent:e}):n},logicalOR:function(){for(var t=this.logicalAND();this.expect("||");)t={type:co.LogicalExpression,operator:"||",left:t,right:this.logicalAND()};return t},logicalAND:function(){for(var t=this.equality();this.expect("&&");)t={type:co.LogicalExpression,operator:"&&",left:t,right:this.equality()};return t},equality:function(){for(var t,e=this.relational();t=this.expect("==","!=","===","!==");)e={type:co.BinaryExpression,operator:t.text,left:e,right:this.relational()};return e},relational:function(){for(var t,e=this.additive();t=this.expect("<",">","<=",">=");)e={type:co.BinaryExpression,operator:t.text,left:e,right:this.additive()};return e},additive:function(){for(var t,e=this.multiplicative();t=this.expect("+","-");)e={type:co.BinaryExpression,operator:t.text,left:e,right:this.multiplicative()};return e},multiplicative:function(){for(var t,e=this.unary();t=this.expect("*","/","%");)e={type:co.BinaryExpression,operator:t.text,left:e,right:this.unary()};return e},unary:function(){var t;return(t=this.expect("+","-","!"))?{type:co.UnaryExpression,operator:t.text,prefix:!0,argument:this.unary()}:this.primary()},primary:function(){var t;this.expect("(")?(t=this.filterChain(),this.consume(")")):this.expect("[")?t=this.arrayDeclaration():this.expect("{")?t=this.object():this.constants.hasOwnProperty(this.peek().text)?t=z(this.constants[this.consume().text]):this.peek().identifier?t=this.identifier():this.peek().constant?t=this.constant():this.throwError("not a primary expression",this.peek());for(var e;e=this.expect("(","[",".");)"("===e.text?(t={type:co.CallExpression,callee:t,arguments:this.parseArguments()},this.consume(")")):"["===e.text?(t={type:co.MemberExpression,object:t,property:this.expression(),computed:!0},this.consume("]")):"."===e.text?t={type:co.MemberExpression,object:t,property:this.identifier(),computed:!1}:this.throwError("IMPOSSIBLE");return t},filter:function(t){for(var e=[t],n={type:co.CallExpression,callee:this.identifier(),arguments:e,filter:!0};this.expect(":");)e.push(this.expression());return n},parseArguments:function(){var t=[];if(")"!==this.peekToken().text)do t.push(this.expression());while(this.expect(","));return t},identifier:function(){var t=this.consume();return t.identifier||this.throwError("is not a valid identifier",t),{type:co.Identifier,name:t.text}},constant:function(){return{type:co.Literal,value:this.consume().value}},arrayDeclaration:function(){var t=[];if("]"!==this.peekToken().text)do{if(this.peek("]"))break;t.push(this.expression())}while(this.expect(","));return this.consume("]"),{type:co.ArrayExpression,elements:t}},object:function(){var t,e=[];if("}"!==this.peekToken().text)do{if(this.peek("}"))break;t={type:co.Property,kind:"init"},this.peek().constant?t.key=this.constant():this.peek().identifier?t.key=this.identifier():this.throwError("invalid key",this.peek()),this.consume(":"),t.value=this.expression(),e.push(t)}while(this.expect(","));return this.consume("}"),{type:co.ObjectExpression,properties:e}},throwError:function(t,e){throw io("syntax","Syntax Error: Token '{0}' {1} at column {2} of the expression [{3}] starting at [{4}].",e.text,t,e.index+1,this.text,this.text.substring(e.index))},consume:function(t){if(0===this.tokens.length)throw io("ueoe","Unexpected end of expression: {0}",this.text);var e=this.expect(t);return e||this.throwError("is unexpected, expecting ["+t+"]",this.peek()),e},peekToken:function(){if(0===this.tokens.length)throw io("ueoe","Unexpected end of expression: {0}",this.text);return this.tokens[0]},peek:function(t,e,n,i){return this.peekAhead(0,t,e,n,i)},peekAhead:function(t,e,n,i,r){if(this.tokens.length>t){var o=this.tokens[t],a=o.text;if(a===e||a===n||a===i||a===r||!e&&!n&&!i&&!r)return o}return!1},expect:function(t,e,n,i){var r=this.peek(t,e,n,i);return r?(this.tokens.shift(),r):!1},constants:{"true":{type:co.Literal,value:!0},"false":{type:co.Literal,value:!1},"null":{type:co.Literal,value:null},undefined:{type:co.Literal,value:n},"this":{type:co.ThisExpression}}},cn.prototype={compile:function(t,e){var i=this,r=this.astBuilder.ast(t);this.state={nextId:0,filters:{},expensiveChecks:e,fn:{vars:[],body:[],own:{}},assign:{vars:[],body:[],own:{}},inputs:[]},rn(r,i.$filter);var a,s="";if(this.stage="assign",a=sn(r)){this.state.computing="assign";var u=this.nextId();this.recurse(a,u),this.return_(u),s="fn.assign="+this.generateFunction("assign","s,v,l")}var l=on(r.body);i.stage="inputs",o(l,function(t,e){var n="fn"+e;i.state[n]={vars:[],body:[],own:{}},i.state.computing=n;var r=i.nextId();i.recurse(t,r),i.return_(r),i.state.inputs.push(n),t.watchId=e}),this.state.computing="fn",this.stage="main",this.recurse(r);var c='"'+this.USE+" "+this.STRICT+'";\n'+this.filterPrefix()+"var fn="+this.generateFunction("fn","s,l,a,i")+s+this.watchFns()+"return fn;",d=new Function("$filter","ensureSafeMemberName","ensureSafeObject","ensureSafeFunction","getStringValue","ensureSafeAssignContext","ifDefined","plus","text",c)(this.$filter,Xe,Ze,Qe,Ke,Je,tn,en,t);return this.state=this.stage=n,d.literal=un(r),d.constant=ln(r),d},USE:"use",STRICT:"strict",watchFns:function(){var t=[],e=this.state.inputs,n=this;return o(e,function(e){t.push("var "+e+"="+n.generateFunction(e,"s"))}),e.length&&t.push("fn.inputs=["+e.join(",")+"];"),t.join("")},generateFunction:function(t,e){return"function("+e+"){"+this.varsPrefix(t)+this.body(t)+"};"},filterPrefix:function(){var t=[],e=this;return o(this.state.filters,function(n,i){t.push(n+"=$filter("+e.escape(i)+")")}),t.length?"var "+t.join(",")+";":""},varsPrefix:function(t){return this.state[t].vars.length?"var "+this.state[t].vars.join(",")+";":""},body:function(t){return this.state[t].body.join("")},recurse:function(t,e,i,r,a,s){var u,l,c,d,h=this;if(r=r||g,!s&&x(t.watchId))return e=e||this.nextId(),void this.if_("i",this.lazyAssign(e,this.computedMember("i",t.watchId)),this.lazyRecurse(t,e,i,r,a,!0));switch(t.type){case co.Program:o(t.body,function(e,i){h.recurse(e.expression,n,n,function(t){l=t}),i!==t.body.length-1?h.current().body.push(l,";"):h.return_(l)});break;case co.Literal:d=this.escape(t.value),this.assign(e,d),r(d);break;case co.UnaryExpression:this.recurse(t.argument,n,n,function(t){l=t}),d=t.operator+"("+this.ifDefined(l,0)+")",this.assign(e,d),r(d);break;case co.BinaryExpression:this.recurse(t.left,n,n,function(t){u=t}),this.recurse(t.right,n,n,function(t){l=t}),d="+"===t.operator?this.plus(u,l):"-"===t.operator?this.ifDefined(u,0)+t.operator+this.ifDefined(l,0):"("+u+")"+t.operator+"("+l+")",this.assign(e,d),r(d);break;case co.LogicalExpression:e=e||this.nextId(),h.recurse(t.left,e),h.if_("&&"===t.operator?e:h.not(e),h.lazyRecurse(t.right,e)),r(e);break;case co.ConditionalExpression:e=e||this.nextId(),h.recurse(t.test,e),h.if_(e,h.lazyRecurse(t.alternate,e),h.lazyRecurse(t.consequent,e)),r(e);break;case co.Identifier:e=e||this.nextId(),i&&(i.context="inputs"===h.stage?"s":this.assign(this.nextId(),this.getHasOwnProperty("l",t.name)+"?l:s"),i.computed=!1,i.name=t.name),Xe(t.name),h.if_("inputs"===h.stage||h.not(h.getHasOwnProperty("l",t.name)),function(){h.if_("inputs"===h.stage||"s",function(){a&&1!==a&&h.if_(h.not(h.nonComputedMember("s",t.name)),h.lazyAssign(h.nonComputedMember("s",t.name),"{}")),h.assign(e,h.nonComputedMember("s",t.name))})},e&&h.lazyAssign(e,h.nonComputedMember("l",t.name))),(h.state.expensiveChecks||hn(t.name))&&h.addEnsureSafeObject(e),r(e);break;case co.MemberExpression:u=i&&(i.context=this.nextId())||this.nextId(),e=e||this.nextId(),h.recurse(t.object,u,n,function(){h.if_(h.notNull(u),function(){a&&1!==a&&h.addEnsureSafeAssignContext(u),t.computed?(l=h.nextId(),h.recurse(t.property,l),h.getStringValue(l),h.addEnsureSafeMemberName(l),a&&1!==a&&h.if_(h.not(h.computedMember(u,l)),h.lazyAssign(h.computedMember(u,l),"{}")),d=h.ensureSafeObject(h.computedMember(u,l)),h.assign(e,d),i&&(i.computed=!0,i.name=l)):(Xe(t.property.name),a&&1!==a&&h.if_(h.not(h.nonComputedMember(u,t.property.name)),h.lazyAssign(h.nonComputedMember(u,t.property.name),"{}")),d=h.nonComputedMember(u,t.property.name),(h.state.expensiveChecks||hn(t.property.name))&&(d=h.ensureSafeObject(d)),h.assign(e,d),i&&(i.computed=!1,i.name=t.property.name))},function(){h.assign(e,"undefined")}),r(e)},!!a);break;case co.CallExpression:e=e||this.nextId(),t.filter?(l=h.filter(t.callee.name),c=[],o(t.arguments,function(t){var e=h.nextId();h.recurse(t,e),c.push(e)}),d=l+"("+c.join(",")+")",h.assign(e,d),r(e)):(l=h.nextId(),u={},c=[],h.recurse(t.callee,l,u,function(){h.if_(h.notNull(l),function(){h.addEnsureSafeFunction(l),o(t.arguments,function(t){h.recurse(t,h.nextId(),n,function(t){c.push(h.ensureSafeObject(t))})}),u.name?(h.state.expensiveChecks||h.addEnsureSafeObject(u.context),d=h.member(u.context,u.name,u.computed)+"("+c.join(",")+")"):d=l+"("+c.join(",")+")",d=h.ensureSafeObject(d),h.assign(e,d)},function(){h.assign(e,"undefined")}),r(e)}));break;case co.AssignmentExpression:if(l=this.nextId(),u={},!an(t.left))throw io("lval","Trying to assign a value to a non l-value");this.recurse(t.left,n,u,function(){h.if_(h.notNull(u.context),function(){h.recurse(t.right,l),h.addEnsureSafeObject(h.member(u.context,u.name,u.computed)),h.addEnsureSafeAssignContext(u.context),d=h.member(u.context,u.name,u.computed)+t.operator+l,h.assign(e,d),r(e||d)})},1);break;case co.ArrayExpression:c=[],o(t.elements,function(t){h.recurse(t,h.nextId(),n,function(t){c.push(t)})}),d="["+c.join(",")+"]",this.assign(e,d),r(d);break;case co.ObjectExpression:c=[],o(t.properties,function(t){h.recurse(t.value,h.nextId(),n,function(e){c.push(h.escape(t.key.type===co.Identifier?t.key.name:""+t.key.value)+":"+e)})}),d="{"+c.join(",")+"}",this.assign(e,d),r(d);break;case co.ThisExpression:this.assign(e,"s"),r("s");break;case co.NGValueParameter:this.assign(e,"v"),r("v")}},getHasOwnProperty:function(t,e){var n=t+"."+e,i=this.current().own;return i.hasOwnProperty(n)||(i[n]=this.nextId(!1,t+"&&("+this.escape(e)+" in "+t+")")),i[n]},assign:function(t,e){return t?(this.current().body.push(t,"=",e,";"),t):void 0},filter:function(t){return this.state.filters.hasOwnProperty(t)||(this.state.filters[t]=this.nextId(!0)),this.state.filters[t]},ifDefined:function(t,e){return"ifDefined("+t+","+this.escape(e)+")"},plus:function(t,e){return"plus("+t+","+e+")"},return_:function(t){this.current().body.push("return ",t,";")},if_:function(t,e,n){if(t===!0)e();else{var i=this.current().body;i.push("if(",t,"){"),e(),i.push("}"),n&&(i.push("else{"),n(),i.push("}"))}},not:function(t){return"!("+t+")"},notNull:function(t){return t+"!=null"},nonComputedMember:function(t,e){return t+"."+e},computedMember:function(t,e){return t+"["+e+"]"},member:function(t,e,n){return n?this.computedMember(t,e):this.nonComputedMember(t,e)},addEnsureSafeObject:function(t){this.current().body.push(this.ensureSafeObject(t),";")},addEnsureSafeMemberName:function(t){this.current().body.push(this.ensureSafeMemberName(t),";")},addEnsureSafeFunction:function(t){this.current().body.push(this.ensureSafeFunction(t),";")},addEnsureSafeAssignContext:function(t){this.current().body.push(this.ensureSafeAssignContext(t),";")},ensureSafeObject:function(t){return"ensureSafeObject("+t+",text)"},ensureSafeMemberName:function(t){return"ensureSafeMemberName("+t+",text)"},ensureSafeFunction:function(t){return"ensureSafeFunction("+t+",text)"},getStringValue:function(t){this.assign(t,"getStringValue("+t+",text)")},ensureSafeAssignContext:function(t){return"ensureSafeAssignContext("+t+",text)"},lazyRecurse:function(t,e,n,i,r,o){var a=this;return function(){a.recurse(t,e,n,i,r,o)}},lazyAssign:function(t,e){var n=this;return function(){n.assign(t,e)}},stringEscapeRegex:/[^ a-zA-Z0-9]/g,stringEscapeFn:function(t){return"\\u"+("0000"+t.charCodeAt(0).toString(16)).slice(-4)},escape:function(t){if($(t))return"'"+t.replace(this.stringEscapeRegex,this.stringEscapeFn)+"'";if(k(t))return t.toString();if(t===!0)return"true";if(t===!1)return"false";if(null===t)return"null";if("undefined"==typeof t)return"undefined";throw io("esc","IMPOSSIBLE")},nextId:function(t,e){var n="v"+this.state.nextId++;return t||this.current().vars.push(n+(e?"="+e:"")),n},current:function(){return this.state[this.state.computing]}},dn.prototype={compile:function(t,e){var n=this,i=this.astBuilder.ast(t);this.expression=t,this.expensiveChecks=e,rn(i,n.$filter);var r,a;(r=sn(i))&&(a=this.recurse(r));var s,u=on(i.body);u&&(s=[],o(u,function(t,e){var i=n.recurse(t);t.input=i,s.push(i),t.watchId=e}));var l=[];o(i.body,function(t){l.push(n.recurse(t.expression))});var c=0===i.body.length?function(){}:1===i.body.length?l[0]:function(t,e){var n;return o(l,function(i){n=i(t,e)}),n};return a&&(c.assign=function(t,e,n){return a(t,n,e)}),s&&(c.inputs=s),c.literal=un(i),c.constant=ln(i),c},recurse:function(t,e,i){var r,a,s,u=this;if(t.input)return this.inputs(t.input,t.watchId);switch(t.type){case co.Literal:return this.value(t.value,e);case co.UnaryExpression:return a=this.recurse(t.argument),this["unary"+t.operator](a,e);case co.BinaryExpression:return r=this.recurse(t.left),a=this.recurse(t.right),this["binary"+t.operator](r,a,e);case co.LogicalExpression:return r=this.recurse(t.left),a=this.recurse(t.right),this["binary"+t.operator](r,a,e);case co.ConditionalExpression:return this["ternary?:"](this.recurse(t.test),this.recurse(t.alternate),this.recurse(t.consequent),e);case co.Identifier:return Xe(t.name,u.expression),u.identifier(t.name,u.expensiveChecks||hn(t.name),e,i,u.expression);case co.MemberExpression:return r=this.recurse(t.object,!1,!!i),t.computed||(Xe(t.property.name,u.expression),a=t.property.name),t.computed&&(a=this.recurse(t.property)),t.computed?this.computedMember(r,a,e,i,u.expression):this.nonComputedMember(r,a,u.expensiveChecks,e,i,u.expression);case co.CallExpression:return s=[],o(t.arguments,function(t){s.push(u.recurse(t))}),t.filter&&(a=this.$filter(t.callee.name)),t.filter||(a=this.recurse(t.callee,!0)),t.filter?function(t,i,r,o){for(var u=[],l=0;l<s.length;++l)u.push(s[l](t,i,r,o));var c=a.apply(n,u,o);return e?{context:n,name:n,value:c}:c}:function(t,n,i,r){var o,l=a(t,n,i,r);if(null!=l.value){Ze(l.context,u.expression),Qe(l.value,u.expression);for(var c=[],d=0;d<s.length;++d)c.push(Ze(s[d](t,n,i,r),u.expression));o=Ze(l.value.apply(l.context,c),u.expression)}return e?{value:o}:o};case co.AssignmentExpression:return r=this.recurse(t.left,!0,1),a=this.recurse(t.right),function(t,n,i,o){var s=r(t,n,i,o),l=a(t,n,i,o);return Ze(s.value,u.expression),Je(s.context),s.context[s.name]=l,e?{value:l}:l};case co.ArrayExpression:return s=[],o(t.elements,function(t){s.push(u.recurse(t))}),function(t,n,i,r){for(var o=[],a=0;a<s.length;++a)o.push(s[a](t,n,i,r));return e?{value:o}:o};case co.ObjectExpression:return s=[],o(t.properties,function(t){s.push({key:t.key.type===co.Identifier?t.key.name:""+t.key.value,value:u.recurse(t.value)})}),function(t,n,i,r){for(var o={},a=0;a<s.length;++a)o[s[a].key]=s[a].value(t,n,i,r);return e?{value:o}:o};case co.ThisExpression:return function(t){return e?{value:t}:t};case co.NGValueParameter:return function(t,n,i,r){return e?{value:i}:i}}},"unary+":function(t,e){return function(n,i,r,o){var a=t(n,i,r,o);return a=x(a)?+a:0,e?{value:a}:a}},"unary-":function(t,e){return function(n,i,r,o){var a=t(n,i,r,o);return a=x(a)?-a:0,e?{value:a}:a}},"unary!":function(t,e){
return function(n,i,r,o){var a=!t(n,i,r,o);return e?{value:a}:a}},"binary+":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a),u=e(i,r,o,a),l=en(s,u);return n?{value:l}:l}},"binary-":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a),u=e(i,r,o,a),l=(x(s)?s:0)-(x(u)?u:0);return n?{value:l}:l}},"binary*":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)*e(i,r,o,a);return n?{value:s}:s}},"binary/":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)/e(i,r,o,a);return n?{value:s}:s}},"binary%":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)%e(i,r,o,a);return n?{value:s}:s}},"binary===":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)===e(i,r,o,a);return n?{value:s}:s}},"binary!==":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)!==e(i,r,o,a);return n?{value:s}:s}},"binary==":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)==e(i,r,o,a);return n?{value:s}:s}},"binary!=":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)!=e(i,r,o,a);return n?{value:s}:s}},"binary<":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)<e(i,r,o,a);return n?{value:s}:s}},"binary>":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)>e(i,r,o,a);return n?{value:s}:s}},"binary<=":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)<=e(i,r,o,a);return n?{value:s}:s}},"binary>=":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)>=e(i,r,o,a);return n?{value:s}:s}},"binary&&":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)&&e(i,r,o,a);return n?{value:s}:s}},"binary||":function(t,e,n){return function(i,r,o,a){var s=t(i,r,o,a)||e(i,r,o,a);return n?{value:s}:s}},"ternary?:":function(t,e,n,i){return function(r,o,a,s){var u=t(r,o,a,s)?e(r,o,a,s):n(r,o,a,s);return i?{value:u}:u}},value:function(t,e){return function(){return e?{context:n,name:n,value:t}:t}},identifier:function(t,e,i,r,o){return function(a,s,u,l){var c=s&&t in s?s:a;r&&1!==r&&c&&!c[t]&&(c[t]={});var d=c?c[t]:n;return e&&Ze(d,o),i?{context:c,name:t,value:d}:d}},computedMember:function(t,e,n,i,r){return function(o,a,s,u){var l,c,d=t(o,a,s,u);return null!=d&&(l=e(o,a,s,u),l=Ke(l),Xe(l,r),i&&1!==i&&(Je(d),d&&!d[l]&&(d[l]={})),c=d[l],Ze(c,r)),n?{context:d,name:l,value:c}:c}},nonComputedMember:function(t,e,i,r,o,a){return function(s,u,l,c){var d=t(s,u,l,c);o&&1!==o&&(Je(d),d&&!d[e]&&(d[e]={}));var h=null!=d?d[e]:n;return(i||hn(e))&&Ze(h,a),r?{context:d,name:e,value:h}:h}},inputs:function(t,e){return function(n,i,r,o){return o?o[e]:t(n,i,r)}}};var ho=function(t,e,n){this.lexer=t,this.$filter=e,this.options=n,this.ast=new co(this.lexer),this.astCompiler=n.csp?new dn(this.ast,e):new cn(this.ast,e)};ho.prototype={constructor:ho,parse:function(t){return this.astCompiler.compile(t,this.options.expensiveChecks)}};var fo=Object.prototype.valueOf,po=i("$sce"),go={HTML:"html",CSS:"css",URL:"url",RESOURCE_URL:"resourceUrl",JS:"js"},zr=i("$compile"),mo=e.createElement("a"),vo=Tn(t.location.href);On.$inject=["$document"],In.$inject=["$provide"];var yo=22,bo=".",xo="0";Ln.$inject=["$locale"],zn.$inject=["$locale"];var wo={yyyy:Bn("FullYear",4),yy:Bn("FullYear",2,0,!0),y:Bn("FullYear",1),MMMM:Vn("Month"),MMM:Vn("Month",!0),MM:Bn("Month",2,1),M:Bn("Month",1,1),dd:Bn("Date",2),d:Bn("Date",1),HH:Bn("Hours",2),H:Bn("Hours",1),hh:Bn("Hours",2,-12),h:Bn("Hours",1,-12),mm:Bn("Minutes",2),m:Bn("Minutes",1),ss:Bn("Seconds",2),s:Bn("Seconds",1),sss:Bn("Milliseconds",3),EEEE:Vn("Day"),EEE:Vn("Day",!0),a:Zn,Z:Yn,ww:Kn(2),w:Kn(1),G:Qn,GG:Qn,GGG:Qn,GGGG:Jn},_o=/((?:[^yMdHhmsaZEwG']+)|(?:'(?:[^']|'')*')|(?:E+|y+|M+|d+|H+|h+|m+|s+|a|Z|G+|w+))(.*)/,$o=/^\-?\d+$/;ti.$inject=["$locale"];var ko=v(Mi),Co=v(Si);ii.$inject=["$parse"];var Mo=v({restrict:"E",compile:function(t,e){return e.href||e.xlinkHref?void 0:function(t,e){if("a"===e[0].nodeName.toLowerCase()){var n="[object SVGAnimatedString]"===Hi.call(e.prop("href"))?"xlink:href":"href";e.on("click",function(t){e.attr(n)||t.preventDefault()})}}}}),Do={};o(_r,function(t,e){function n(t,n,r){t.$watch(r[i],function(t){r.$set(e,!!t)})}if("multiple"!=t){var i=he("ng-"+e),r=n;"checked"===t&&(r=function(t,e,r){r.ngModel!==r[i]&&n(t,e,r)}),Do[i]=function(){return{restrict:"A",priority:100,link:r}}}}),o(kr,function(t,e){Do[e]=function(){return{priority:100,link:function(t,n,i){if("ngPattern"===e&&"/"==i.ngPattern.charAt(0)){var r=i.ngPattern.match(ki);if(r)return void i.$set("ngPattern",new RegExp(r[1],r[2]))}t.$watch(i[e],function(t){i.$set(e,t)})}}}}),o(["src","srcset","href"],function(t){var e=he("ng-"+t);Do[e]=function(){return{priority:99,link:function(n,i,r){var o=t,a=t;"href"===t&&"[object SVGAnimatedString]"===Hi.call(i.prop("href"))&&(a="xlinkHref",r.$attr[a]="xlink:href",o=null),r.$observe(e,function(e){return e?(r.$set(a,e),void(Ei&&o&&i.prop(o,r[a]))):void("href"===t&&r.$set(a,null))})}}}});var So={$addControl:g,$$renameControl:oi,$removeControl:g,$setValidity:g,$setDirty:g,$setPristine:g,$setSubmitted:g},To="ng-submitted";ai.$inject=["$element","$attrs","$scope","$animate","$interpolate"];var Ao=function(t){return["$timeout","$parse",function(e,i){function r(t){return""===t?i('this[""]').assign:i(t).assign||g}var o={name:"form",restrict:t?"EAC":"E",require:["form","^^?form"],controller:ai,compile:function(i,o){i.addClass(ha).addClass(ca);var a=o.name?"name":t&&o.ngForm?"ngForm":!1;return{pre:function(t,i,o,s){var u=s[0];if(!("action"in o)){var l=function(e){t.$apply(function(){u.$commitViewValue(),u.$setSubmitted()}),e.preventDefault()};lr(i[0],"submit",l),i.on("$destroy",function(){e(function(){cr(i[0],"submit",l)},0,!1)})}var c=s[1]||u.$$parentForm;c.$addControl(u);var h=a?r(u.$name):g;a&&(h(t,u),o.$observe(a,function(e){u.$name!==e&&(h(t,n),u.$$parentForm.$$renameControl(u,e),(h=r(u.$name))(t,u))})),i.on("$destroy",function(){u.$$parentForm.$removeControl(u),h(t,n),d(u,So)})}}}};return o}]},Eo=Ao(),Oo=Ao(!0),No=/\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+([+-][0-2]\d:[0-5]\d|Z)/,Io=/^[a-z][a-z\d.+-]*:\/*(?:[^:@]+(?::[^@]+)?@)?(?:[^\s:/?#]+|\[[a-f\d:]+\])(?::\d+)?(?:\/[^?#]*)?(?:\?[^#]*)?(?:#.*)?$/i,Po=/^[a-z0-9!#$%&'*+\/=?^_`{|}~.-]+@[a-z0-9]([a-z0-9-]*[a-z0-9])?(\.[a-z0-9]([a-z0-9-]*[a-z0-9])?)*$/i,Fo=/^\s*(\-|\+)?(\d+|(\d*(\.\d*)))([eE][+-]?\d+)?\s*$/,Wo=/^(\d{4})-(\d{2})-(\d{2})$/,Ho=/^(\d{4})-(\d\d)-(\d\d)T(\d\d):(\d\d)(?::(\d\d)(\.\d{1,3})?)?$/,Lo=/^(\d{4})-W(\d\d)$/,zo=/^(\d{4})-(\d\d)$/,jo=/^(\d\d):(\d\d)(?::(\d\d)(\.\d{1,3})?)?$/,Ro="keydown wheel mousedown",Uo=mt();o("date,datetime-local,month,time,week".split(","),function(t){Uo[t]=!0});var qo={text:ui,date:hi("date",Wo,di(Wo,["yyyy","MM","dd"]),"yyyy-MM-dd"),"datetime-local":hi("datetimelocal",Ho,di(Ho,["yyyy","MM","dd","HH","mm","ss","sss"]),"yyyy-MM-ddTHH:mm:ss.sss"),time:hi("time",jo,di(jo,["HH","mm","ss","sss"]),"HH:mm:ss.sss"),week:hi("week",Lo,ci,"yyyy-Www"),month:hi("month",zo,di(zo,["yyyy","MM"]),"yyyy-MM"),number:pi,url:gi,email:mi,radio:vi,checkbox:bi,hidden:g,button:g,submit:g,reset:g,file:g},Bo=["$browser","$sniffer","$filter","$parse",function(t,e,n,i){return{restrict:"E",require:["?ngModel"],link:{pre:function(r,o,a,s){s[0]&&(qo[Mi(a.type)]||qo.text)(r,o,a,s[0],e,t,n,i)}}}}],Vo=/^(true|false|\d+)$/,Yo=function(){return{restrict:"A",priority:100,compile:function(t,e){return Vo.test(e.ngValue)?function(t,e,n){n.$set("value",t.$eval(n.ngValue))}:function(t,e,n){t.$watch(n.ngValue,function(t){n.$set("value",t)})}}}},Go=["$compile",function(t){return{restrict:"AC",compile:function(e){return t.$$addBindingClass(e),function(e,n,i){t.$$addBindingInfo(n,i.ngBind),n=n[0],e.$watch(i.ngBind,function(t){n.textContent=b(t)?"":t})}}}}],Xo=["$interpolate","$compile",function(t,e){return{compile:function(n){return e.$$addBindingClass(n),function(n,i,r){var o=t(i.attr(r.$attr.ngBindTemplate));e.$$addBindingInfo(i,o.expressions),i=i[0],r.$observe("ngBindTemplate",function(t){i.textContent=b(t)?"":t})}}}}],Ko=["$sce","$parse","$compile",function(t,e,n){return{restrict:"A",compile:function(i,r){var o=e(r.ngBindHtml),a=e(r.ngBindHtml,function(e){return t.valueOf(e)});return n.$$addBindingClass(i),function(e,i,r){n.$$addBindingInfo(i,r.ngBindHtml),e.$watch(a,function(){var n=o(e);i.html(t.getTrustedHtml(n)||"")})}}}}],Zo=v({restrict:"A",require:"ngModel",link:function(t,e,n,i){i.$viewChangeListeners.push(function(){t.$eval(n.ngChange)})}}),Qo=xi("",!0),Jo=xi("Odd",0),ta=xi("Even",1),ea=ri({compile:function(t,e){e.$set("ngCloak",n),t.removeClass("ng-cloak")}}),na=[function(){return{restrict:"A",scope:!0,controller:"@",priority:500}}],ia={},ra={blur:!0,focus:!0};o("click dblclick mousedown mouseup mouseover mouseout mousemove mouseenter mouseleave keydown keyup keypress submit focus blur copy cut paste".split(" "),function(t){var e=he("ng-"+t);ia[e]=["$parse","$rootScope",function(n,i){return{restrict:"A",compile:function(r,o){var a=n(o[e],null,!0);return function(e,n){n.on(t,function(n){var r=function(){a(e,{$event:n})};ra[t]&&i.$$phase?e.$evalAsync(r):e.$apply(r)})}}}}]});var oa=["$animate",function(t){return{multiElement:!0,transclude:"element",priority:600,terminal:!0,restrict:"A",$$tlb:!0,link:function(n,i,r,o,a){var s,u,l;n.$watch(r.ngIf,function(n){n?u||a(function(n,o){u=o,n[n.length++]=e.createComment(" end ngIf: "+r.ngIf+" "),s={clone:n},t.enter(n,i.parent(),i)}):(l&&(l.remove(),l=null),u&&(u.$destroy(),u=null),s&&(l=gt(s.clone),t.leave(l).then(function(){l=null}),s=null))})}}}],aa=["$templateRequest","$anchorScroll","$animate",function(t,e,n){return{restrict:"ECA",priority:400,terminal:!0,transclude:"element",controller:ji.noop,compile:function(i,r){var o=r.ngInclude||r.src,a=r.onload||"",s=r.autoscroll;return function(i,r,u,l,c){var d,h,f,p=0,g=function(){h&&(h.remove(),h=null),d&&(d.$destroy(),d=null),f&&(n.leave(f).then(function(){h=null}),h=f,f=null)};i.$watch(o,function(o){var u=function(){!x(s)||s&&!i.$eval(s)||e()},h=++p;o?(t(o,!0).then(function(t){if(!i.$$destroyed&&h===p){var e=i.$new();l.template=t;var s=c(e,function(t){g(),n.enter(t,null,r).then(u)});d=e,f=s,d.$emit("$includeContentLoaded",o),i.$eval(a)}},function(){i.$$destroyed||h===p&&(g(),i.$emit("$includeContentError",o))}),i.$emit("$includeContentRequested",o)):(g(),l.template=null)})}}}}],sa=["$compile",function(t){return{restrict:"ECA",priority:-400,require:"ngInclude",link:function(n,i,r,o){return/SVG/.test(i[0].toString())?(i.empty(),void t(Mt(o.template,e).childNodes)(n,function(t){i.append(t)},{futureParentElement:i})):(i.html(o.template),void t(i.contents())(n))}}}],ua=ri({priority:450,compile:function(){return{pre:function(t,e,n){t.$eval(n.ngInit)}}}}),la=function(){return{restrict:"A",priority:100,require:"ngModel",link:function(t,e,i,r){var a=e.attr(i.$attr.ngList)||", ",s="false"!==i.ngTrim,u=s?Vi(a):a,l=function(t){if(!b(t)){var e=[];return t&&o(t.split(u),function(t){t&&e.push(s?Vi(t):t)}),e}};r.$parsers.push(l),r.$formatters.push(function(t){return qi(t)?t.join(a):n}),r.$isEmpty=function(t){return!t||!t.length}}}},ca="ng-valid",da="ng-invalid",ha="ng-pristine",fa="ng-dirty",pa="ng-untouched",ga="ng-touched",ma="ng-pending",va=i("ngModel"),ya=["$scope","$exceptionHandler","$attrs","$element","$parse","$animate","$timeout","$rootScope","$q","$interpolate",function(t,e,i,r,a,s,u,l,c,d){this.$viewValue=Number.NaN,this.$modelValue=Number.NaN,this.$$rawModelValue=n,this.$validators={},this.$asyncValidators={},this.$parsers=[],this.$formatters=[],this.$viewChangeListeners=[],this.$untouched=!0,this.$touched=!1,this.$pristine=!0,this.$dirty=!1,this.$valid=!0,this.$invalid=!1,this.$error={},this.$$success={},this.$pending=n,this.$name=d(i.name||"",!1)(t),this.$$parentForm=So;var h,f=a(i.ngModel),p=f.assign,m=f,v=p,y=null,w=this;this.$$setOptions=function(t){if(w.$options=t,t&&t.getterSetter){var e=a(i.ngModel+"()"),n=a(i.ngModel+"($$$p)");m=function(t){var n=f(t);return M(n)&&(n=e(t)),n},v=function(t,e){M(f(t))?n(t,{$$$p:w.$modelValue}):p(t,w.$modelValue)}}else if(!f.assign)throw va("nonassign","Expression '{0}' is non-assignable. Element: {1}",i.ngModel,Q(r))},this.$render=g,this.$isEmpty=function(t){return b(t)||""===t||null===t||t!==t};var _=0;wi({ctrl:this,$element:r,set:function(t,e){t[e]=!0},unset:function(t,e){delete t[e]},$animate:s}),this.$setPristine=function(){w.$dirty=!1,w.$pristine=!0,s.removeClass(r,fa),s.addClass(r,ha)},this.$setDirty=function(){w.$dirty=!0,w.$pristine=!1,s.removeClass(r,ha),s.addClass(r,fa),w.$$parentForm.$setDirty()},this.$setUntouched=function(){w.$touched=!1,w.$untouched=!0,s.setClass(r,pa,ga)},this.$setTouched=function(){w.$touched=!0,w.$untouched=!1,s.setClass(r,ga,pa)},this.$rollbackViewValue=function(){u.cancel(y),w.$viewValue=w.$$lastCommittedViewValue,w.$render()},this.$validate=function(){if(!k(w.$modelValue)||!isNaN(w.$modelValue)){var t=w.$$lastCommittedViewValue,e=w.$$rawModelValue,i=w.$valid,r=w.$modelValue,o=w.$options&&w.$options.allowInvalid;w.$$runValidators(e,t,function(t){o||i===t||(w.$modelValue=t?e:n,w.$modelValue!==r&&w.$$writeModelToScope())})}},this.$$runValidators=function(t,e,i){function r(){var t=w.$$parserName||"parse";return b(h)?(u(t,null),!0):(h||(o(w.$validators,function(t,e){u(e,null)}),o(w.$asyncValidators,function(t,e){u(e,null)})),u(t,h),h)}function a(){var n=!0;return o(w.$validators,function(i,r){var o=i(t,e);n=n&&o,u(r,o)}),n?!0:(o(w.$asyncValidators,function(t,e){u(e,null)}),!1)}function s(){var i=[],r=!0;o(w.$asyncValidators,function(o,a){var s=o(t,e);if(!I(s))throw va("nopromise","Expected asynchronous validator to return a promise but got '{0}' instead.",s);u(a,n),i.push(s.then(function(){u(a,!0)},function(t){r=!1,u(a,!1)}))}),i.length?c.all(i).then(function(){l(r)},g):l(!0)}function u(t,e){d===_&&w.$setValidity(t,e)}function l(t){d===_&&i(t)}_++;var d=_;return r()&&a()?void s():void l(!1)},this.$commitViewValue=function(){var t=w.$viewValue;u.cancel(y),(w.$$lastCommittedViewValue!==t||""===t&&w.$$hasNativeValidators)&&(w.$$lastCommittedViewValue=t,w.$pristine&&this.$setDirty(),this.$$parseAndValidate())},this.$$parseAndValidate=function(){function e(){w.$modelValue!==a&&w.$$writeModelToScope()}var i=w.$$lastCommittedViewValue,r=i;if(h=b(r)?n:!0)for(var o=0;o<w.$parsers.length;o++)if(r=w.$parsers[o](r),b(r)){h=!1;break}k(w.$modelValue)&&isNaN(w.$modelValue)&&(w.$modelValue=m(t));var a=w.$modelValue,s=w.$options&&w.$options.allowInvalid;w.$$rawModelValue=r,s&&(w.$modelValue=r,e()),w.$$runValidators(r,w.$$lastCommittedViewValue,function(t){s||(w.$modelValue=t?r:n,e())})},this.$$writeModelToScope=function(){v(t,w.$modelValue),o(w.$viewChangeListeners,function(t){try{t()}catch(n){e(n)}})},this.$setViewValue=function(t,e){w.$viewValue=t,(!w.$options||w.$options.updateOnDefault)&&w.$$debounceViewValueCommit(e)},this.$$debounceViewValueCommit=function(e){var n,i=0,r=w.$options;r&&x(r.debounce)&&(n=r.debounce,k(n)?i=n:k(n[e])?i=n[e]:k(n["default"])&&(i=n["default"])),u.cancel(y),i?y=u(function(){w.$commitViewValue()},i):l.$$phase?w.$commitViewValue():t.$apply(function(){w.$commitViewValue()})},t.$watch(function(){var e=m(t);if(e!==w.$modelValue&&(w.$modelValue===w.$modelValue||e===e)){w.$modelValue=w.$$rawModelValue=e,h=n;for(var i=w.$formatters,r=i.length,o=e;r--;)o=i[r](o);w.$viewValue!==o&&(w.$viewValue=w.$$lastCommittedViewValue=o,w.$render(),w.$$runValidators(e,o,g))}return e})}],ba=["$rootScope",function(t){return{restrict:"A",require:["ngModel","^?form","^?ngModelOptions"],controller:ya,priority:1,compile:function(e){return e.addClass(ha).addClass(pa).addClass(ca),{pre:function(t,e,n,i){var r=i[0],o=i[1]||r.$$parentForm;r.$$setOptions(i[2]&&i[2].$options),o.$addControl(r),n.$observe("name",function(t){r.$name!==t&&r.$$parentForm.$$renameControl(r,t)}),t.$on("$destroy",function(){r.$$parentForm.$removeControl(r)})},post:function(e,n,i,r){var o=r[0];o.$options&&o.$options.updateOn&&n.on(o.$options.updateOn,function(t){o.$$debounceViewValueCommit(t&&t.type)}),n.on("blur",function(n){o.$touched||(t.$$phase?e.$evalAsync(o.$setTouched):e.$apply(o.$setTouched))})}}}}}],xa=/(\s+|^)default(\s+|$)/,wa=function(){return{restrict:"A",controller:["$scope","$attrs",function(t,e){var n=this;this.$options=z(t.$eval(e.ngModelOptions)),x(this.$options.updateOn)?(this.$options.updateOnDefault=!1,this.$options.updateOn=Vi(this.$options.updateOn.replace(xa,function(){return n.$options.updateOnDefault=!0," "}))):this.$options.updateOnDefault=!0}]}},_a=ri({terminal:!0,priority:1e3}),$a=i("ngOptions"),ka=/^\s*([\s\S]+?)(?:\s+as\s+([\s\S]+?))?(?:\s+group\s+by\s+([\s\S]+?))?(?:\s+disable\s+when\s+([\s\S]+?))?\s+for\s+(?:([\$\w][\$\w]*)|(?:\(\s*([\$\w][\$\w]*)\s*,\s*([\$\w][\$\w]*)\s*\)))\s+in\s+([\s\S]+?)(?:\s+track\s+by\s+([\s\S]+?))?$/,Ca=["$compile","$parse",function(t,n){function i(t,e,i){function o(t,e,n,i,r){this.selectValue=t,this.viewValue=e,this.label=n,this.group=i,this.disabled=r}function a(t){var e;if(!l&&r(t))e=t;else{e=[];for(var n in t)t.hasOwnProperty(n)&&"$"!==n.charAt(0)&&e.push(n)}return e}var s=t.match(ka);if(!s)throw $a("iexp","Expected expression in form of '_select_ (as _label_)? for (_key_,)?_value_ in _collection_' but got '{0}'. Element: {1}",t,Q(e));var u=s[5]||s[7],l=s[6],c=/ as /.test(s[0])&&s[1],d=s[9],h=n(s[2]?s[1]:u),f=c&&n(c),p=f||h,g=d&&n(d),m=d?function(t,e){return g(i,e)}:function(t){return Zt(t)},v=function(t,e){return m(t,$(t,e))},y=n(s[2]||s[1]),b=n(s[3]||""),x=n(s[4]||""),w=n(s[8]),_={},$=l?function(t,e){return _[l]=e,_[u]=t,_}:function(t){return _[u]=t,_};return{trackBy:d,getTrackByValue:v,getWatchables:n(w,function(t){var e=[];t=t||[];for(var n=a(t),r=n.length,o=0;r>o;o++){var u=t===n?o:n[o],l=(t[u],$(t[u],u)),c=m(t[u],l);if(e.push(c),s[2]||s[1]){var d=y(i,l);e.push(d)}if(s[4]){var h=x(i,l);e.push(h)}}return e}),getOptions:function(){for(var t=[],e={},n=w(i)||[],r=a(n),s=r.length,u=0;s>u;u++){var l=n===r?u:r[u],c=n[l],h=$(c,l),f=p(i,h),g=m(f,h),_=y(i,h),k=b(i,h),C=x(i,h),M=new o(g,f,_,k,C);t.push(M),e[g]=M}return{items:t,selectValueMap:e,getOptionFromViewValue:function(t){return e[v(t)]},getViewValueFromOption:function(t){return d?ji.copy(t.viewValue):t.viewValue}}}}}function a(e,n,r,a){function l(t,e){t.element=e,e.disabled=t.disabled,t.label!==e.label&&(e.label=t.label,e.textContent=t.label),t.value!==e.value&&(e.value=t.selectValue)}function c(t,e,n,i){var r;return e&&Mi(e.nodeName)===n?r=e:(r=i.cloneNode(!1),e?t.insertBefore(r,e):t.appendChild(r)),r}function d(t){for(var e;t;)e=t.nextSibling,Ut(t),t=e}function h(t){var e=g&&g[0],n=_&&_[0];if(e||n)for(;t&&(t===e||t===n||t.nodeType===ir||"option"===H(t)&&""===t.value);)t=t.nextSibling;return t}function f(){var t=$&&m.readValue();$=k.getOptions();var e={},i=n[0].firstChild;if(w&&n.prepend(g),i=h(i),$.items.forEach(function(t){var r,o,a;t.group?(r=e[t.group],r||(o=c(n[0],i,"optgroup",u),i=o.nextSibling,o.label=t.group,r=e[t.group]={groupElement:o,currentOptionElement:o.firstChild}),a=c(r.groupElement,r.currentOptionElement,"option",s),l(t,a),r.currentOptionElement=a.nextSibling):(a=c(n[0],i,"option",s),l(t,a),i=a.nextSibling)}),Object.keys(e).forEach(function(t){d(e[t].currentOptionElement)}),d(i),p.$render(),!p.$isEmpty(t)){var r=m.readValue(),o=k.trackBy||v;(o?R(t,r):t===r)||(p.$setViewValue(r),p.$render())}}var p=a[1];if(p){for(var g,m=a[0],v=r.multiple,y=0,b=n.children(),x=b.length;x>y;y++)if(""===b[y].value){g=b.eq(y);break}var w=!!g,_=Oi(s.cloneNode(!1));_.val("?");var $,k=i(r.ngOptions,n,e),C=function(){w||n.prepend(g),n.val(""),g.prop("selected",!0),g.attr("selected",!0)},M=function(){w||g.remove()},D=function(){n.prepend(_),n.val("?"),_.prop("selected",!0),_.attr("selected",!0)},S=function(){_.remove()};v?(p.$isEmpty=function(t){return!t||0===t.length},m.writeValue=function(t){$.items.forEach(function(t){t.element.selected=!1}),t&&t.forEach(function(t){var e=$.getOptionFromViewValue(t);e&&!e.disabled&&(e.element.selected=!0)})},m.readValue=function(){var t=n.val()||[],e=[];return o(t,function(t){var n=$.selectValueMap[t];n&&!n.disabled&&e.push($.getViewValueFromOption(n))}),e},k.trackBy&&e.$watchCollection(function(){return qi(p.$viewValue)?p.$viewValue.map(function(t){return k.getTrackByValue(t)}):void 0},function(){p.$render()})):(m.writeValue=function(t){var e=$.getOptionFromViewValue(t);e&&!e.disabled?(n[0].value!==e.selectValue&&(S(),M(),n[0].value=e.selectValue,e.element.selected=!0),e.element.setAttribute("selected","selected")):null===t||w?(S(),C()):(M(),D())},m.readValue=function(){var t=$.selectValueMap[n.val()];return t&&!t.disabled?(M(),S(),$.getViewValueFromOption(t)):null},k.trackBy&&e.$watch(function(){return k.getTrackByValue(p.$viewValue)},function(){p.$render()})),w?(g.remove(),t(g)(e),g.removeClass("ng-scope")):g=Oi(s.cloneNode(!1)),f(),e.$watchCollection(k.getWatchables,f)}}var s=e.createElement("option"),u=e.createElement("optgroup");return{restrict:"A",terminal:!0,require:["select","?ngModel"],link:{pre:function(t,e,n,i){i[0].registerOption=g},post:a}}}],Ma=["$locale","$interpolate","$log",function(t,e,n){var i=/{}/g,r=/^when(Minus)?(.+)$/;return{link:function(a,s,u){function l(t){s.text(t||"")}var c,d=u.count,h=u.$attr.when&&s.attr(u.$attr.when),f=u.offset||0,p=a.$eval(h)||{},m={},v=e.startSymbol(),y=e.endSymbol(),x=v+d+"-"+f+y,w=ji.noop;o(u,function(t,e){var n=r.exec(e);if(n){var i=(n[1]?"-":"")+Mi(n[2]);p[i]=s.attr(u.$attr[e])}}),o(p,function(t,n){m[n]=e(t.replace(i,x))}),a.$watch(d,function(e){var i=parseFloat(e),r=isNaN(i);if(r||i in p||(i=t.pluralCat(i-f)),i!==c&&!(r&&k(c)&&isNaN(c))){w();var o=m[i];b(o)?(null!=e&&n.debug("ngPluralize: no rule defined for '"+i+"' in "+h),w=g,l()):w=a.$watch(o,l),c=i}})}}}],Da=["$parse","$animate",function(t,a){var s="$$NG_REMOVED",u=i("ngRepeat"),l=function(t,e,n,i,r,o,a){t[n]=i,r&&(t[r]=o),t.$index=e,t.$first=0===e,t.$last=e===a-1,t.$middle=!(t.$first||t.$last),t.$odd=!(t.$even=0===(1&e))},c=function(t){return t.clone[0]},d=function(t){return t.clone[t.clone.length-1]};return{restrict:"A",multiElement:!0,transclude:"element",priority:1e3,terminal:!0,$$tlb:!0,compile:function(i,h){var f=h.ngRepeat,p=e.createComment(" end ngRepeat: "+f+" "),g=f.match(/^\s*([\s\S]+?)\s+in\s+([\s\S]+?)(?:\s+as\s+([\s\S]+?))?(?:\s+track\s+by\s+([\s\S]+?))?\s*$/);if(!g)throw u("iexp","Expected expression in form of '_item_ in _collection_[ track by _id_]' but got '{0}'.",f);var m=g[1],v=g[2],y=g[3],b=g[4];if(g=m.match(/^(?:(\s*[\$\w]+)|\(\s*([\$\w]+)\s*,\s*([\$\w]+)\s*\))$/),!g)throw u("iidexp","'_item_' in '_item_ in _collection_' should be an identifier or '(_key_, _value_)' expression, but got '{0}'.",m);var x=g[3]||g[1],w=g[2];if(y&&(!/^[$a-zA-Z_][$a-zA-Z0-9_]*$/.test(y)||/^(null|undefined|this|\$index|\$first|\$middle|\$last|\$even|\$odd|\$parent|\$root|\$id)$/.test(y)))throw u("badident","alias '{0}' is invalid --- must be a valid JS identifier which is not a reserved name.",y);var _,$,k,C,M={$id:Zt};return b?_=t(b):(k=function(t,e){return Zt(e)},C=function(t){return t}),function(t,e,i,h,g){_&&($=function(e,n,i){return w&&(M[w]=e),M[x]=n,M.$index=i,_(t,M)});var m=mt();t.$watchCollection(v,function(i){var h,v,b,_,M,D,S,T,A,E,O,N,I=e[0],P=mt();if(y&&(t[y]=i),r(i))A=i,T=$||k;else{T=$||C,A=[];for(var F in i)Di.call(i,F)&&"$"!==F.charAt(0)&&A.push(F)}for(_=A.length,O=new Array(_),h=0;_>h;h++)if(M=i===A?h:A[h],D=i[M],S=T(M,D,h),m[S])E=m[S],delete m[S],P[S]=E,O[h]=E;else{if(P[S])throw o(O,function(t){t&&t.scope&&(m[t.id]=t)}),u("dupes","Duplicates in a repeater are not allowed. Use 'track by' expression to specify unique keys. Repeater: {0}, Duplicate key: {1}, Duplicate value: {2}",f,S,D);O[h]={id:S,scope:n,clone:n},P[S]=!0}for(var W in m){if(E=m[W],N=gt(E.clone),a.leave(N),N[0].parentNode)for(h=0,v=N.length;v>h;h++)N[h][s]=!0;E.scope.$destroy()}for(h=0;_>h;h++)if(M=i===A?h:A[h],D=i[M],E=O[h],E.scope){b=I;do b=b.nextSibling;while(b&&b[s]);c(E)!=b&&a.move(gt(E.clone),null,I),I=d(E),l(E.scope,h,x,D,w,M,_)}else g(function(t,e){E.scope=e;var n=p.cloneNode(!1);t[t.length++]=n,a.enter(t,null,I),I=n,E.clone=t,P[E.id]=E,l(E.scope,h,x,D,w,M,_)});m=P})}}}}],Sa="ng-hide",Ta="ng-hide-animate",Aa=["$animate",function(t){return{restrict:"A",multiElement:!0,link:function(e,n,i){e.$watch(i.ngShow,function(e){t[e?"removeClass":"addClass"](n,Sa,{tempClasses:Ta})})}}}],Ea=["$animate",function(t){return{restrict:"A",multiElement:!0,link:function(e,n,i){e.$watch(i.ngHide,function(e){t[e?"addClass":"removeClass"](n,Sa,{tempClasses:Ta})})}}}],Oa=ri(function(t,e,n){t.$watch(n.ngStyle,function(t,n){n&&t!==n&&o(n,function(t,n){e.css(n,"")}),t&&e.css(t)},!0)}),Na=["$animate",function(t){return{require:"ngSwitch",controller:["$scope",function(){this.cases={}}],link:function(n,i,r,a){var s=r.ngSwitch||r.on,u=[],l=[],c=[],d=[],h=function(t,e){return function(){t.splice(e,1)}};n.$watch(s,function(n){var i,r;for(i=0,r=c.length;r>i;++i)t.cancel(c[i]);for(c.length=0,i=0,r=d.length;r>i;++i){var s=gt(l[i].clone);d[i].$destroy();var f=c[i]=t.leave(s);f.then(h(c,i))}l.length=0,d.length=0,(u=a.cases["!"+n]||a.cases["?"])&&o(u,function(n){n.transclude(function(i,r){d.push(r);var o=n.element;i[i.length++]=e.createComment(" end ngSwitchWhen: ");var a={clone:i};l.push(a),t.enter(i,o.parent(),o)})})})}}}],Ia=ri({transclude:"element",priority:1200,require:"^ngSwitch",multiElement:!0,link:function(t,e,n,i,r){i.cases["!"+n.ngSwitchWhen]=i.cases["!"+n.ngSwitchWhen]||[],i.cases["!"+n.ngSwitchWhen].push({transclude:r,element:e})}}),Pa=ri({transclude:"element",priority:1200,require:"^ngSwitch",multiElement:!0,link:function(t,e,n,i,r){i.cases["?"]=i.cases["?"]||[],i.cases["?"].push({transclude:r,element:e})}}),Fa=ri({restrict:"EAC",link:function(t,e,n,r,o){if(!o)throw i("ngTransclude")("orphan","Illegal use of ngTransclude directive in the template! No parent directive that requires a transclusion found. Element: {0}",Q(e));o(function(t){e.empty(),e.append(t)})}}),Wa=["$templateCache",function(t){return{restrict:"E",terminal:!0,compile:function(e,n){if("text/ng-template"==n.type){var i=n.id,r=e[0].text;t.put(i,r)}}}}],Ha={$setViewValue:g,$render:g},La=["$element","$scope","$attrs",function(t,i,r){var o=this,a=new Qt;o.ngModelCtrl=Ha,o.unknownOption=Oi(e.createElement("option")),o.renderUnknownOption=function(e){var n="? "+Zt(e)+" ?";o.unknownOption.val(n),t.prepend(o.unknownOption),t.val(n)},i.$on("$destroy",function(){o.renderUnknownOption=g}),o.removeUnknownOption=function(){o.unknownOption.parent()&&o.unknownOption.remove()},o.readValue=function(){return o.removeUnknownOption(),t.val()},o.writeValue=function(e){o.hasOption(e)?(o.removeUnknownOption(),t.val(e),""===e&&o.emptyOption.prop("selected",!0)):null==e&&o.emptyOption?(o.removeUnknownOption(),t.val("")):o.renderUnknownOption(e)},o.addOption=function(t,e){if(e[0].nodeType!==ir){ft(t,'"option value"'),""===t&&(o.emptyOption=e);var n=a.get(t)||0;a.put(t,n+1),o.ngModelCtrl.$render(),$i(e)}},o.removeOption=function(t){var e=a.get(t);e&&(1===e?(a.remove(t),""===t&&(o.emptyOption=n)):a.put(t,e-1))},o.hasOption=function(t){return!!a.get(t)},o.registerOption=function(t,e,n,i,r){if(i){var a;n.$observe("value",function(t){x(a)&&o.removeOption(a),a=t,o.addOption(t,e)})}else r?t.$watch(r,function(t,i){n.$set("value",t),i!==t&&o.removeOption(i),o.addOption(t,e)}):o.addOption(n.value,e);e.on("$destroy",function(){o.removeOption(n.value),o.ngModelCtrl.$render()})}}],za=function(){function t(t,e,n,i){var r=i[1];if(r){var a=i[0];if(a.ngModelCtrl=r,e.on("change",function(){t.$apply(function(){r.$setViewValue(a.readValue())})}),n.multiple){a.readValue=function(){var t=[];return o(e.find("option"),function(e){e.selected&&t.push(e.value)}),t},a.writeValue=function(t){var n=new Qt(t);o(e.find("option"),function(t){t.selected=x(n.get(t.value))})};var s,u=NaN;t.$watch(function(){u!==r.$viewValue||R(s,r.$viewValue)||(s=j(r.$viewValue),r.$render()),u=r.$viewValue}),r.$isEmpty=function(t){return!t||0===t.length}}}}function e(t,e,n,i){var r=i[1];if(r){var o=i[0];r.$render=function(){o.writeValue(r.$viewValue)}}}return{restrict:"E",require:["select","?ngModel"],controller:La,priority:1,link:{pre:t,post:e}}},ja=["$interpolate",function(t){return{restrict:"E",priority:100,compile:function(e,n){if(x(n.value))var i=t(n.value,!0);else{var r=t(e.text(),!0);r||n.$set("value",e.text())}return function(t,e,n){var o="$selectController",a=e.parent(),s=a.data(o)||a.parent().data(o);s&&s.registerOption(t,e,n,i,r)}}}}],Ra=v({restrict:"E",terminal:!1}),Ua=function(){return{restrict:"A",require:"?ngModel",link:function(t,e,n,i){i&&(n.required=!0,i.$validators.required=function(t,e){return!n.required||!i.$isEmpty(e)},n.$observe("required",function(){i.$validate()}))}}},qa=function(){return{restrict:"A",require:"?ngModel",link:function(t,e,r,o){if(o){var a,s=r.ngPattern||r.pattern;r.$observe("pattern",function(t){if($(t)&&t.length>0&&(t=new RegExp("^"+t+"$")),t&&!t.test)throw i("ngPattern")("noregexp","Expected {0} to be a RegExp but was {1}. Element: {2}",s,t,Q(e));a=t||n,o.$validate()}),o.$validators.pattern=function(t,e){return o.$isEmpty(e)||b(a)||a.test(e)}}}}},Ba=function(){return{restrict:"A",require:"?ngModel",link:function(t,e,n,i){if(i){var r=-1;n.$observe("maxlength",function(t){var e=f(t);r=isNaN(e)?-1:e,i.$validate()}),i.$validators.maxlength=function(t,e){return 0>r||i.$isEmpty(e)||e.length<=r}}}}},Va=function(){return{restrict:"A",require:"?ngModel",link:function(t,e,n,i){if(i){var r=0;n.$observe("minlength",function(t){r=f(t)||0,i.$validate()}),i.$validators.minlength=function(t,e){return i.$isEmpty(e)||e.length>=r}}}}};return t.angular.bootstrap?void(t.console&&console.log("WARNING: Tried to load angular more than once.")):(ct(),xt(ji),ji.module("ngLocale",[],["$provide",function(t){function e(t){t+="";var e=t.indexOf(".");return-1==e?0:t.length-e-1}function i(t,i){var r=i;n===r&&(r=Math.min(e(t),3));var o=Math.pow(10,r),a=(t*o|0)%o;return{v:r,f:a}}var r={ZERO:"zero",ONE:"one",TWO:"two",FEW:"few",MANY:"many",OTHER:"other"};t.value("$locale",{DATETIME_FORMATS:{AMPMS:["AM","PM"],DAY:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],ERANAMES:["Before Christ","Anno Domini"],ERAS:["BC","AD"],FIRSTDAYOFWEEK:6,MONTH:["January","February","March","April","May","June","July","August","September","October","November","December"],SHORTDAY:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],SHORTMONTH:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],STANDALONEMONTH:["January","February","March","April","May","June","July","August","September","October","November","December"],WEEKENDRANGE:[5,6],fullDate:"EEEE, MMMM d, y",longDate:"MMMM d, y",medium:"MMM d, y h:mm:ss a",mediumDate:"MMM d, y",mediumTime:"h:mm:ss a","short":"M/d/yy h:mm a",shortDate:"M/d/yy",shortTime:"h:mm a"},NUMBER_FORMATS:{CURRENCY_SYM:"$",DECIMAL_SEP:".",GROUP_SEP:",",PATTERNS:[{gSize:3,lgSize:3,maxFrac:3,minFrac:0,minInt:1,negPre:"-",negSuf:"",posPre:"",posSuf:""},{gSize:3,lgSize:3,maxFrac:2,minFrac:2,minInt:1,negPre:"-¤",negSuf:"",posPre:"¤",posSuf:""}]},id:"en-us",localeID:"en_US",pluralCat:function(t,e){var n=0|t,o=i(t,e);return 1==n&&0==o.v?r.ONE:r.OTHER}})}]),void Oi(e).ready(function(){ot(e,at)}))}(window,document),!window.angular.$$csp().noInlineStyle&&window.angular.element(document.head).prepend('<style type="text/css">@charset "UTF-8";[ng\\:cloak],[ng-cloak],[data-ng-cloak],[x-ng-cloak],.ng-cloak,.x-ng-cloak,.ng-hide:not(.ng-hide-animate){display:none !important;}ng\\:form{display:block;}.ng-animate-shim{visibility:hidden;}.ng-anchor{position:absolute;}</style>'),/**
 * @license AngularJS v1.4.11
 * (c) 2010-2015 Google, Inc. http://angularjs.org
 * License: MIT
 */
function(t,e,n){"use strict";function i(){function t(t,n){return e.extend(Object.create(t),n)}function n(t,e){var n=e.caseInsensitiveMatch,i={originalPath:t,regexp:t},r=i.keys=[];return t=t.replace(/([().])/g,"\\$1").replace(/(\/)?:(\w+)(\*\?|[\?\*])?/g,function(t,e,n,i){var o="?"===i||"*?"===i?"?":null,a="*"===i||"*?"===i?"*":null;return r.push({name:n,optional:!!o}),e=e||"",""+(o?"":e)+"(?:"+(o?e:"")+(a&&"(.+?)"||"([^/]+)")+(o||"")+")"+(o||"")}).replace(/([\/$\*])/g,"\\$1"),i.regexp=new RegExp("^"+t+"$",n?"i":""),i}var i={};this.when=function(t,r){var o=e.copy(r);if(e.isUndefined(o.reloadOnSearch)&&(o.reloadOnSearch=!0),e.isUndefined(o.caseInsensitiveMatch)&&(o.caseInsensitiveMatch=this.caseInsensitiveMatch),i[t]=e.extend(o,t&&n(t,o)),t){var a="/"==t[t.length-1]?t.substr(0,t.length-1):t+"/";i[a]=e.extend({redirectTo:t},n(a,o))}return this},this.caseInsensitiveMatch=!1,this.otherwise=function(t){return"string"==typeof t&&(t={redirectTo:t}),this.when(null,t),this},this.$get=["$rootScope","$location","$routeParams","$q","$injector","$templateRequest","$sce",function(n,r,o,a,s,l,c){function d(t,e){var n=e.keys,i={};if(!e.regexp)return null;var r=e.regexp.exec(t);if(!r)return null;for(var o=1,a=r.length;a>o;++o){var s=n[o-1],u=r[o];s&&u&&(i[s.name]=u)}return i}function h(t){var i=b.current;m=p(),v=m&&i&&m.$$route===i.$$route&&e.equals(m.pathParams,i.pathParams)&&!m.reloadOnSearch&&!y,v||!i&&!m||n.$broadcast("$routeChangeStart",m,i).defaultPrevented&&t&&t.preventDefault()}function f(){var t=b.current,i=m;v?(t.params=i.params,e.copy(t.params,o),n.$broadcast("$routeUpdate",t)):(i||t)&&(y=!1,b.current=i,i&&i.redirectTo&&(e.isString(i.redirectTo)?r.path(g(i.redirectTo,i.params)).search(i.params).replace():r.url(i.redirectTo(i.pathParams,r.path(),r.search())).replace()),a.when(i).then(function(){if(i){var t,n,r=e.extend({},i.resolve);return e.forEach(r,function(t,n){r[n]=e.isString(t)?s.get(t):s.invoke(t,null,null,n)}),e.isDefined(t=i.template)?e.isFunction(t)&&(t=t(i.params)):e.isDefined(n=i.templateUrl)&&(e.isFunction(n)&&(n=n(i.params)),e.isDefined(n)&&(i.loadedTemplateUrl=c.valueOf(n),t=l(n))),e.isDefined(t)&&(r.$template=t),a.all(r)}}).then(function(r){i==b.current&&(i&&(i.locals=r,e.copy(i.params,o)),n.$broadcast("$routeChangeSuccess",i,t))},function(e){i==b.current&&n.$broadcast("$routeChangeError",i,t,e)}))}function p(){var n,o;return e.forEach(i,function(i,a){!o&&(n=d(r.path(),i))&&(o=t(i,{params:e.extend({},r.search(),n),pathParams:n}),o.$$route=i)}),o||i[null]&&t(i[null],{params:{},pathParams:{}})}function g(t,n){var i=[];return e.forEach((t||"").split(":"),function(t,e){if(0===e)i.push(t);else{var r=t.match(/(\w+)(?:[?*])?(.*)/),o=r[1];i.push(n[o]),i.push(r[2]||""),delete n[o]}}),i.join("")}var m,v,y=!1,b={routes:i,reload:function(){y=!0;var t={defaultPrevented:!1,preventDefault:function(){this.defaultPrevented=!0,y=!1}};n.$evalAsync(function(){h(t),t.defaultPrevented||f()})},updateParams:function(t){if(!this.current||!this.current.$$route)throw u("norout","Tried updating route when with no current route");t=e.extend({},this.current.params,t),r.path(g(this.current.$$route.originalPath,t)),r.search(t)}};return n.$on("$locationChangeStart",h),n.$on("$locationChangeSuccess",f),b}]}function r(){this.$get=function(){return{}}}function o(t,n,i){return{restrict:"ECA",terminal:!0,priority:400,transclude:"element",link:function(r,o,a,s,u){function l(){f&&(i.cancel(f),f=null),d&&(d.$destroy(),d=null),h&&(f=i.leave(h),f.then(function(){f=null}),h=null)}function c(){var a=t.current&&t.current.locals,s=a&&a.$template;if(e.isDefined(s)){var c=r.$new(),f=t.current,m=u(c,function(t){i.enter(t,null,h||o).then(function(){!e.isDefined(p)||p&&!r.$eval(p)||n()}),l()});h=m,d=f.scope=c,d.$emit("$viewContentLoaded"),d.$eval(g)}else l()}var d,h,f,p=a.autoscroll,g=a.onload||"";r.$on("$routeChangeSuccess",c),c()}}}function a(t,e,n){return{restrict:"ECA",priority:-400,link:function(i,r){var o=n.current,a=o.locals;r.html(a.$template);var s=t(r.contents());if(o.controller){a.$scope=i;var u=e(o.controller,a);o.controllerAs&&(i[o.controllerAs]=u),r.data("$ngControllerController",u),r.children().data("$ngControllerController",u)}s(i)}}}var s=e.module("ngRoute",["ng"]).provider("$route",i),u=e.$$minErr("ngRoute");s.provider("$routeParams",r),s.directive("ngView",o),s.directive("ngView",a),o.$inject=["$route","$anchorScroll","$animate"],a.$inject=["$compile","$controller","$route"]}(window,window.angular),"undefined"==typeof jQuery)throw new Error("Bootstrap's JavaScript requires jQuery");+function(t){"use strict";var e=t.fn.jquery.split(" ")[0].split(".");if(e[0]<2&&e[1]<9||1==e[0]&&9==e[1]&&e[2]<1||e[0]>2)throw new Error("Bootstrap's JavaScript requires jQuery version 1.9.1 or higher, but lower than version 3")}(jQuery),/* ========================================================================
 * Bootstrap: transition.js v3.3.6
 * http://getbootstrap.com/javascript/#transitions
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(){var t=document.createElement("bootstrap"),e={WebkitTransition:"webkitTransitionEnd",MozTransition:"transitionend",OTransition:"oTransitionEnd otransitionend",transition:"transitionend"};for(var n in e)if(void 0!==t.style[n])return{end:e[n]};return!1}t.fn.emulateTransitionEnd=function(e){var n=!1,i=this;t(this).one("bsTransitionEnd",function(){n=!0});var r=function(){n||t(i).trigger(t.support.transition.end)};return setTimeout(r,e),this},t(function(){t.support.transition=e(),t.support.transition&&(t.event.special.bsTransitionEnd={bindType:t.support.transition.end,delegateType:t.support.transition.end,handle:function(e){return t(e.target).is(this)?e.handleObj.handler.apply(this,arguments):void 0}})})}(jQuery),/* ========================================================================
 * Bootstrap: alert.js v3.3.6
 * http://getbootstrap.com/javascript/#alerts
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(e){return this.each(function(){var n=t(this),r=n.data("bs.alert");r||n.data("bs.alert",r=new i(this)),"string"==typeof e&&r[e].call(n)})}var n='[data-dismiss="alert"]',i=function(e){t(e).on("click",n,this.close)};i.VERSION="3.3.6",i.TRANSITION_DURATION=150,i.prototype.close=function(e){function n(){a.detach().trigger("closed.bs.alert").remove()}var r=t(this),o=r.attr("data-target");o||(o=r.attr("href"),o=o&&o.replace(/.*(?=#[^\s]*$)/,""));var a=t(o);e&&e.preventDefault(),a.length||(a=r.closest(".alert")),a.trigger(e=t.Event("close.bs.alert")),e.isDefaultPrevented()||(a.removeClass("in"),t.support.transition&&a.hasClass("fade")?a.one("bsTransitionEnd",n).emulateTransitionEnd(i.TRANSITION_DURATION):n())};var r=t.fn.alert;t.fn.alert=e,t.fn.alert.Constructor=i,t.fn.alert.noConflict=function(){return t.fn.alert=r,this},t(document).on("click.bs.alert.data-api",n,i.prototype.close)}(jQuery),/* ========================================================================
 * Bootstrap: button.js v3.3.6
 * http://getbootstrap.com/javascript/#buttons
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(e){return this.each(function(){var i=t(this),r=i.data("bs.button"),o="object"==typeof e&&e;r||i.data("bs.button",r=new n(this,o)),"toggle"==e?r.toggle():e&&r.setState(e)})}var n=function(e,i){this.$element=t(e),this.options=t.extend({},n.DEFAULTS,i),this.isLoading=!1};n.VERSION="3.3.6",n.DEFAULTS={loadingText:"loading..."},n.prototype.setState=function(e){var n="disabled",i=this.$element,r=i.is("input")?"val":"html",o=i.data();e+="Text",null==o.resetText&&i.data("resetText",i[r]()),setTimeout(t.proxy(function(){i[r](null==o[e]?this.options[e]:o[e]),"loadingText"==e?(this.isLoading=!0,i.addClass(n).attr(n,n)):this.isLoading&&(this.isLoading=!1,i.removeClass(n).removeAttr(n))},this),0)},n.prototype.toggle=function(){var t=!0,e=this.$element.closest('[data-toggle="buttons"]');if(e.length){var n=this.$element.find("input");"radio"==n.prop("type")?(n.prop("checked")&&(t=!1),e.find(".active").removeClass("active"),this.$element.addClass("active")):"checkbox"==n.prop("type")&&(n.prop("checked")!==this.$element.hasClass("active")&&(t=!1),this.$element.toggleClass("active")),n.prop("checked",this.$element.hasClass("active")),t&&n.trigger("change")}else this.$element.attr("aria-pressed",!this.$element.hasClass("active")),this.$element.toggleClass("active")};var i=t.fn.button;t.fn.button=e,t.fn.button.Constructor=n,t.fn.button.noConflict=function(){return t.fn.button=i,this},t(document).on("click.bs.button.data-api",'[data-toggle^="button"]',function(n){var i=t(n.target);i.hasClass("btn")||(i=i.closest(".btn")),e.call(i,"toggle"),t(n.target).is('input[type="radio"]')||t(n.target).is('input[type="checkbox"]')||n.preventDefault()}).on("focus.bs.button.data-api blur.bs.button.data-api",'[data-toggle^="button"]',function(e){t(e.target).closest(".btn").toggleClass("focus",/^focus(in)?$/.test(e.type))})}(jQuery),/* ========================================================================
 * Bootstrap: carousel.js v3.3.6
 * http://getbootstrap.com/javascript/#carousel
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(e){return this.each(function(){var i=t(this),r=i.data("bs.carousel"),o=t.extend({},n.DEFAULTS,i.data(),"object"==typeof e&&e),a="string"==typeof e?e:o.slide;r||i.data("bs.carousel",r=new n(this,o)),"number"==typeof e?r.to(e):a?r[a]():o.interval&&r.pause().cycle()})}var n=function(e,n){this.$element=t(e),this.$indicators=this.$element.find(".carousel-indicators"),this.options=n,this.paused=null,this.sliding=null,this.interval=null,this.$active=null,this.$items=null,this.options.keyboard&&this.$element.on("keydown.bs.carousel",t.proxy(this.keydown,this)),"hover"==this.options.pause&&!("ontouchstart"in document.documentElement)&&this.$element.on("mouseenter.bs.carousel",t.proxy(this.pause,this)).on("mouseleave.bs.carousel",t.proxy(this.cycle,this))};n.VERSION="3.3.6",n.TRANSITION_DURATION=600,n.DEFAULTS={interval:5e3,pause:"hover",wrap:!0,keyboard:!0},n.prototype.keydown=function(t){if(!/input|textarea/i.test(t.target.tagName)){switch(t.which){case 37:this.prev();break;case 39:this.next();break;default:return}t.preventDefault()}},n.prototype.cycle=function(e){return e||(this.paused=!1),this.interval&&clearInterval(this.interval),this.options.interval&&!this.paused&&(this.interval=setInterval(t.proxy(this.next,this),this.options.interval)),this},n.prototype.getItemIndex=function(t){return this.$items=t.parent().children(".item"),this.$items.index(t||this.$active)},n.prototype.getItemForDirection=function(t,e){var n=this.getItemIndex(e),i="prev"==t&&0===n||"next"==t&&n==this.$items.length-1;if(i&&!this.options.wrap)return e;var r="prev"==t?-1:1,o=(n+r)%this.$items.length;return this.$items.eq(o)},n.prototype.to=function(t){var e=this,n=this.getItemIndex(this.$active=this.$element.find(".item.active"));return t>this.$items.length-1||0>t?void 0:this.sliding?this.$element.one("slid.bs.carousel",function(){e.to(t)}):n==t?this.pause().cycle():this.slide(t>n?"next":"prev",this.$items.eq(t))},n.prototype.pause=function(e){return e||(this.paused=!0),this.$element.find(".next, .prev").length&&t.support.transition&&(this.$element.trigger(t.support.transition.end),this.cycle(!0)),this.interval=clearInterval(this.interval),this},n.prototype.next=function(){return this.sliding?void 0:this.slide("next")},n.prototype.prev=function(){return this.sliding?void 0:this.slide("prev")},n.prototype.slide=function(e,i){var r=this.$element.find(".item.active"),o=i||this.getItemForDirection(e,r),a=this.interval,s="next"==e?"left":"right",u=this;if(o.hasClass("active"))return this.sliding=!1;var l=o[0],c=t.Event("slide.bs.carousel",{relatedTarget:l,direction:s});if(this.$element.trigger(c),!c.isDefaultPrevented()){if(this.sliding=!0,a&&this.pause(),this.$indicators.length){this.$indicators.find(".active").removeClass("active");var d=t(this.$indicators.children()[this.getItemIndex(o)]);d&&d.addClass("active")}var h=t.Event("slid.bs.carousel",{relatedTarget:l,direction:s});return t.support.transition&&this.$element.hasClass("slide")?(o.addClass(e),o[0].offsetWidth,r.addClass(s),o.addClass(s),r.one("bsTransitionEnd",function(){o.removeClass([e,s].join(" ")).addClass("active"),r.removeClass(["active",s].join(" ")),u.sliding=!1,setTimeout(function(){u.$element.trigger(h)},0)}).emulateTransitionEnd(n.TRANSITION_DURATION)):(r.removeClass("active"),o.addClass("active"),this.sliding=!1,this.$element.trigger(h)),a&&this.cycle(),this}};var i=t.fn.carousel;t.fn.carousel=e,t.fn.carousel.Constructor=n,t.fn.carousel.noConflict=function(){return t.fn.carousel=i,this};var r=function(n){var i,r=t(this),o=t(r.attr("data-target")||(i=r.attr("href"))&&i.replace(/.*(?=#[^\s]+$)/,""));if(o.hasClass("carousel")){var a=t.extend({},o.data(),r.data()),s=r.attr("data-slide-to");s&&(a.interval=!1),e.call(o,a),s&&o.data("bs.carousel").to(s),n.preventDefault()}};t(document).on("click.bs.carousel.data-api","[data-slide]",r).on("click.bs.carousel.data-api","[data-slide-to]",r),t(window).on("load",function(){t('[data-ride="carousel"]').each(function(){var n=t(this);e.call(n,n.data())})})}(jQuery),/* ========================================================================
 * Bootstrap: collapse.js v3.3.6
 * http://getbootstrap.com/javascript/#collapse
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(e){var n,i=e.attr("data-target")||(n=e.attr("href"))&&n.replace(/.*(?=#[^\s]+$)/,"");return t(i)}function n(e){return this.each(function(){var n=t(this),r=n.data("bs.collapse"),o=t.extend({},i.DEFAULTS,n.data(),"object"==typeof e&&e);!r&&o.toggle&&/show|hide/.test(e)&&(o.toggle=!1),r||n.data("bs.collapse",r=new i(this,o)),"string"==typeof e&&r[e]()})}var i=function(e,n){this.$element=t(e),this.options=t.extend({},i.DEFAULTS,n),this.$trigger=t('[data-toggle="collapse"][href="#'+e.id+'"],[data-toggle="collapse"][data-target="#'+e.id+'"]'),this.transitioning=null,this.options.parent?this.$parent=this.getParent():this.addAriaAndCollapsedClass(this.$element,this.$trigger),this.options.toggle&&this.toggle()};i.VERSION="3.3.6",i.TRANSITION_DURATION=350,i.DEFAULTS={toggle:!0},i.prototype.dimension=function(){var t=this.$element.hasClass("width");return t?"width":"height"},i.prototype.show=function(){if(!this.transitioning&&!this.$element.hasClass("in")){var e,r=this.$parent&&this.$parent.children(".panel").children(".in, .collapsing");if(!(r&&r.length&&(e=r.data("bs.collapse"),e&&e.transitioning))){var o=t.Event("show.bs.collapse");if(this.$element.trigger(o),!o.isDefaultPrevented()){r&&r.length&&(n.call(r,"hide"),e||r.data("bs.collapse",null));var a=this.dimension();this.$element.removeClass("collapse").addClass("collapsing")[a](0).attr("aria-expanded",!0),this.$trigger.removeClass("collapsed").attr("aria-expanded",!0),this.transitioning=1;var s=function(){this.$element.removeClass("collapsing").addClass("collapse in")[a](""),this.transitioning=0,this.$element.trigger("shown.bs.collapse")};if(!t.support.transition)return s.call(this);var u=t.camelCase(["scroll",a].join("-"));this.$element.one("bsTransitionEnd",t.proxy(s,this)).emulateTransitionEnd(i.TRANSITION_DURATION)[a](this.$element[0][u])}}}},i.prototype.hide=function(){if(!this.transitioning&&this.$element.hasClass("in")){var e=t.Event("hide.bs.collapse");if(this.$element.trigger(e),!e.isDefaultPrevented()){var n=this.dimension();this.$element[n](this.$element[n]())[0].offsetHeight,this.$element.addClass("collapsing").removeClass("collapse in").attr("aria-expanded",!1),this.$trigger.addClass("collapsed").attr("aria-expanded",!1),this.transitioning=1;var r=function(){this.transitioning=0,this.$element.removeClass("collapsing").addClass("collapse").trigger("hidden.bs.collapse")};return t.support.transition?void this.$element[n](0).one("bsTransitionEnd",t.proxy(r,this)).emulateTransitionEnd(i.TRANSITION_DURATION):r.call(this)}}},i.prototype.toggle=function(){this[this.$element.hasClass("in")?"hide":"show"]()},i.prototype.getParent=function(){return t(this.options.parent).find('[data-toggle="collapse"][data-parent="'+this.options.parent+'"]').each(t.proxy(function(n,i){var r=t(i);this.addAriaAndCollapsedClass(e(r),r)},this)).end()},i.prototype.addAriaAndCollapsedClass=function(t,e){var n=t.hasClass("in");t.attr("aria-expanded",n),e.toggleClass("collapsed",!n).attr("aria-expanded",n)};var r=t.fn.collapse;t.fn.collapse=n,t.fn.collapse.Constructor=i,t.fn.collapse.noConflict=function(){return t.fn.collapse=r,this},t(document).on("click.bs.collapse.data-api",'[data-toggle="collapse"]',function(i){var r=t(this);r.attr("data-target")||i.preventDefault();var o=e(r),a=o.data("bs.collapse"),s=a?"toggle":r.data();n.call(o,s)})}(jQuery),/* ========================================================================
 * Bootstrap: dropdown.js v3.3.6
 * http://getbootstrap.com/javascript/#dropdowns
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(e){var n=e.attr("data-target");n||(n=e.attr("href"),n=n&&/#[A-Za-z]/.test(n)&&n.replace(/.*(?=#[^\s]*$)/,""));var i=n&&t(n);return i&&i.length?i:e.parent()}function n(n){n&&3===n.which||(t(r).remove(),t(o).each(function(){var i=t(this),r=e(i),o={relatedTarget:this};r.hasClass("open")&&(n&&"click"==n.type&&/input|textarea/i.test(n.target.tagName)&&t.contains(r[0],n.target)||(r.trigger(n=t.Event("hide.bs.dropdown",o)),n.isDefaultPrevented()||(i.attr("aria-expanded","false"),r.removeClass("open").trigger(t.Event("hidden.bs.dropdown",o)))))}))}function i(e){return this.each(function(){var n=t(this),i=n.data("bs.dropdown");i||n.data("bs.dropdown",i=new a(this)),"string"==typeof e&&i[e].call(n)})}var r=".dropdown-backdrop",o='[data-toggle="dropdown"]',a=function(e){t(e).on("click.bs.dropdown",this.toggle)};a.VERSION="3.3.6",a.prototype.toggle=function(i){var r=t(this);if(!r.is(".disabled, :disabled")){var o=e(r),a=o.hasClass("open");if(n(),!a){"ontouchstart"in document.documentElement&&!o.closest(".navbar-nav").length&&t(document.createElement("div")).addClass("dropdown-backdrop").insertAfter(t(this)).on("click",n);var s={relatedTarget:this};if(o.trigger(i=t.Event("show.bs.dropdown",s)),i.isDefaultPrevented())return;r.trigger("focus").attr("aria-expanded","true"),o.toggleClass("open").trigger(t.Event("shown.bs.dropdown",s))}return!1}},a.prototype.keydown=function(n){if(/(38|40|27|32)/.test(n.which)&&!/input|textarea/i.test(n.target.tagName)){var i=t(this);if(n.preventDefault(),n.stopPropagation(),!i.is(".disabled, :disabled")){var r=e(i),a=r.hasClass("open");if(!a&&27!=n.which||a&&27==n.which)return 27==n.which&&r.find(o).trigger("focus"),i.trigger("click");var s=" li:not(.disabled):visible a",u=r.find(".dropdown-menu"+s);if(u.length){var l=u.index(n.target);38==n.which&&l>0&&l--,40==n.which&&l<u.length-1&&l++,~l||(l=0),u.eq(l).trigger("focus")}}}};var s=t.fn.dropdown;t.fn.dropdown=i,t.fn.dropdown.Constructor=a,t.fn.dropdown.noConflict=function(){return t.fn.dropdown=s,this},t(document).on("click.bs.dropdown.data-api",n).on("click.bs.dropdown.data-api",".dropdown form",function(t){t.stopPropagation()}).on("click.bs.dropdown.data-api",o,a.prototype.toggle).on("keydown.bs.dropdown.data-api",o,a.prototype.keydown).on("keydown.bs.dropdown.data-api",".dropdown-menu",a.prototype.keydown)}(jQuery),/* ========================================================================
 * Bootstrap: modal.js v3.3.6
 * http://getbootstrap.com/javascript/#modals
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(e,i){return this.each(function(){var r=t(this),o=r.data("bs.modal"),a=t.extend({},n.DEFAULTS,r.data(),"object"==typeof e&&e);o||r.data("bs.modal",o=new n(this,a)),"string"==typeof e?o[e](i):a.show&&o.show(i)})}var n=function(e,n){this.options=n,this.$body=t(document.body),this.$element=t(e),this.$dialog=this.$element.find(".modal-dialog"),this.$backdrop=null,this.isShown=null,this.originalBodyPad=null,this.scrollbarWidth=0,this.ignoreBackdropClick=!1,this.options.remote&&this.$element.find(".modal-content").load(this.options.remote,t.proxy(function(){this.$element.trigger("loaded.bs.modal")},this))};n.VERSION="3.3.6",n.TRANSITION_DURATION=300,n.BACKDROP_TRANSITION_DURATION=150,n.DEFAULTS={backdrop:!0,keyboard:!0,show:!0},n.prototype.toggle=function(t){return this.isShown?this.hide():this.show(t)},n.prototype.show=function(e){var i=this,r=t.Event("show.bs.modal",{relatedTarget:e});this.$element.trigger(r),this.isShown||r.isDefaultPrevented()||(this.isShown=!0,this.checkScrollbar(),this.setScrollbar(),this.$body.addClass("modal-open"),this.escape(),this.resize(),this.$element.on("click.dismiss.bs.modal",'[data-dismiss="modal"]',t.proxy(this.hide,this)),this.$dialog.on("mousedown.dismiss.bs.modal",function(){i.$element.one("mouseup.dismiss.bs.modal",function(e){t(e.target).is(i.$element)&&(i.ignoreBackdropClick=!0)})}),this.backdrop(function(){var r=t.support.transition&&i.$element.hasClass("fade");i.$element.parent().length||i.$element.appendTo(i.$body),i.$element.show().scrollTop(0),i.adjustDialog(),r&&i.$element[0].offsetWidth,i.$element.addClass("in"),i.enforceFocus();var o=t.Event("shown.bs.modal",{relatedTarget:e});r?i.$dialog.one("bsTransitionEnd",function(){i.$element.trigger("focus").trigger(o)}).emulateTransitionEnd(n.TRANSITION_DURATION):i.$element.trigger("focus").trigger(o)}))},n.prototype.hide=function(e){e&&e.preventDefault(),e=t.Event("hide.bs.modal"),this.$element.trigger(e),this.isShown&&!e.isDefaultPrevented()&&(this.isShown=!1,this.escape(),this.resize(),t(document).off("focusin.bs.modal"),this.$element.removeClass("in").off("click.dismiss.bs.modal").off("mouseup.dismiss.bs.modal"),this.$dialog.off("mousedown.dismiss.bs.modal"),t.support.transition&&this.$element.hasClass("fade")?this.$element.one("bsTransitionEnd",t.proxy(this.hideModal,this)).emulateTransitionEnd(n.TRANSITION_DURATION):this.hideModal())},n.prototype.enforceFocus=function(){t(document).off("focusin.bs.modal").on("focusin.bs.modal",t.proxy(function(t){this.$element[0]===t.target||this.$element.has(t.target).length||this.$element.trigger("focus")},this))},n.prototype.escape=function(){this.isShown&&this.options.keyboard?this.$element.on("keydown.dismiss.bs.modal",t.proxy(function(t){27==t.which&&this.hide()},this)):this.isShown||this.$element.off("keydown.dismiss.bs.modal")},n.prototype.resize=function(){this.isShown?t(window).on("resize.bs.modal",t.proxy(this.handleUpdate,this)):t(window).off("resize.bs.modal")},n.prototype.hideModal=function(){var t=this;this.$element.hide(),this.backdrop(function(){t.$body.removeClass("modal-open"),t.resetAdjustments(),t.resetScrollbar(),t.$element.trigger("hidden.bs.modal")})},n.prototype.removeBackdrop=function(){this.$backdrop&&this.$backdrop.remove(),this.$backdrop=null},n.prototype.backdrop=function(e){var i=this,r=this.$element.hasClass("fade")?"fade":"";if(this.isShown&&this.options.backdrop){var o=t.support.transition&&r;if(this.$backdrop=t(document.createElement("div")).addClass("modal-backdrop "+r).appendTo(this.$body),this.$element.on("click.dismiss.bs.modal",t.proxy(function(t){return this.ignoreBackdropClick?void(this.ignoreBackdropClick=!1):void(t.target===t.currentTarget&&("static"==this.options.backdrop?this.$element[0].focus():this.hide()))},this)),o&&this.$backdrop[0].offsetWidth,this.$backdrop.addClass("in"),!e)return;o?this.$backdrop.one("bsTransitionEnd",e).emulateTransitionEnd(n.BACKDROP_TRANSITION_DURATION):e()}else if(!this.isShown&&this.$backdrop){this.$backdrop.removeClass("in");var a=function(){i.removeBackdrop(),e&&e()};t.support.transition&&this.$element.hasClass("fade")?this.$backdrop.one("bsTransitionEnd",a).emulateTransitionEnd(n.BACKDROP_TRANSITION_DURATION):a()}else e&&e()},n.prototype.handleUpdate=function(){this.adjustDialog()},n.prototype.adjustDialog=function(){var t=this.$element[0].scrollHeight>document.documentElement.clientHeight;this.$element.css({paddingLeft:!this.bodyIsOverflowing&&t?this.scrollbarWidth:"",paddingRight:this.bodyIsOverflowing&&!t?this.scrollbarWidth:""})},n.prototype.resetAdjustments=function(){this.$element.css({paddingLeft:"",paddingRight:""})},n.prototype.checkScrollbar=function(){var t=window.innerWidth;if(!t){var e=document.documentElement.getBoundingClientRect();t=e.right-Math.abs(e.left)}this.bodyIsOverflowing=document.body.clientWidth<t,this.scrollbarWidth=this.measureScrollbar()},n.prototype.setScrollbar=function(){var t=parseInt(this.$body.css("padding-right")||0,10);this.originalBodyPad=document.body.style.paddingRight||"",this.bodyIsOverflowing&&this.$body.css("padding-right",t+this.scrollbarWidth)},n.prototype.resetScrollbar=function(){this.$body.css("padding-right",this.originalBodyPad)},n.prototype.measureScrollbar=function(){var t=document.createElement("div");t.className="modal-scrollbar-measure",this.$body.append(t);var e=t.offsetWidth-t.clientWidth;return this.$body[0].removeChild(t),e};var i=t.fn.modal;t.fn.modal=e,t.fn.modal.Constructor=n,t.fn.modal.noConflict=function(){return t.fn.modal=i,this},t(document).on("click.bs.modal.data-api",'[data-toggle="modal"]',function(n){var i=t(this),r=i.attr("href"),o=t(i.attr("data-target")||r&&r.replace(/.*(?=#[^\s]+$)/,"")),a=o.data("bs.modal")?"toggle":t.extend({remote:!/#/.test(r)&&r},o.data(),i.data());i.is("a")&&n.preventDefault(),o.one("show.bs.modal",function(t){t.isDefaultPrevented()||o.one("hidden.bs.modal",function(){i.is(":visible")&&i.trigger("focus")})}),e.call(o,a,this)})}(jQuery),/* ========================================================================
 * Bootstrap: tooltip.js v3.3.6
 * http://getbootstrap.com/javascript/#tooltip
 * Inspired by the original jQuery.tipsy by Jason Frame
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(e){return this.each(function(){var i=t(this),r=i.data("bs.tooltip"),o="object"==typeof e&&e;(r||!/destroy|hide/.test(e))&&(r||i.data("bs.tooltip",r=new n(this,o)),"string"==typeof e&&r[e]())})}var n=function(t,e){this.type=null,this.options=null,this.enabled=null,this.timeout=null,this.hoverState=null,this.$element=null,this.inState=null,this.init("tooltip",t,e)};n.VERSION="3.3.6",n.TRANSITION_DURATION=150,n.DEFAULTS={animation:!0,placement:"top",selector:!1,template:'<div class="tooltip" role="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>',trigger:"hover focus",title:"",delay:0,html:!1,container:!1,viewport:{selector:"body",padding:0}},n.prototype.init=function(e,n,i){if(this.enabled=!0,this.type=e,this.$element=t(n),this.options=this.getOptions(i),this.$viewport=this.options.viewport&&t(t.isFunction(this.options.viewport)?this.options.viewport.call(this,this.$element):this.options.viewport.selector||this.options.viewport),this.inState={click:!1,hover:!1,focus:!1},this.$element[0]instanceof document.constructor&&!this.options.selector)throw new Error("`selector` option must be specified when initializing "+this.type+" on the window.document object!");for(var r=this.options.trigger.split(" "),o=r.length;o--;){var a=r[o];if("click"==a)this.$element.on("click."+this.type,this.options.selector,t.proxy(this.toggle,this));else if("manual"!=a){var s="hover"==a?"mouseenter":"focusin",u="hover"==a?"mouseleave":"focusout";this.$element.on(s+"."+this.type,this.options.selector,t.proxy(this.enter,this)),this.$element.on(u+"."+this.type,this.options.selector,t.proxy(this.leave,this))}}this.options.selector?this._options=t.extend({},this.options,{trigger:"manual",selector:""}):this.fixTitle()},n.prototype.getDefaults=function(){return n.DEFAULTS},n.prototype.getOptions=function(e){return e=t.extend({},this.getDefaults(),this.$element.data(),e),e.delay&&"number"==typeof e.delay&&(e.delay={show:e.delay,hide:e.delay}),e},n.prototype.getDelegateOptions=function(){var e={},n=this.getDefaults();return this._options&&t.each(this._options,function(t,i){n[t]!=i&&(e[t]=i)}),e},n.prototype.enter=function(e){var n=e instanceof this.constructor?e:t(e.currentTarget).data("bs."+this.type);return n||(n=new this.constructor(e.currentTarget,this.getDelegateOptions()),t(e.currentTarget).data("bs."+this.type,n)),e instanceof t.Event&&(n.inState["focusin"==e.type?"focus":"hover"]=!0),n.tip().hasClass("in")||"in"==n.hoverState?void(n.hoverState="in"):(clearTimeout(n.timeout),n.hoverState="in",n.options.delay&&n.options.delay.show?void(n.timeout=setTimeout(function(){"in"==n.hoverState&&n.show()},n.options.delay.show)):n.show())},n.prototype.isInStateTrue=function(){for(var t in this.inState)if(this.inState[t])return!0;return!1},n.prototype.leave=function(e){var n=e instanceof this.constructor?e:t(e.currentTarget).data("bs."+this.type);return n||(n=new this.constructor(e.currentTarget,this.getDelegateOptions()),t(e.currentTarget).data("bs."+this.type,n)),e instanceof t.Event&&(n.inState["focusout"==e.type?"focus":"hover"]=!1),n.isInStateTrue()?void 0:(clearTimeout(n.timeout),n.hoverState="out",n.options.delay&&n.options.delay.hide?void(n.timeout=setTimeout(function(){"out"==n.hoverState&&n.hide()},n.options.delay.hide)):n.hide())},n.prototype.show=function(){var e=t.Event("show.bs."+this.type);if(this.hasContent()&&this.enabled){this.$element.trigger(e);var i=t.contains(this.$element[0].ownerDocument.documentElement,this.$element[0]);if(e.isDefaultPrevented()||!i)return;var r=this,o=this.tip(),a=this.getUID(this.type);this.setContent(),o.attr("id",a),this.$element.attr("aria-describedby",a),this.options.animation&&o.addClass("fade");var s="function"==typeof this.options.placement?this.options.placement.call(this,o[0],this.$element[0]):this.options.placement,u=/\s?auto?\s?/i,l=u.test(s);l&&(s=s.replace(u,"")||"top"),o.detach().css({top:0,left:0,display:"block"}).addClass(s).data("bs."+this.type,this),this.options.container?o.appendTo(this.options.container):o.insertAfter(this.$element),this.$element.trigger("inserted.bs."+this.type);var c=this.getPosition(),d=o[0].offsetWidth,h=o[0].offsetHeight;if(l){var f=s,p=this.getPosition(this.$viewport);s="bottom"==s&&c.bottom+h>p.bottom?"top":"top"==s&&c.top-h<p.top?"bottom":"right"==s&&c.right+d>p.width?"left":"left"==s&&c.left-d<p.left?"right":s,o.removeClass(f).addClass(s)}var g=this.getCalculatedOffset(s,c,d,h);this.applyPlacement(g,s);var m=function(){var t=r.hoverState;r.$element.trigger("shown.bs."+r.type),r.hoverState=null,"out"==t&&r.leave(r)};t.support.transition&&this.$tip.hasClass("fade")?o.one("bsTransitionEnd",m).emulateTransitionEnd(n.TRANSITION_DURATION):m()}},n.prototype.applyPlacement=function(e,n){var i=this.tip(),r=i[0].offsetWidth,o=i[0].offsetHeight,a=parseInt(i.css("margin-top"),10),s=parseInt(i.css("margin-left"),10);isNaN(a)&&(a=0),isNaN(s)&&(s=0),e.top+=a,e.left+=s,t.offset.setOffset(i[0],t.extend({using:function(t){i.css({top:Math.round(t.top),left:Math.round(t.left)})}},e),0),i.addClass("in");var u=i[0].offsetWidth,l=i[0].offsetHeight;"top"==n&&l!=o&&(e.top=e.top+o-l);var c=this.getViewportAdjustedDelta(n,e,u,l);c.left?e.left+=c.left:e.top+=c.top;var d=/top|bottom/.test(n),h=d?2*c.left-r+u:2*c.top-o+l,f=d?"offsetWidth":"offsetHeight";i.offset(e),this.replaceArrow(h,i[0][f],d)},n.prototype.replaceArrow=function(t,e,n){this.arrow().css(n?"left":"top",50*(1-t/e)+"%").css(n?"top":"left","")},n.prototype.setContent=function(){var t=this.tip(),e=this.getTitle();t.find(".tooltip-inner")[this.options.html?"html":"text"](e),t.removeClass("fade in top bottom left right")},n.prototype.hide=function(e){function i(){"in"!=r.hoverState&&o.detach(),r.$element.removeAttr("aria-describedby").trigger("hidden.bs."+r.type),e&&e()}var r=this,o=t(this.$tip),a=t.Event("hide.bs."+this.type);return this.$element.trigger(a),a.isDefaultPrevented()?void 0:(o.removeClass("in"),t.support.transition&&o.hasClass("fade")?o.one("bsTransitionEnd",i).emulateTransitionEnd(n.TRANSITION_DURATION):i(),this.hoverState=null,this)},n.prototype.fixTitle=function(){var t=this.$element;(t.attr("title")||"string"!=typeof t.attr("data-original-title"))&&t.attr("data-original-title",t.attr("title")||"").attr("title","")},n.prototype.hasContent=function(){return this.getTitle()},n.prototype.getPosition=function(e){e=e||this.$element;var n=e[0],i="BODY"==n.tagName,r=n.getBoundingClientRect();null==r.width&&(r=t.extend({},r,{width:r.right-r.left,height:r.bottom-r.top}));var o=i?{top:0,left:0}:e.offset(),a={scroll:i?document.documentElement.scrollTop||document.body.scrollTop:e.scrollTop()},s=i?{width:t(window).width(),height:t(window).height()}:null;return t.extend({},r,a,s,o)},n.prototype.getCalculatedOffset=function(t,e,n,i){return"bottom"==t?{top:e.top+e.height,left:e.left+e.width/2-n/2}:"top"==t?{top:e.top-i,left:e.left+e.width/2-n/2}:"left"==t?{top:e.top+e.height/2-i/2,left:e.left-n}:{top:e.top+e.height/2-i/2,left:e.left+e.width}},n.prototype.getViewportAdjustedDelta=function(t,e,n,i){var r={top:0,left:0};if(!this.$viewport)return r;var o=this.options.viewport&&this.options.viewport.padding||0,a=this.getPosition(this.$viewport);if(/right|left/.test(t)){var s=e.top-o-a.scroll,u=e.top+o-a.scroll+i;s<a.top?r.top=a.top-s:u>a.top+a.height&&(r.top=a.top+a.height-u)}else{var l=e.left-o,c=e.left+o+n;l<a.left?r.left=a.left-l:c>a.right&&(r.left=a.left+a.width-c)}return r},n.prototype.getTitle=function(){var t,e=this.$element,n=this.options;return t=e.attr("data-original-title")||("function"==typeof n.title?n.title.call(e[0]):n.title)},n.prototype.getUID=function(t){do t+=~~(1e6*Math.random());while(document.getElementById(t));return t},n.prototype.tip=function(){if(!this.$tip&&(this.$tip=t(this.options.template),1!=this.$tip.length))throw new Error(this.type+" `template` option must consist of exactly 1 top-level element!");return this.$tip},n.prototype.arrow=function(){return this.$arrow=this.$arrow||this.tip().find(".tooltip-arrow")},n.prototype.enable=function(){this.enabled=!0},n.prototype.disable=function(){this.enabled=!1},n.prototype.toggleEnabled=function(){this.enabled=!this.enabled},n.prototype.toggle=function(e){var n=this;e&&(n=t(e.currentTarget).data("bs."+this.type),n||(n=new this.constructor(e.currentTarget,this.getDelegateOptions()),t(e.currentTarget).data("bs."+this.type,n))),e?(n.inState.click=!n.inState.click,n.isInStateTrue()?n.enter(n):n.leave(n)):n.tip().hasClass("in")?n.leave(n):n.enter(n)},n.prototype.destroy=function(){var t=this;clearTimeout(this.timeout),this.hide(function(){t.$element.off("."+t.type).removeData("bs."+t.type),t.$tip&&t.$tip.detach(),t.$tip=null,t.$arrow=null,t.$viewport=null})};var i=t.fn.tooltip;t.fn.tooltip=e,t.fn.tooltip.Constructor=n,t.fn.tooltip.noConflict=function(){return t.fn.tooltip=i,this}}(jQuery),/* ========================================================================
 * Bootstrap: popover.js v3.3.6
 * http://getbootstrap.com/javascript/#popovers
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(e){return this.each(function(){var i=t(this),r=i.data("bs.popover"),o="object"==typeof e&&e;(r||!/destroy|hide/.test(e))&&(r||i.data("bs.popover",r=new n(this,o)),"string"==typeof e&&r[e]())})}var n=function(t,e){this.init("popover",t,e)};if(!t.fn.tooltip)throw new Error("Popover requires tooltip.js");n.VERSION="3.3.6",n.DEFAULTS=t.extend({},t.fn.tooltip.Constructor.DEFAULTS,{placement:"right",trigger:"click",content:"",template:'<div class="popover" role="tooltip"><div class="arrow"></div><h3 class="popover-title"></h3><div class="popover-content"></div></div>'}),n.prototype=t.extend({},t.fn.tooltip.Constructor.prototype),n.prototype.constructor=n,n.prototype.getDefaults=function(){return n.DEFAULTS},n.prototype.setContent=function(){var t=this.tip(),e=this.getTitle(),n=this.getContent();t.find(".popover-title")[this.options.html?"html":"text"](e),t.find(".popover-content").children().detach().end()[this.options.html?"string"==typeof n?"html":"append":"text"](n),t.removeClass("fade top bottom left right in"),t.find(".popover-title").html()||t.find(".popover-title").hide()},n.prototype.hasContent=function(){return this.getTitle()||this.getContent()},n.prototype.getContent=function(){var t=this.$element,e=this.options;return t.attr("data-content")||("function"==typeof e.content?e.content.call(t[0]):e.content)},n.prototype.arrow=function(){return this.$arrow=this.$arrow||this.tip().find(".arrow")};var i=t.fn.popover;t.fn.popover=e,t.fn.popover.Constructor=n,t.fn.popover.noConflict=function(){return t.fn.popover=i,this}}(jQuery),/* ========================================================================
 * Bootstrap: scrollspy.js v3.3.6
 * http://getbootstrap.com/javascript/#scrollspy
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(n,i){this.$body=t(document.body),this.$scrollElement=t(t(n).is(document.body)?window:n),this.options=t.extend({},e.DEFAULTS,i),this.selector=(this.options.target||"")+" .nav li > a",this.offsets=[],this.targets=[],this.activeTarget=null,this.scrollHeight=0,this.$scrollElement.on("scroll.bs.scrollspy",t.proxy(this.process,this)),this.refresh(),this.process()}function n(n){return this.each(function(){var i=t(this),r=i.data("bs.scrollspy"),o="object"==typeof n&&n;r||i.data("bs.scrollspy",r=new e(this,o)),"string"==typeof n&&r[n]()})}e.VERSION="3.3.6",e.DEFAULTS={offset:10},e.prototype.getScrollHeight=function(){return this.$scrollElement[0].scrollHeight||Math.max(this.$body[0].scrollHeight,document.documentElement.scrollHeight)},e.prototype.refresh=function(){var e=this,n="offset",i=0;this.offsets=[],this.targets=[],this.scrollHeight=this.getScrollHeight(),t.isWindow(this.$scrollElement[0])||(n="position",i=this.$scrollElement.scrollTop()),this.$body.find(this.selector).map(function(){var e=t(this),r=e.data("target")||e.attr("href"),o=/^#./.test(r)&&t(r);return o&&o.length&&o.is(":visible")&&[[o[n]().top+i,r]]||null}).sort(function(t,e){return t[0]-e[0]}).each(function(){e.offsets.push(this[0]),e.targets.push(this[1])})},e.prototype.process=function(){var t,e=this.$scrollElement.scrollTop()+this.options.offset,n=this.getScrollHeight(),i=this.options.offset+n-this.$scrollElement.height(),r=this.offsets,o=this.targets,a=this.activeTarget;if(this.scrollHeight!=n&&this.refresh(),e>=i)return a!=(t=o[o.length-1])&&this.activate(t);if(a&&e<r[0])return this.activeTarget=null,this.clear();for(t=r.length;t--;)a!=o[t]&&e>=r[t]&&(void 0===r[t+1]||e<r[t+1])&&this.activate(o[t])},e.prototype.activate=function(e){this.activeTarget=e,this.clear();var n=this.selector+'[data-target="'+e+'"],'+this.selector+'[href="'+e+'"]',i=t(n).parents("li").addClass("active");i.parent(".dropdown-menu").length&&(i=i.closest("li.dropdown").addClass("active")),i.trigger("activate.bs.scrollspy")},e.prototype.clear=function(){t(this.selector).parentsUntil(this.options.target,".active").removeClass("active")};var i=t.fn.scrollspy;t.fn.scrollspy=n,t.fn.scrollspy.Constructor=e,t.fn.scrollspy.noConflict=function(){return t.fn.scrollspy=i,this},t(window).on("load.bs.scrollspy.data-api",function(){t('[data-spy="scroll"]').each(function(){var e=t(this);n.call(e,e.data())})})}(jQuery),/* ========================================================================
 * Bootstrap: tab.js v3.3.6
 * http://getbootstrap.com/javascript/#tabs
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(e){return this.each(function(){var i=t(this),r=i.data("bs.tab");r||i.data("bs.tab",r=new n(this)),"string"==typeof e&&r[e]()})}var n=function(e){this.element=t(e)};n.VERSION="3.3.6",n.TRANSITION_DURATION=150,n.prototype.show=function(){var e=this.element,n=e.closest("ul:not(.dropdown-menu)"),i=e.data("target");if(i||(i=e.attr("href"),i=i&&i.replace(/.*(?=#[^\s]*$)/,"")),!e.parent("li").hasClass("active")){var r=n.find(".active:last a"),o=t.Event("hide.bs.tab",{relatedTarget:e[0]}),a=t.Event("show.bs.tab",{relatedTarget:r[0]});if(r.trigger(o),e.trigger(a),!a.isDefaultPrevented()&&!o.isDefaultPrevented()){var s=t(i);this.activate(e.closest("li"),n),this.activate(s,s.parent(),function(){r.trigger({type:"hidden.bs.tab",relatedTarget:e[0]}),e.trigger({type:"shown.bs.tab",relatedTarget:r[0]})})}}},n.prototype.activate=function(e,i,r){function o(){a.removeClass("active").find("> .dropdown-menu > .active").removeClass("active").end().find('[data-toggle="tab"]').attr("aria-expanded",!1),e.addClass("active").find('[data-toggle="tab"]').attr("aria-expanded",!0),s?(e[0].offsetWidth,e.addClass("in")):e.removeClass("fade"),e.parent(".dropdown-menu").length&&e.closest("li.dropdown").addClass("active").end().find('[data-toggle="tab"]').attr("aria-expanded",!0),r&&r()}var a=i.find("> .active"),s=r&&t.support.transition&&(a.length&&a.hasClass("fade")||!!i.find("> .fade").length);a.length&&s?a.one("bsTransitionEnd",o).emulateTransitionEnd(n.TRANSITION_DURATION):o(),a.removeClass("in")};var i=t.fn.tab;t.fn.tab=e,t.fn.tab.Constructor=n,t.fn.tab.noConflict=function(){return t.fn.tab=i,this};var r=function(n){n.preventDefault(),e.call(t(this),"show")};t(document).on("click.bs.tab.data-api",'[data-toggle="tab"]',r).on("click.bs.tab.data-api",'[data-toggle="pill"]',r)}(jQuery),/* ========================================================================
 * Bootstrap: affix.js v3.3.6
 * http://getbootstrap.com/javascript/#affix
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */
+function(t){"use strict";function e(e){return this.each(function(){var i=t(this),r=i.data("bs.affix"),o="object"==typeof e&&e;r||i.data("bs.affix",r=new n(this,o)),"string"==typeof e&&r[e]()})}var n=function(e,i){this.options=t.extend({},n.DEFAULTS,i),this.$target=t(this.options.target).on("scroll.bs.affix.data-api",t.proxy(this.checkPosition,this)).on("click.bs.affix.data-api",t.proxy(this.checkPositionWithEventLoop,this)),this.$element=t(e),this.affixed=null,this.unpin=null,this.pinnedOffset=null,this.checkPosition()};n.VERSION="3.3.6",n.RESET="affix affix-top affix-bottom",n.DEFAULTS={offset:0,target:window},n.prototype.getState=function(t,e,n,i){var r=this.$target.scrollTop(),o=this.$element.offset(),a=this.$target.height();if(null!=n&&"top"==this.affixed)return n>r?"top":!1;if("bottom"==this.affixed)return null!=n?r+this.unpin<=o.top?!1:"bottom":t-i>=r+a?!1:"bottom";var s=null==this.affixed,u=s?r:o.top,l=s?a:e;return null!=n&&n>=r?"top":null!=i&&u+l>=t-i?"bottom":!1},n.prototype.getPinnedOffset=function(){if(this.pinnedOffset)return this.pinnedOffset;this.$element.removeClass(n.RESET).addClass("affix");var t=this.$target.scrollTop(),e=this.$element.offset();return this.pinnedOffset=e.top-t},n.prototype.checkPositionWithEventLoop=function(){setTimeout(t.proxy(this.checkPosition,this),1)},n.prototype.checkPosition=function(){if(this.$element.is(":visible")){var e=this.$element.height(),i=this.options.offset,r=i.top,o=i.bottom,a=Math.max(t(document).height(),t(document.body).height());"object"!=typeof i&&(o=r=i),"function"==typeof r&&(r=i.top(this.$element)),"function"==typeof o&&(o=i.bottom(this.$element));var s=this.getState(a,e,r,o);if(this.affixed!=s){null!=this.unpin&&this.$element.css("top","");var u="affix"+(s?"-"+s:""),l=t.Event(u+".bs.affix");if(this.$element.trigger(l),l.isDefaultPrevented())return;this.affixed=s,this.unpin="bottom"==s?this.getPinnedOffset():null,this.$element.removeClass(n.RESET).addClass(u).trigger(u.replace("affix","affixed")+".bs.affix")}"bottom"==s&&this.$element.offset({top:a-e-o})}};var i=t.fn.affix;t.fn.affix=e,t.fn.affix.Constructor=n,t.fn.affix.noConflict=function(){return t.fn.affix=i,this},t(window).on("load",function(){t('[data-spy="affix"]').each(function(){var n=t(this),i=n.data();i.offset=i.offset||{},null!=i.offsetBottom&&(i.offset.bottom=i.offsetBottom),null!=i.offsetTop&&(i.offset.top=i.offsetTop),e.call(n,i)})})}(jQuery),/*
 * angular-ui-bootstrap
 * http://angular-ui.github.io/bootstrap/

 * Version: 1.3.3 - 2016-05-22
 * License: MIT
 */
angular.module("ui.bootstrap",["ui.bootstrap.tpls","ui.bootstrap.collapse","ui.bootstrap.accordion","ui.bootstrap.alert","ui.bootstrap.buttons","ui.bootstrap.carousel","ui.bootstrap.dateparser","ui.bootstrap.isClass","ui.bootstrap.datepicker","ui.bootstrap.position","ui.bootstrap.datepickerPopup","ui.bootstrap.debounce","ui.bootstrap.dropdown","ui.bootstrap.stackedMap","ui.bootstrap.modal","ui.bootstrap.paging","ui.bootstrap.pager","ui.bootstrap.pagination","ui.bootstrap.tooltip","ui.bootstrap.popover","ui.bootstrap.progressbar","ui.bootstrap.rating","ui.bootstrap.tabs","ui.bootstrap.timepicker","ui.bootstrap.typeahead"]),angular.module("ui.bootstrap.tpls",["uib/template/accordion/accordion-group.html","uib/template/accordion/accordion.html","uib/template/alert/alert.html","uib/template/carousel/carousel.html","uib/template/carousel/slide.html","uib/template/datepicker/datepicker.html","uib/template/datepicker/day.html","uib/template/datepicker/month.html","uib/template/datepicker/year.html","uib/template/datepickerPopup/popup.html","uib/template/modal/backdrop.html","uib/template/modal/window.html","uib/template/pager/pager.html","uib/template/pagination/pagination.html","uib/template/tooltip/tooltip-html-popup.html","uib/template/tooltip/tooltip-popup.html","uib/template/tooltip/tooltip-template-popup.html","uib/template/popover/popover-html.html","uib/template/popover/popover-template.html","uib/template/popover/popover.html","uib/template/progressbar/bar.html","uib/template/progressbar/progress.html","uib/template/progressbar/progressbar.html","uib/template/rating/rating.html","uib/template/tabs/tab.html","uib/template/tabs/tabset.html","uib/template/timepicker/timepicker.html","uib/template/typeahead/typeahead-match.html","uib/template/typeahead/typeahead-popup.html"]),angular.module("ui.bootstrap.collapse",[]).directive("uibCollapse",["$animate","$q","$parse","$injector",function(t,e,n,i){var r=i.has("$animateCss")?i.get("$animateCss"):null;return{link:function(i,o,a){function s(){o.hasClass("collapse")&&o.hasClass("in")||e.resolve(d(i)).then(function(){o.removeClass("collapse").addClass("collapsing").attr("aria-expanded",!0).attr("aria-hidden",!1),r?r(o,{addClass:"in",easing:"ease",to:{height:o[0].scrollHeight+"px"}}).start()["finally"](u):t.addClass(o,"in",{to:{height:o[0].scrollHeight+"px"}}).then(u)})}function u(){o.removeClass("collapsing").addClass("collapse").css({height:"auto"}),h(i)}function l(){return o.hasClass("collapse")||o.hasClass("in")?void e.resolve(f(i)).then(function(){o.css({height:o[0].scrollHeight+"px"}).removeClass("collapse").addClass("collapsing").attr("aria-expanded",!1).attr("aria-hidden",!0),r?r(o,{removeClass:"in",to:{height:"0"}}).start()["finally"](c):t.removeClass(o,"in",{to:{height:"0"}}).then(c)}):c()}function c(){o.css({height:"0"}),o.removeClass("collapsing").addClass("collapse"),p(i)}var d=n(a.expanding),h=n(a.expanded),f=n(a.collapsing),p=n(a.collapsed);i.$eval(a.uibCollapse)||o.addClass("in").addClass("collapse").attr("aria-expanded",!0).attr("aria-hidden",!1).css({height:"auto"}),i.$watch(a.uibCollapse,function(t){t?l():s()})}}}]),angular.module("ui.bootstrap.accordion",["ui.bootstrap.collapse"]).constant("uibAccordionConfig",{closeOthers:!0}).controller("UibAccordionController",["$scope","$attrs","uibAccordionConfig",function(t,e,n){this.groups=[],this.closeOthers=function(i){var r=angular.isDefined(e.closeOthers)?t.$eval(e.closeOthers):n.closeOthers;r&&angular.forEach(this.groups,function(t){t!==i&&(t.isOpen=!1)})},this.addGroup=function(t){var e=this;this.groups.push(t),t.$on("$destroy",function(n){e.removeGroup(t)})},this.removeGroup=function(t){var e=this.groups.indexOf(t);-1!==e&&this.groups.splice(e,1)}}]).directive("uibAccordion",function(){return{controller:"UibAccordionController",controllerAs:"accordion",transclude:!0,templateUrl:function(t,e){return e.templateUrl||"uib/template/accordion/accordion.html"}}}).directive("uibAccordionGroup",function(){return{require:"^uibAccordion",transclude:!0,replace:!0,templateUrl:function(t,e){return e.templateUrl||"uib/template/accordion/accordion-group.html"},scope:{heading:"@",panelClass:"@?",isOpen:"=?",isDisabled:"=?"},controller:function(){this.setHeading=function(t){this.heading=t}},link:function(t,e,n,i){i.addGroup(t),t.openClass=n.openClass||"panel-open",t.panelClass=n.panelClass||"panel-default",t.$watch("isOpen",function(n){e.toggleClass(t.openClass,!!n),n&&i.closeOthers(t)}),t.toggleOpen=function(e){t.isDisabled||e&&32!==e.which||(t.isOpen=!t.isOpen)};var r="accordiongroup-"+t.$id+"-"+Math.floor(1e4*Math.random());t.headingId=r+"-tab",t.panelId=r+"-panel"}}}).directive("uibAccordionHeading",function(){return{transclude:!0,template:"",replace:!0,require:"^uibAccordionGroup",link:function(t,e,n,i,r){i.setHeading(r(t,angular.noop))}}}).directive("uibAccordionTransclude",function(){function t(){return"uib-accordion-header,data-uib-accordion-header,x-uib-accordion-header,uib\\:accordion-header,[uib-accordion-header],[data-uib-accordion-header],[x-uib-accordion-header]"}return{require:"^uibAccordionGroup",link:function(e,n,i,r){e.$watch(function(){return r[i.uibAccordionTransclude]},function(e){if(e){var i=angular.element(n[0].querySelector(t()));i.html(""),i.append(e)}})}}}),angular.module("ui.bootstrap.alert",[]).controller("UibAlertController",["$scope","$attrs","$interpolate","$timeout",function(t,e,n,i){t.closeable=!!e.close;var r=angular.isDefined(e.dismissOnTimeout)?n(e.dismissOnTimeout)(t.$parent):null;r&&i(function(){t.close()},parseInt(r,10))}]).directive("uibAlert",function(){return{controller:"UibAlertController",controllerAs:"alert",templateUrl:function(t,e){return e.templateUrl||"uib/template/alert/alert.html"},transclude:!0,replace:!0,scope:{type:"@",close:"&"}}}),angular.module("ui.bootstrap.buttons",[]).constant("uibButtonConfig",{activeClass:"active",toggleEvent:"click"}).controller("UibButtonsController",["uibButtonConfig",function(t){this.activeClass=t.activeClass||"active",this.toggleEvent=t.toggleEvent||"click"}]).directive("uibBtnRadio",["$parse",function(t){return{require:["uibBtnRadio","ngModel"],controller:"UibButtonsController",controllerAs:"buttons",link:function(e,n,i,r){var o=r[0],a=r[1],s=t(i.uibUncheckable);n.find("input").css({display:"none"}),a.$render=function(){n.toggleClass(o.activeClass,angular.equals(a.$modelValue,e.$eval(i.uibBtnRadio)))},n.on(o.toggleEvent,function(){if(!i.disabled){var t=n.hasClass(o.activeClass);(!t||angular.isDefined(i.uncheckable))&&e.$apply(function(){a.$setViewValue(t?null:e.$eval(i.uibBtnRadio)),a.$render()})}}),i.uibUncheckable&&e.$watch(s,function(t){i.$set("uncheckable",t?"":void 0)})}}}]).directive("uibBtnCheckbox",function(){return{require:["uibBtnCheckbox","ngModel"],controller:"UibButtonsController",controllerAs:"button",link:function(t,e,n,i){function r(){return a(n.btnCheckboxTrue,!0)}function o(){return a(n.btnCheckboxFalse,!1)}function a(e,n){return angular.isDefined(e)?t.$eval(e):n}var s=i[0],u=i[1];e.find("input").css({display:"none"}),u.$render=function(){e.toggleClass(s.activeClass,angular.equals(u.$modelValue,r()))},e.on(s.toggleEvent,function(){n.disabled||t.$apply(function(){u.$setViewValue(e.hasClass(s.activeClass)?o():r()),u.$render()})})}}}),angular.module("ui.bootstrap.carousel",[]).controller("UibCarouselController",["$scope","$element","$interval","$timeout","$animate",function(t,e,n,i,r){function o(){for(;b.length;)b.shift()}function a(t){for(var e=0;e<m.length;e++)m[e].slide.active=e===t}function s(n,i,u){if(!x){if(angular.extend(n,{direction:u}),angular.extend(m[y].slide||{},{direction:u}),r.enabled(e)&&!t.$currentTransition&&m[i].element&&g.slides.length>1){m[i].element.data(v,n.direction);var l=g.getCurrentIndex();angular.isNumber(l)&&m[l].element&&m[l].element.data(v,n.direction),t.$currentTransition=!0,r.on("addClass",m[i].element,function(e,n){if("close"===n&&(t.$currentTransition=null,r.off("addClass",e),b.length)){var i=b.pop().slide,a=i.index,u=a>g.getCurrentIndex()?"next":"prev";o(),s(i,a,u)}})}t.active=n.index,y=n.index,a(i),d()}}function u(t){for(var e=0;e<m.length;e++)if(m[e].slide===t)return e}function l(){f&&(n.cancel(f),f=null)}function c(e){e.length||(t.$currentTransition=null,o())}function d(){l();var e=+t.interval;!isNaN(e)&&e>0&&(f=n(h,e))}function h(){var e=+t.interval;p&&!isNaN(e)&&e>0&&m.length?t.next():t.pause()}var f,p,g=this,m=g.slides=t.slides=[],v="uib-slideDirection",y=t.active,b=[],x=!1;g.addSlide=function(e,n){m.push({slide:e,element:n}),m.sort(function(t,e){return+t.slide.index-+e.slide.index}),(e.index===t.active||1===m.length&&!angular.isNumber(t.active))&&(t.$currentTransition&&(t.$currentTransition=null),y=e.index,t.active=e.index,a(y),g.select(m[u(e)]),1===m.length&&t.play())},g.getCurrentIndex=function(){for(var t=0;t<m.length;t++)if(m[t].slide.index===y)return t},g.next=t.next=function(){var e=(g.getCurrentIndex()+1)%m.length;return 0===e&&t.noWrap()?void t.pause():g.select(m[e],"next")},g.prev=t.prev=function(){var e=g.getCurrentIndex()-1<0?m.length-1:g.getCurrentIndex()-1;return t.noWrap()&&e===m.length-1?void t.pause():g.select(m[e],"prev")},g.removeSlide=function(e){var n=u(e),i=b.indexOf(m[n]);-1!==i&&b.splice(i,1),m.splice(n,1),m.length>0&&y===n?n>=m.length?(y=m.length-1,t.active=y,a(y),g.select(m[m.length-1])):(y=n,t.active=y,a(y),g.select(m[n])):y>n&&(y--,t.active=y),0===m.length&&(y=null,t.active=null,o())},g.select=t.select=function(e,n){var i=u(e.slide);void 0===n&&(n=i>g.getCurrentIndex()?"next":"prev"),e.slide.index===y||t.$currentTransition?e&&e.slide.index!==y&&t.$currentTransition&&b.push(m[i]):s(e.slide,i,n)},t.indexOfSlide=function(t){return+t.slide.index},t.isActive=function(e){return t.active===e.slide.index},t.isPrevDisabled=function(){return 0===t.active&&t.noWrap()},t.isNextDisabled=function(){return t.active===m.length-1&&t.noWrap()},t.pause=function(){t.noPause||(p=!1,l())},t.play=function(){p||(p=!0,d())},t.$on("$destroy",function(){x=!0,l()}),t.$watch("noTransition",function(t){r.enabled(e,!t)}),t.$watch("interval",d),t.$watchCollection("slides",c),t.$watch("active",function(t){if(angular.isNumber(t)&&y!==t){for(var e=0;e<m.length;e++)if(m[e].slide.index===t){t=e;break}var n=m[t];n&&(a(t),g.select(m[t]),y=t)}})}]).directive("uibCarousel",function(){return{transclude:!0,replace:!0,controller:"UibCarouselController",controllerAs:"carousel",templateUrl:function(t,e){return e.templateUrl||"uib/template/carousel/carousel.html"},scope:{active:"=",interval:"=",noTransition:"=",noPause:"=",noWrap:"&"}}}).directive("uibSlide",function(){return{require:"^uibCarousel",transclude:!0,replace:!0,templateUrl:function(t,e){return e.templateUrl||"uib/template/carousel/slide.html"},scope:{actual:"=?",index:"=?"},link:function(t,e,n,i){i.addSlide(t,e),t.$on("$destroy",function(){i.removeSlide(t)})}}}).animation(".item",["$animateCss",function(t){function e(t,e,n){t.removeClass(e),n&&n()}var n="uib-slideDirection";return{beforeAddClass:function(i,r,o){if("active"===r){var a=!1,s=i.data(n),u="next"===s?"left":"right",l=e.bind(this,i,u+" "+s,o);return i.addClass(s),t(i,{addClass:u}).start().done(l),function(){a=!0}}o()},beforeRemoveClass:function(i,r,o){if("active"===r){var a=!1,s=i.data(n),u="next"===s?"left":"right",l=e.bind(this,i,u,o);return t(i,{addClass:u}).start().done(l),function(){a=!0}}o()}}}]),angular.module("ui.bootstrap.dateparser",[]).service("uibDateParser",["$log","$locale","dateFilter","orderByFilter",function(t,e,n,i){function r(t,e){var n=[],r=t.split(""),o=t.indexOf("'");if(o>-1){var a=!1;t=t.split("");for(var s=o;s<t.length;s++)a?("'"===t[s]&&(s+1<t.length&&"'"===t[s+1]?(t[s+1]="$",r[s+1]=""):(r[s]="",a=!1)),t[s]="$"):"'"===t[s]&&(t[s]="$",r[s]="",a=!0);t=t.join("")}return angular.forEach(f,function(i){var o=t.indexOf(i.key);if(o>-1){t=t.split(""),r[o]="("+i.regex+")",t[o]="$";for(var a=o+1,s=o+i.key.length;s>a;a++)r[a]="",t[a]="$";t=t.join(""),n.push({index:o,key:i.key,apply:i[e],matcher:i.regex})}}),{regex:new RegExp("^"+r.join("")+"$"),map:i(n,"index")}}function o(t,e,n){return 1>n?!1:1===e&&n>28?29===n&&(t%4===0&&t%100!==0||t%400===0):3===e||5===e||8===e||10===e?31>n:!0}function a(t){return parseInt(t,10)}function s(t,e){return t&&e?d(t,e):t}function u(t,e){return t&&e?d(t,e,!0):t}function l(t,e){t=t.replace(/:/g,"");var n=Date.parse("Jan 01, 1970 00:00:00 "+t)/6e4;return isNaN(n)?e:n}function c(t,e){return t=new Date(t.getTime()),t.setMinutes(t.getMinutes()+e),t}function d(t,e,n){n=n?-1:1;var i=t.getTimezoneOffset(),r=l(e,i);return c(t,n*(r-i))}var h,f,p=/[\\\^\$\*\+\?\|\[\]\(\)\.\{\}]/g;this.init=function(){h=e.id,this.parsers={},this.formatters={},f=[{key:"yyyy",regex:"\\d{4}",apply:function(t){this.year=+t},formatter:function(t){var e=new Date;return e.setFullYear(Math.abs(t.getFullYear())),n(e,"yyyy")}},{key:"yy",regex:"\\d{2}",apply:function(t){t=+t,this.year=69>t?t+2e3:t+1900},formatter:function(t){var e=new Date;return e.setFullYear(Math.abs(t.getFullYear())),n(e,"yy")}},{key:"y",regex:"\\d{1,4}",apply:function(t){this.year=+t},formatter:function(t){var e=new Date;return e.setFullYear(Math.abs(t.getFullYear())),n(e,"y")}},{key:"M!",regex:"0?[1-9]|1[0-2]",apply:function(t){this.month=t-1},formatter:function(t){var e=t.getMonth();return/^[0-9]$/.test(e)?n(t,"MM"):n(t,"M")}},{key:"MMMM",regex:e.DATETIME_FORMATS.MONTH.join("|"),apply:function(t){this.month=e.DATETIME_FORMATS.MONTH.indexOf(t)},formatter:function(t){return n(t,"MMMM")}},{key:"MMM",regex:e.DATETIME_FORMATS.SHORTMONTH.join("|"),apply:function(t){this.month=e.DATETIME_FORMATS.SHORTMONTH.indexOf(t)},formatter:function(t){return n(t,"MMM")}},{key:"MM",regex:"0[1-9]|1[0-2]",apply:function(t){this.month=t-1},formatter:function(t){return n(t,"MM")}},{key:"M",regex:"[1-9]|1[0-2]",apply:function(t){this.month=t-1},formatter:function(t){return n(t,"M")}},{key:"d!",regex:"[0-2]?[0-9]{1}|3[0-1]{1}",apply:function(t){this.date=+t},formatter:function(t){var e=t.getDate();return/^[1-9]$/.test(e)?n(t,"dd"):n(t,"d")}},{key:"dd",regex:"[0-2][0-9]{1}|3[0-1]{1}",apply:function(t){this.date=+t},formatter:function(t){return n(t,"dd")}},{key:"d",regex:"[1-2]?[0-9]{1}|3[0-1]{1}",apply:function(t){this.date=+t},formatter:function(t){return n(t,"d")}},{key:"EEEE",regex:e.DATETIME_FORMATS.DAY.join("|"),formatter:function(t){return n(t,"EEEE")}},{key:"EEE",regex:e.DATETIME_FORMATS.SHORTDAY.join("|"),formatter:function(t){return n(t,"EEE")}},{key:"HH",regex:"(?:0|1)[0-9]|2[0-3]",apply:function(t){this.hours=+t},formatter:function(t){return n(t,"HH")}},{key:"hh",regex:"0[0-9]|1[0-2]",apply:function(t){this.hours=+t},formatter:function(t){return n(t,"hh")}},{key:"H",regex:"1?[0-9]|2[0-3]",apply:function(t){this.hours=+t},formatter:function(t){return n(t,"H")}},{key:"h",regex:"[0-9]|1[0-2]",apply:function(t){this.hours=+t},formatter:function(t){return n(t,"h")}},{key:"mm",regex:"[0-5][0-9]",apply:function(t){this.minutes=+t},formatter:function(t){return n(t,"mm")}},{key:"m",regex:"[0-9]|[1-5][0-9]",apply:function(t){this.minutes=+t},formatter:function(t){return n(t,"m")}},{key:"sss",regex:"[0-9][0-9][0-9]",apply:function(t){this.milliseconds=+t},formatter:function(t){return n(t,"sss")}},{key:"ss",regex:"[0-5][0-9]",apply:function(t){this.seconds=+t},formatter:function(t){return n(t,"ss")}},{key:"s",regex:"[0-9]|[1-5][0-9]",apply:function(t){this.seconds=+t},formatter:function(t){return n(t,"s")}},{key:"a",regex:e.DATETIME_FORMATS.AMPMS.join("|"),apply:function(t){12===this.hours&&(this.hours=0),"PM"===t&&(this.hours+=12)},formatter:function(t){return n(t,"a")}},{key:"Z",regex:"[+-]\\d{4}",apply:function(t){var e=t.match(/([+-])(\d{2})(\d{2})/),n=e[1],i=e[2],r=e[3];this.hours+=a(n+i),this.minutes+=a(n+r)},formatter:function(t){return n(t,"Z")}},{key:"ww",regex:"[0-4][0-9]|5[0-3]",formatter:function(t){return n(t,"ww")}},{key:"w",regex:"[0-9]|[1-4][0-9]|5[0-3]",formatter:function(t){return n(t,"w")}},{key:"GGGG",regex:e.DATETIME_FORMATS.ERANAMES.join("|").replace(/\s/g,"\\s"),formatter:function(t){return n(t,"GGGG")}},{key:"GGG",regex:e.DATETIME_FORMATS.ERAS.join("|"),formatter:function(t){return n(t,"GGG")}},{key:"GG",regex:e.DATETIME_FORMATS.ERAS.join("|"),formatter:function(t){return n(t,"GG")}},{key:"G",regex:e.DATETIME_FORMATS.ERAS.join("|"),formatter:function(t){return n(t,"G")}}]},this.init(),this.filter=function(t,n){if(!angular.isDate(t)||isNaN(t)||!n)return"";n=e.DATETIME_FORMATS[n]||n,e.id!==h&&this.init(),this.formatters[n]||(this.formatters[n]=r(n,"formatter"));var i=this.formatters[n],o=i.map,a=n;return o.reduce(function(e,n,i){var r=a.match(new RegExp("(.*)"+n.key));r&&angular.isString(r[1])&&(e+=r[1],a=a.replace(r[1]+n.key,""));var s=i===o.length-1?a:"";return n.apply?e+n.apply.call(null,t)+s:e+s},"")},this.parse=function(n,i,a){if(!angular.isString(n)||!i)return n;i=e.DATETIME_FORMATS[i]||i,i=i.replace(p,"\\$&"),e.id!==h&&this.init(),this.parsers[i]||(this.parsers[i]=r(i,"apply"));var s=this.parsers[i],u=s.regex,l=s.map,c=n.match(u),d=!1;if(c&&c.length){var f,g;angular.isDate(a)&&!isNaN(a.getTime())?f={year:a.getFullYear(),month:a.getMonth(),date:a.getDate(),hours:a.getHours(),minutes:a.getMinutes(),seconds:a.getSeconds(),milliseconds:a.getMilliseconds()}:(a&&t.warn("dateparser:","baseDate is not a valid date"),f={year:1900,month:0,date:1,hours:0,minutes:0,seconds:0,milliseconds:0});for(var m=1,v=c.length;v>m;m++){var y=l[m-1];"Z"===y.matcher&&(d=!0),y.apply&&y.apply.call(f,c[m])}var b=d?Date.prototype.setUTCFullYear:Date.prototype.setFullYear,x=d?Date.prototype.setUTCHours:Date.prototype.setHours;return o(f.year,f.month,f.date)&&(!angular.isDate(a)||isNaN(a.getTime())||d?(g=new Date(0),b.call(g,f.year,f.month,f.date),x.call(g,f.hours||0,f.minutes||0,f.seconds||0,f.milliseconds||0)):(g=new Date(a),b.call(g,f.year,f.month,f.date),x.call(g,f.hours,f.minutes,f.seconds,f.milliseconds))),g}},this.toTimezone=s,this.fromTimezone=u,this.timezoneToOffset=l,this.addDateMinutes=c,this.convertTimezoneToLocal=d}]),angular.module("ui.bootstrap.isClass",[]).directive("uibIsClass",["$animate",function(t){var e=/^\s*([\s\S]+?)\s+on\s+([\s\S]+?)\s*$/,n=/^\s*([\s\S]+?)\s+for\s+([\s\S]+?)\s*$/;return{restrict:"A",compile:function(i,r){function o(t,e,n){u.push(t),l.push({scope:t,element:e}),p.forEach(function(e,n){a(e,t)}),t.$on("$destroy",s)}function a(e,i){var r=e.match(n),o=i.$eval(r[1]),a=r[2],s=c[e];if(!s){var u=function(e){var n=null;l.some(function(t){var i=t.scope.$eval(h);return i===e?(n=t,!0):void 0}),s.lastActivated!==n&&(s.lastActivated&&t.removeClass(s.lastActivated.element,o),n&&t.addClass(n.element,o),s.lastActivated=n)};c[e]=s={lastActivated:null,scope:i,watchFn:u,compareWithExp:a,watcher:i.$watch(a,u)}}s.watchFn(i.$eval(a))}function s(t){var e=t.targetScope,n=u.indexOf(e);if(u.splice(n,1),l.splice(n,1),u.length){var i=u[0];angular.forEach(c,function(t){t.scope===e&&(t.watcher=i.$watch(t.compareWithExp,t.watchFn),t.scope=i)})}else c={}}var u=[],l=[],c={},d=r.uibIsClass.match(e),h=d[2],f=d[1],p=f.split(",");return o}}}]),angular.module("ui.bootstrap.datepicker",["ui.bootstrap.dateparser","ui.bootstrap.isClass"]).value("$datepickerSuppressError",!1).value("$datepickerLiteralWarning",!0).constant("uibDatepickerConfig",{datepickerMode:"day",formatDay:"dd",formatMonth:"MMMM",formatYear:"yyyy",formatDayHeader:"EEE",formatDayTitle:"MMMM yyyy",formatMonthTitle:"yyyy",maxDate:null,maxMode:"year",minDate:null,minMode:"day",ngModelOptions:{},shortcutPropagation:!1,showWeeks:!0,yearColumns:5,yearRows:4}).controller("UibDatepickerController",["$scope","$attrs","$parse","$interpolate","$locale","$log","dateFilter","uibDatepickerConfig","$datepickerLiteralWarning","$datepickerSuppressError","uibDateParser",function(t,e,n,i,r,o,a,s,u,l,c){function d(e){t.datepickerMode=e,t.datepickerOptions.datepickerMode=e}var h=this,f={$setViewValue:angular.noop},p={},g=[];!!e.datepickerOptions;t.datepickerOptions||(t.datepickerOptions={}),this.modes=["day","month","year"],["customClass","dateDisabled","datepickerMode","formatDay","formatDayHeader","formatDayTitle","formatMonth","formatMonthTitle","formatYear","maxDate","maxMode","minDate","minMode","showWeeks","shortcutPropagation","startingDay","yearColumns","yearRows"].forEach(function(e){switch(e){case"customClass":case"dateDisabled":t[e]=t.datepickerOptions[e]||angular.noop;break;case"datepickerMode":t.datepickerMode=angular.isDefined(t.datepickerOptions.datepickerMode)?t.datepickerOptions.datepickerMode:s.datepickerMode;break;case"formatDay":case"formatDayHeader":case"formatDayTitle":case"formatMonth":case"formatMonthTitle":case"formatYear":h[e]=angular.isDefined(t.datepickerOptions[e])?i(t.datepickerOptions[e])(t.$parent):s[e];break;case"showWeeks":case"shortcutPropagation":case"yearColumns":case"yearRows":h[e]=angular.isDefined(t.datepickerOptions[e])?t.datepickerOptions[e]:s[e];break;case"startingDay":angular.isDefined(t.datepickerOptions.startingDay)?h.startingDay=t.datepickerOptions.startingDay:angular.isNumber(s.startingDay)?h.startingDay=s.startingDay:h.startingDay=(r.DATETIME_FORMATS.FIRSTDAYOFWEEK+8)%7;break;case"maxDate":case"minDate":t.$watch("datepickerOptions."+e,function(t){t?angular.isDate(t)?h[e]=c.fromTimezone(new Date(t),p.timezone):(u&&o.warn("Literal date support has been deprecated, please switch to date object usage"),h[e]=new Date(a(t,"medium"))):h[e]=s[e]?c.fromTimezone(new Date(s[e]),p.timezone):null,h.refreshView()});break;case"maxMode":case"minMode":t.datepickerOptions[e]?t.$watch(function(){return t.datepickerOptions[e]},function(n){h[e]=t[e]=angular.isDefined(n)?n:datepickerOptions[e],("minMode"===e&&h.modes.indexOf(t.datepickerOptions.datepickerMode)<h.modes.indexOf(h[e])||"maxMode"===e&&h.modes.indexOf(t.datepickerOptions.datepickerMode)>h.modes.indexOf(h[e]))&&(t.datepickerMode=h[e],t.datepickerOptions.datepickerMode=h[e])}):h[e]=t[e]=s[e]||null}}),t.uniqueId="datepicker-"+t.$id+"-"+Math.floor(1e4*Math.random()),t.disabled=angular.isDefined(e.disabled)||!1,angular.isDefined(e.ngDisabled)&&g.push(t.$parent.$watch(e.ngDisabled,function(e){t.disabled=e,h.refreshView()})),t.isActive=function(e){return 0===h.compare(e.date,h.activeDate)?(t.activeDateId=e.uid,!0):!1},this.init=function(e){f=e,p=e.$options||s.ngModelOptions,t.datepickerOptions.initDate?(h.activeDate=c.fromTimezone(t.datepickerOptions.initDate,p.timezone)||new Date,t.$watch("datepickerOptions.initDate",function(t){t&&(f.$isEmpty(f.$modelValue)||f.$invalid)&&(h.activeDate=c.fromTimezone(t,p.timezone),h.refreshView())})):h.activeDate=new Date;var n=f.$modelValue?new Date(f.$modelValue):new Date;this.activeDate=isNaN(n)?c.fromTimezone(new Date,p.timezone):c.fromTimezone(n,p.timezone),f.$render=function(){h.render()}},this.render=function(){if(f.$viewValue){var t=new Date(f.$viewValue),e=!isNaN(t);e?this.activeDate=c.fromTimezone(t,p.timezone):l||o.error('Datepicker directive: "ng-model" value must be a Date object')}this.refreshView()},this.refreshView=function(){if(this.element){t.selectedDt=null,this._refreshView(),t.activeDt&&(t.activeDateId=t.activeDt.uid);var e=f.$viewValue?new Date(f.$viewValue):null;e=c.fromTimezone(e,p.timezone),f.$setValidity("dateDisabled",!e||this.element&&!this.isDisabled(e))}},this.createDateObject=function(e,n){var i=f.$viewValue?new Date(f.$viewValue):null;i=c.fromTimezone(i,p.timezone);var r=new Date;r=c.fromTimezone(r,p.timezone);var o=this.compare(e,r),a={date:e,label:c.filter(e,n),selected:i&&0===this.compare(e,i),disabled:this.isDisabled(e),past:0>o,current:0===o,future:o>0,customClass:this.customClass(e)||null};return i&&0===this.compare(e,i)&&(t.selectedDt=a),h.activeDate&&0===this.compare(a.date,h.activeDate)&&(t.activeDt=a),a},this.isDisabled=function(e){return t.disabled||this.minDate&&this.compare(e,this.minDate)<0||this.maxDate&&this.compare(e,this.maxDate)>0||t.dateDisabled&&t.dateDisabled({date:e,mode:t.datepickerMode})},this.customClass=function(e){return t.customClass({date:e,mode:t.datepickerMode})},this.split=function(t,e){for(var n=[];t.length>0;)n.push(t.splice(0,e));return n},t.select=function(e){if(t.datepickerMode===h.minMode){var n=f.$viewValue?c.fromTimezone(new Date(f.$viewValue),p.timezone):new Date(0,0,0,0,0,0,0);n.setFullYear(e.getFullYear(),e.getMonth(),e.getDate()),n=c.toTimezone(n,p.timezone),f.$setViewValue(n),f.$render()}else h.activeDate=e,d(h.modes[h.modes.indexOf(t.datepickerMode)-1]),t.$emit("uib:datepicker.mode");t.$broadcast("uib:datepicker.focus")},t.move=function(t){var e=h.activeDate.getFullYear()+t*(h.step.years||0),n=h.activeDate.getMonth()+t*(h.step.months||0);h.activeDate.setFullYear(e,n,1),h.refreshView()},t.toggleMode=function(e){e=e||1,t.datepickerMode===h.maxMode&&1===e||t.datepickerMode===h.minMode&&-1===e||(d(h.modes[h.modes.indexOf(t.datepickerMode)+e]),t.$emit("uib:datepicker.mode"))},t.keys={13:"enter",32:"space",33:"pageup",34:"pagedown",35:"end",36:"home",37:"left",38:"up",39:"right",40:"down"};var m=function(){h.element[0].focus()};t.$on("uib:datepicker.focus",m),t.keydown=function(e){var n=t.keys[e.which];if(n&&!e.shiftKey&&!e.altKey&&!t.disabled)if(e.preventDefault(),h.shortcutPropagation||e.stopPropagation(),"enter"===n||"space"===n){if(h.isDisabled(h.activeDate))return;t.select(h.activeDate)}else!e.ctrlKey||"up"!==n&&"down"!==n?(h.handleKeyDown(n,e),h.refreshView()):t.toggleMode("up"===n?1:-1)},t.$on("$destroy",function(){for(;g.length;)g.shift()()})}]).controller("UibDaypickerController",["$scope","$element","dateFilter",function(t,e,n){function i(t,e){return 1!==e||t%4!==0||t%100===0&&t%400!==0?o[e]:29}function r(t){var e=new Date(t);e.setDate(e.getDate()+4-(e.getDay()||7));var n=e.getTime();return e.setMonth(0),e.setDate(1),Math.floor(Math.round((n-e)/864e5)/7)+1}var o=[31,28,31,30,31,30,31,31,30,31,30,31];this.step={months:1},this.element=e,this.init=function(e){angular.extend(e,this),t.showWeeks=e.showWeeks,e.refreshView()},this.getDates=function(t,e){for(var n,i=new Array(e),r=new Date(t),o=0;e>o;)n=new Date(r),i[o++]=n,r.setDate(r.getDate()+1);return i},this._refreshView=function(){var e=this.activeDate.getFullYear(),i=this.activeDate.getMonth(),o=new Date(this.activeDate);o.setFullYear(e,i,1);var a=this.startingDay-o.getDay(),s=a>0?7-a:-a,u=new Date(o);s>0&&u.setDate(-s+1);for(var l=this.getDates(u,42),c=0;42>c;c++)l[c]=angular.extend(this.createDateObject(l[c],this.formatDay),{secondary:l[c].getMonth()!==i,uid:t.uniqueId+"-"+c});t.labels=new Array(7);for(var d=0;7>d;d++)t.labels[d]={abbr:n(l[d].date,this.formatDayHeader),full:n(l[d].date,"EEEE")};if(t.title=n(this.activeDate,this.formatDayTitle),t.rows=this.split(l,7),t.showWeeks){t.weekNumbers=[];for(var h=(11-this.startingDay)%7,f=t.rows.length,p=0;f>p;p++)t.weekNumbers.push(r(t.rows[p][h].date))}},this.compare=function(t,e){var n=new Date(t.getFullYear(),t.getMonth(),t.getDate()),i=new Date(e.getFullYear(),e.getMonth(),e.getDate());return n.setFullYear(t.getFullYear()),i.setFullYear(e.getFullYear()),n-i},this.handleKeyDown=function(t,e){var n=this.activeDate.getDate();if("left"===t)n-=1;else if("up"===t)n-=7;else if("right"===t)n+=1;else if("down"===t)n+=7;else if("pageup"===t||"pagedown"===t){var r=this.activeDate.getMonth()+("pageup"===t?-1:1);this.activeDate.setMonth(r,1),n=Math.min(i(this.activeDate.getFullYear(),this.activeDate.getMonth()),n)}else"home"===t?n=1:"end"===t&&(n=i(this.activeDate.getFullYear(),this.activeDate.getMonth()));this.activeDate.setDate(n)}}]).controller("UibMonthpickerController",["$scope","$element","dateFilter",function(t,e,n){this.step={years:1},this.element=e,this.init=function(t){angular.extend(t,this),t.refreshView()},this._refreshView=function(){for(var e,i=new Array(12),r=this.activeDate.getFullYear(),o=0;12>o;o++)e=new Date(this.activeDate),e.setFullYear(r,o,1),i[o]=angular.extend(this.createDateObject(e,this.formatMonth),{uid:t.uniqueId+"-"+o});t.title=n(this.activeDate,this.formatMonthTitle),t.rows=this.split(i,3)},this.compare=function(t,e){var n=new Date(t.getFullYear(),t.getMonth()),i=new Date(e.getFullYear(),e.getMonth());return n.setFullYear(t.getFullYear()),i.setFullYear(e.getFullYear()),n-i},this.handleKeyDown=function(t,e){var n=this.activeDate.getMonth();if("left"===t)n-=1;else if("up"===t)n-=3;else if("right"===t)n+=1;else if("down"===t)n+=3;else if("pageup"===t||"pagedown"===t){var i=this.activeDate.getFullYear()+("pageup"===t?-1:1);this.activeDate.setFullYear(i)}else"home"===t?n=0:"end"===t&&(n=11);this.activeDate.setMonth(n)}}]).controller("UibYearpickerController",["$scope","$element","dateFilter",function(t,e,n){function i(t){return parseInt((t-1)/o,10)*o+1}var r,o;this.element=e,this.yearpickerInit=function(){r=this.yearColumns,o=this.yearRows*r,this.step={years:o}},this._refreshView=function(){for(var e,n=new Array(o),a=0,s=i(this.activeDate.getFullYear());o>a;a++)e=new Date(this.activeDate),e.setFullYear(s+a,0,1),n[a]=angular.extend(this.createDateObject(e,this.formatYear),{uid:t.uniqueId+"-"+a});t.title=[n[0].label,n[o-1].label].join(" - "),t.rows=this.split(n,r),t.columns=r},this.compare=function(t,e){return t.getFullYear()-e.getFullYear()},this.handleKeyDown=function(t,e){var n=this.activeDate.getFullYear();"left"===t?n-=1:"up"===t?n-=r:"right"===t?n+=1:"down"===t?n+=r:"pageup"===t||"pagedown"===t?n+=("pageup"===t?-1:1)*o:"home"===t?n=i(this.activeDate.getFullYear()):"end"===t&&(n=i(this.activeDate.getFullYear())+o-1),this.activeDate.setFullYear(n)}}]).directive("uibDatepicker",function(){return{replace:!0,templateUrl:function(t,e){return e.templateUrl||"uib/template/datepicker/datepicker.html"},scope:{datepickerOptions:"=?"},require:["uibDatepicker","^ngModel"],controller:"UibDatepickerController",controllerAs:"datepicker",link:function(t,e,n,i){var r=i[0],o=i[1];r.init(o)}}}).directive("uibDaypicker",function(){return{replace:!0,templateUrl:function(t,e){return e.templateUrl||"uib/template/datepicker/day.html"},require:["^uibDatepicker","uibDaypicker"],controller:"UibDaypickerController",link:function(t,e,n,i){var r=i[0],o=i[1];o.init(r)}}}).directive("uibMonthpicker",function(){return{replace:!0,templateUrl:function(t,e){return e.templateUrl||"uib/template/datepicker/month.html"},require:["^uibDatepicker","uibMonthpicker"],controller:"UibMonthpickerController",link:function(t,e,n,i){var r=i[0],o=i[1];o.init(r)}}}).directive("uibYearpicker",function(){return{replace:!0,templateUrl:function(t,e){return e.templateUrl||"uib/template/datepicker/year.html"},require:["^uibDatepicker","uibYearpicker"],controller:"UibYearpickerController",link:function(t,e,n,i){var r=i[0];angular.extend(r,i[1]),r.yearpickerInit(),r.refreshView()}}}),angular.module("ui.bootstrap.position",[]).factory("$uibPosition",["$document","$window",function(t,e){var n,i,r={normal:/(auto|scroll)/,hidden:/(auto|scroll|hidden)/},o={auto:/\s?auto?\s?/i,primary:/^(top|bottom|left|right)$/,secondary:/^(top|bottom|left|right|center)$/,vertical:/^(top|bottom)$/},a=/(HTML|BODY)/;return{getRawNode:function(t){return t.nodeName?t:t[0]||t},parseStyle:function(t){return t=parseFloat(t),isFinite(t)?t:0},offsetParent:function(n){function i(t){return"static"===(e.getComputedStyle(t).position||"static")}n=this.getRawNode(n);for(var r=n.offsetParent||t[0].documentElement;r&&r!==t[0].documentElement&&i(r);)r=r.offsetParent;return r||t[0].documentElement},scrollbarWidth:function(r){if(r){if(angular.isUndefined(i)){var o=t.find("body");o.addClass("uib-position-body-scrollbar-measure"),i=e.innerWidth-o[0].clientWidth,i=isFinite(i)?i:0,o.removeClass("uib-position-body-scrollbar-measure")}return i}if(angular.isUndefined(n)){var a=angular.element('<div class="uib-position-scrollbar-measure"></div>');t.find("body").append(a),n=a[0].offsetWidth-a[0].clientWidth,n=isFinite(n)?n:0,a.remove()}return n},scrollbarPadding:function(t){t=this.getRawNode(t);var n=e.getComputedStyle(t),i=this.parseStyle(n.paddingRight),r=this.parseStyle(n.paddingBottom),o=this.scrollParent(t,!1,!0),s=this.scrollbarWidth(o,a.test(o.tagName));return{scrollbarWidth:s,widthOverflow:o.scrollWidth>o.clientWidth,right:i+s,originalRight:i,heightOverflow:o.scrollHeight>o.clientHeight,
bottom:r+s,originalBottom:r}},isScrollable:function(t,n){t=this.getRawNode(t);var i=n?r.hidden:r.normal,o=e.getComputedStyle(t);return i.test(o.overflow+o.overflowY+o.overflowX)},scrollParent:function(n,i,o){n=this.getRawNode(n);var a=i?r.hidden:r.normal,s=t[0].documentElement,u=e.getComputedStyle(n);if(o&&a.test(u.overflow+u.overflowY+u.overflowX))return n;var l="absolute"===u.position,c=n.parentElement||s;if(c===s||"fixed"===u.position)return s;for(;c.parentElement&&c!==s;){var d=e.getComputedStyle(c);if(l&&"static"!==d.position&&(l=!1),!l&&a.test(d.overflow+d.overflowY+d.overflowX))break;c=c.parentElement}return c},position:function(n,i){n=this.getRawNode(n);var r=this.offset(n);if(i){var o=e.getComputedStyle(n);r.top-=this.parseStyle(o.marginTop),r.left-=this.parseStyle(o.marginLeft)}var a=this.offsetParent(n),s={top:0,left:0};return a!==t[0].documentElement&&(s=this.offset(a),s.top+=a.clientTop-a.scrollTop,s.left+=a.clientLeft-a.scrollLeft),{width:Math.round(angular.isNumber(r.width)?r.width:n.offsetWidth),height:Math.round(angular.isNumber(r.height)?r.height:n.offsetHeight),top:Math.round(r.top-s.top),left:Math.round(r.left-s.left)}},offset:function(n){n=this.getRawNode(n);var i=n.getBoundingClientRect();return{width:Math.round(angular.isNumber(i.width)?i.width:n.offsetWidth),height:Math.round(angular.isNumber(i.height)?i.height:n.offsetHeight),top:Math.round(i.top+(e.pageYOffset||t[0].documentElement.scrollTop)),left:Math.round(i.left+(e.pageXOffset||t[0].documentElement.scrollLeft))}},viewportOffset:function(n,i,r){n=this.getRawNode(n),r=r!==!1?!0:!1;var o=n.getBoundingClientRect(),a={top:0,left:0,bottom:0,right:0},s=i?t[0].documentElement:this.scrollParent(n),u=s.getBoundingClientRect();if(a.top=u.top+s.clientTop,a.left=u.left+s.clientLeft,s===t[0].documentElement&&(a.top+=e.pageYOffset,a.left+=e.pageXOffset),a.bottom=a.top+s.clientHeight,a.right=a.left+s.clientWidth,r){var l=e.getComputedStyle(s);a.top+=this.parseStyle(l.paddingTop),a.bottom-=this.parseStyle(l.paddingBottom),a.left+=this.parseStyle(l.paddingLeft),a.right-=this.parseStyle(l.paddingRight)}return{top:Math.round(o.top-a.top),bottom:Math.round(a.bottom-o.bottom),left:Math.round(o.left-a.left),right:Math.round(a.right-o.right)}},parsePlacement:function(t){var e=o.auto.test(t);return e&&(t=t.replace(o.auto,"")),t=t.split("-"),t[0]=t[0]||"top",o.primary.test(t[0])||(t[0]="top"),t[1]=t[1]||"center",o.secondary.test(t[1])||(t[1]="center"),e?t[2]=!0:t[2]=!1,t},positionElements:function(t,n,i,r){t=this.getRawNode(t),n=this.getRawNode(n);var a=angular.isDefined(n.offsetWidth)?n.offsetWidth:n.prop("offsetWidth"),s=angular.isDefined(n.offsetHeight)?n.offsetHeight:n.prop("offsetHeight");i=this.parsePlacement(i);var u=r?this.offset(t):this.position(t),l={top:0,left:0,placement:""};if(i[2]){var c=this.viewportOffset(t,r),d=e.getComputedStyle(n),h={width:a+Math.round(Math.abs(this.parseStyle(d.marginLeft)+this.parseStyle(d.marginRight))),height:s+Math.round(Math.abs(this.parseStyle(d.marginTop)+this.parseStyle(d.marginBottom)))};if(i[0]="top"===i[0]&&h.height>c.top&&h.height<=c.bottom?"bottom":"bottom"===i[0]&&h.height>c.bottom&&h.height<=c.top?"top":"left"===i[0]&&h.width>c.left&&h.width<=c.right?"right":"right"===i[0]&&h.width>c.right&&h.width<=c.left?"left":i[0],i[1]="top"===i[1]&&h.height-u.height>c.bottom&&h.height-u.height<=c.top?"bottom":"bottom"===i[1]&&h.height-u.height>c.top&&h.height-u.height<=c.bottom?"top":"left"===i[1]&&h.width-u.width>c.right&&h.width-u.width<=c.left?"right":"right"===i[1]&&h.width-u.width>c.left&&h.width-u.width<=c.right?"left":i[1],"center"===i[1])if(o.vertical.test(i[0])){var f=u.width/2-a/2;c.left+f<0&&h.width-u.width<=c.right?i[1]="left":c.right+f<0&&h.width-u.width<=c.left&&(i[1]="right")}else{var p=u.height/2-h.height/2;c.top+p<0&&h.height-u.height<=c.bottom?i[1]="top":c.bottom+p<0&&h.height-u.height<=c.top&&(i[1]="bottom")}}switch(i[0]){case"top":l.top=u.top-s;break;case"bottom":l.top=u.top+u.height;break;case"left":l.left=u.left-a;break;case"right":l.left=u.left+u.width}switch(i[1]){case"top":l.top=u.top;break;case"bottom":l.top=u.top+u.height-s;break;case"left":l.left=u.left;break;case"right":l.left=u.left+u.width-a;break;case"center":o.vertical.test(i[0])?l.left=u.left+u.width/2-a/2:l.top=u.top+u.height/2-s/2}return l.top=Math.round(l.top),l.left=Math.round(l.left),l.placement="center"===i[1]?i[0]:i[0]+"-"+i[1],l},positionArrow:function(t,n){t=this.getRawNode(t);var i=t.querySelector(".tooltip-inner, .popover-inner");if(i){var r=angular.element(i).hasClass("tooltip-inner"),a=r?t.querySelector(".tooltip-arrow"):t.querySelector(".arrow");if(a){var s={top:"",bottom:"",left:"",right:""};if(n=this.parsePlacement(n),"center"===n[1])return void angular.element(a).css(s);var u="border-"+n[0]+"-width",l=e.getComputedStyle(a)[u],c="border-";c+=o.vertical.test(n[0])?n[0]+"-"+n[1]:n[1]+"-"+n[0],c+="-radius";var d=e.getComputedStyle(r?i:t)[c];switch(n[0]){case"top":s.bottom=r?"0":"-"+l;break;case"bottom":s.top=r?"0":"-"+l;break;case"left":s.right=r?"0":"-"+l;break;case"right":s.left=r?"0":"-"+l}s[n[1]]=d,angular.element(a).css(s)}}}}}]),angular.module("ui.bootstrap.datepickerPopup",["ui.bootstrap.datepicker","ui.bootstrap.position"]).value("$datepickerPopupLiteralWarning",!0).constant("uibDatepickerPopupConfig",{altInputFormats:[],appendToBody:!1,clearText:"Clear",closeOnDateSelection:!0,closeText:"Done",currentText:"Today",datepickerPopup:"yyyy-MM-dd",datepickerPopupTemplateUrl:"uib/template/datepickerPopup/popup.html",datepickerTemplateUrl:"uib/template/datepicker/datepicker.html",html5Types:{date:"yyyy-MM-dd","datetime-local":"yyyy-MM-ddTHH:mm:ss.sss",month:"yyyy-MM"},onOpenFocus:!0,showButtonBar:!0,placement:"auto bottom-left"}).controller("UibDatepickerPopupController",["$scope","$element","$attrs","$compile","$log","$parse","$window","$document","$rootScope","$uibPosition","dateFilter","uibDateParser","uibDatepickerPopupConfig","$timeout","uibDatepickerConfig","$datepickerPopupLiteralWarning",function(t,e,n,i,r,o,a,s,u,l,c,d,h,f,p,g){function m(e){var n=d.parse(e,_,t.date);if(isNaN(n))for(var i=0;i<I.length;i++)if(n=d.parse(e,I[i],t.date),!isNaN(n))return n;return n}function v(t){if(angular.isNumber(t)&&(t=new Date(t)),!t)return null;if(angular.isDate(t)&&!isNaN(t))return t;if(angular.isString(t)){var e=m(t);if(!isNaN(e))return d.toTimezone(e,P)}return E.$options&&E.$options.allowInvalid?t:void 0}function y(t,e){var i=t||e;return n.ngRequired||i?(angular.isNumber(i)&&(i=new Date(i)),i?angular.isDate(i)&&!isNaN(i)?!0:angular.isString(i)?!isNaN(m(e)):!1:!0):!0}function b(n){if(t.isOpen||!t.disabled){var i=N[0],r=e[0].contains(n.target),o=void 0!==i.contains&&i.contains(n.target);!t.isOpen||r||o||t.$apply(function(){t.isOpen=!1})}}function x(n){27===n.which&&t.isOpen?(n.preventDefault(),n.stopPropagation(),t.$apply(function(){t.isOpen=!1}),e[0].focus()):40!==n.which||t.isOpen||(n.preventDefault(),n.stopPropagation(),t.$apply(function(){t.isOpen=!0}))}function w(){if(t.isOpen){var i=angular.element(N[0].querySelector(".uib-datepicker-popup")),r=n.popupPlacement?n.popupPlacement:h.placement,o=l.positionElements(e,i,r,k);i.css({top:o.top+"px",left:o.left+"px"}),i.hasClass("uib-position-measure")&&i.removeClass("uib-position-measure")}}var _,$,k,C,M,D,S,T,A,E,O,N,I,P,F=!1,W=[];this.init=function(r){if(E=r,O=r.$options,$=angular.isDefined(n.closeOnDateSelection)?t.$parent.$eval(n.closeOnDateSelection):h.closeOnDateSelection,k=angular.isDefined(n.datepickerAppendToBody)?t.$parent.$eval(n.datepickerAppendToBody):h.appendToBody,C=angular.isDefined(n.onOpenFocus)?t.$parent.$eval(n.onOpenFocus):h.onOpenFocus,M=angular.isDefined(n.datepickerPopupTemplateUrl)?n.datepickerPopupTemplateUrl:h.datepickerPopupTemplateUrl,D=angular.isDefined(n.datepickerTemplateUrl)?n.datepickerTemplateUrl:h.datepickerTemplateUrl,I=angular.isDefined(n.altInputFormats)?t.$parent.$eval(n.altInputFormats):h.altInputFormats,t.showButtonBar=angular.isDefined(n.showButtonBar)?t.$parent.$eval(n.showButtonBar):h.showButtonBar,h.html5Types[n.type]?(_=h.html5Types[n.type],F=!0):(_=n.uibDatepickerPopup||h.datepickerPopup,n.$observe("uibDatepickerPopup",function(t,e){var n=t||h.datepickerPopup;if(n!==_&&(_=n,E.$modelValue=null,!_))throw new Error("uibDatepickerPopup must have a date format specified.")})),!_)throw new Error("uibDatepickerPopup must have a date format specified.");if(F&&n.uibDatepickerPopup)throw new Error("HTML5 date input types do not support custom formats.");S=angular.element("<div uib-datepicker-popup-wrap><div uib-datepicker></div></div>"),O?(P=O.timezone,t.ngModelOptions=angular.copy(O),t.ngModelOptions.timezone=null,t.ngModelOptions.updateOnDefault===!0&&(t.ngModelOptions.updateOn=t.ngModelOptions.updateOn?t.ngModelOptions.updateOn+" default":"default"),S.attr("ng-model-options","ngModelOptions")):P=null,S.attr({"ng-model":"date","ng-change":"dateSelection(date)","template-url":M}),T=angular.element(S.children()[0]),T.attr("template-url",D),t.datepickerOptions||(t.datepickerOptions={}),F&&"month"===n.type&&(t.datepickerOptions.datepickerMode="month",t.datepickerOptions.minMode="month"),T.attr("datepicker-options","datepickerOptions"),F?E.$formatters.push(function(e){return t.date=d.fromTimezone(e,P),e}):(E.$$parserName="date",E.$validators.date=y,E.$parsers.unshift(v),E.$formatters.push(function(e){return E.$isEmpty(e)?(t.date=e,e):(angular.isNumber(e)&&(e=new Date(e)),t.date=d.fromTimezone(e,P),d.filter(t.date,_))})),E.$viewChangeListeners.push(function(){t.date=m(E.$viewValue)}),e.on("keydown",x),N=i(S)(t),S.remove(),k?s.find("body").append(N):e.after(N),t.$on("$destroy",function(){for(t.isOpen===!0&&(u.$$phase||t.$apply(function(){t.isOpen=!1})),N.remove(),e.off("keydown",x),s.off("click",b),A&&A.off("scroll",w),angular.element(a).off("resize",w);W.length;)W.shift()()})},t.getText=function(e){return t[e+"Text"]||h[e+"Text"]},t.isDisabled=function(e){"today"===e&&(e=d.fromTimezone(new Date,P));var n={};return angular.forEach(["minDate","maxDate"],function(e){t.datepickerOptions[e]?angular.isDate(t.datepickerOptions[e])?n[e]=d.fromTimezone(new Date(t.datepickerOptions[e]),P):(g&&r.warn("Literal date support has been deprecated, please switch to date object usage"),n[e]=new Date(c(t.datepickerOptions[e],"medium"))):n[e]=null}),t.datepickerOptions&&n.minDate&&t.compare(e,n.minDate)<0||n.maxDate&&t.compare(e,n.maxDate)>0},t.compare=function(t,e){return new Date(t.getFullYear(),t.getMonth(),t.getDate())-new Date(e.getFullYear(),e.getMonth(),e.getDate())},t.dateSelection=function(n){angular.isDefined(n)&&(t.date=n);var i=t.date?d.filter(t.date,_):null;e.val(i),E.$setViewValue(i),$&&(t.isOpen=!1,e[0].focus())},t.keydown=function(n){27===n.which&&(n.stopPropagation(),t.isOpen=!1,e[0].focus())},t.select=function(e,n){if(n.stopPropagation(),"today"===e){var i=new Date;angular.isDate(t.date)?(e=new Date(t.date),e.setFullYear(i.getFullYear(),i.getMonth(),i.getDate())):e=new Date(i.setHours(0,0,0,0))}t.dateSelection(e)},t.close=function(n){n.stopPropagation(),t.isOpen=!1,e[0].focus()},t.disabled=angular.isDefined(n.disabled)||!1,n.ngDisabled&&W.push(t.$parent.$watch(o(n.ngDisabled),function(e){t.disabled=e})),t.$watch("isOpen",function(i){i?t.disabled?t.isOpen=!1:f(function(){w(),C&&t.$broadcast("uib:datepicker.focus"),s.on("click",b);var i=n.popupPlacement?n.popupPlacement:h.placement;k||l.parsePlacement(i)[2]?(A=A||angular.element(l.scrollParent(e)),A&&A.on("scroll",w)):A=null,angular.element(a).on("resize",w)},0,!1):(s.off("click",b),A&&A.off("scroll",w),angular.element(a).off("resize",w))}),t.$on("uib:datepicker.mode",function(){f(w,0,!1)})}]).directive("uibDatepickerPopup",function(){return{require:["ngModel","uibDatepickerPopup"],controller:"UibDatepickerPopupController",scope:{datepickerOptions:"=?",isOpen:"=?",currentText:"@",clearText:"@",closeText:"@"},link:function(t,e,n,i){var r=i[0],o=i[1];o.init(r)}}}).directive("uibDatepickerPopupWrap",function(){return{replace:!0,transclude:!0,templateUrl:function(t,e){return e.templateUrl||"uib/template/datepickerPopup/popup.html"}}}),angular.module("ui.bootstrap.debounce",[]).factory("$$debounce",["$timeout",function(t){return function(e,n){var i;return function(){var r=this,o=Array.prototype.slice.call(arguments);i&&t.cancel(i),i=t(function(){e.apply(r,o)},n)}}}]),angular.module("ui.bootstrap.dropdown",["ui.bootstrap.position"]).constant("uibDropdownConfig",{appendToOpenClass:"uib-dropdown-open",openClass:"open"}).service("uibDropdownService",["$document","$rootScope",function(t,e){var n=null;this.open=function(e,o){n||(t.on("click",i),o.on("keydown",r)),n&&n!==e&&(n.isOpen=!1),n=e},this.close=function(e,o){n===e&&(n=null,t.off("click",i),o.off("keydown",r))};var i=function(t){if(n&&!(t&&"disabled"===n.getAutoClose()||t&&3===t.which)){var i=n.getToggleElement();if(!(t&&i&&i[0].contains(t.target))){var r=n.getDropdownElement();t&&"outsideClick"===n.getAutoClose()&&r&&r[0].contains(t.target)||(n.isOpen=!1,e.$$phase||n.$apply())}}},r=function(t){27===t.which?(t.stopPropagation(),n.focusToggleElement(),i()):n.isKeynavEnabled()&&-1!==[38,40].indexOf(t.which)&&n.isOpen&&(t.preventDefault(),t.stopPropagation(),n.focusDropdownEntry(t.which))}}]).controller("UibDropdownController",["$scope","$element","$attrs","$parse","uibDropdownConfig","uibDropdownService","$animate","$uibPosition","$document","$compile","$templateRequest",function(t,e,n,i,r,o,a,s,u,l,c){var d,h,f=this,p=t.$new(),g=r.appendToOpenClass,m=r.openClass,v=angular.noop,y=n.onToggle?i(n.onToggle):angular.noop,b=!1,x=null,w=!1,_=u.find("body");e.addClass("dropdown"),this.init=function(){if(n.isOpen&&(h=i(n.isOpen),v=h.assign,t.$watch(h,function(t){p.isOpen=!!t})),angular.isDefined(n.dropdownAppendTo)){var r=i(n.dropdownAppendTo)(p);r&&(x=angular.element(r))}b=angular.isDefined(n.dropdownAppendToBody),w=angular.isDefined(n.keyboardNav),b&&!x&&(x=_),x&&f.dropdownMenu&&(x.append(f.dropdownMenu),e.on("$destroy",function(){f.dropdownMenu.remove()}))},this.toggle=function(t){return p.isOpen=arguments.length?!!t:!p.isOpen,angular.isFunction(v)&&v(p,p.isOpen),p.isOpen},this.isOpen=function(){return p.isOpen},p.getToggleElement=function(){return f.toggleElement},p.getAutoClose=function(){return n.autoClose||"always"},p.getElement=function(){return e},p.isKeynavEnabled=function(){return w},p.focusDropdownEntry=function(t){var n=f.dropdownMenu?angular.element(f.dropdownMenu).find("a"):e.find("ul").eq(0).find("a");switch(t){case 40:angular.isNumber(f.selectedOption)?f.selectedOption=f.selectedOption===n.length-1?f.selectedOption:f.selectedOption+1:f.selectedOption=0;break;case 38:angular.isNumber(f.selectedOption)?f.selectedOption=0===f.selectedOption?0:f.selectedOption-1:f.selectedOption=n.length-1}n[f.selectedOption].focus()},p.getDropdownElement=function(){return f.dropdownMenu},p.focusToggleElement=function(){f.toggleElement&&f.toggleElement[0].focus()},p.$watch("isOpen",function(n,i){if(x&&f.dropdownMenu){var r,u,h,w=s.positionElements(e,f.dropdownMenu,"bottom-left",!0);if(r={top:w.top+"px",display:n?"block":"none"},u=f.dropdownMenu.hasClass("dropdown-menu-right"),u?(r.left="auto",h=s.scrollbarWidth(!0),r.right=window.innerWidth-h-(w.left+e.prop("offsetWidth"))+"px"):(r.left=w.left+"px",r.right="auto"),!b){var _=s.offset(x);r.top=w.top-_.top+"px",u?r.right=window.innerWidth-(w.left-_.left+e.prop("offsetWidth"))+"px":r.left=w.left-_.left+"px"}f.dropdownMenu.css(r)}var $=x?x:e,k=$.hasClass(x?g:m);if(k===!n&&a[n?"addClass":"removeClass"]($,x?g:m).then(function(){angular.isDefined(n)&&n!==i&&y(t,{open:!!n})}),n)f.dropdownMenuTemplateUrl&&c(f.dropdownMenuTemplateUrl).then(function(t){d=p.$new(),l(t.trim())(d,function(t){var e=t;f.dropdownMenu.replaceWith(e),f.dropdownMenu=e})}),p.focusToggleElement(),o.open(p,e);else{if(f.dropdownMenuTemplateUrl){d&&d.$destroy();var C=angular.element('<ul class="dropdown-menu"></ul>');f.dropdownMenu.replaceWith(C),f.dropdownMenu=C}o.close(p,e),f.selectedOption=null}angular.isFunction(v)&&v(t,n)})}]).directive("uibDropdown",function(){return{controller:"UibDropdownController",link:function(t,e,n,i){i.init()}}}).directive("uibDropdownMenu",function(){return{restrict:"A",require:"?^uibDropdown",link:function(t,e,n,i){if(i&&!angular.isDefined(n.dropdownNested)){e.addClass("dropdown-menu");var r=n.templateUrl;r&&(i.dropdownMenuTemplateUrl=r),i.dropdownMenu||(i.dropdownMenu=e)}}}}).directive("uibDropdownToggle",function(){return{require:"?^uibDropdown",link:function(t,e,n,i){if(i){e.addClass("dropdown-toggle"),i.toggleElement=e;var r=function(r){r.preventDefault(),e.hasClass("disabled")||n.disabled||t.$apply(function(){i.toggle()})};e.bind("click",r),e.attr({"aria-haspopup":!0,"aria-expanded":!1}),t.$watch(i.isOpen,function(t){e.attr("aria-expanded",!!t)}),t.$on("$destroy",function(){e.unbind("click",r)})}}}}),angular.module("ui.bootstrap.stackedMap",[]).factory("$$stackedMap",function(){return{createNew:function(){var t=[];return{add:function(e,n){t.push({key:e,value:n})},get:function(e){for(var n=0;n<t.length;n++)if(e===t[n].key)return t[n]},keys:function(){for(var e=[],n=0;n<t.length;n++)e.push(t[n].key);return e},top:function(){return t[t.length-1]},remove:function(e){for(var n=-1,i=0;i<t.length;i++)if(e===t[i].key){n=i;break}return t.splice(n,1)[0]},removeTop:function(){return t.splice(t.length-1,1)[0]},length:function(){return t.length}}}}}),angular.module("ui.bootstrap.modal",["ui.bootstrap.stackedMap","ui.bootstrap.position"]).factory("$$multiMap",function(){return{createNew:function(){var t={};return{entries:function(){return Object.keys(t).map(function(e){return{key:e,value:t[e]}})},get:function(e){return t[e]},hasKey:function(e){return!!t[e]},keys:function(){return Object.keys(t)},put:function(e,n){t[e]||(t[e]=[]),t[e].push(n)},remove:function(e,n){var i=t[e];if(i){var r=i.indexOf(n);-1!==r&&i.splice(r,1),i.length||delete t[e]}}}}}}).provider("$uibResolve",function(){var t=this;this.resolver=null,this.setResolver=function(t){this.resolver=t},this.$get=["$injector","$q",function(e,n){var i=t.resolver?e.get(t.resolver):null;return{resolve:function(t,r,o,a){if(i)return i.resolve(t,r,o,a);var s=[];return angular.forEach(t,function(t){angular.isFunction(t)||angular.isArray(t)?s.push(n.resolve(e.invoke(t))):angular.isString(t)?s.push(n.resolve(e.get(t))):s.push(n.resolve(t))}),n.all(s).then(function(e){var n={},i=0;return angular.forEach(t,function(t,r){n[r]=e[i++]}),n})}}}]}).directive("uibModalBackdrop",["$animate","$injector","$uibModalStack",function(t,e,n){function i(e,i,r){r.modalInClass&&(t.addClass(i,r.modalInClass),e.$on(n.NOW_CLOSING_EVENT,function(n,o){var a=o();e.modalOptions.animation?t.removeClass(i,r.modalInClass).then(a):a()}))}return{replace:!0,templateUrl:"uib/template/modal/backdrop.html",compile:function(t,e){return t.addClass(e.backdropClass),i}}}]).directive("uibModalWindow",["$uibModalStack","$q","$animateCss","$document",function(t,e,n,i){return{scope:{index:"@"},replace:!0,transclude:!0,templateUrl:function(t,e){return e.templateUrl||"uib/template/modal/window.html"},link:function(r,o,a){o.addClass(a.windowClass||""),o.addClass(a.windowTopClass||""),r.size=a.size,r.close=function(e){var n=t.getTop();n&&n.value.backdrop&&"static"!==n.value.backdrop&&e.target===e.currentTarget&&(e.preventDefault(),e.stopPropagation(),t.dismiss(n.key,"backdrop click"))},o.on("click",r.close),r.$isRendered=!0;var s=e.defer();a.$observe("modalRender",function(t){"true"===t&&s.resolve()}),s.promise.then(function(){var s=null;a.modalInClass&&(s=n(o,{addClass:a.modalInClass}).start(),r.$on(t.NOW_CLOSING_EVENT,function(t,e){var i=e();n(o,{removeClass:a.modalInClass}).start().then(i)})),e.when(s).then(function(){var e=t.getTop();if(e&&t.modalRendered(e.key),!i[0].activeElement||!o[0].contains(i[0].activeElement)){var n=o[0].querySelector("[autofocus]");n?n.focus():o[0].focus()}})})}}}]).directive("uibModalAnimationClass",function(){return{compile:function(t,e){e.modalAnimation&&t.addClass(e.uibModalAnimationClass)}}}).directive("uibModalTransclude",function(){return{link:function(t,e,n,i,r){r(t.$parent,function(t){e.empty(),e.append(t)})}}}).factory("$uibModalStack",["$animate","$animateCss","$document","$compile","$rootScope","$q","$$multiMap","$$stackedMap","$uibPosition",function(t,e,n,i,r,o,a,s,u){function l(t){return!!(t.offsetWidth||t.offsetHeight||t.getClientRects().length)}function c(){for(var t=-1,e=w.keys(),n=0;n<e.length;n++)w.get(e[n]).value.backdrop&&(t=n);return t>-1&&k>t&&(t=k),t}function d(t,e){var n=w.get(t).value,i=n.appendTo;w.remove(t),C=w.top(),C&&(k=parseInt(C.value.modalDomEl.attr("index"),10)),p(n.modalDomEl,n.modalScope,function(){var e=n.openedClass||x;_.remove(e,t);var r=_.hasKey(e);i.toggleClass(e,r),!r&&b&&b.heightOverflow&&b.scrollbarWidth&&(b.originalRight?i.css({paddingRight:b.originalRight+"px"}):i.css({paddingRight:""}),b=null),h(!0)},n.closedDeferred),f(),e&&e.focus?e.focus():i.focus&&i.focus()}function h(t){var e;w.length()>0&&(e=w.top().value,e.modalDomEl.toggleClass(e.windowTopClass||"",t))}function f(){if(v&&-1===c()){var t=y;p(v,y,function(){t=null}),v=void 0,y=void 0}}function p(e,n,i,r){function a(){a.done||(a.done=!0,t.leave(e).then(function(){e.remove(),r&&r.resolve()}),n.$destroy(),i&&i())}var s,u=null,l=function(){return s||(s=o.defer(),u=s.promise),function(){s.resolve()}};return n.$broadcast($.NOW_CLOSING_EVENT,l),o.when(u).then(a)}function g(t){if(t.isDefaultPrevented())return t;var e=w.top();if(e)switch(t.which){case 27:e.value.keyboard&&(t.preventDefault(),r.$apply(function(){$.dismiss(e.key,"escape key press")}));break;case 9:var n=$.loadFocusElementList(e),i=!1;t.shiftKey?($.isFocusInFirstItem(t,n)||$.isModalFocused(t,e))&&(i=$.focusLastFocusableElement(n)):$.isFocusInLastItem(t,n)&&(i=$.focusFirstFocusableElement(n)),i&&(t.preventDefault(),t.stopPropagation())}}function m(t,e,n){return!t.value.modalScope.$broadcast("modal.closing",e,n).defaultPrevented}var v,y,b,x="modal-open",w=s.createNew(),_=a.createNew(),$={NOW_CLOSING_EVENT:"modal.stack.now-closing"},k=0,C=null,M="a[href], area[href], input:not([disabled]), button:not([disabled]),select:not([disabled]), textarea:not([disabled]), iframe, object, embed, *[tabindex], *[contenteditable=true]";return r.$watch(c,function(t){y&&(y.index=t)}),n.on("keydown",g),r.$on("$destroy",function(){n.off("keydown",g)}),$.open=function(e,o){var a=n[0].activeElement,s=o.openedClass||x;h(!1),C=w.top(),w.add(e,{deferred:o.deferred,renderDeferred:o.renderDeferred,closedDeferred:o.closedDeferred,modalScope:o.scope,backdrop:o.backdrop,keyboard:o.keyboard,openedClass:o.openedClass,windowTopClass:o.windowTopClass,animation:o.animation,appendTo:o.appendTo}),_.put(s,e);var l=o.appendTo,d=c();if(!l.length)throw new Error("appendTo element not found. Make sure that the element passed is in DOM.");d>=0&&!v&&(y=r.$new(!0),y.modalOptions=o,y.index=d,v=angular.element('<div uib-modal-backdrop="modal-backdrop"></div>'),v.attr("backdrop-class",o.backdropClass),o.animation&&v.attr("modal-animation","true"),i(v)(y),t.enter(v,l),b=u.scrollbarPadding(l),b.heightOverflow&&b.scrollbarWidth&&l.css({paddingRight:b.right+"px"})),k=C?parseInt(C.value.modalDomEl.attr("index"),10)+1:0;var f=angular.element('<div uib-modal-window="modal-window"></div>');f.attr({"template-url":o.windowTemplateUrl,"window-class":o.windowClass,"window-top-class":o.windowTopClass,size:o.size,index:k,animate:"animate"}).html(o.content),o.animation&&f.attr("modal-animation","true"),l.addClass(s),t.enter(i(f)(o.scope),l),w.top().value.modalDomEl=f,w.top().value.modalOpener=a},$.close=function(t,e){var n=w.get(t);return n&&m(n,e,!0)?(n.value.modalScope.$$uibDestructionScheduled=!0,n.value.deferred.resolve(e),d(t,n.value.modalOpener),!0):!n},$.dismiss=function(t,e){var n=w.get(t);return n&&m(n,e,!1)?(n.value.modalScope.$$uibDestructionScheduled=!0,n.value.deferred.reject(e),d(t,n.value.modalOpener),!0):!n},$.dismissAll=function(t){for(var e=this.getTop();e&&this.dismiss(e.key,t);)e=this.getTop()},$.getTop=function(){return w.top()},$.modalRendered=function(t){var e=w.get(t);e&&e.value.renderDeferred.resolve()},$.focusFirstFocusableElement=function(t){return t.length>0?(t[0].focus(),!0):!1},$.focusLastFocusableElement=function(t){return t.length>0?(t[t.length-1].focus(),!0):!1},$.isModalFocused=function(t,e){if(t&&e){var n=e.value.modalDomEl;if(n&&n.length)return(t.target||t.srcElement)===n[0]}return!1},$.isFocusInFirstItem=function(t,e){return e.length>0?(t.target||t.srcElement)===e[0]:!1},$.isFocusInLastItem=function(t,e){return e.length>0?(t.target||t.srcElement)===e[e.length-1]:!1},$.loadFocusElementList=function(t){if(t){var e=t.value.modalDomEl;if(e&&e.length){var n=e[0].querySelectorAll(M);return n?Array.prototype.filter.call(n,function(t){return l(t)}):n}}},$}]).provider("$uibModal",function(){var t={options:{animation:!0,backdrop:!0,keyboard:!0},$get:["$rootScope","$q","$document","$templateRequest","$controller","$uibResolve","$uibModalStack",function(e,n,i,r,o,a,s){function u(t){return t.template?n.when(t.template):r(angular.isFunction(t.templateUrl)?t.templateUrl():t.templateUrl)}var l={},c=null;return l.getPromiseChain=function(){return c},l.open=function(r){function l(){return v}var d=n.defer(),h=n.defer(),f=n.defer(),p=n.defer(),g={result:d.promise,opened:h.promise,closed:f.promise,rendered:p.promise,close:function(t){return s.close(g,t)},dismiss:function(t){return s.dismiss(g,t)}};if(r=angular.extend({},t.options,r),r.resolve=r.resolve||{},r.appendTo=r.appendTo||i.find("body").eq(0),!r.template&&!r.templateUrl)throw new Error("One of template or templateUrl options is required.");var m,v=n.all([u(r),a.resolve(r.resolve,{},null,null)]);return m=c=n.all([c]).then(l,l).then(function(t){var n=r.scope||e,i=n.$new();i.$close=g.close,i.$dismiss=g.dismiss,i.$on("$destroy",function(){i.$$uibDestructionScheduled||i.$dismiss("$uibUnscheduledDestruction")});var a,u,l={};r.controller&&(l.$scope=i,l.$scope.$resolve={},l.$uibModalInstance=g,angular.forEach(t[1],function(t,e){l[e]=t,l.$scope.$resolve[e]=t}),u=o(r.controller,l,!0,r.controllerAs),r.controllerAs&&r.bindToController&&(a=u.instance,a.$close=i.$close,a.$dismiss=i.$dismiss,angular.extend(a,{$resolve:l.$scope.$resolve},n)),a=u(),angular.isFunction(a.$onInit)&&a.$onInit()),s.open(g,{scope:i,deferred:d,renderDeferred:p,closedDeferred:f,content:t[0],animation:r.animation,backdrop:r.backdrop,keyboard:r.keyboard,backdropClass:r.backdropClass,windowTopClass:r.windowTopClass,windowClass:r.windowClass,windowTemplateUrl:r.windowTemplateUrl,size:r.size,openedClass:r.openedClass,appendTo:r.appendTo}),h.resolve(!0)},function(t){h.reject(t),d.reject(t)})["finally"](function(){c===m&&(c=null)}),g},l}]};return t}),angular.module("ui.bootstrap.paging",[]).factory("uibPaging",["$parse",function(t){return{create:function(e,n,i){e.setNumPages=i.numPages?t(i.numPages).assign:angular.noop,e.ngModelCtrl={$setViewValue:angular.noop},e._watchers=[],e.init=function(t,r){e.ngModelCtrl=t,e.config=r,t.$render=function(){e.render()},i.itemsPerPage?e._watchers.push(n.$parent.$watch(i.itemsPerPage,function(t){e.itemsPerPage=parseInt(t,10),n.totalPages=e.calculateTotalPages(),e.updatePage()})):e.itemsPerPage=r.itemsPerPage,n.$watch("totalItems",function(t,i){(angular.isDefined(t)||t!==i)&&(n.totalPages=e.calculateTotalPages(),e.updatePage())})},e.calculateTotalPages=function(){var t=e.itemsPerPage<1?1:Math.ceil(n.totalItems/e.itemsPerPage);return Math.max(t||0,1)},e.render=function(){n.page=parseInt(e.ngModelCtrl.$viewValue,10)||1},n.selectPage=function(t,i){i&&i.preventDefault();var r=!n.ngDisabled||!i;r&&n.page!==t&&t>0&&t<=n.totalPages&&(i&&i.target&&i.target.blur(),e.ngModelCtrl.$setViewValue(t),e.ngModelCtrl.$render())},n.getText=function(t){return n[t+"Text"]||e.config[t+"Text"]},n.noPrevious=function(){return 1===n.page},n.noNext=function(){return n.page===n.totalPages},e.updatePage=function(){e.setNumPages(n.$parent,n.totalPages),n.page>n.totalPages?n.selectPage(n.totalPages):e.ngModelCtrl.$render()},n.$on("$destroy",function(){for(;e._watchers.length;)e._watchers.shift()()})}}}]),angular.module("ui.bootstrap.pager",["ui.bootstrap.paging"]).controller("UibPagerController",["$scope","$attrs","uibPaging","uibPagerConfig",function(t,e,n,i){t.align=angular.isDefined(e.align)?t.$parent.$eval(e.align):i.align,n.create(this,t,e)}]).constant("uibPagerConfig",{itemsPerPage:10,previousText:"« Previous",nextText:"Next »",align:!0}).directive("uibPager",["uibPagerConfig",function(t){return{scope:{totalItems:"=",previousText:"@",nextText:"@",ngDisabled:"="},require:["uibPager","?ngModel"],controller:"UibPagerController",controllerAs:"pager",templateUrl:function(t,e){return e.templateUrl||"uib/template/pager/pager.html"},replace:!0,link:function(e,n,i,r){var o=r[0],a=r[1];a&&o.init(a,t)}}}]),angular.module("ui.bootstrap.pagination",["ui.bootstrap.paging"]).controller("UibPaginationController",["$scope","$attrs","$parse","uibPaging","uibPaginationConfig",function(t,e,n,i,r){function o(t,e,n){return{number:t,text:e,active:n}}function a(t,e){var n=[],i=1,r=e,a=angular.isDefined(u)&&e>u;a&&(l?(i=Math.max(t-Math.floor(u/2),1),r=i+u-1,r>e&&(r=e,i=r-u+1)):(i=(Math.ceil(t/u)-1)*u+1,r=Math.min(i+u-1,e)));for(var s=i;r>=s;s++){var f=o(s,h(s),s===t);n.push(f)}if(a&&u>0&&(!l||c||d)){if(i>1){if(!d||i>3){var p=o(i-1,"...",!1);n.unshift(p)}if(d){if(3===i){var g=o(2,"2",!1);n.unshift(g)}var m=o(1,"1",!1);n.unshift(m)}}if(e>r){if(!d||e-2>r){var v=o(r+1,"...",!1);n.push(v)}if(d){if(r===e-2){var y=o(e-1,e-1,!1);n.push(y)}var b=o(e,e,!1);n.push(b)}}}return n}var s=this,u=angular.isDefined(e.maxSize)?t.$parent.$eval(e.maxSize):r.maxSize,l=angular.isDefined(e.rotate)?t.$parent.$eval(e.rotate):r.rotate,c=angular.isDefined(e.forceEllipses)?t.$parent.$eval(e.forceEllipses):r.forceEllipses,d=angular.isDefined(e.boundaryLinkNumbers)?t.$parent.$eval(e.boundaryLinkNumbers):r.boundaryLinkNumbers,h=angular.isDefined(e.pageLabel)?function(n){return t.$parent.$eval(e.pageLabel,{$page:n})}:angular.identity;t.boundaryLinks=angular.isDefined(e.boundaryLinks)?t.$parent.$eval(e.boundaryLinks):r.boundaryLinks,t.directionLinks=angular.isDefined(e.directionLinks)?t.$parent.$eval(e.directionLinks):r.directionLinks,i.create(this,t,e),e.maxSize&&s._watchers.push(t.$parent.$watch(n(e.maxSize),function(t){u=parseInt(t,10),s.render()}));var f=this.render;this.render=function(){f(),t.page>0&&t.page<=t.totalPages&&(t.pages=a(t.page,t.totalPages))}}]).constant("uibPaginationConfig",{itemsPerPage:10,boundaryLinks:!1,boundaryLinkNumbers:!1,directionLinks:!0,firstText:"First",previousText:"Previous",nextText:"Next",lastText:"Last",rotate:!0,forceEllipses:!1}).directive("uibPagination",["$parse","uibPaginationConfig",function(t,e){return{scope:{totalItems:"=",firstText:"@",previousText:"@",nextText:"@",lastText:"@",ngDisabled:"="},require:["uibPagination","?ngModel"],controller:"UibPaginationController",controllerAs:"pagination",templateUrl:function(t,e){return e.templateUrl||"uib/template/pagination/pagination.html"},replace:!0,link:function(t,n,i,r){var o=r[0],a=r[1];a&&o.init(a,e)}}}]),angular.module("ui.bootstrap.tooltip",["ui.bootstrap.position","ui.bootstrap.stackedMap"]).provider("$uibTooltip",function(){function t(t){var e=/[A-Z]/g,n="-";return t.replace(e,function(t,e){return(e?n:"")+t.toLowerCase()})}var e={placement:"top",placementClassPrefix:"",animation:!0,popupDelay:0,popupCloseDelay:0,useContentExp:!1},n={mouseenter:"mouseleave",click:"click",outsideClick:"outsideClick",focus:"blur",none:""},i={};this.options=function(t){angular.extend(i,t)},this.setTriggers=function(t){angular.extend(n,t)},this.$get=["$window","$compile","$timeout","$document","$uibPosition","$interpolate","$rootScope","$parse","$$stackedMap",function(r,o,a,s,u,l,c,d,h){function f(t){if(27===t.which){var e=p.top();e&&(e.value.close(),p.removeTop(),e=null)}}var p=h.createNew();return s.on("keypress",f),c.$on("$destroy",function(){s.off("keypress",f)}),function(r,c,h,f){function g(t){var e=(t||f.trigger||h).split(" "),i=e.map(function(t){
return n[t]||t});return{show:e,hide:i}}f=angular.extend({},e,i,f);var m=t(r),v=l.startSymbol(),y=l.endSymbol(),b="<div "+m+'-popup uib-title="'+v+"title"+y+'" '+(f.useContentExp?'content-exp="contentExp()" ':'content="'+v+"content"+y+'" ')+'placement="'+v+"placement"+y+'" popup-class="'+v+"popupClass"+y+'" animation="animation" is-open="isOpen" origin-scope="origScope" class="uib-position-measure"></div>';return{compile:function(t,e){var n=o(b);return function(t,e,i,o){function l(){L.isOpen?m():h()}function h(){(!H||t.$eval(i[c+"Enable"]))&&(x(),$(),L.popupDelay?O||(O=a(v,L.popupDelay,!1)):v())}function m(){y(),L.popupCloseDelay?N||(N=a(b,L.popupCloseDelay,!1)):b()}function v(){return y(),x(),L.content?(w(),void L.$evalAsync(function(){L.isOpen=!0,k(!0),q()})):angular.noop}function y(){O&&(a.cancel(O),O=null),I&&(a.cancel(I),I=null)}function b(){L&&L.$evalAsync(function(){L&&(L.isOpen=!1,k(!1),L.animation?E||(E=a(_,150,!1)):_())})}function x(){N&&(a.cancel(N),N=null),E&&(a.cancel(E),E=null)}function w(){T||(A=L.$new(),T=n(A,function(t){F?s.find("body").append(t):e.after(t)}),C())}function _(){y(),x(),M(),T&&(T.remove(),T=null),A&&(A.$destroy(),A=null)}function $(){L.title=i[c+"Title"],R?L.content=R(t):L.content=i[r],L.popupClass=i[c+"Class"],L.placement=angular.isDefined(i[c+"Placement"])?i[c+"Placement"]:f.placement;var e=u.parsePlacement(L.placement);P=e[1]?e[0]+"-"+e[1]:e[0];var n=parseInt(i[c+"PopupDelay"],10),o=parseInt(i[c+"PopupCloseDelay"],10);L.popupDelay=isNaN(n)?f.popupDelay:n,L.popupCloseDelay=isNaN(o)?f.popupCloseDelay:o}function k(e){j&&angular.isFunction(j.assign)&&j.assign(t,e)}function C(){U.length=0,R?(U.push(t.$watch(R,function(t){L.content=t,!t&&L.isOpen&&b()})),U.push(A.$watch(function(){z||(z=!0,A.$$postDigest(function(){z=!1,L&&L.isOpen&&q()}))}))):U.push(i.$observe(r,function(t){L.content=t,!t&&L.isOpen?b():q()})),U.push(i.$observe(c+"Title",function(t){L.title=t,L.isOpen&&q()})),U.push(i.$observe(c+"Placement",function(t){L.placement=t?t:f.placement,L.isOpen&&q()}))}function M(){U.length&&(angular.forEach(U,function(t){t()}),U.length=0)}function D(t){L&&L.isOpen&&T&&(e[0].contains(t.target)||T[0].contains(t.target)||m())}function S(){var t=i[c+"Trigger"];B(),W=g(t),"none"!==W.show&&W.show.forEach(function(t,n){"outsideClick"===t?(e.on("click",l),s.on("click",D)):t===W.hide[n]?e.on(t,l):t&&(e.on(t,h),e.on(W.hide[n],m)),e.on("keypress",function(t){27===t.which&&m()})})}var T,A,E,O,N,I,P,F=angular.isDefined(f.appendToBody)?f.appendToBody:!1,W=g(void 0),H=angular.isDefined(i[c+"Enable"]),L=t.$new(!0),z=!1,j=angular.isDefined(i[c+"IsOpen"])?d(i[c+"IsOpen"]):!1,R=f.useContentExp?d(i[r]):!1,U=[],q=function(){T&&T.html()&&(I||(I=a(function(){var t=u.positionElements(e,T,L.placement,F);T.css({top:t.top+"px",left:t.left+"px"}),T.hasClass(t.placement.split("-")[0])||(T.removeClass(P.split("-")[0]),T.addClass(t.placement.split("-")[0])),T.hasClass(f.placementClassPrefix+t.placement)||(T.removeClass(f.placementClassPrefix+P),T.addClass(f.placementClassPrefix+t.placement)),T.hasClass("uib-position-measure")?(u.positionArrow(T,t.placement),T.removeClass("uib-position-measure")):P!==t.placement&&u.positionArrow(T,t.placement),P=t.placement,I=null},0,!1)))};L.origScope=t,L.isOpen=!1,p.add(L,{close:b}),L.contentExp=function(){return L.content},i.$observe("disabled",function(t){t&&y(),t&&L.isOpen&&b()}),j&&t.$watch(j,function(t){L&&!t===L.isOpen&&l()});var B=function(){W.show.forEach(function(t){"outsideClick"===t?e.off("click",l):(e.off(t,h),e.off(t,l))}),W.hide.forEach(function(t){"outsideClick"===t?s.off("click",D):e.off(t,m)})};S();var V=t.$eval(i[c+"Animation"]);L.animation=angular.isDefined(V)?!!V:f.animation;var Y,G=c+"AppendToBody";Y=G in i&&void 0===i[G]?!0:t.$eval(i[G]),F=angular.isDefined(Y)?Y:F,t.$on("$destroy",function(){B(),_(),p.remove(L),L=null})}}}}}]}).directive("uibTooltipTemplateTransclude",["$animate","$sce","$compile","$templateRequest",function(t,e,n,i){return{link:function(r,o,a){var s,u,l,c=r.$eval(a.tooltipTemplateTranscludeScope),d=0,h=function(){u&&(u.remove(),u=null),s&&(s.$destroy(),s=null),l&&(t.leave(l).then(function(){u=null}),u=l,l=null)};r.$watch(e.parseAsResourceUrl(a.uibTooltipTemplateTransclude),function(e){var a=++d;e?(i(e,!0).then(function(i){if(a===d){var r=c.$new(),u=i,f=n(u)(r,function(e){h(),t.enter(e,o)});s=r,l=f,s.$emit("$includeContentLoaded",e)}},function(){a===d&&(h(),r.$emit("$includeContentError",e))}),r.$emit("$includeContentRequested",e)):h()}),r.$on("$destroy",h)}}}]).directive("uibTooltipClasses",["$uibPosition",function(t){return{restrict:"A",link:function(e,n,i){if(e.placement){var r=t.parsePlacement(e.placement);n.addClass(r[0])}e.popupClass&&n.addClass(e.popupClass),e.animation()&&n.addClass(i.tooltipAnimationClass)}}}]).directive("uibTooltipPopup",function(){return{replace:!0,scope:{content:"@",placement:"@",popupClass:"@",animation:"&",isOpen:"&"},templateUrl:"uib/template/tooltip/tooltip-popup.html"}}).directive("uibTooltip",["$uibTooltip",function(t){return t("uibTooltip","tooltip","mouseenter")}]).directive("uibTooltipTemplatePopup",function(){return{replace:!0,scope:{contentExp:"&",placement:"@",popupClass:"@",animation:"&",isOpen:"&",originScope:"&"},templateUrl:"uib/template/tooltip/tooltip-template-popup.html"}}).directive("uibTooltipTemplate",["$uibTooltip",function(t){return t("uibTooltipTemplate","tooltip","mouseenter",{useContentExp:!0})}]).directive("uibTooltipHtmlPopup",function(){return{replace:!0,scope:{contentExp:"&",placement:"@",popupClass:"@",animation:"&",isOpen:"&"},templateUrl:"uib/template/tooltip/tooltip-html-popup.html"}}).directive("uibTooltipHtml",["$uibTooltip",function(t){return t("uibTooltipHtml","tooltip","mouseenter",{useContentExp:!0})}]),angular.module("ui.bootstrap.popover",["ui.bootstrap.tooltip"]).directive("uibPopoverTemplatePopup",function(){return{replace:!0,scope:{uibTitle:"@",contentExp:"&",placement:"@",popupClass:"@",animation:"&",isOpen:"&",originScope:"&"},templateUrl:"uib/template/popover/popover-template.html"}}).directive("uibPopoverTemplate",["$uibTooltip",function(t){return t("uibPopoverTemplate","popover","click",{useContentExp:!0})}]).directive("uibPopoverHtmlPopup",function(){return{replace:!0,scope:{contentExp:"&",uibTitle:"@",placement:"@",popupClass:"@",animation:"&",isOpen:"&"},templateUrl:"uib/template/popover/popover-html.html"}}).directive("uibPopoverHtml",["$uibTooltip",function(t){return t("uibPopoverHtml","popover","click",{useContentExp:!0})}]).directive("uibPopoverPopup",function(){return{replace:!0,scope:{uibTitle:"@",content:"@",placement:"@",popupClass:"@",animation:"&",isOpen:"&"},templateUrl:"uib/template/popover/popover.html"}}).directive("uibPopover",["$uibTooltip",function(t){return t("uibPopover","popover","click")}]),angular.module("ui.bootstrap.progressbar",[]).constant("uibProgressConfig",{animate:!0,max:100}).controller("UibProgressController",["$scope","$attrs","uibProgressConfig",function(t,e,n){function i(){return angular.isDefined(t.maxParam)?t.maxParam:n.max}var r=this,o=angular.isDefined(e.animate)?t.$parent.$eval(e.animate):n.animate;this.bars=[],t.max=i(),this.addBar=function(t,e,n){o||e.css({transition:"none"}),this.bars.push(t),t.max=i(),t.title=n&&angular.isDefined(n.title)?n.title:"progressbar",t.$watch("value",function(e){t.recalculatePercentage()}),t.recalculatePercentage=function(){var e=r.bars.reduce(function(t,e){return e.percent=+(100*e.value/e.max).toFixed(2),t+e.percent},0);e>100&&(t.percent-=e-100)},t.$on("$destroy",function(){e=null,r.removeBar(t)})},this.removeBar=function(t){this.bars.splice(this.bars.indexOf(t),1),this.bars.forEach(function(t){t.recalculatePercentage()})},t.$watch("maxParam",function(t){r.bars.forEach(function(t){t.max=i(),t.recalculatePercentage()})})}]).directive("uibProgress",function(){return{replace:!0,transclude:!0,controller:"UibProgressController",require:"uibProgress",scope:{maxParam:"=?max"},templateUrl:"uib/template/progressbar/progress.html"}}).directive("uibBar",function(){return{replace:!0,transclude:!0,require:"^uibProgress",scope:{value:"=",type:"@"},templateUrl:"uib/template/progressbar/bar.html",link:function(t,e,n,i){i.addBar(t,e,n)}}}).directive("uibProgressbar",function(){return{replace:!0,transclude:!0,controller:"UibProgressController",scope:{value:"=",maxParam:"=?max",type:"@"},templateUrl:"uib/template/progressbar/progressbar.html",link:function(t,e,n,i){i.addBar(t,angular.element(e.children()[0]),{title:n.title})}}}),angular.module("ui.bootstrap.rating",[]).constant("uibRatingConfig",{max:5,stateOn:null,stateOff:null,enableReset:!0,titles:["one","two","three","four","five"]}).controller("UibRatingController",["$scope","$attrs","uibRatingConfig",function(t,e,n){var i={$setViewValue:angular.noop},r=this;this.init=function(r){i=r,i.$render=this.render,i.$formatters.push(function(t){return angular.isNumber(t)&&t<<0!==t&&(t=Math.round(t)),t}),this.stateOn=angular.isDefined(e.stateOn)?t.$parent.$eval(e.stateOn):n.stateOn,this.stateOff=angular.isDefined(e.stateOff)?t.$parent.$eval(e.stateOff):n.stateOff,this.enableReset=angular.isDefined(e.enableReset)?t.$parent.$eval(e.enableReset):n.enableReset;var o=angular.isDefined(e.titles)?t.$parent.$eval(e.titles):n.titles;this.titles=angular.isArray(o)&&o.length>0?o:n.titles;var a=angular.isDefined(e.ratingStates)?t.$parent.$eval(e.ratingStates):new Array(angular.isDefined(e.max)?t.$parent.$eval(e.max):n.max);t.range=this.buildTemplateObjects(a)},this.buildTemplateObjects=function(t){for(var e=0,n=t.length;n>e;e++)t[e]=angular.extend({index:e},{stateOn:this.stateOn,stateOff:this.stateOff,title:this.getTitle(e)},t[e]);return t},this.getTitle=function(t){return t>=this.titles.length?t+1:this.titles[t]},t.rate=function(e){if(!t.readonly&&e>=0&&e<=t.range.length){var n=r.enableReset&&i.$viewValue===e?0:e;i.$setViewValue(n),i.$render()}},t.enter=function(e){t.readonly||(t.value=e),t.onHover({value:e})},t.reset=function(){t.value=i.$viewValue,t.onLeave()},t.onKeydown=function(e){/(37|38|39|40)/.test(e.which)&&(e.preventDefault(),e.stopPropagation(),t.rate(t.value+(38===e.which||39===e.which?1:-1)))},this.render=function(){t.value=i.$viewValue,t.title=r.getTitle(t.value-1)}}]).directive("uibRating",function(){return{require:["uibRating","ngModel"],scope:{readonly:"=?readOnly",onHover:"&",onLeave:"&"},controller:"UibRatingController",templateUrl:"uib/template/rating/rating.html",replace:!0,link:function(t,e,n,i){var r=i[0],o=i[1];r.init(o)}}}),angular.module("ui.bootstrap.tabs",[]).controller("UibTabsetController",["$scope",function(t){function e(t){for(var e=0;e<i.tabs.length;e++)if(i.tabs[e].index===t)return e}var n,i=this;i.tabs=[],i.select=function(t,o){if(!r){var a=e(n),s=i.tabs[a];if(s){if(s.tab.onDeselect({$event:o,$selectedIndex:t}),o&&o.isDefaultPrevented())return;s.tab.active=!1}var u=i.tabs[t];u?(u.tab.onSelect({$event:o}),u.tab.active=!0,i.active=u.index,n=u.index):!u&&angular.isDefined(n)&&(i.active=null,n=null)}},i.addTab=function(t){if(i.tabs.push({tab:t,index:t.index}),i.tabs.sort(function(t,e){return t.index>e.index?1:t.index<e.index?-1:0}),t.index===i.active||!angular.isDefined(i.active)&&1===i.tabs.length){var n=e(t.index);i.select(n)}},i.removeTab=function(t){for(var e,n=0;n<i.tabs.length;n++)if(i.tabs[n].tab===t){e=n;break}if(i.tabs[e].index===i.active){var r=e===i.tabs.length-1?e-1:e+1%i.tabs.length;i.select(r)}i.tabs.splice(e,1)},t.$watch("tabset.active",function(t){angular.isDefined(t)&&t!==n&&i.select(e(t))});var r;t.$on("$destroy",function(){r=!0})}]).directive("uibTabset",function(){return{transclude:!0,replace:!0,scope:{},bindToController:{active:"=?",type:"@"},controller:"UibTabsetController",controllerAs:"tabset",templateUrl:function(t,e){return e.templateUrl||"uib/template/tabs/tabset.html"},link:function(t,e,n){t.vertical=angular.isDefined(n.vertical)?t.$parent.$eval(n.vertical):!1,t.justified=angular.isDefined(n.justified)?t.$parent.$eval(n.justified):!1}}}).directive("uibTab",["$parse",function(t){return{require:"^uibTabset",replace:!0,templateUrl:function(t,e){return e.templateUrl||"uib/template/tabs/tab.html"},transclude:!0,scope:{heading:"@",index:"=?",classes:"@?",onSelect:"&select",onDeselect:"&deselect"},controller:function(){},controllerAs:"tab",link:function(e,n,i,r,o){e.disabled=!1,i.disable&&e.$parent.$watch(t(i.disable),function(t){e.disabled=!!t}),angular.isUndefined(i.index)&&(r.tabs&&r.tabs.length?e.index=Math.max.apply(null,r.tabs.map(function(t){return t.index}))+1:e.index=0),angular.isUndefined(i.classes)&&(e.classes=""),e.select=function(t){if(!e.disabled){for(var n,i=0;i<r.tabs.length;i++)if(r.tabs[i].tab===e){n=i;break}r.select(n,t)}},r.addTab(e),e.$on("$destroy",function(){r.removeTab(e)}),e.$transcludeFn=o}}}]).directive("uibTabHeadingTransclude",function(){return{restrict:"A",require:"^uibTab",link:function(t,e){t.$watch("headingElement",function(t){t&&(e.html(""),e.append(t))})}}}).directive("uibTabContentTransclude",function(){function t(t){return t.tagName&&(t.hasAttribute("uib-tab-heading")||t.hasAttribute("data-uib-tab-heading")||t.hasAttribute("x-uib-tab-heading")||"uib-tab-heading"===t.tagName.toLowerCase()||"data-uib-tab-heading"===t.tagName.toLowerCase()||"x-uib-tab-heading"===t.tagName.toLowerCase()||"uib:tab-heading"===t.tagName.toLowerCase())}return{restrict:"A",require:"^uibTabset",link:function(e,n,i){var r=e.$eval(i.uibTabContentTransclude).tab;r.$transcludeFn(r.$parent,function(e){angular.forEach(e,function(e){t(e)?r.headingElement=e:n.append(e)})})}}}),angular.module("ui.bootstrap.timepicker",[]).constant("uibTimepickerConfig",{hourStep:1,minuteStep:1,secondStep:1,showMeridian:!0,showSeconds:!1,meridians:null,readonlyInput:!1,mousewheel:!0,arrowkeys:!0,showSpinners:!0,templateUrl:"uib/template/timepicker/timepicker.html"}).controller("UibTimepickerController",["$scope","$element","$attrs","$parse","$log","$locale","uibTimepickerConfig",function(t,e,n,i,r,o,a){function s(){var e=+t.hours,n=t.showMeridian?e>0&&13>e:e>=0&&24>e;return n&&""!==t.hours?(t.showMeridian&&(12===e&&(e=0),t.meridian===w[1]&&(e+=12)),e):void 0}function u(){var e=+t.minutes,n=e>=0&&60>e;return n&&""!==t.minutes?e:void 0}function l(){var e=+t.seconds;return e>=0&&60>e?e:void 0}function c(t,e){return null===t?"":angular.isDefined(t)&&t.toString().length<2&&!e?"0"+t:t.toString()}function d(t){h(),x.$setViewValue(new Date(y)),f(t)}function h(){x.$setValidity("time",!0),t.invalidHours=!1,t.invalidMinutes=!1,t.invalidSeconds=!1}function f(e){if(x.$modelValue){var n=y.getHours(),i=y.getMinutes(),r=y.getSeconds();t.showMeridian&&(n=0===n||12===n?12:n%12),t.hours="h"===e?n:c(n,!_),"m"!==e&&(t.minutes=c(i)),t.meridian=y.getHours()<12?w[0]:w[1],"s"!==e&&(t.seconds=c(r)),t.meridian=y.getHours()<12?w[0]:w[1]}else t.hours=null,t.minutes=null,t.seconds=null,t.meridian=w[0]}function p(t){y=m(y,t),d()}function g(t,e){return m(t,60*e)}function m(t,e){var n=new Date(t.getTime()+1e3*e),i=new Date(t);return i.setHours(n.getHours(),n.getMinutes(),n.getSeconds()),i}function v(){return(null===t.hours||""===t.hours)&&(null===t.minutes||""===t.minutes)&&(!t.showSeconds||t.showSeconds&&(null===t.seconds||""===t.seconds))}var y=new Date,b=[],x={$setViewValue:angular.noop},w=angular.isDefined(n.meridians)?t.$parent.$eval(n.meridians):a.meridians||o.DATETIME_FORMATS.AMPMS,_=angular.isDefined(n.padHours)?t.$parent.$eval(n.padHours):!0;t.tabindex=angular.isDefined(n.tabindex)?n.tabindex:0,e.removeAttr("tabindex"),this.init=function(e,i){x=e,x.$render=this.render,x.$formatters.unshift(function(t){return t?new Date(t):null});var r=i.eq(0),o=i.eq(1),s=i.eq(2),u=angular.isDefined(n.mousewheel)?t.$parent.$eval(n.mousewheel):a.mousewheel;u&&this.setupMousewheelEvents(r,o,s);var l=angular.isDefined(n.arrowkeys)?t.$parent.$eval(n.arrowkeys):a.arrowkeys;l&&this.setupArrowkeyEvents(r,o,s),t.readonlyInput=angular.isDefined(n.readonlyInput)?t.$parent.$eval(n.readonlyInput):a.readonlyInput,this.setupInputEvents(r,o,s)};var $=a.hourStep;n.hourStep&&b.push(t.$parent.$watch(i(n.hourStep),function(t){$=+t}));var k=a.minuteStep;n.minuteStep&&b.push(t.$parent.$watch(i(n.minuteStep),function(t){k=+t}));var C;b.push(t.$parent.$watch(i(n.min),function(t){var e=new Date(t);C=isNaN(e)?void 0:e}));var M;b.push(t.$parent.$watch(i(n.max),function(t){var e=new Date(t);M=isNaN(e)?void 0:e}));var D=!1;n.ngDisabled&&b.push(t.$parent.$watch(i(n.ngDisabled),function(t){D=t})),t.noIncrementHours=function(){var t=g(y,60*$);return D||t>M||y>t&&C>t},t.noDecrementHours=function(){var t=g(y,60*-$);return D||C>t||t>y&&t>M},t.noIncrementMinutes=function(){var t=g(y,k);return D||t>M||y>t&&C>t},t.noDecrementMinutes=function(){var t=g(y,-k);return D||C>t||t>y&&t>M},t.noIncrementSeconds=function(){var t=m(y,S);return D||t>M||y>t&&C>t},t.noDecrementSeconds=function(){var t=m(y,-S);return D||C>t||t>y&&t>M},t.noToggleMeridian=function(){return y.getHours()<12?D||g(y,720)>M:D||g(y,-720)<C};var S=a.secondStep;n.secondStep&&b.push(t.$parent.$watch(i(n.secondStep),function(t){S=+t})),t.showSeconds=a.showSeconds,n.showSeconds&&b.push(t.$parent.$watch(i(n.showSeconds),function(e){t.showSeconds=!!e})),t.showMeridian=a.showMeridian,n.showMeridian&&b.push(t.$parent.$watch(i(n.showMeridian),function(e){if(t.showMeridian=!!e,x.$error.time){var n=s(),i=u();angular.isDefined(n)&&angular.isDefined(i)&&(y.setHours(n),d())}else f()})),this.setupMousewheelEvents=function(e,n,i){var r=function(t){t.originalEvent&&(t=t.originalEvent);var e=t.wheelDelta?t.wheelDelta:-t.deltaY;return t.detail||e>0};e.bind("mousewheel wheel",function(e){D||t.$apply(r(e)?t.incrementHours():t.decrementHours()),e.preventDefault()}),n.bind("mousewheel wheel",function(e){D||t.$apply(r(e)?t.incrementMinutes():t.decrementMinutes()),e.preventDefault()}),i.bind("mousewheel wheel",function(e){D||t.$apply(r(e)?t.incrementSeconds():t.decrementSeconds()),e.preventDefault()})},this.setupArrowkeyEvents=function(e,n,i){e.bind("keydown",function(e){D||(38===e.which?(e.preventDefault(),t.incrementHours(),t.$apply()):40===e.which&&(e.preventDefault(),t.decrementHours(),t.$apply()))}),n.bind("keydown",function(e){D||(38===e.which?(e.preventDefault(),t.incrementMinutes(),t.$apply()):40===e.which&&(e.preventDefault(),t.decrementMinutes(),t.$apply()))}),i.bind("keydown",function(e){D||(38===e.which?(e.preventDefault(),t.incrementSeconds(),t.$apply()):40===e.which&&(e.preventDefault(),t.decrementSeconds(),t.$apply()))})},this.setupInputEvents=function(e,n,i){if(t.readonlyInput)return t.updateHours=angular.noop,t.updateMinutes=angular.noop,void(t.updateSeconds=angular.noop);var r=function(e,n,i){x.$setViewValue(null),x.$setValidity("time",!1),angular.isDefined(e)&&(t.invalidHours=e),angular.isDefined(n)&&(t.invalidMinutes=n),angular.isDefined(i)&&(t.invalidSeconds=i)};t.updateHours=function(){var t=s(),e=u();x.$setDirty(),angular.isDefined(t)&&angular.isDefined(e)?(y.setHours(t),y.setMinutes(e),C>y||y>M?r(!0):d("h")):r(!0)},e.bind("blur",function(e){x.$setTouched(),v()?h():null===t.hours||""===t.hours?r(!0):!t.invalidHours&&t.hours<10&&t.$apply(function(){t.hours=c(t.hours,!_)})}),t.updateMinutes=function(){var t=u(),e=s();x.$setDirty(),angular.isDefined(t)&&angular.isDefined(e)?(y.setHours(e),y.setMinutes(t),C>y||y>M?r(void 0,!0):d("m")):r(void 0,!0)},n.bind("blur",function(e){x.$setTouched(),v()?h():null===t.minutes?r(void 0,!0):!t.invalidMinutes&&t.minutes<10&&t.$apply(function(){t.minutes=c(t.minutes)})}),t.updateSeconds=function(){var t=l();x.$setDirty(),angular.isDefined(t)?(y.setSeconds(t),d("s")):r(void 0,void 0,!0)},i.bind("blur",function(e){v()?h():!t.invalidSeconds&&t.seconds<10&&t.$apply(function(){t.seconds=c(t.seconds)})})},this.render=function(){var e=x.$viewValue;isNaN(e)?(x.$setValidity("time",!1),r.error('Timepicker directive: "ng-model" value must be a Date object, a number of milliseconds since 01.01.1970 or a string representing an RFC2822 or ISO 8601 date.')):(e&&(y=e),C>y||y>M?(x.$setValidity("time",!1),t.invalidHours=!0,t.invalidMinutes=!0):h(),f())},t.showSpinners=angular.isDefined(n.showSpinners)?t.$parent.$eval(n.showSpinners):a.showSpinners,t.incrementHours=function(){t.noIncrementHours()||p(60*$*60)},t.decrementHours=function(){t.noDecrementHours()||p(60*-$*60)},t.incrementMinutes=function(){t.noIncrementMinutes()||p(60*k)},t.decrementMinutes=function(){t.noDecrementMinutes()||p(60*-k)},t.incrementSeconds=function(){t.noIncrementSeconds()||p(S)},t.decrementSeconds=function(){t.noDecrementSeconds()||p(-S)},t.toggleMeridian=function(){var e=u(),n=s();t.noToggleMeridian()||(angular.isDefined(e)&&angular.isDefined(n)?p(720*(y.getHours()<12?60:-60)):t.meridian=t.meridian===w[0]?w[1]:w[0])},t.blur=function(){x.$setTouched()},t.$on("$destroy",function(){for(;b.length;)b.shift()()})}]).directive("uibTimepicker",["uibTimepickerConfig",function(t){return{require:["uibTimepicker","?^ngModel"],controller:"UibTimepickerController",controllerAs:"timepicker",replace:!0,scope:{},templateUrl:function(e,n){return n.templateUrl||t.templateUrl},link:function(t,e,n,i){var r=i[0],o=i[1];o&&r.init(o,e.find("input"))}}}]),angular.module("ui.bootstrap.typeahead",["ui.bootstrap.debounce","ui.bootstrap.position"]).factory("uibTypeaheadParser",["$parse",function(t){var e=/^\s*([\s\S]+?)(?:\s+as\s+([\s\S]+?))?\s+for\s+(?:([\$\w][\$\w\d]*))\s+in\s+([\s\S]+?)$/;return{parse:function(n){var i=n.match(e);if(!i)throw new Error('Expected typeahead specification in form of "_modelValue_ (as _label_)? for _item_ in _collection_" but got "'+n+'".');return{itemName:i[3],source:t(i[4]),viewMapper:t(i[2]||i[1]),modelMapper:t(i[1])}}}}]).controller("UibTypeaheadController",["$scope","$element","$attrs","$compile","$parse","$q","$timeout","$document","$window","$rootScope","$$debounce","$uibPosition","uibTypeaheadParser",function(t,e,n,i,r,o,a,s,u,l,c,d,h){function f(){z.moveInProgress||(z.moveInProgress=!0,z.$digest()),Z()}function p(){z.position=A?d.offset(e):d.position(e),z.position.top+=e.prop("offsetHeight")}var g,m,v=[9,13,27,38,40],y=200,b=t.$eval(n.typeaheadMinLength);b||0===b||(b=1),t.$watch(n.typeaheadMinLength,function(t){b=t||0===t?t:1});var x=t.$eval(n.typeaheadWaitMs)||0,w=t.$eval(n.typeaheadEditable)!==!1;t.$watch(n.typeaheadEditable,function(t){w=t!==!1});var _,$,k=r(n.typeaheadLoading).assign||angular.noop,C=n.typeaheadShouldSelect?r(n.typeaheadShouldSelect):function(t,e){var n=e.$event;return 13===n.which||9===n.which},M=r(n.typeaheadOnSelect),D=angular.isDefined(n.typeaheadSelectOnBlur)?t.$eval(n.typeaheadSelectOnBlur):!1,S=r(n.typeaheadNoResults).assign||angular.noop,T=n.typeaheadInputFormatter?r(n.typeaheadInputFormatter):void 0,A=n.typeaheadAppendToBody?t.$eval(n.typeaheadAppendToBody):!1,E=n.typeaheadAppendTo?t.$eval(n.typeaheadAppendTo):null,O=t.$eval(n.typeaheadFocusFirst)!==!1,N=n.typeaheadSelectOnExact?t.$eval(n.typeaheadSelectOnExact):!1,I=r(n.typeaheadIsOpen).assign||angular.noop,P=t.$eval(n.typeaheadShowHint)||!1,F=r(n.ngModel),W=r(n.ngModel+"($$$p)"),H=function(e,n){return angular.isFunction(F(t))&&m&&m.$options&&m.$options.getterSetter?W(e,{$$$p:n}):F.assign(e,n)},L=h.parse(n.uibTypeahead),z=t.$new(),j=t.$on("$destroy",function(){z.$destroy()});z.$on("$destroy",j);var R="typeahead-"+z.$id+"-"+Math.floor(1e4*Math.random());e.attr({"aria-autocomplete":"list","aria-expanded":!1,"aria-owns":R});var U,q;P&&(U=angular.element("<div></div>"),U.css("position","relative"),e.after(U),q=e.clone(),q.attr("placeholder",""),q.attr("tabindex","-1"),q.val(""),q.css({position:"absolute",top:"0px",left:"0px","border-color":"transparent","box-shadow":"none",opacity:1,background:"none 0% 0% / auto repeat scroll padding-box border-box rgb(255, 255, 255)",color:"#999"}),e.css({position:"relative","vertical-align":"top","background-color":"transparent"}),U.append(q),q.after(e));var B=angular.element("<div uib-typeahead-popup></div>");B.attr({id:R,matches:"matches",active:"activeIdx",select:"select(activeIdx, evt)","move-in-progress":"moveInProgress",query:"query",position:"position","assign-is-open":"assignIsOpen(isOpen)",debounce:"debounceUpdate"}),angular.isDefined(n.typeaheadTemplateUrl)&&B.attr("template-url",n.typeaheadTemplateUrl),angular.isDefined(n.typeaheadPopupTemplateUrl)&&B.attr("popup-template-url",n.typeaheadPopupTemplateUrl);var V=function(){P&&q.val("")},Y=function(){z.matches=[],z.activeIdx=-1,e.attr("aria-expanded",!1),V()},G=function(t){return R+"-option-"+t};z.$watch("activeIdx",function(t){0>t?e.removeAttr("aria-activedescendant"):e.attr("aria-activedescendant",G(t))});var X=function(t,e){return z.matches.length>e&&t?t.toUpperCase()===z.matches[e].label.toUpperCase():!1},K=function(n,i){var r={$viewValue:n};k(t,!0),S(t,!1),o.when(L.source(t,r)).then(function(o){var a=n===g.$viewValue;if(a&&_)if(o&&o.length>0){z.activeIdx=O?0:-1,S(t,!1),z.matches.length=0;for(var s=0;s<o.length;s++)r[L.itemName]=o[s],z.matches.push({id:G(s),label:L.viewMapper(z,r),model:o[s]});if(z.query=n,p(),e.attr("aria-expanded",!0),N&&1===z.matches.length&&X(n,0)&&(angular.isNumber(z.debounceUpdate)||angular.isObject(z.debounceUpdate)?c(function(){z.select(0,i)},angular.isNumber(z.debounceUpdate)?z.debounceUpdate:z.debounceUpdate["default"]):z.select(0,i)),P){var u=z.matches[0].label;angular.isString(n)&&n.length>0&&u.slice(0,n.length).toUpperCase()===n.toUpperCase()?q.val(n+u.slice(n.length)):q.val("")}}else Y(),S(t,!0);a&&k(t,!1)},function(){Y(),k(t,!1),S(t,!0)})};A&&(angular.element(u).on("resize",f),s.find("body").on("scroll",f));var Z=c(function(){z.matches.length&&p(),z.moveInProgress=!1},y);z.moveInProgress=!1,z.query=void 0;var Q,J=function(t){Q=a(function(){K(t)},x)},tt=function(){Q&&a.cancel(Q)};Y(),z.assignIsOpen=function(e){I(t,e)},z.select=function(i,r){var o,s,u={};$=!0,u[L.itemName]=s=z.matches[i].model,o=L.modelMapper(t,u),H(t,o),g.$setValidity("editable",!0),g.$setValidity("parse",!0),M(t,{$item:s,$model:o,$label:L.viewMapper(t,u),$event:r}),Y(),z.$eval(n.typeaheadFocusOnSelect)!==!1&&a(function(){e[0].focus()},0,!1)},e.on("keydown",function(e){if(0!==z.matches.length&&-1!==v.indexOf(e.which)){var n=C(t,{$event:e});if(-1===z.activeIdx&&n||9===e.which&&e.shiftKey)return Y(),void z.$digest();e.preventDefault();var i;switch(e.which){case 27:e.stopPropagation(),Y(),t.$digest();break;case 38:z.activeIdx=(z.activeIdx>0?z.activeIdx:z.matches.length)-1,z.$digest(),i=B.find("li")[z.activeIdx],i.parentNode.scrollTop=i.offsetTop;break;case 40:z.activeIdx=(z.activeIdx+1)%z.matches.length,z.$digest(),i=B.find("li")[z.activeIdx],i.parentNode.scrollTop=i.offsetTop;break;default:n&&z.$apply(function(){angular.isNumber(z.debounceUpdate)||angular.isObject(z.debounceUpdate)?c(function(){z.select(z.activeIdx,e)},angular.isNumber(z.debounceUpdate)?z.debounceUpdate:z.debounceUpdate["default"]):z.select(z.activeIdx,e)})}}}),e.bind("focus",function(t){_=!0,0!==b||g.$viewValue||a(function(){K(g.$viewValue,t)},0)}),e.bind("blur",function(t){D&&z.matches.length&&-1!==z.activeIdx&&!$&&($=!0,z.$apply(function(){angular.isObject(z.debounceUpdate)&&angular.isNumber(z.debounceUpdate.blur)?c(function(){z.select(z.activeIdx,t)},z.debounceUpdate.blur):z.select(z.activeIdx,t)})),!w&&g.$error.editable&&(g.$setViewValue(),g.$setValidity("editable",!0),g.$setValidity("parse",!0),e.val("")),_=!1,$=!1});var et=function(n){e[0]!==n.target&&3!==n.which&&0!==z.matches.length&&(Y(),l.$$phase||t.$digest())};s.on("click",et),t.$on("$destroy",function(){s.off("click",et),(A||E)&&nt.remove(),A&&(angular.element(u).off("resize",f),s.find("body").off("scroll",f)),B.remove(),P&&U.remove()});var nt=i(B)(z);A?s.find("body").append(nt):E?angular.element(E).eq(0).append(nt):e.after(nt),this.init=function(e,n){g=e,m=n,z.debounceUpdate=g.$options&&r(g.$options.debounce)(t),g.$parsers.unshift(function(e){return _=!0,0===b||e&&e.length>=b?x>0?(tt(),J(e)):K(e):(k(t,!1),tt(),Y()),w?e:e?void g.$setValidity("editable",!1):(g.$setValidity("editable",!0),null)}),g.$formatters.push(function(e){var n,i,r={};return w||g.$setValidity("editable",!0),T?(r.$model=e,T(t,r)):(r[L.itemName]=e,n=L.viewMapper(t,r),r[L.itemName]=void 0,i=L.viewMapper(t,r),n!==i?n:e)})}}]).directive("uibTypeahead",function(){return{controller:"UibTypeaheadController",require:["ngModel","^?ngModelOptions","uibTypeahead"],link:function(t,e,n,i){i[2].init(i[0],i[1])}}}).directive("uibTypeaheadPopup",["$$debounce",function(t){return{scope:{matches:"=",query:"=",active:"=",position:"&",moveInProgress:"=",select:"&",assignIsOpen:"&",debounce:"&"},replace:!0,templateUrl:function(t,e){return e.popupTemplateUrl||"uib/template/typeahead/typeahead-popup.html"},link:function(e,n,i){e.templateUrl=i.templateUrl,e.isOpen=function(){var t=e.matches.length>0;return e.assignIsOpen({isOpen:t}),t},e.isActive=function(t){return e.active===t},e.selectActive=function(t){e.active=t},e.selectMatch=function(n,i){var r=e.debounce();angular.isNumber(r)||angular.isObject(r)?t(function(){e.select({activeIdx:n,evt:i})},angular.isNumber(r)?r:r["default"]):e.select({activeIdx:n,evt:i})}}}}]).directive("uibTypeaheadMatch",["$templateRequest","$compile","$parse",function(t,e,n){return{scope:{index:"=",match:"=",query:"="},link:function(i,r,o){var a=n(o.templateUrl)(i.$parent)||"uib/template/typeahead/typeahead-match.html";t(a).then(function(t){var n=angular.element(t.trim());r.replaceWith(n),e(n)(i)})}}}]).filter("uibTypeaheadHighlight",["$sce","$injector","$log",function(t,e,n){function i(t){return t.replace(/([.?*+^$[\]\\(){}|-])/g,"\\$1")}function r(t){return/<.*>/g.test(t)}var o;return o=e.has("$sanitize"),function(e,a){return!o&&r(e)&&n.warn("Unsafe use of typeahead please use ngSanitize"),e=a?(""+e).replace(new RegExp(i(a),"gi"),"<strong>$&</strong>"):e,o||(e=t.trustAsHtml(e)),e}}]),angular.module("uib/template/accordion/accordion-group.html",[]).run(["$templateCache",function(t){t.put("uib/template/accordion/accordion-group.html",'<div class="panel" ng-class="panelClass || \'panel-default\'">\n  <div role="tab" id="{{::headingId}}" aria-selected="{{isOpen}}" class="panel-heading" ng-keypress="toggleOpen($event)">\n    <h4 class="panel-title">\n      <a role="button" data-toggle="collapse" href aria-expanded="{{isOpen}}" aria-controls="{{::panelId}}" tabindex="0" class="accordion-toggle" ng-click="toggleOpen()" uib-accordion-transclude="heading"><span uib-accordion-header ng-class="{\'text-muted\': isDisabled}">{{heading}}</span></a>\n    </h4>\n  </div>\n  <div id="{{::panelId}}" aria-labelledby="{{::headingId}}" aria-hidden="{{!isOpen}}" role="tabpanel" class="panel-collapse collapse" uib-collapse="!isOpen">\n    <div class="panel-body" ng-transclude></div>\n  </div>\n</div>\n')}]),angular.module("uib/template/accordion/accordion.html",[]).run(["$templateCache",function(t){t.put("uib/template/accordion/accordion.html",'<div role="tablist" class="panel-group" ng-transclude></div>')}]),angular.module("uib/template/alert/alert.html",[]).run(["$templateCache",function(t){t.put("uib/template/alert/alert.html",'<div class="alert" ng-class="[\'alert-\' + (type || \'warning\'), closeable ? \'alert-dismissible\' : null]" role="alert">\n    <button ng-show="closeable" type="button" class="close" ng-click="close({$event: $event})">\n        <span aria-hidden="true">&times;</span>\n        <span class="sr-only">Close</span>\n    </button>\n    <div ng-transclude></div>\n</div>\n')}]),angular.module("uib/template/carousel/carousel.html",[]).run(["$templateCache",function(t){t.put("uib/template/carousel/carousel.html",'<div ng-mouseenter="pause()" ng-mouseleave="play()" class="carousel" ng-swipe-right="prev()" ng-swipe-left="next()">\n  <div class="carousel-inner" ng-transclude></div>\n  <a role="button" href class="left carousel-control" ng-click="prev()" ng-class="{ disabled: isPrevDisabled() }" ng-show="slides.length > 1">\n    <span aria-hidden="true" class="glyphicon glyphicon-chevron-left"></span>\n    <span class="sr-only">previous</span>\n  </a>\n  <a role="button" href class="right carousel-control" ng-click="next()" ng-class="{ disabled: isNextDisabled() }" ng-show="slides.length > 1">\n    <span aria-hidden="true" class="glyphicon glyphicon-chevron-right"></span>\n    <span class="sr-only">next</span>\n  </a>\n  <ol class="carousel-indicators" ng-show="slides.length > 1">\n    <li ng-repeat="slide in slides | orderBy:indexOfSlide track by $index" ng-class="{ active: isActive(slide) }" ng-click="select(slide)">\n      <span class="sr-only">slide {{ $index + 1 }} of {{ slides.length }}<span ng-if="isActive(slide)">, currently active</span></span>\n    </li>\n  </ol>\n</div>\n');
}]),angular.module("uib/template/carousel/slide.html",[]).run(["$templateCache",function(t){t.put("uib/template/carousel/slide.html",'<div ng-class="{\n    \'active\': active\n  }" class="item text-center" ng-transclude></div>\n')}]),angular.module("uib/template/datepicker/datepicker.html",[]).run(["$templateCache",function(t){t.put("uib/template/datepicker/datepicker.html",'<div class="uib-datepicker" ng-switch="datepickerMode" role="application" ng-keydown="keydown($event)">\n  <uib-daypicker ng-switch-when="day" tabindex="0"></uib-daypicker>\n  <uib-monthpicker ng-switch-when="month" tabindex="0"></uib-monthpicker>\n  <uib-yearpicker ng-switch-when="year" tabindex="0"></uib-yearpicker>\n</div>\n')}]),angular.module("uib/template/datepicker/day.html",[]).run(["$templateCache",function(t){t.put("uib/template/datepicker/day.html",'<table class="uib-daypicker" role="grid" aria-labelledby="{{::uniqueId}}-title" aria-activedescendant="{{activeDateId}}">\n  <thead>\n    <tr>\n      <th><button type="button" class="btn btn-default btn-sm pull-left uib-left" ng-click="move(-1)" tabindex="-1"><i class="glyphicon glyphicon-chevron-left"></i></button></th>\n      <th colspan="{{::5 + showWeeks}}"><button id="{{::uniqueId}}-title" role="heading" aria-live="assertive" aria-atomic="true" type="button" class="btn btn-default btn-sm uib-title" ng-click="toggleMode()" ng-disabled="datepickerMode === maxMode" tabindex="-1"><strong>{{title}}</strong></button></th>\n      <th><button type="button" class="btn btn-default btn-sm pull-right uib-right" ng-click="move(1)" tabindex="-1"><i class="glyphicon glyphicon-chevron-right"></i></button></th>\n    </tr>\n    <tr>\n      <th ng-if="showWeeks" class="text-center"></th>\n      <th ng-repeat="label in ::labels track by $index" class="text-center"><small aria-label="{{::label.full}}">{{::label.abbr}}</small></th>\n    </tr>\n  </thead>\n  <tbody>\n    <tr class="uib-weeks" ng-repeat="row in rows track by $index">\n      <td ng-if="showWeeks" class="text-center h6"><em>{{ weekNumbers[$index] }}</em></td>\n      <td ng-repeat="dt in row" class="uib-day text-center" role="gridcell"\n        id="{{::dt.uid}}"\n        ng-class="::dt.customClass">\n        <button type="button" class="btn btn-default btn-sm"\n          uib-is-class="\n            \'btn-info\' for selectedDt,\n            \'active\' for activeDt\n            on dt"\n          ng-click="select(dt.date)"\n          ng-disabled="::dt.disabled"\n          tabindex="-1"><span ng-class="::{\'text-muted\': dt.secondary, \'text-info\': dt.current}">{{::dt.label}}</span></button>\n      </td>\n    </tr>\n  </tbody>\n</table>\n')}]),angular.module("uib/template/datepicker/month.html",[]).run(["$templateCache",function(t){t.put("uib/template/datepicker/month.html",'<table class="uib-monthpicker" role="grid" aria-labelledby="{{::uniqueId}}-title" aria-activedescendant="{{activeDateId}}">\n  <thead>\n    <tr>\n      <th><button type="button" class="btn btn-default btn-sm pull-left uib-left" ng-click="move(-1)" tabindex="-1"><i class="glyphicon glyphicon-chevron-left"></i></button></th>\n      <th><button id="{{::uniqueId}}-title" role="heading" aria-live="assertive" aria-atomic="true" type="button" class="btn btn-default btn-sm uib-title" ng-click="toggleMode()" ng-disabled="datepickerMode === maxMode" tabindex="-1"><strong>{{title}}</strong></button></th>\n      <th><button type="button" class="btn btn-default btn-sm pull-right uib-right" ng-click="move(1)" tabindex="-1"><i class="glyphicon glyphicon-chevron-right"></i></button></th>\n    </tr>\n  </thead>\n  <tbody>\n    <tr class="uib-months" ng-repeat="row in rows track by $index">\n      <td ng-repeat="dt in row" class="uib-month text-center" role="gridcell"\n        id="{{::dt.uid}}"\n        ng-class="::dt.customClass">\n        <button type="button" class="btn btn-default"\n          uib-is-class="\n            \'btn-info\' for selectedDt,\n            \'active\' for activeDt\n            on dt"\n          ng-click="select(dt.date)"\n          ng-disabled="::dt.disabled"\n          tabindex="-1"><span ng-class="::{\'text-info\': dt.current}">{{::dt.label}}</span></button>\n      </td>\n    </tr>\n  </tbody>\n</table>\n')}]),angular.module("uib/template/datepicker/year.html",[]).run(["$templateCache",function(t){t.put("uib/template/datepicker/year.html",'<table class="uib-yearpicker" role="grid" aria-labelledby="{{::uniqueId}}-title" aria-activedescendant="{{activeDateId}}">\n  <thead>\n    <tr>\n      <th><button type="button" class="btn btn-default btn-sm pull-left uib-left" ng-click="move(-1)" tabindex="-1"><i class="glyphicon glyphicon-chevron-left"></i></button></th>\n      <th colspan="{{::columns - 2}}"><button id="{{::uniqueId}}-title" role="heading" aria-live="assertive" aria-atomic="true" type="button" class="btn btn-default btn-sm uib-title" ng-click="toggleMode()" ng-disabled="datepickerMode === maxMode" tabindex="-1"><strong>{{title}}</strong></button></th>\n      <th><button type="button" class="btn btn-default btn-sm pull-right uib-right" ng-click="move(1)" tabindex="-1"><i class="glyphicon glyphicon-chevron-right"></i></button></th>\n    </tr>\n  </thead>\n  <tbody>\n    <tr class="uib-years" ng-repeat="row in rows track by $index">\n      <td ng-repeat="dt in row" class="uib-year text-center" role="gridcell"\n        id="{{::dt.uid}}"\n        ng-class="::dt.customClass">\n        <button type="button" class="btn btn-default"\n          uib-is-class="\n            \'btn-info\' for selectedDt,\n            \'active\' for activeDt\n            on dt"\n          ng-click="select(dt.date)"\n          ng-disabled="::dt.disabled"\n          tabindex="-1"><span ng-class="::{\'text-info\': dt.current}">{{::dt.label}}</span></button>\n      </td>\n    </tr>\n  </tbody>\n</table>\n')}]),angular.module("uib/template/datepickerPopup/popup.html",[]).run(["$templateCache",function(t){t.put("uib/template/datepickerPopup/popup.html",'<div>\n  <ul class="uib-datepicker-popup dropdown-menu uib-position-measure" dropdown-nested ng-if="isOpen" ng-keydown="keydown($event)" ng-click="$event.stopPropagation()">\n    <li ng-transclude></li>\n    <li ng-if="showButtonBar" class="uib-button-bar">\n      <span class="btn-group pull-left">\n        <button type="button" class="btn btn-sm btn-info uib-datepicker-current" ng-click="select(\'today\', $event)" ng-disabled="isDisabled(\'today\')">{{ getText(\'current\') }}</button>\n        <button type="button" class="btn btn-sm btn-danger uib-clear" ng-click="select(null, $event)">{{ getText(\'clear\') }}</button>\n      </span>\n      <button type="button" class="btn btn-sm btn-success pull-right uib-close" ng-click="close($event)">{{ getText(\'close\') }}</button>\n    </li>\n  </ul>\n</div>\n')}]),angular.module("uib/template/modal/backdrop.html",[]).run(["$templateCache",function(t){t.put("uib/template/modal/backdrop.html",'<div class="modal-backdrop"\n     uib-modal-animation-class="fade"\n     modal-in-class="in"\n     ng-style="{\'z-index\': 1040 + (index && 1 || 0) + index*10}"\n></div>\n')}]),angular.module("uib/template/modal/window.html",[]).run(["$templateCache",function(t){t.put("uib/template/modal/window.html",'<div modal-render="{{$isRendered}}" tabindex="-1" role="dialog" class="modal"\n    uib-modal-animation-class="fade"\n    modal-in-class="in"\n    ng-style="{\'z-index\': 1050 + index*10, display: \'block\'}">\n    <div class="modal-dialog {{size ? \'modal-\' + size : \'\'}}"><div class="modal-content" uib-modal-transclude></div></div>\n</div>\n')}]),angular.module("uib/template/pager/pager.html",[]).run(["$templateCache",function(t){t.put("uib/template/pager/pager.html",'<ul class="pager">\n  <li ng-class="{disabled: noPrevious()||ngDisabled, previous: align}"><a href ng-click="selectPage(page - 1, $event)">{{::getText(\'previous\')}}</a></li>\n  <li ng-class="{disabled: noNext()||ngDisabled, next: align}"><a href ng-click="selectPage(page + 1, $event)">{{::getText(\'next\')}}</a></li>\n</ul>\n')}]),angular.module("uib/template/pagination/pagination.html",[]).run(["$templateCache",function(t){t.put("uib/template/pagination/pagination.html",'<ul class="pagination">\n  <li ng-if="::boundaryLinks" ng-class="{disabled: noPrevious()||ngDisabled}" class="pagination-first"><a href ng-click="selectPage(1, $event)">{{::getText(\'first\')}}</a></li>\n  <li ng-if="::directionLinks" ng-class="{disabled: noPrevious()||ngDisabled}" class="pagination-prev"><a href ng-click="selectPage(page - 1, $event)">{{::getText(\'previous\')}}</a></li>\n  <li ng-repeat="page in pages track by $index" ng-class="{active: page.active,disabled: ngDisabled&&!page.active}" class="pagination-page"><a href ng-click="selectPage(page.number, $event)">{{page.text}}</a></li>\n  <li ng-if="::directionLinks" ng-class="{disabled: noNext()||ngDisabled}" class="pagination-next"><a href ng-click="selectPage(page + 1, $event)">{{::getText(\'next\')}}</a></li>\n  <li ng-if="::boundaryLinks" ng-class="{disabled: noNext()||ngDisabled}" class="pagination-last"><a href ng-click="selectPage(totalPages, $event)">{{::getText(\'last\')}}</a></li>\n</ul>\n')}]),angular.module("uib/template/tooltip/tooltip-html-popup.html",[]).run(["$templateCache",function(t){t.put("uib/template/tooltip/tooltip-html-popup.html",'<div class="tooltip"\n  tooltip-animation-class="fade"\n  uib-tooltip-classes\n  ng-class="{ in: isOpen() }">\n  <div class="tooltip-arrow"></div>\n  <div class="tooltip-inner" ng-bind-html="contentExp()"></div>\n</div>\n')}]),angular.module("uib/template/tooltip/tooltip-popup.html",[]).run(["$templateCache",function(t){t.put("uib/template/tooltip/tooltip-popup.html",'<div class="tooltip"\n  tooltip-animation-class="fade"\n  uib-tooltip-classes\n  ng-class="{ in: isOpen() }">\n  <div class="tooltip-arrow"></div>\n  <div class="tooltip-inner" ng-bind="content"></div>\n</div>\n')}]),angular.module("uib/template/tooltip/tooltip-template-popup.html",[]).run(["$templateCache",function(t){t.put("uib/template/tooltip/tooltip-template-popup.html",'<div class="tooltip"\n  tooltip-animation-class="fade"\n  uib-tooltip-classes\n  ng-class="{ in: isOpen() }">\n  <div class="tooltip-arrow"></div>\n  <div class="tooltip-inner"\n    uib-tooltip-template-transclude="contentExp()"\n    tooltip-template-transclude-scope="originScope()"></div>\n</div>\n')}]),angular.module("uib/template/popover/popover-html.html",[]).run(["$templateCache",function(t){t.put("uib/template/popover/popover-html.html",'<div class="popover"\n  tooltip-animation-class="fade"\n  uib-tooltip-classes\n  ng-class="{ in: isOpen() }">\n  <div class="arrow"></div>\n\n  <div class="popover-inner">\n      <h3 class="popover-title" ng-bind="uibTitle" ng-if="uibTitle"></h3>\n      <div class="popover-content" ng-bind-html="contentExp()"></div>\n  </div>\n</div>\n')}]),angular.module("uib/template/popover/popover-template.html",[]).run(["$templateCache",function(t){t.put("uib/template/popover/popover-template.html",'<div class="popover"\n  tooltip-animation-class="fade"\n  uib-tooltip-classes\n  ng-class="{ in: isOpen() }">\n  <div class="arrow"></div>\n\n  <div class="popover-inner">\n      <h3 class="popover-title" ng-bind="uibTitle" ng-if="uibTitle"></h3>\n      <div class="popover-content"\n        uib-tooltip-template-transclude="contentExp()"\n        tooltip-template-transclude-scope="originScope()"></div>\n  </div>\n</div>\n')}]),angular.module("uib/template/popover/popover.html",[]).run(["$templateCache",function(t){t.put("uib/template/popover/popover.html",'<div class="popover"\n  tooltip-animation-class="fade"\n  uib-tooltip-classes\n  ng-class="{ in: isOpen() }">\n  <div class="arrow"></div>\n\n  <div class="popover-inner">\n      <h3 class="popover-title" ng-bind="uibTitle" ng-if="uibTitle"></h3>\n      <div class="popover-content" ng-bind="content"></div>\n  </div>\n</div>\n')}]),angular.module("uib/template/progressbar/bar.html",[]).run(["$templateCache",function(t){t.put("uib/template/progressbar/bar.html",'<div class="progress-bar" ng-class="type && \'progress-bar-\' + type" role="progressbar" aria-valuenow="{{value}}" aria-valuemin="0" aria-valuemax="{{max}}" ng-style="{width: (percent < 100 ? percent : 100) + \'%\'}" aria-valuetext="{{percent | number:0}}%" aria-labelledby="{{::title}}" ng-transclude></div>\n')}]),angular.module("uib/template/progressbar/progress.html",[]).run(["$templateCache",function(t){t.put("uib/template/progressbar/progress.html",'<div class="progress" ng-transclude aria-labelledby="{{::title}}"></div>')}]),angular.module("uib/template/progressbar/progressbar.html",[]).run(["$templateCache",function(t){t.put("uib/template/progressbar/progressbar.html",'<div class="progress">\n  <div class="progress-bar" ng-class="type && \'progress-bar-\' + type" role="progressbar" aria-valuenow="{{value}}" aria-valuemin="0" aria-valuemax="{{max}}" ng-style="{width: (percent < 100 ? percent : 100) + \'%\'}" aria-valuetext="{{percent | number:0}}%" aria-labelledby="{{::title}}" ng-transclude></div>\n</div>\n')}]),angular.module("uib/template/rating/rating.html",[]).run(["$templateCache",function(t){t.put("uib/template/rating/rating.html",'<span ng-mouseleave="reset()" ng-keydown="onKeydown($event)" tabindex="0" role="slider" aria-valuemin="0" aria-valuemax="{{range.length}}" aria-valuenow="{{value}}" aria-valuetext="{{title}}">\n    <span ng-repeat-start="r in range track by $index" class="sr-only">({{ $index < value ? \'*\' : \' \' }})</span>\n    <i ng-repeat-end ng-mouseenter="enter($index + 1)" ng-click="rate($index + 1)" class="glyphicon" ng-class="$index < value && (r.stateOn || \'glyphicon-star\') || (r.stateOff || \'glyphicon-star-empty\')" ng-attr-title="{{r.title}}"></i>\n</span>\n')}]),angular.module("uib/template/tabs/tab.html",[]).run(["$templateCache",function(t){t.put("uib/template/tabs/tab.html",'<li ng-class="[{active: active, disabled: disabled}, classes]" class="uib-tab nav-item">\n  <a href ng-click="select($event)" class="nav-link" uib-tab-heading-transclude>{{heading}}</a>\n</li>\n')}]),angular.module("uib/template/tabs/tabset.html",[]).run(["$templateCache",function(t){t.put("uib/template/tabs/tabset.html",'<div>\n  <ul class="nav nav-{{tabset.type || \'tabs\'}}" ng-class="{\'nav-stacked\': vertical, \'nav-justified\': justified}" ng-transclude></ul>\n  <div class="tab-content">\n    <div class="tab-pane"\n         ng-repeat="tab in tabset.tabs"\n         ng-class="{active: tabset.active === tab.index}"\n         uib-tab-content-transclude="tab">\n    </div>\n  </div>\n</div>\n')}]),angular.module("uib/template/timepicker/timepicker.html",[]).run(["$templateCache",function(t){t.put("uib/template/timepicker/timepicker.html",'<table class="uib-timepicker">\n  <tbody>\n    <tr class="text-center" ng-show="::showSpinners">\n      <td class="uib-increment hours"><a ng-click="incrementHours()" ng-class="{disabled: noIncrementHours()}" class="btn btn-link" ng-disabled="noIncrementHours()" tabindex="{{::tabindex}}"><span class="glyphicon glyphicon-chevron-up"></span></a></td>\n      <td>&nbsp;</td>\n      <td class="uib-increment minutes"><a ng-click="incrementMinutes()" ng-class="{disabled: noIncrementMinutes()}" class="btn btn-link" ng-disabled="noIncrementMinutes()" tabindex="{{::tabindex}}"><span class="glyphicon glyphicon-chevron-up"></span></a></td>\n      <td ng-show="showSeconds">&nbsp;</td>\n      <td ng-show="showSeconds" class="uib-increment seconds"><a ng-click="incrementSeconds()" ng-class="{disabled: noIncrementSeconds()}" class="btn btn-link" ng-disabled="noIncrementSeconds()" tabindex="{{::tabindex}}"><span class="glyphicon glyphicon-chevron-up"></span></a></td>\n      <td ng-show="showMeridian"></td>\n    </tr>\n    <tr>\n      <td class="form-group uib-time hours" ng-class="{\'has-error\': invalidHours}">\n        <input type="text" placeholder="HH" ng-model="hours" ng-change="updateHours()" class="form-control text-center" ng-readonly="::readonlyInput" maxlength="2" tabindex="{{::tabindex}}" ng-disabled="noIncrementHours()" ng-blur="blur()">\n      </td>\n      <td class="uib-separator">:</td>\n      <td class="form-group uib-time minutes" ng-class="{\'has-error\': invalidMinutes}">\n        <input type="text" placeholder="MM" ng-model="minutes" ng-change="updateMinutes()" class="form-control text-center" ng-readonly="::readonlyInput" maxlength="2" tabindex="{{::tabindex}}" ng-disabled="noIncrementMinutes()" ng-blur="blur()">\n      </td>\n      <td ng-show="showSeconds" class="uib-separator">:</td>\n      <td class="form-group uib-time seconds" ng-class="{\'has-error\': invalidSeconds}" ng-show="showSeconds">\n        <input type="text" placeholder="SS" ng-model="seconds" ng-change="updateSeconds()" class="form-control text-center" ng-readonly="readonlyInput" maxlength="2" tabindex="{{::tabindex}}" ng-disabled="noIncrementSeconds()" ng-blur="blur()">\n      </td>\n      <td ng-show="showMeridian" class="uib-time am-pm"><button type="button" ng-class="{disabled: noToggleMeridian()}" class="btn btn-default text-center" ng-click="toggleMeridian()" ng-disabled="noToggleMeridian()" tabindex="{{::tabindex}}">{{meridian}}</button></td>\n    </tr>\n    <tr class="text-center" ng-show="::showSpinners">\n      <td class="uib-decrement hours"><a ng-click="decrementHours()" ng-class="{disabled: noDecrementHours()}" class="btn btn-link" ng-disabled="noDecrementHours()" tabindex="{{::tabindex}}"><span class="glyphicon glyphicon-chevron-down"></span></a></td>\n      <td>&nbsp;</td>\n      <td class="uib-decrement minutes"><a ng-click="decrementMinutes()" ng-class="{disabled: noDecrementMinutes()}" class="btn btn-link" ng-disabled="noDecrementMinutes()" tabindex="{{::tabindex}}"><span class="glyphicon glyphicon-chevron-down"></span></a></td>\n      <td ng-show="showSeconds">&nbsp;</td>\n      <td ng-show="showSeconds" class="uib-decrement seconds"><a ng-click="decrementSeconds()" ng-class="{disabled: noDecrementSeconds()}" class="btn btn-link" ng-disabled="noDecrementSeconds()" tabindex="{{::tabindex}}"><span class="glyphicon glyphicon-chevron-down"></span></a></td>\n      <td ng-show="showMeridian"></td>\n    </tr>\n  </tbody>\n</table>\n')}]),angular.module("uib/template/typeahead/typeahead-match.html",[]).run(["$templateCache",function(t){t.put("uib/template/typeahead/typeahead-match.html",'<a href\n   tabindex="-1"\n   ng-bind-html="match.label | uibTypeaheadHighlight:query"\n   ng-attr-title="{{match.label}}"></a>\n')}]),angular.module("uib/template/typeahead/typeahead-popup.html",[]).run(["$templateCache",function(t){t.put("uib/template/typeahead/typeahead-popup.html",'<ul class="dropdown-menu" ng-show="isOpen() && !moveInProgress" ng-style="{top: position().top+\'px\', left: position().left+\'px\'}" role="listbox" aria-hidden="{{!isOpen()}}">\n    <li ng-repeat="match in matches track by $index" ng-class="{active: isActive($index) }" ng-mouseenter="selectActive($index)" ng-click="selectMatch($index, $event)" role="option" id="{{::match.id}}">\n        <div uib-typeahead-match index="$index" match="match" query="query" template-url="templateUrl"></div>\n    </li>\n</ul>\n')}]),angular.module("ui.bootstrap.carousel").run(function(){!angular.$$csp().noInlineStyle&&!angular.$$uibCarouselCss&&angular.element(document).find("head").prepend('<style type="text/css">.ng-animate.item:not(.left):not(.right){-webkit-transition:0s ease-in-out left;transition:0s ease-in-out left}</style>'),angular.$$uibCarouselCss=!0}),angular.module("ui.bootstrap.datepicker").run(function(){!angular.$$csp().noInlineStyle&&!angular.$$uibDatepickerCss&&angular.element(document).find("head").prepend('<style type="text/css">.uib-datepicker .uib-title{width:100%;}.uib-day button,.uib-month button,.uib-year button{min-width:100%;}.uib-left,.uib-right{width:100%}</style>'),angular.$$uibDatepickerCss=!0}),angular.module("ui.bootstrap.position").run(function(){!angular.$$csp().noInlineStyle&&!angular.$$uibPositionCss&&angular.element(document).find("head").prepend('<style type="text/css">.uib-position-measure{display:block !important;visibility:hidden !important;position:absolute !important;top:-9999px !important;left:-9999px !important;}.uib-position-scrollbar-measure{position:absolute !important;top:-9999px !important;width:50px !important;height:50px !important;overflow:scroll !important;}.uib-position-body-scrollbar-measure{overflow:scroll !important;}</style>'),angular.$$uibPositionCss=!0}),angular.module("ui.bootstrap.datepickerPopup").run(function(){!angular.$$csp().noInlineStyle&&!angular.$$uibDatepickerpopupCss&&angular.element(document).find("head").prepend('<style type="text/css">.uib-datepicker-popup.dropdown-menu{display:block;float:none;margin:0;}.uib-button-bar{padding:10px 9px 2px;}</style>'),angular.$$uibDatepickerpopupCss=!0}),angular.module("ui.bootstrap.tooltip").run(function(){!angular.$$csp().noInlineStyle&&!angular.$$uibTooltipCss&&angular.element(document).find("head").prepend('<style type="text/css">[uib-tooltip-popup].tooltip.top-left > .tooltip-arrow,[uib-tooltip-popup].tooltip.top-right > .tooltip-arrow,[uib-tooltip-popup].tooltip.bottom-left > .tooltip-arrow,[uib-tooltip-popup].tooltip.bottom-right > .tooltip-arrow,[uib-tooltip-popup].tooltip.left-top > .tooltip-arrow,[uib-tooltip-popup].tooltip.left-bottom > .tooltip-arrow,[uib-tooltip-popup].tooltip.right-top > .tooltip-arrow,[uib-tooltip-popup].tooltip.right-bottom > .tooltip-arrow,[uib-tooltip-html-popup].tooltip.top-left > .tooltip-arrow,[uib-tooltip-html-popup].tooltip.top-right > .tooltip-arrow,[uib-tooltip-html-popup].tooltip.bottom-left > .tooltip-arrow,[uib-tooltip-html-popup].tooltip.bottom-right > .tooltip-arrow,[uib-tooltip-html-popup].tooltip.left-top > .tooltip-arrow,[uib-tooltip-html-popup].tooltip.left-bottom > .tooltip-arrow,[uib-tooltip-html-popup].tooltip.right-top > .tooltip-arrow,[uib-tooltip-html-popup].tooltip.right-bottom > .tooltip-arrow,[uib-tooltip-template-popup].tooltip.top-left > .tooltip-arrow,[uib-tooltip-template-popup].tooltip.top-right > .tooltip-arrow,[uib-tooltip-template-popup].tooltip.bottom-left > .tooltip-arrow,[uib-tooltip-template-popup].tooltip.bottom-right > .tooltip-arrow,[uib-tooltip-template-popup].tooltip.left-top > .tooltip-arrow,[uib-tooltip-template-popup].tooltip.left-bottom > .tooltip-arrow,[uib-tooltip-template-popup].tooltip.right-top > .tooltip-arrow,[uib-tooltip-template-popup].tooltip.right-bottom > .tooltip-arrow,[uib-popover-popup].popover.top-left > .arrow,[uib-popover-popup].popover.top-right > .arrow,[uib-popover-popup].popover.bottom-left > .arrow,[uib-popover-popup].popover.bottom-right > .arrow,[uib-popover-popup].popover.left-top > .arrow,[uib-popover-popup].popover.left-bottom > .arrow,[uib-popover-popup].popover.right-top > .arrow,[uib-popover-popup].popover.right-bottom > .arrow,[uib-popover-html-popup].popover.top-left > .arrow,[uib-popover-html-popup].popover.top-right > .arrow,[uib-popover-html-popup].popover.bottom-left > .arrow,[uib-popover-html-popup].popover.bottom-right > .arrow,[uib-popover-html-popup].popover.left-top > .arrow,[uib-popover-html-popup].popover.left-bottom > .arrow,[uib-popover-html-popup].popover.right-top > .arrow,[uib-popover-html-popup].popover.right-bottom > .arrow,[uib-popover-template-popup].popover.top-left > .arrow,[uib-popover-template-popup].popover.top-right > .arrow,[uib-popover-template-popup].popover.bottom-left > .arrow,[uib-popover-template-popup].popover.bottom-right > .arrow,[uib-popover-template-popup].popover.left-top > .arrow,[uib-popover-template-popup].popover.left-bottom > .arrow,[uib-popover-template-popup].popover.right-top > .arrow,[uib-popover-template-popup].popover.right-bottom > .arrow{top:auto;bottom:auto;left:auto;right:auto;margin:0;}[uib-popover-popup].popover,[uib-popover-html-popup].popover,[uib-popover-template-popup].popover{display:block !important;}</style>'),angular.$$uibTooltipCss=!0}),angular.module("ui.bootstrap.timepicker").run(function(){!angular.$$csp().noInlineStyle&&!angular.$$uibTimepickerCss&&angular.element(document).find("head").prepend('<style type="text/css">.uib-time input{width:50px;}</style>'),angular.$$uibTimepickerCss=!0}),angular.module("ui.bootstrap.typeahead").run(function(){!angular.$$csp().noInlineStyle&&!angular.$$uibTypeaheadCss&&angular.element(document).find("head").prepend('<style type="text/css">[uib-typeahead-popup].dropdown-menu{display:block;}</style>'),angular.$$uibTypeaheadCss=!0}),function(){function t(t,e){return t.set(e[0],e[1]),t}function e(t,e){return t.add(e),t}function n(t,e,n){var i=n.length;switch(i){case 0:return t.call(e);case 1:return t.call(e,n[0]);case 2:return t.call(e,n[0],n[1]);case 3:return t.call(e,n[0],n[1],n[2])}return t.apply(e,n)}function i(t,e,n,i){for(var r=-1,o=t.length;++r<o;){var a=t[r];e(i,a,n(a),t)}return i}function r(t,e){for(var n=-1,i=t.length,r=-1,o=e.length,a=Array(i+o);++n<i;)a[n]=t[n];for(;++r<o;)a[n++]=e[r];return a}function o(t,e){for(var n=-1,i=t.length;++n<i&&e(t[n],n,t)!==!1;);return t}function a(t,e){for(var n=t.length;n--&&e(t[n],n,t)!==!1;);return t}function s(t,e){for(var n=-1,i=t.length;++n<i;)if(!e(t[n],n,t))return!1;return!0}function u(t,e){for(var n=-1,i=t.length,r=-1,o=[];++n<i;){var a=t[n];e(a,n,t)&&(o[++r]=a)}return o}function l(t,e){return!!t.length&&b(t,e,0)>-1}function c(t,e,n){for(var i=-1,r=t.length;++i<r;)if(n(e,t[i]))return!0;return!1}function d(t,e){for(var n=-1,i=t.length,r=Array(i);++n<i;)r[n]=e(t[n],n,t);return r}function h(t,e){for(var n=-1,i=e.length,r=t.length;++n<i;)t[r+n]=e[n];return t}function f(t,e,n,i){var r=-1,o=t.length;for(i&&o&&(n=t[++r]);++r<o;)n=e(n,t[r],r,t);return n}function p(t,e,n,i){var r=t.length;for(i&&r&&(n=t[--r]);r--;)n=e(n,t[r],r,t);return n}function g(t,e){for(var n=-1,i=t.length;++n<i;)if(e(t[n],n,t))return!0;return!1}function m(t,e,n){for(var i=-1,r=t.length;++i<r;){var o=t[i],a=e(o);if(null!=a&&(s===Y?a===a:n(a,s)))var s=a,u=o}return u}function v(t,e,n,i){var r;return n(t,function(t,n,o){return e(t,n,o)?(r=i?n:t,!1):void 0}),r}function y(t,e,n){for(var i=t.length,r=n?i:-1;n?r--:++r<i;)if(e(t[r],r,t))return r;return-1}function b(t,e,n){if(e!==e)return F(t,n);for(var i=n-1,r=t.length;++i<r;)if(t[i]===e)return i;return-1}function x(t,e,n,i,r){return r(t,function(t,r,o){n=i?(i=!1,t):e(n,t,r,o)}),n}function w(t,e){var n=t.length;for(t.sort(e);n--;)t[n]=t[n].value;return t}function _(t,e){for(var n,i=-1,r=t.length;++i<r;){var o=e(t[i]);o!==Y&&(n=n===Y?o:n+o)}return n}function $(t,e){for(var n=-1,i=Array(t);++n<t;)i[n]=e(n);return i}function k(t,e){return d(e,function(e){return[e,t[e]]})}function C(t){return function(e){return t(e)}}function M(t,e){return d(e,function(e){return t[e]})}function D(t,e){for(var n=-1,i=t.length;++n<i&&b(e,t[n],0)>-1;);return n}function S(t,e){for(var n=t.length;n--&&b(e,t[n],0)>-1;);return n}function T(t){return t&&t.Object===Object?t:null}function A(t,e){if(t!==e){var n=null===t,i=t===Y,r=t===t,o=null===e,a=e===Y,s=e===e;if(t>e&&!o||!r||n&&!a&&s||i&&s)return 1;if(e>t&&!n||!s||o&&!i&&r||a&&r)return-1}return 0}function E(t,e,n){for(var i=-1,r=t.criteria,o=e.criteria,a=r.length,s=n.length;++i<a;){var u=A(r[i],o[i]);if(u){if(i>=s)return u;var l=n[i];return u*("desc"==l?-1:1)}}return t.index-e.index}function O(t,e){for(var n=t.length,i=0;n--;)t[n]===e&&i++;return i}function N(t){return yn[t]}function I(t){return bn[t]}function P(t){return"\\"+_n[t]}function F(t,e,n){for(var i=t.length,r=e+(n?0:-1);n?r--:++r<i;){var o=t[r];if(o!==o)return r}return-1}function W(t){var e=!1;if(null!=t&&"function"!=typeof t.toString)try{e=!!(t+"")}catch(n){}return e}function H(t,e){return t="number"==typeof t||$e.test(t)?+t:-1,e=null==e?yt:e,t>-1&&t%1==0&&e>t}function L(t){for(var e,n=[];!(e=t.next()).done;)n.push(e.value);return n}function z(t){var e=-1,n=Array(t.size);return t.forEach(function(t,i){n[++e]=[i,t]}),n}function j(t,e){for(var n=-1,i=t.length,r=-1,o=[];++n<i;){var a=t[n];(a===e||a===kt)&&(t[n]=kt,o[++r]=n)}return o}function R(t){var e=-1,n=Array(t.size);return t.forEach(function(t){n[++e]=t}),n}function U(t){if(!t||!cn.test(t))return t.length;for(var e=ln.lastIndex=0;ln.test(t);)e++;return e}function q(t){return t.match(ln)}function B(t){return xn[t]}function V(T){function $e(t){if(La(t)&&!wc(t)&&!(t instanceof Te)){if(t instanceof Se)return t;if(qu.call(t,"__wrapped__"))return Nr(t)}return new Se(t)}function De(){}function Se(t,e){this.__wrapped__=t,this.__actions__=[],this.__chain__=!!e,this.__index__=0,this.__values__=Y}function Te(t){this.__wrapped__=t,this.__actions__=[],this.__dir__=1,this.__filtered__=!1,this.__iteratees__=[],this.__takeCount__=wt,this.__views__=[]}function Ae(){var t=new Te(this.__wrapped__);return t.__actions__=Hi(this.__actions__),t.__dir__=this.__dir__,t.__filtered__=this.__filtered__,t.__iteratees__=Hi(this.__iteratees__),t.__takeCount__=this.__takeCount__,t.__views__=Hi(this.__views__),t}function Ee(){if(this.__filtered__){var t=new Te(this);t.__dir__=-1,t.__filtered__=!0}else t=this.clone(),t.__dir__*=-1;return t}function Oe(){var t=this.__wrapped__.value(),e=this.__dir__,n=wc(t),i=0>e,r=n?t.length:0,o=mr(0,r,this.__views__),a=o.start,s=o.end,u=s-a,l=i?s:a-1,c=this.__iteratees__,d=c.length,h=0,f=gl(u,this.__takeCount__);if(!n||dt>r||r==u&&f==u)return Mi(t,this.__actions__);var p=[];t:for(;u--&&f>h;){l+=e;for(var g=-1,m=t[l];++g<d;){var v=c[g],y=v.iteratee,b=v.type,x=y(m);if(b==ft)m=x;else if(!x){if(b==ht)continue t;break t}}p[h++]=m}return p}function Ne(){}function Ie(t,e){return Fe(t,e)&&delete t[e]}function Pe(t,e){if(_l){var n=t[e];return n===mt?Y:n}return qu.call(t,e)?t[e]:Y}function Fe(t,e){return _l?t[e]!==Y:qu.call(t,e)}function We(t,e,n){t[e]=_l&&n===Y?mt:n}function He(t){var e=-1,n=t?t.length:0;for(this.clear();++e<n;){var i=t[e];this.set(i[0],i[1])}}function Le(){this.__data__={hash:new Ne,map:bl?new bl:[],string:new Ne}}function ze(t){var e=this.__data__;return kr(t)?Ie("string"==typeof t?e.string:e.hash,t):bl?e.map["delete"](t):Je(e.map,t)}function je(t){var e=this.__data__;return kr(t)?Pe("string"==typeof t?e.string:e.hash,t):bl?e.map.get(t):tn(e.map,t)}function Re(t){var e=this.__data__;return kr(t)?Fe("string"==typeof t?e.string:e.hash,t):bl?e.map.has(t):en(e.map,t)}function Ue(t,e){var n=this.__data__;return kr(t)?We("string"==typeof t?n.string:n.hash,t,e):bl?n.map.set(t,e):rn(n.map,t,e),this}function qe(t){var e=-1,n=t?t.length:0;for(this.__data__=new He;++e<n;)this.push(t[e])}function Be(t,e){var n=t.__data__;if(kr(e)){var i=n.__data__,r="string"==typeof e?i.string:i.hash;return r[e]===mt}return n.has(e)}function Ve(t){var e=this.__data__;if(kr(t)){var n=e.__data__,i="string"==typeof t?n.string:n.hash;i[t]=mt}else e.set(t,mt)}function Ye(t){var e=-1,n=t?t.length:0;for(this.clear();++e<n;){var i=t[e];this.set(i[0],i[1])}}function Ge(){this.__data__={array:[],map:null}}function Xe(t){var e=this.__data__,n=e.array;return n?Je(n,t):e.map["delete"](t)}function Ke(t){var e=this.__data__,n=e.array;return n?tn(n,t):e.map.get(t)}function Ze(t){var e=this.__data__,n=e.array;return n?en(n,t):e.map.has(t)}function Qe(t,e){var n=this.__data__,i=n.array;i&&(i.length<dt-1?rn(i,t,e):(n.array=null,n.map=new He(i)));var r=n.map;return r&&r.set(t,e),this}function Je(t,e){var n=nn(t,e);if(0>n)return!1;var i=t.length-1;return n==i?t.pop():ul.call(t,n,1),!0}function tn(t,e){var n=nn(t,e);return 0>n?Y:t[n][1]}function en(t,e){return nn(t,e)>-1}function nn(t,e){for(var n=t.length;n--;)if(xa(t[n][0],e))return n;return-1}function rn(t,e,n){var i=nn(t,e);0>i?t.push([e,n]):t[i][1]=n}function on(t,e,n,i){return t===Y||xa(t,Ru[n])&&!qu.call(i,n)?e:t}function an(t,e,n){(n!==Y&&!xa(t[e],n)||"number"==typeof e&&n===Y&&!(e in t))&&(t[e]=n)}function sn(t,e,n){var i=t[e];qu.call(t,e)&&xa(i,n)&&(n!==Y||e in t)||(t[e]=n)}function ln(t,e,n,i){return El(t,function(t,r,o){e(i,t,n(t),o)}),i}function yn(t,e){return t&&Li(e,Cs(e),t)}function bn(t,e){for(var n=-1,i=null==t,r=e.length,o=Array(r);++n<r;)o[n]=i?Y:_s(t,e[n]);return o;
}function xn(t){return Ma(t)?t:[]}function wn(t){return"function"==typeof t?t:pu}function _n(t){return wc(t)?t:Or(t)}function Cn(t,e,n){return t===t&&(n!==Y&&(t=n>=t?t:n),e!==Y&&(t=t>=e?t:e)),t}function Mn(t,e,n,i,r,a){var s;if(n&&(s=r?n(t,i,r,a):n(t)),s!==Y)return s;if(!Ha(t))return t;var u=wc(t);if(u){if(s=yr(t),!e)return Hi(t,s)}else{var l=gr(t),c=l==At||l==Et;if(_c(t))return Ti(t,e);if(l==It||l==Ct||c&&!r){if(W(t))return r?t:{};if(s=br(c?{}:t),!e)return ji(t,yn(s,t))}else{if(!vn[l])return r?t:{};s=xr(t,l,e)}}a||(a=new Ye);var d=a.get(t);return d?d:(a.set(t,s),(u?o:Ln)(t,function(i,r){sn(s,r,Mn(i,e,n,r,t,a))}),u?s:ji(t,s))}function Sn(t){var e=Cs(t),n=e.length;return function(i){if(null==i)return!n;for(var r=n;r--;){var o=e[r],a=t[o],s=i[o];if(s===Y&&!(o in Object(i))||!a(s))return!1}return!0}}function Tn(t){return Ha(t)?ol(t):{}}function An(t,e,n){if("function"!=typeof t)throw new zu(gt);return sl(function(){t.apply(Y,n)},e)}function En(t,e,n,i){var r=-1,o=l,a=!0,s=t.length,u=[],h=e.length;if(!s)return u;n&&(e=d(e,C(n))),i?(o=c,a=!1):e.length>=dt&&(o=Be,a=!1,e=new qe(e));t:for(;++r<s;){var f=t[r],p=n?n(f):f;if(a&&p===p){for(var g=h;g--;)if(e[g]===p)continue t;u.push(f)}else o(e,p,i)||u.push(f)}return u}function In(t,e){var n=!0;return El(t,function(t,i,r){return n=!!e(t,i,r)}),n}function Pn(t,e,n,i){var r=t.length;for(n=ss(n),0>n&&(n=-n>r?0:r+n),i=i===Y||i>r?r:ss(i),0>i&&(i+=r),i=n>i?0:us(i);i>n;)t[n++]=e;return t}function Fn(t,e){var n=[];return El(t,function(t,i,r){e(t,i,r)&&n.push(t)}),n}function Wn(t,e,n,i){i||(i=[]);for(var r=-1,o=t.length;++r<o;){var a=t[r];e>0&&Ma(a)&&(n||wc(a)||$a(a))?e>1?Wn(a,e-1,n,i):h(i,a):n||(i[i.length]=a)}return i}function Hn(t,e){return null==t?t:Nl(t,e,Ms)}function Ln(t,e){return t&&Nl(t,e,Cs)}function zn(t,e){return t&&Il(t,e,Cs)}function jn(t,e){return u(e,function(e){return Pa(t[e])})}function Rn(t,e){e=$r(e,t)?[e+""]:_n(e);for(var n=0,i=e.length;null!=t&&i>n;)t=t[e[n++]];return n&&n==i?t:Y}function Un(t,e){return qu.call(t,e)||"object"==typeof t&&e in t&&null===nl(t)}function qn(t,e){return e in Object(t)}function Bn(t,e,n){return t>=gl(e,n)&&t<pl(e,n)}function Vn(t,e,n){for(var i=n?c:l,r=t.length,o=r,a=Array(r),s=[];o--;){var u=t[o];o&&e&&(u=d(u,C(e))),a[o]=!n&&(e||u.length>=120)?new qe(o&&u):Y}u=t[0];var h=-1,f=u.length,p=a[0];t:for(;++h<f;){var g=u[h],m=e?e(g):g;if(!(p?Be(p,m):i(s,m,n))){for(var o=r;--o;){var v=a[o];if(!(v?Be(v,m):i(t[o],m,n)))continue t}p&&p.push(m),s.push(g)}}return s}function Yn(t,e,n,i){return Ln(t,function(t,r,o){e(i,n(t),r,o)}),i}function Gn(t,e,i){$r(e,t)||(e=_n(e),t=Ar(t,e),e=Zr(e));var r=null==t?t:t[e];return null==r?Y:n(r,t,i)}function Xn(t,e,n,i,r){return t===e?!0:null==t||null==e||!Ha(t)&&!La(e)?t!==t&&e!==e:Kn(t,e,Xn,n,i,r)}function Kn(t,e,n,i,r,o){var a=wc(t),s=wc(e),u=Mt,l=Mt;a||(u=gr(t),u==Ct?u=It:u!=It&&(a=ts(t))),s||(l=gr(e),l==Ct?l=It:l!=It&&(s=ts(e)));var c=u==It&&!W(t),d=l==It&&!W(e),h=u==l;if(h&&!a&&!c)return ur(t,e,u,n,i,r);var f=r&at;if(!f){var p=c&&qu.call(t,"__wrapped__"),g=d&&qu.call(e,"__wrapped__");if(p||g)return n(p?t.value():t,g?e.value():e,i,r,o)}return h?(o||(o=new Ye),(a?sr:lr)(t,e,n,i,r,o)):!1}function Zn(t,e,n,i){var r=n.length,o=r,a=!i;if(null==t)return!o;for(t=Object(t);r--;){var s=n[r];if(a&&s[2]?s[1]!==t[s[0]]:!(s[0]in t))return!1}for(;++r<o;){s=n[r];var u=s[0],l=t[u],c=s[1];if(a&&s[2]){if(l===Y&&!(u in t))return!1}else{var d=new Ye,h=i?i(l,c,u,t,e,d):Y;if(!(h===Y?Xn(c,l,i,ot|at,d):h))return!1}}return!0}function Qn(t){var e=typeof t;return"function"==e?t:null==t?pu:"object"==e?wc(t)?ii(t[0],t[1]):ni(t):_u(t)}function Jn(t){return fl(Object(t))}function ti(t){t=null==t?t:Object(t);var e=[];for(var n in t)e.push(n);return e}function ei(t,e){var n=-1,i=Ca(t)?Array(t.length):[];return El(t,function(t,r,o){i[++n]=e(t,r,o)}),i}function ni(t){var e=hr(t);if(1==e.length&&e[0][2]){var n=e[0][0],i=e[0][1];return function(t){return null==t?!1:t[n]===i&&(i!==Y||n in Object(t))}}return function(n){return n===t||Zn(n,t,e)}}function ii(t,e){return function(n){var i=_s(n,t);return i===Y&&i===e?ks(n,t):Xn(e,i,Y,ot|at)}}function ri(t,e,n,i,r){if(t!==e){var a=wc(e)||ts(e)?Y:Ms(e);o(a||e,function(o,s){if(a&&(s=o,o=e[s]),Ha(o))r||(r=new Ye),oi(t,e,s,n,ri,i,r);else{var u=i?i(t[s],o,s+"",t,e,r):Y;u===Y&&(u=o),an(t,s,u)}})}}function oi(t,e,n,i,r,o,a){var s=t[n],u=e[n],l=a.get(u);if(l)return void an(t,n,l);var c=o?o(s,u,n+"",t,e,a):Y,d=c===Y;d&&(c=u,wc(u)||ts(u)?wc(s)?c=s:Ma(s)?c=Hi(s):(d=!1,c=Mn(u,!0)):Ga(u)||$a(u)?$a(s)?c=cs(s):!Ha(s)||i&&Pa(s)?(d=!1,c=Mn(u,!0)):c=s:d=!1),a.set(u,c),d&&r(c,u,i,o,a),an(t,n,c)}function ai(t,e,n){var i=-1,r=dr();e=d(e.length?e:Array(1),function(t){return r(t)});var o=ei(t,function(t,n,r){var o=d(e,function(e){return e(t)});return{criteria:o,index:++i,value:t}});return w(o,function(t,e){return E(t,e,n)})}function si(t,e){return t=Object(t),f(e,function(e,n){return n in t&&(e[n]=t[n]),e},{})}function ui(t,e){var n={};return Hn(t,function(t,i){e(t,i)&&(n[i]=t)}),n}function li(t){return function(e){return null==e?Y:e[t]}}function ci(t){return function(e){return Rn(e,t)}}function di(t,e){return hi(t,e)}function hi(t,e,n){var i=-1,r=e.length,o=t;for(n&&(o=d(t,function(t){return n(t)}));++i<r;)for(var a=0,s=e[i],u=n?n(s):s;(a=b(o,u,a))>-1;)o!==t&&ul.call(o,a,1),ul.call(t,a,1);return t}function fi(t,e){for(var n=t?e.length:0,i=n-1;n--;){var r=e[n];if(i==n||r!=o){var o=r;if(H(r))ul.call(t,r,1);else if($r(r,t))delete t[r];else{var a=_n(r),s=Ar(t,a);null!=s&&delete s[Zr(a)]}}}return t}function pi(t,e){return t+cl(vl()*(e-t+1))}function gi(t,e,n,i){for(var r=-1,o=pl(ll((e-t)/(n||1)),0),a=Array(o);o--;)a[i?o:++r]=t,t+=n;return a}function mi(t,e,n,i){e=$r(e,t)?[e+""]:_n(e);for(var r=-1,o=e.length,a=o-1,s=t;null!=s&&++r<o;){var u=e[r];if(Ha(s)){var l=n;if(r!=a){var c=s[u];l=i?i(c,u,s):Y,l===Y&&(l=null==c?H(e[r+1])?[]:{}:c)}sn(s,u,l)}s=s[u]}return t}function vi(t,e,n){var i=-1,r=t.length;0>e&&(e=-e>r?0:r+e),n=n>r?r:n,0>n&&(n+=r),r=e>n?0:n-e>>>0,e>>>=0;for(var o=Array(r);++i<r;)o[i]=t[i+e];return o}function yi(t,e){var n;return El(t,function(t,i,r){return n=e(t,i,r),!n}),!!n}function bi(t,e,n){var i=0,r=t?t.length:i;if("number"==typeof e&&e===e&&$t>=r){for(;r>i;){var o=i+r>>>1,a=t[o];(n?e>=a:e>a)&&null!==a?i=o+1:r=o}return r}return xi(t,e,pu,n)}function xi(t,e,n,i){e=n(e);for(var r=0,o=t?t.length:0,a=e!==e,s=null===e,u=e===Y;o>r;){var l=cl((r+o)/2),c=n(t[l]),d=c!==Y,h=c===c;if(a)var f=h||i;else f=s?h&&d&&(i||null!=c):u?h&&(i||d):null==c?!1:i?e>=c:e>c;f?r=l+1:o=l}return gl(o,_t)}function wi(t){return _i(t)}function _i(t,e){for(var n=0,i=t.length,r=t[0],o=e?e(r):r,a=o,s=0,u=[r];++n<i;)r=t[n],o=e?e(r):r,xa(o,a)||(a=o,u[++s]=r);return u}function $i(t,e,n){var i=-1,r=l,o=t.length,a=!0,s=[],u=s;if(n)a=!1,r=c;else if(o>=dt){var d=e?null:Fl(t);if(d)return R(d);a=!1,r=Be,u=new qe}else u=e?[]:s;t:for(;++i<o;){var h=t[i],f=e?e(h):h;if(a&&f===f){for(var p=u.length;p--;)if(u[p]===f)continue t;e&&u.push(f),s.push(h)}else r(u,f,n)||(u!==s&&u.push(f),s.push(h))}return s}function ki(t,e){e=$r(e,t)?[e+""]:_n(e),t=Ar(t,e);var n=Zr(e);return null!=t&&$s(t,n)?delete t[n]:!0}function Ci(t,e,n,i){for(var r=t.length,o=i?r:-1;(i?o--:++o<r)&&e(t[o],o,t););return n?vi(t,i?0:o,i?o+1:r):vi(t,i?o+1:0,i?r:o)}function Mi(t,e){var n=t;return n instanceof Te&&(n=n.value()),f(e,function(t,e){return e.func.apply(e.thisArg,h([t],e.args))},n)}function Di(t,e,n){for(var i=-1,r=t.length;++i<r;)var o=o?h(En(o,t[i],e,n),En(t[i],o,e,n)):t[i];return o&&o.length?$i(o,e,n):[]}function Si(t,e,n){for(var i=-1,r=t.length,o=e.length,a={};++i<r;)n(a,t[i],o>i?e[i]:Y);return a}function Ti(t,e){if(e)return t.slice();var n=t.constructor,i=new n(t.length);return t.copy(i),i}function Ai(t){var e=t.constructor,n=new e(t.byteLength),i=new Ju(n);return i.set(new Ju(t)),n}function Ei(e){var n=e.constructor;return f(z(e),t,new n)}function Oi(t){var e=t.constructor,n=new e(t.source,ve.exec(t));return n.lastIndex=t.lastIndex,n}function Ni(t){var n=t.constructor;return f(R(t),e,new n)}function Ii(t){return Qu?Object(Sl.call(t)):{}}function Pi(t,e){var n=t.buffer,i=e?Ai(n):n,r=t.constructor;return new r(i,t.byteOffset,t.length)}function Fi(t,e,n,i){for(var r=-1,o=t.length,a=n.length,s=-1,u=e.length,l=pl(o-a,0),c=Array(u+l),d=!i;++s<u;)c[s]=e[s];for(;++r<a;)(d||o>r)&&(c[n[r]]=t[r]);for(;l--;)c[s++]=t[r++];return c}function Wi(t,e,n,i){for(var r=-1,o=t.length,a=-1,s=n.length,u=-1,l=e.length,c=pl(o-s,0),d=Array(c+l),h=!i;++r<c;)d[r]=t[r];for(var f=r;++u<l;)d[f+u]=e[u];for(;++a<s;)(h||o>r)&&(d[f+n[a]]=t[r++]);return d}function Hi(t,e){var n=-1,i=t.length;for(e||(e=Array(i));++n<i;)e[n]=t[n];return e}function Li(t,e,n){return zi(t,e,n)}function zi(t,e,n,i){n||(n={});for(var r=-1,o=e.length;++r<o;){var a=e[r],s=i?i(n[a],t[a],a,n,t):t[a];sn(n,a,s)}return n}function ji(t,e){return Li(t,Ll(t),e)}function Ri(t,e){return function(n,r){var o=wc(n)?i:ln,a=e?e():{};return o(n,t,dr(r),a)}}function Ui(t){return ca(function(e,n){var i=-1,r=n.length,o=r>1?n[r-1]:Y,a=r>2?n[2]:Y;for(o="function"==typeof o?(r--,o):Y,a&&_r(n[0],n[1],a)&&(o=3>r?Y:o,r=1),e=Object(e);++i<r;){var s=n[i];s&&t(e,s,i,o)}return e})}function qi(t,e){return function(n,i){if(null==n)return n;if(!Ca(n))return t(n,i);for(var r=n.length,o=e?r:-1,a=Object(n);(e?o--:++o<r)&&i(a[o],o,a)!==!1;);return n}}function Bi(t){return function(e,n,i){for(var r=-1,o=Object(e),a=i(e),s=a.length;s--;){var u=a[t?s:++r];if(n(o[u],u,o)===!1)break}return e}}function Vi(t,e,n){function i(){var e=this&&this!==On&&this instanceof i?o:t;return e.apply(r?n:this,arguments)}var r=e&X,o=Xi(t);return i}function Yi(t){return function(e){e=hs(e);var n=cn.test(e)?q(e):Y,i=n?n[0]:e.charAt(0),r=n?n.slice(1).join(""):e.slice(1);return i[t]()+r}}function Gi(t){return function(e){return f(cu(qs(e)),t,"")}}function Xi(t){return function(){var e=arguments;switch(e.length){case 0:return new t;case 1:return new t(e[0]);case 2:return new t(e[0],e[1]);case 3:return new t(e[0],e[1],e[2]);case 4:return new t(e[0],e[1],e[2],e[3]);case 5:return new t(e[0],e[1],e[2],e[3],e[4]);case 6:return new t(e[0],e[1],e[2],e[3],e[4],e[5]);case 7:return new t(e[0],e[1],e[2],e[3],e[4],e[5],e[6])}var n=Tn(t.prototype),i=t.apply(n,e);return Ha(i)?i:n}}function Ki(t,e,i){function r(){for(var a=arguments.length,s=Array(a),u=a,l=pr(r);u--;)s[u]=arguments[u];var c=3>a&&s[0]!==l&&s[a-1]!==l?[]:j(s,l);if(a-=c.length,i>a)return rr(t,e,Qi,r.placeholder,Y,s,c,Y,Y,i-a);var d=this&&this!==On&&this instanceof r?o:t;return n(d,this,s)}var o=Xi(t);return r}function Zi(t){return ca(function(e){e=Wn(e,1);var n=e.length,i=n,r=Se.prototype.thru;for(t&&e.reverse();i--;){var o=e[i];if("function"!=typeof o)throw new zu(gt);if(r&&!a&&"wrapper"==cr(o))var a=new Se([],!0)}for(i=a?i:n;++i<n;){o=e[i];var s=cr(o),u="wrapper"==s?Wl(o):Y;a=u&&Cr(u[0])&&u[1]==(nt|Q|tt|it)&&!u[4].length&&1==u[9]?a[cr(u[0])].apply(a,u[3]):1==o.length&&Cr(o)?a[s]():a.thru(o)}return function(){var t=arguments,i=t[0];if(a&&1==t.length&&wc(i)&&i.length>=dt)return a.plant(i).value();for(var r=0,o=n?e[r].apply(this,t):i;++r<n;)o=e[r].call(this,o);return o}})}function Qi(t,e,n,i,r,o,a,s,u,l){function c(){for(var v=arguments.length,y=v,b=Array(v);y--;)b[y]=arguments[y];if(p)var x=pr(c),w=O(b,x);if(i&&(b=Fi(b,i,r,p)),o&&(b=Wi(b,o,a,p)),v-=w,p&&l>v){var _=j(b,x);return rr(t,e,Qi,c.placeholder,n,b,_,s,u,l-v)}var $=h?n:this,k=f?$[t]:t;return v=b.length,s?b=Er(b,s):g&&v>1&&b.reverse(),d&&v>u&&(b.length=u),this&&this!==On&&this instanceof c&&(k=m||Xi(k)),k.apply($,b)}var d=e&nt,h=e&X,f=e&K,p=e&(Q|J),g=e&rt,m=f?Y:Xi(t);return c}function Ji(t,e){return function(n,i){return Yn(n,t,e(i),{})}}function tr(t){return ca(function(e){return e=d(Wn(e,1),dr()),ca(function(i){var r=this;return t(e,function(t){return n(t,r,i)})})})}function er(t,e,n){e=ss(e);var i=U(t);if(!e||i>=e)return"";var r=e-i;n=n===Y?" ":n+"";var o=Qs(n,ll(r/U(n)));return cn.test(n)?q(o).slice(0,r).join(""):o.slice(0,r)}function nr(t,e,i,r){function o(){for(var e=-1,u=arguments.length,l=-1,c=r.length,d=Array(c+u),h=this&&this!==On&&this instanceof o?s:t;++l<c;)d[l]=r[l];for(;u--;)d[l++]=arguments[++e];return n(h,a?i:this,d)}var a=e&X,s=Xi(t);return o}function ir(t){return function(e,n,i){return i&&"number"!=typeof i&&_r(e,n,i)&&(n=i=Y),e=ls(e),e=e===e?e:0,n===Y?(n=e,e=0):n=ls(n)||0,i=i===Y?n>e?1:-1:ls(i)||0,gi(e,n,i,t)}}function rr(t,e,n,i,r,o,a,s,u,l){var c=e&Q,d=s?Hi(s):Y,h=c?a:Y,f=c?Y:a,p=c?o:Y,g=c?Y:o;e|=c?tt:et,e&=~(c?et:tt),e&Z||(e&=~(X|K));var m=[t,e,r,p,h,g,f,d,u,l],v=n.apply(Y,m);return Cr(t)&&zl(v,m),v.placeholder=i,v}function or(t){var e=Hu[t];return function(t,n){if(t=ls(t),n=ss(n)){var i=(hs(t)+"e").split("e"),r=e(i[0]+"e"+(+i[1]+n));return i=(hs(r)+"e").split("e"),+(i[0]+"e"+(+i[1]-n))}return e(t)}}function ar(t,e,n,i,r,o,a,s){var u=e&K;if(!u&&"function"!=typeof t)throw new zu(gt);var l=i?i.length:0;if(l||(e&=~(tt|et),i=r=Y),a=a===Y?a:pl(ss(a),0),s=s===Y?s:ss(s),l-=r?r.length:0,e&et){var c=i,d=r;i=r=Y}var h=u?Y:Wl(t),f=[t,e,n,i,r,c,d,o,a,s];if(h&&Sr(f,h),t=f[0],e=f[1],n=f[2],i=f[3],r=f[4],s=f[9]=null==f[9]?u?0:t.length:pl(f[9]-l,0),!s&&e&(Q|J)&&(e&=~(Q|J)),e&&e!=X)p=e==Q||e==J?Ki(t,e,s):e!=tt&&e!=(X|tt)||r.length?Qi.apply(Y,f):nr(t,e,n,i);else var p=Vi(t,e,n);var g=h?Pl:zl;return g(p,f)}function sr(t,e,n,i,r,o){var a=-1,s=r&at,u=r&ot,l=t.length,c=e.length;if(l!=c&&!(s&&c>l))return!1;var d=o.get(t);if(d)return d==e;var h=!0;for(o.set(t,e);++a<l;){var f=t[a],p=e[a];if(i)var m=s?i(p,f,a,e,t,o):i(f,p,a,t,e,o);if(m!==Y){if(m)continue;h=!1;break}if(u){if(!g(e,function(t){return f===t||n(f,t,i,r,o)})){h=!1;break}}else if(f!==p&&!n(f,p,i,r,o)){h=!1;break}}return o["delete"](t),h}function ur(t,e,n,i,r,o){switch(n){case jt:return t.byteLength==e.byteLength&&i(new Ju(t),new Ju(e))?!0:!1;case Dt:case St:return+t==+e;case Tt:return t.name==e.name&&t.message==e.message;case Nt:return t!=+t?e!=+e:t==+e;case Pt:case Wt:return t==e+"";case Ot:var a=z;case Ft:var s=o&at;return a||(a=R),(s||t.size==e.size)&&i(a(t),a(e),r,o|ot);case Ht:return!!Qu&&Sl.call(t)==Sl.call(e)}return!1}function lr(t,e,n,i,r,o){var a=r&at,s=Cs(t),u=s.length,l=Cs(e),c=l.length;if(u!=c&&!a)return!1;for(var d=u;d--;){var h=s[d];if(!(a?h in e:Un(e,h)))return!1}var f=o.get(t);if(f)return f==e;var p=!0;o.set(t,e);for(var g=a;++d<u;){h=s[d];var m=t[h],v=e[h];if(i)var y=a?i(v,m,h,e,t,o):i(m,v,h,t,e,o);if(!(y===Y?m===v||n(m,v,i,r,o):y)){p=!1;break}g||(g="constructor"==h)}if(p&&!g){var b=t.constructor,x=e.constructor;b!=x&&"constructor"in t&&"constructor"in e&&!("function"==typeof b&&b instanceof b&&"function"==typeof x&&x instanceof x)&&(p=!1)}return o["delete"](t),p}function cr(t){for(var e=t.name+"",n=Al[e],i=qu.call(Al,e)?n.length:0;i--;){var r=n[i],o=r.func;if(null==o||o==t)return r.name}return e}function dr(){var t=$e.iteratee||gu;return t=t===gu?Qn:t,arguments.length?t(arguments[0],arguments[1]):t}function hr(t){for(var e=Is(t),n=e.length;n--;)e[n][2]=Dr(e[n][1]);return e}function fr(t,e){var n=null==t?Y:t[e];return qa(n)?n:Y}function pr(t){var e=qu.call($e,"placeholder")?$e:t;return e.placeholder}function gr(t){return Yu.call(t)}function mr(t,e,n){for(var i=-1,r=n.length;++i<r;){var o=n[i],a=o.size;switch(o.type){case"drop":t+=a;break;case"dropRight":e-=a;break;case"take":e=gl(e,t+a);break;case"takeRight":t=pl(t,e-a)}}return{start:t,end:e}}function vr(t,e,n){if(null==t)return!1;var i=n(t,e);i||$r(e)||(e=_n(e),t=Ar(t,e),null!=t&&(e=Zr(e),i=n(t,e)));var r=t?t.length:Y;return i||!!r&&Wa(r)&&H(e,r)&&(wc(t)||Qa(t)||$a(t))}function yr(t){var e=t.length,n=t.constructor(e);return e&&"string"==typeof t[0]&&qu.call(t,"index")&&(n.index=t.index,n.input=t.input),n}function br(t){return Pa(t.constructor)&&!Mr(t)?Tn(nl(t)):{}}function xr(t,e,n){var i=t.constructor;switch(e){case jt:return Ai(t);case Dt:case St:return new i(+t);case Rt:case Ut:case qt:case Bt:case Vt:case Yt:case Gt:case Xt:case Kt:return Pi(t,n);case Ot:return Ei(t);case Nt:case Wt:return new i(t);case Pt:return Oi(t);case Ft:return Ni(t);case Ht:return Ii(t)}}function wr(t){var e=t?t.length:Y;return Wa(e)&&(wc(t)||Qa(t)||$a(t))?$(e,String):null}function _r(t,e,n){if(!Ha(n))return!1;var i=typeof e;return("number"==i?Ca(n)&&H(e,n.length):"string"==i&&e in n)?xa(n[e],t):!1}function $r(t,e){return"number"==typeof t?!0:!wc(t)&&(ue.test(t)||!se.test(t)||null!=e&&t in Object(e))}function kr(t){var e=typeof t;return"number"==e||"boolean"==e||"string"==e&&"__proto__"!=t||null==t}function Cr(t){var e=cr(t),n=$e[e];if("function"!=typeof n||!(e in Te.prototype))return!1;if(t===n)return!0;var i=Wl(n);return!!i&&t===i[0]}function Mr(t){var e=t&&t.constructor,n=Pa(e)&&e.prototype||Ru;return t===n}function Dr(t){return t===t&&!Ha(t)}function Sr(t,e){var n=t[1],i=e[1],r=n|i,o=(X|K|nt)>r,a=i==nt&&n==Q||i==nt&&n==it&&t[7].length<=e[8]||i==(nt|it)&&e[7].length<=e[8]&&n==Q;if(!o&&!a)return t;i&X&&(t[2]=e[2],r|=n&X?0:Z);var s=e[3];if(s){var u=t[3];t[3]=u?Fi(u,s,e[4]):Hi(s),t[4]=u?j(t[3],kt):Hi(e[4])}return s=e[5],s&&(u=t[5],t[5]=u?Wi(u,s,e[6]):Hi(s),t[6]=u?j(t[5],kt):Hi(e[6])),s=e[7],s&&(t[7]=Hi(s)),i&nt&&(t[8]=null==t[8]?e[8]:gl(t[8],e[8])),null==t[9]&&(t[9]=e[9]),t[0]=e[0],t[1]=r,t}function Tr(t,e,n,i,r,o){return Ha(t)&&Ha(e)&&(o.set(e,t),ri(t,e,Y,Tr,o)),t}function Ar(t,e){return 1==e.length?t:_s(t,vi(e,0,-1))}function Er(t,e){for(var n=t.length,i=gl(e.length,n),r=Hi(t);i--;){var o=e[i];t[i]=H(o,n)?r[o]:Y}return t}function Or(t){var e=[];return hs(t).replace(le,function(t,n,i,r){e.push(i?r.replace(ge,"$1"):n||t)}),e}function Nr(t){if(t instanceof Te)return t.clone();var e=new Se(t.__wrapped__,t.__chain__);return e.__actions__=Hi(t.__actions__),e.__index__=t.__index__,e.__values__=t.__values__,e}function Ir(t,e){e=pl(ss(e),0);var n=t?t.length:0;if(!n||1>e)return[];for(var i=0,r=-1,o=Array(ll(n/e));n>i;)o[++r]=vi(t,i,i+=e);return o}function Pr(t){for(var e=-1,n=t?t.length:0,i=-1,r=[];++e<n;){var o=t[e];o&&(r[++i]=o)}return r}function Fr(t,e,n){var i=t?t.length:0;return i?(e=n||e===Y?1:ss(e),vi(t,0>e?0:e,i)):[]}function Wr(t,e,n){var i=t?t.length:0;return i?(e=n||e===Y?1:ss(e),e=i-e,vi(t,0,0>e?0:e)):[]}function Hr(t,e){return t&&t.length?Ci(t,dr(e,3),!0,!0):[]}function Lr(t,e){return t&&t.length?Ci(t,dr(e,3),!0):[]}function zr(t,e,n,i){var r=t?t.length:0;return r?(n&&"number"!=typeof n&&_r(t,e,n)&&(n=0,i=r),Pn(t,e,n,i)):[]}function jr(t,e){return t&&t.length?y(t,dr(e,3)):-1}function Rr(t,e){return t&&t.length?y(t,dr(e,3),!0):-1}function Ur(t){var e=t?t.length:0;return e?Wn(t,1):[]}function qr(t){var e=t?t.length:0;return e?Wn(t,vt):[]}function Br(t,e){var n=t?t.length:0;return n?(e=e===Y?1:ss(e),Wn(t,e)):[]}function Vr(t){for(var e=-1,n=t?t.length:0,i={};++e<n;){var r=t[e];i[r[0]]=r[1]}return i}function Yr(t){return t?t[0]:Y}function Gr(t,e,n){var i=t?t.length:0;return i?(n=ss(n),0>n&&(n=pl(i+n,0)),b(t,e,n)):-1}function Xr(t){return Wr(t,1)}function Kr(t,e){return t?hl.call(t,e):""}function Zr(t){var e=t?t.length:0;return e?t[e-1]:Y}function Qr(t,e,n){var i=t?t.length:0;if(!i)return-1;var r=i;if(n!==Y&&(r=ss(n),r=(0>r?pl(i+r,0):gl(r,i-1))+1),e!==e)return F(t,r,!0);for(;r--;)if(t[r]===e)return r;return-1}function Jr(t,e){return t&&t.length&&e&&e.length?di(t,e):t}function to(t,e,n){return t&&t.length&&e&&e.length?hi(t,e,dr(n)):t}function eo(t,e){var n=[];if(!t||!t.length)return n;var i=-1,r=[],o=t.length;for(e=dr(e,3);++i<o;){var a=t[i];e(a,i,t)&&(n.push(a),r.push(i))}return fi(t,r),n}function no(t){return t?yl.call(t):t}function io(t,e,n){var i=t?t.length:0;return i?(n&&"number"!=typeof n&&_r(t,e,n)?(e=0,n=i):(e=null==e?0:ss(e),n=n===Y?i:ss(n)),vi(t,e,n)):[]}function ro(t,e){return bi(t,e)}function oo(t,e,n){return xi(t,e,dr(n))}function ao(t,e){var n=t?t.length:0;if(n){var i=bi(t,e);if(n>i&&xa(t[i],e))return i}return-1}function so(t,e){return bi(t,e,!0)}function uo(t,e,n){return xi(t,e,dr(n),!0)}function lo(t,e){var n=t?t.length:0;if(n){var i=bi(t,e,!0)-1;if(xa(t[i],e))return i}return-1}function co(t){return t&&t.length?wi(t):[]}function ho(t,e){return t&&t.length?_i(t,dr(e)):[]}function fo(t){return Fr(t,1)}function po(t,e,n){return t&&t.length?(e=n||e===Y?1:ss(e),vi(t,0,0>e?0:e)):[]}function go(t,e,n){var i=t?t.length:0;return i?(e=n||e===Y?1:ss(e),e=i-e,vi(t,0>e?0:e,i)):[]}function mo(t,e){return t&&t.length?Ci(t,dr(e,3),!1,!0):[]}function vo(t,e){return t&&t.length?Ci(t,dr(e,3)):[]}function yo(t){return t&&t.length?$i(t):[]}function bo(t,e){return t&&t.length?$i(t,dr(e)):[]}function xo(t,e){return t&&t.length?$i(t,Y,e):[]}function wo(t){if(!t||!t.length)return[];var e=0;return t=u(t,function(t){return Ma(t)?(e=pl(t.length,e),!0):void 0}),$(e,function(e){return d(t,li(e))})}function _o(t,e){if(!t||!t.length)return[];var i=wo(t);return null==e?i:d(i,function(t){return n(e,Y,t)})}function $o(t,e){return Si(t||[],e||[],sn)}function ko(t,e){return Si(t||[],e||[],mi)}function Co(t){var e=$e(t);return e.__chain__=!0,e}function Mo(t,e){return e(t),t}function Do(t,e){return e(t)}function So(){return Co(this)}function To(){return new Se(this.value(),this.__chain__)}function Ao(t){return this.map(t).flatten()}function Eo(){this.__values__===Y&&(this.__values__=as(this.value()));var t=this.__index__>=this.__values__.length,e=t?Y:this.__values__[this.__index__++];return{done:t,value:e}}function Oo(){return this}function No(t){for(var e,n=this;n instanceof De;){var i=Nr(n);i.__index__=0,i.__values__=Y,e?r.__wrapped__=i:e=i;var r=i;n=n.__wrapped__}return r.__wrapped__=t,e}function Io(){var t=this.__wrapped__;if(t instanceof Te){var e=t;return this.__actions__.length&&(e=new Te(this)),e=e.reverse(),e.__actions__.push({func:Do,args:[no],thisArg:Y}),new Se(e,this.__chain__)}return this.thru(no)}function Po(){return Mi(this.__wrapped__,this.__actions__)}function Fo(t,e,n){var i=wc(t)?s:In;return n&&_r(t,e,n)&&(e=Y),i(t,dr(e,3))}function Wo(t,e){var n=wc(t)?u:Fn;return n(t,dr(e,3))}function Ho(t,e){if(e=dr(e,3),wc(t)){var n=y(t,e);return n>-1?t[n]:Y}return v(t,e,El)}function Lo(t,e){if(e=dr(e,3),wc(t)){var n=y(t,e,!0);return n>-1?t[n]:Y}return v(t,e,Ol)}function zo(t,e){return Wn(qo(t,e),1)}function jo(t,e){return"function"==typeof e&&wc(t)?o(t,e):El(t,wn(e))}function Ro(t,e){return"function"==typeof e&&wc(t)?a(t,e):Ol(t,wn(e))}function Uo(t,e,n,i){t=Ca(t)?t:Hs(t),n=n&&!i?ss(n):0;var r=t.length;return 0>n&&(n=pl(r+n,0)),Qa(t)?r>=n&&t.indexOf(e,n)>-1:!!r&&b(t,e,n)>-1}function qo(t,e){var n=wc(t)?d:ei;return n(t,dr(e,3))}function Bo(t,e,n,i){return null==t?[]:(wc(e)||(e=null==e?[]:[e]),n=i?Y:n,wc(n)||(n=null==n?[]:[n]),ai(t,e,n))}function Vo(t,e,n){var i=wc(t)?f:x,r=arguments.length<3;return i(t,dr(e,4),n,r,El)}function Yo(t,e,n){var i=wc(t)?p:x,r=arguments.length<3;return i(t,dr(e,4),n,r,Ol)}function Go(t,e){var n=wc(t)?u:Fn;return e=dr(e,3),n(t,function(t,n,i){return!e(t,n,i)})}function Xo(t){var e=Ca(t)?t:Hs(t),n=e.length;return n>0?e[pi(0,n-1)]:Y}function Ko(t,e){var n=-1,i=as(t),r=i.length,o=r-1;for(e=Cn(ss(e),0,r);++n<e;){var a=pi(n,o),s=i[a];i[a]=i[n],i[n]=s}return i.length=e,i}function Zo(t){return Ko(t,wt)}function Qo(t){if(null==t)return 0;if(Ca(t)){var e=t.length;return e&&Qa(t)?U(t):e}return Cs(t).length}function Jo(t,e,n){var i=wc(t)?g:yi;return n&&_r(t,e,n)&&(e=Y),i(t,dr(e,3))}function ta(t,e){if("function"!=typeof e)throw new zu(gt);return t=ss(t),function(){return--t<1?e.apply(this,arguments):void 0}}function ea(t,e,n){return e=n?Y:e,e=t&&null==e?t.length:e,ar(t,nt,Y,Y,Y,Y,e)}function na(t,e){var n;if("function"!=typeof e)throw new zu(gt);return t=ss(t),function(){return--t>0&&(n=e.apply(this,arguments)),1>=t&&(e=Y),n}}function ia(t,e,n){e=n?Y:e;var i=ar(t,Q,Y,Y,Y,Y,Y,e);return i.placeholder=ia.placeholder,i}function ra(t,e,n){e=n?Y:e;var i=ar(t,J,Y,Y,Y,Y,Y,e);return i.placeholder=ra.placeholder,i}function oa(t,e,n){function i(){p&&tl(p),c&&tl(c),m=0,l=c=f=p=g=Y}function r(e,n){n&&tl(n),c=p=g=Y,e&&(m=hc(),d=t.apply(f,l),p||c||(l=f=Y))}function o(){var t=e-(hc()-h);0>=t||t>e?r(g,c):p=sl(o,t)}function a(){return(p&&g||c&&b)&&(d=t.apply(f,l)),i(),d}function s(){r(b,p)}function u(){if(l=arguments,h=hc(),f=this,g=b&&(p||!v),y===!1)var n=v&&!p;else{m||c||v||(m=h);var i=y-(h-m),r=(0>=i||i>y)&&(v||c);r?(c&&(c=tl(c)),m=h,d=t.apply(f,l)):c||(c=sl(s,i))}return r&&p?p=tl(p):p||e===y||(p=sl(o,e)),n&&(r=!0,d=t.apply(f,l)),!r||p||c||(l=f=Y),d}var l,c,d,h,f,p,g,m=0,v=!1,y=!1,b=!0;if("function"!=typeof t)throw new zu(gt);return e=ls(e)||0,Ha(n)&&(v=!!n.leading,y="maxWait"in n&&pl(ls(n.maxWait)||0,e),b="trailing"in n?!!n.trailing:b),u.cancel=i,u.flush=a,u}function aa(t){return ar(t,rt)}function sa(t,e){if("function"!=typeof t||e&&"function"!=typeof e)throw new zu(gt);var n=function(){var i=arguments,r=e?e.apply(this,i):i[0],o=n.cache;if(o.has(r))return o.get(r);var a=t.apply(this,i);return n.cache=o.set(r,a),a};return n.cache=new sa.Cache,n}function ua(t){if("function"!=typeof t)throw new zu(gt);return function(){return!t.apply(this,arguments)}}function la(t){return na(2,t)}function ca(t,e){if("function"!=typeof t)throw new zu(gt);return e=pl(e===Y?t.length-1:ss(e),0),function(){for(var i=arguments,r=-1,o=pl(i.length-e,0),a=Array(o);++r<o;)a[r]=i[e+r];switch(e){case 0:return t.call(this,a);case 1:return t.call(this,i[0],a);case 2:return t.call(this,i[0],i[1],a)}var s=Array(e+1);for(r=-1;++r<e;)s[r]=i[r];return s[e]=a,n(t,this,s)}}function da(t,e){if("function"!=typeof t)throw new zu(gt);return e=e===Y?0:pl(ss(e),0),ca(function(i){var r=i[e],o=i.slice(0,e);return r&&h(o,r),n(t,this,o)})}function ha(t,e,n){var i=!0,r=!0;if("function"!=typeof t)throw new zu(gt);return Ha(n)&&(i="leading"in n?!!n.leading:i,r="trailing"in n?!!n.trailing:r),oa(t,e,{leading:i,maxWait:e,trailing:r})}function fa(t){return ea(t,1)}function pa(t,e){return e=null==e?pu:e,yc(e,t)}function ga(){if(!arguments.length)return[];var t=arguments[0];return wc(t)?t:[t]}function ma(t){return Mn(t)}function va(t,e){return Mn(t,!1,e)}function ya(t){return Mn(t,!0)}function ba(t,e){return Mn(t,!0,e)}function xa(t,e){return t===e||t!==t&&e!==e}function wa(t,e){return t>e}function _a(t,e){return t>=e}function $a(t){return Ma(t)&&qu.call(t,"callee")&&(!al.call(t,"callee")||Yu.call(t)==Ct)}function ka(t){return La(t)&&Yu.call(t)==jt}function Ca(t){return null!=t&&!("function"==typeof t&&Pa(t))&&Wa(Hl(t))}function Ma(t){return La(t)&&Ca(t)}function Da(t){return t===!0||t===!1||La(t)&&Yu.call(t)==Dt}function Sa(t){return La(t)&&Yu.call(t)==St}function Ta(t){return!!t&&1===t.nodeType&&La(t)&&!Ga(t)}function Aa(t){if(Ca(t)&&(wc(t)||Qa(t)||Pa(t.splice)||$a(t)))return!t.length;for(var e in t)if(qu.call(t,e))return!1;return!0}function Ea(t,e){return Xn(t,e)}function Oa(t,e,n){n="function"==typeof n?n:Y;var i=n?n(t,e):Y;return i===Y?Xn(t,e,n):!!i}function Na(t){return La(t)?Yu.call(t)==Tt||"string"==typeof t.message&&"string"==typeof t.name:!1}function Ia(t){return"number"==typeof t&&dl(t)}function Pa(t){var e=Ha(t)?Yu.call(t):"";return e==At||e==Et}function Fa(t){return"number"==typeof t&&t==ss(t)}function Wa(t){return"number"==typeof t&&t>-1&&t%1==0&&yt>=t}function Ha(t){var e=typeof t;return!!t&&("object"==e||"function"==e)}function La(t){return!!t&&"object"==typeof t}function za(t){return La(t)&&gr(t)==Ot}function ja(t,e){return t===e||Zn(t,e,hr(e))}function Ra(t,e,n){return n="function"==typeof n?n:Y,Zn(t,e,hr(e),n)}function Ua(t){return Ya(t)&&t!=+t}function qa(t){return null==t?!1:Pa(t)?Xu.test(Uu.call(t)):La(t)&&(W(t)?Xu:we).test(t)}function Ba(t){return null===t}function Va(t){return null==t}function Ya(t){return"number"==typeof t||La(t)&&Yu.call(t)==Nt}function Ga(t){if(!La(t)||Yu.call(t)!=It||W(t))return!1;var e=nl(t);if(null===e)return!0;var n=e.constructor;return"function"==typeof n&&n instanceof n&&Uu.call(n)==Vu}function Xa(t){return Ha(t)&&Yu.call(t)==Pt}function Ka(t){return Fa(t)&&t>=-yt&&yt>=t}function Za(t){return La(t)&&gr(t)==Ft}function Qa(t){return"string"==typeof t||!wc(t)&&La(t)&&Yu.call(t)==Wt}function Ja(t){return"symbol"==typeof t||La(t)&&Yu.call(t)==Ht}function ts(t){return La(t)&&Wa(t.length)&&!!mn[Yu.call(t)]}function es(t){return t===Y}function ns(t){return La(t)&&gr(t)==Lt}function is(t){return La(t)&&Yu.call(t)==zt}function rs(t,e){return e>t}function os(t,e){return e>=t}function as(t){if(!t)return[];if(Ca(t))return Qa(t)?q(t):Hi(t);if(rl&&t[rl])return L(t[rl]());var e=gr(t),n=e==Ot?z:e==Ft?R:Hs;return n(t)}function ss(t){if(!t)return 0===t?t:0;if(t=ls(t),t===vt||t===-vt){var e=0>t?-1:1;return e*bt}var n=t%1;return t===t?n?t-n:t:0}function us(t){return t?Cn(ss(t),0,wt):0}function ls(t){if(Ha(t)){var e=Pa(t.valueOf)?t.valueOf():t;t=Ha(e)?e+"":e}if("string"!=typeof t)return 0===t?t:+t;t=t.replace(he,"");var n=xe.test(t);return n||_e.test(t)?kn(t.slice(2),n?2:8):be.test(t)?xt:+t}function cs(t){return Li(t,Ms(t))}function ds(t){return Cn(ss(t),-yt,yt)}function hs(t){if("string"==typeof t)return t;if(null==t)return"";if(Ja(t))return Qu?Tl.call(t):"";var e=t+"";return"0"==e&&1/t==-vt?"-0":e}function fs(t,e){var n=Tn(t);return e?yn(n,e):n}function ps(t,e){return v(t,dr(e,3),Ln,!0)}function gs(t,e){return v(t,dr(e,3),zn,!0)}function ms(t,e){return null==t?t:Nl(t,wn(e),Ms)}function vs(t,e){return null==t?t:Il(t,wn(e),Ms)}function ys(t,e){return t&&Ln(t,wn(e))}function bs(t,e){return t&&zn(t,wn(e))}function xs(t){return null==t?[]:jn(t,Cs(t))}function ws(t){return null==t?[]:jn(t,Ms(t))}function _s(t,e,n){var i=null==t?Y:Rn(t,e);return i===Y?n:i}function $s(t,e){return vr(t,e,Un)}function ks(t,e){return vr(t,e,qn)}function Cs(t){var e=Mr(t);if(!e&&!Ca(t))return Jn(t);var n=wr(t),i=!!n,r=n||[],o=r.length;for(var a in t)!Un(t,a)||i&&("length"==a||H(a,o))||e&&"constructor"==a||r.push(a);return r}function Ms(t){for(var e=-1,n=Mr(t),i=ti(t),r=i.length,o=wr(t),a=!!o,s=o||[],u=s.length;++e<r;){var l=i[e];a&&("length"==l||H(l,u))||"constructor"==l&&(n||!qu.call(t,l))||s.push(l)}return s}function Ds(t,e){var n={};return e=dr(e,3),Ln(t,function(t,i,r){n[e(t,i,r)]=t}),n}function Ss(t,e){var n={};return e=dr(e,3),Ln(t,function(t,i,r){n[i]=e(t,i,r)}),n}function Ts(t,e){return e=dr(e),ui(t,function(t,n){return!e(t,n)})}function As(t,e){return null==t?{}:ui(t,dr(e))}function Es(t,e,n){if($r(e,t))i=null==t?Y:t[e];else{e=_n(e);var i=_s(t,e);t=Ar(t,e)}return i===Y&&(i=n),Pa(i)?i.call(t):i}function Os(t,e,n){return null==t?t:mi(t,e,n)}function Ns(t,e,n,i){return i="function"==typeof i?i:Y,null==t?t:mi(t,e,n,i)}function Is(t){return k(t,Cs(t))}function Ps(t){return k(t,Ms(t))}function Fs(t,e,n){var i=wc(t)||ts(t);if(e=dr(e,4),null==n)if(i||Ha(t)){var r=t.constructor;n=i?wc(t)?new r:[]:Pa(r)?Tn(nl(t)):{}}else n={};return(i?o:Ln)(t,function(t,i,r){return e(n,t,i,r)}),n}function Ws(t,e){return null==t?!0:ki(t,e)}function Hs(t){return t?M(t,Cs(t)):[]}function Ls(t){return null==t?[]:M(t,Ms(t))}function zs(t,e,n){return n===Y&&(n=e,e=Y),n!==Y&&(n=ls(n),n=n===n?n:0),e!==Y&&(e=ls(e),e=e===e?e:0),Cn(ls(t),e,n)}function js(t,e,n){return e=ls(e)||0,n===Y?(n=e,e=0):n=ls(n)||0,t=ls(t),Bn(t,e,n)}function Rs(t,e,n){if(n&&"boolean"!=typeof n&&_r(t,e,n)&&(e=n=Y),n===Y&&("boolean"==typeof e?(n=e,e=Y):"boolean"==typeof t&&(n=t,t=Y)),t===Y&&e===Y?(t=0,e=1):(t=ls(t)||0,e===Y?(e=t,t=0):e=ls(e)||0),t>e){var i=t;t=e,e=i}if(n||t%1||e%1){var r=vl();return gl(t+r*(e-t+$n("1e-"+((r+"").length-1))),e)}return pi(t,e)}function Us(t){return jc(hs(t).toLowerCase())}function qs(t){return t=hs(t),t&&t.replace(ke,N).replace(un,"")}function Bs(t,e,n){t=hs(t),e="string"==typeof e?e:e+"";var i=t.length;return n=n===Y?i:Cn(ss(n),0,i),n-=e.length,n>=0&&t.indexOf(e,n)==n}function Vs(t){return t=hs(t),t&&ie.test(t)?t.replace(ee,I):t}function Ys(t){return t=hs(t),t&&de.test(t)?t.replace(ce,"\\$&"):t}function Gs(t,e,n){t=hs(t),e=ss(e);var i=U(t);if(!e||i>=e)return t;var r=(e-i)/2,o=cl(r),a=ll(r);return er("",o,n)+t+er("",a,n)}function Xs(t,e,n){return t=hs(t),t+er(t,e,n)}function Ks(t,e,n){return t=hs(t),er(t,e,n)+t}function Zs(t,e,n){return n||null==e?e=0:e&&(e=+e),t=hs(t).replace(he,""),ml(t,e||(ye.test(t)?16:10))}function Qs(t,e){t=hs(t),e=ss(e);var n="";if(!t||1>e||e>yt)return n;do e%2&&(n+=t),e=cl(e/2),t+=t;while(e);return n}function Js(){var t=arguments,e=hs(t[0]);return t.length<3?e:e.replace(t[1],t[2])}function tu(t,e,n){return hs(t).split(e,n)}function eu(t,e,n){return t=hs(t),
n=Cn(ss(n),0,t.length),t.lastIndexOf(e,n)==n}function nu(t,e,n){var i=$e.templateSettings;n&&_r(t,e,n)&&(e=Y),t=hs(t),e=Cc({},e,i,on);var r,o,a=Cc({},e.imports,i.imports,on),s=Cs(a),u=M(a,s),l=0,c=e.interpolate||Ce,d="__p += '",h=Lu((e.escape||Ce).source+"|"+c.source+"|"+(c===ae?me:Ce).source+"|"+(e.evaluate||Ce).source+"|$","g"),f="//# sourceURL="+("sourceURL"in e?e.sourceURL:"lodash.templateSources["+ ++gn+"]")+"\n";t.replace(h,function(e,n,i,a,s,u){return i||(i=a),d+=t.slice(l,u).replace(Me,P),n&&(r=!0,d+="' +\n__e("+n+") +\n'"),s&&(o=!0,d+="';\n"+s+";\n__p += '"),i&&(d+="' +\n((__t = ("+i+")) == null ? '' : __t) +\n'"),l=u+e.length,e}),d+="';\n";var p=e.variable;p||(d="with (obj) {\n"+d+"\n}\n"),d=(o?d.replace(Zt,""):d).replace(Qt,"$1").replace(Jt,"$1;"),d="function("+(p||"obj")+") {\n"+(p?"":"obj || (obj = {});\n")+"var __t, __p = ''"+(r?", __e = _.escape":"")+(o?", __j = Array.prototype.join;\nfunction print() { __p += __j.call(arguments, '') }\n":";\n")+d+"return __p\n}";var g=Bc(function(){return Function(s,f+"return "+d).apply(Y,u)});if(g.source=d,Na(g))throw g;return g}function iu(t){return hs(t).toLowerCase()}function ru(t){return hs(t).toUpperCase()}function ou(t,e,n){if(t=hs(t),!t)return t;if(n||e===Y)return t.replace(he,"");if(e+="",!e)return t;var i=q(t),r=q(e);return i.slice(D(i,r),S(i,r)+1).join("")}function au(t,e,n){if(t=hs(t),!t)return t;if(n||e===Y)return t.replace(pe,"");if(e+="",!e)return t;var i=q(t);return i.slice(0,S(i,q(e))+1).join("")}function su(t,e,n){if(t=hs(t),!t)return t;if(n||e===Y)return t.replace(fe,"");if(e+="",!e)return t;var i=q(t);return i.slice(D(i,q(e))).join("")}function uu(t,e){var n=st,i=ut;if(Ha(e)){var r="separator"in e?e.separator:r;n="length"in e?ss(e.length):n,i="omission"in e?hs(e.omission):i}t=hs(t);var o=t.length;if(cn.test(t)){var a=q(t);o=a.length}if(n>=o)return t;var s=n-U(i);if(1>s)return i;var u=a?a.slice(0,s).join(""):t.slice(0,s);if(r===Y)return u+i;if(a&&(s+=u.length-s),Xa(r)){if(t.slice(s).search(r)){var l,c=u;for(r.global||(r=Lu(r.source,hs(ve.exec(r))+"g")),r.lastIndex=0;l=r.exec(c);)var d=l.index;u=u.slice(0,d===Y?s:d)}}else if(t.indexOf(r,s)!=s){var h=u.lastIndexOf(r);h>-1&&(u=u.slice(0,h))}return u+i}function lu(t){return t=hs(t),t&&ne.test(t)?t.replace(te,B):t}function cu(t,e,n){return t=hs(t),e=n?Y:e,e===Y&&(e=fn.test(t)?hn:dn),t.match(e)||[]}function du(t){var e=t?t.length:0,i=dr();return t=e?d(t,function(t){if("function"!=typeof t[1])throw new zu(gt);return[i(t[0]),t[1]]}):[],ca(function(i){for(var r=-1;++r<e;){var o=t[r];if(n(o[0],this,i))return n(o[1],this,i)}})}function hu(t){return Sn(Mn(t,!0))}function fu(t){return function(){return t}}function pu(t){return t}function gu(t){return Qn("function"==typeof t?t:Mn(t,!0))}function mu(t){return ni(Mn(t,!0))}function vu(t,e){return ii(t,Mn(e,!0))}function yu(t,e,n){var i=Cs(e),r=jn(e,i);null!=n||Ha(e)&&(r.length||!i.length)||(n=e,e=t,t=this,r=jn(e,Cs(e)));var a=Ha(n)&&"chain"in n?n.chain:!0,s=Pa(t);return o(r,function(n){var i=e[n];t[n]=i,s&&(t.prototype[n]=function(){var e=this.__chain__;if(a||e){var n=t(this.__wrapped__),r=n.__actions__=Hi(this.__actions__);return r.push({func:i,args:arguments,thisArg:t}),n.__chain__=e,n}return i.apply(t,h([this.value()],arguments))})}),t}function bu(){return On._===this&&(On._=Gu),this}function xu(){}function wu(t){return t=ss(t),function(){return arguments[t]}}function _u(t){return $r(t)?li(t):ci(t)}function $u(t){return function(e){return null==t?Y:Rn(t,e)}}function ku(t,e){if(t=ss(t),1>t||t>yt)return[];var n=wt,i=gl(t,wt);e=wn(e),t-=wt;for(var r=$(i,e);++n<t;)e(n);return r}function Cu(t){return wc(t)?d(t,String):Or(t)}function Mu(t){var e=++Bu;return hs(t)+e}function Du(t,e){var n;return t===Y&&e===Y?0:(t!==Y&&(n=t),e!==Y&&(n=n===Y?e:n+e),n)}function Su(t){return t&&t.length?m(t,pu,wa):Y}function Tu(t,e){return t&&t.length?m(t,dr(e),wa):Y}function Au(t){return Iu(t)/(t?t.length:0)}function Eu(t){return t&&t.length?m(t,pu,rs):Y}function Ou(t,e){return t&&t.length?m(t,dr(e),rs):Y}function Nu(t,e){var n;return t===Y&&e===Y?0:(t!==Y&&(n=t),e!==Y&&(n=n===Y?e:n-e),n)}function Iu(t){return t&&t.length?_(t,pu):0}function Pu(t,e){return t&&t.length?_(t,dr(e)):0}T=T?Nn.defaults({},T,Nn.pick(On,pn)):On;var Fu=T.Date,Wu=T.Error,Hu=T.Math,Lu=T.RegExp,zu=T.TypeError,ju=T.Array.prototype,Ru=T.Object.prototype,Uu=T.Function.prototype.toString,qu=Ru.hasOwnProperty,Bu=0,Vu=Uu.call(Object),Yu=Ru.toString,Gu=On._,Xu=Lu("^"+Uu.call(qu).replace(ce,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),Ku=Dn?T.Buffer:Y,Zu=T.Reflect,Qu=T.Symbol,Ju=T.Uint8Array,tl=T.clearTimeout,el=Zu?Zu.enumerate:Y,nl=Object.getPrototypeOf,il=Object.getOwnPropertySymbols,rl="symbol"==typeof(rl=Qu&&Qu.iterator)?rl:Y,ol=Object.create,al=Ru.propertyIsEnumerable,sl=T.setTimeout,ul=ju.splice,ll=Hu.ceil,cl=Hu.floor,dl=T.isFinite,hl=ju.join,fl=Object.keys,pl=Hu.max,gl=Hu.min,ml=T.parseInt,vl=Hu.random,yl=ju.reverse,bl=fr(T,"Map"),xl=fr(T,"Set"),wl=fr(T,"WeakMap"),_l=fr(Object,"create"),$l=wl&&new wl,kl=bl?Uu.call(bl):"",Cl=xl?Uu.call(xl):"",Ml=wl?Uu.call(wl):"",Dl=Qu?Qu.prototype:Y,Sl=Qu?Dl.valueOf:Y,Tl=Qu?Dl.toString:Y,Al={};$e.templateSettings={escape:re,evaluate:oe,interpolate:ae,variable:"",imports:{_:$e}};var El=qi(Ln),Ol=qi(zn,!0),Nl=Bi(),Il=Bi(!0);el&&!al.call({valueOf:1},"valueOf")&&(ti=function(t){return L(el(t))});var Pl=$l?function(t,e){return $l.set(t,e),t}:pu,Fl=xl&&2===new xl([1,2]).size?function(t){return new xl(t)}:xu,Wl=$l?function(t){return $l.get(t)}:xu,Hl=li("length"),Ll=il||function(){return[]};(bl&&gr(new bl)!=Ot||xl&&gr(new xl)!=Ft||wl&&gr(new wl)!=Lt)&&(gr=function(t){var e=Yu.call(t),n=e==It?t.constructor:null,i="function"==typeof n?Uu.call(n):"";if(i)switch(i){case kl:return Ot;case Cl:return Ft;case Ml:return Lt}return e});var zl=function(){var t=0,e=0;return function(n,i){var r=hc(),o=ct-(r-e);if(e=r,o>0){if(++t>=lt)return n}else t=0;return Pl(n,i)}}(),jl=ca(function(t,e){return wc(t)||(t=null==t?[]:[Object(t)]),e=Wn(e,1),r(t,e)}),Rl=ca(function(t,e){return Ma(t)?En(t,Wn(e,1,!0)):[]}),Ul=ca(function(t,e){var n=Zr(e);return Ma(n)&&(n=Y),Ma(t)?En(t,Wn(e,1,!0),dr(n)):[]}),ql=ca(function(t,e){var n=Zr(e);return Ma(n)&&(n=Y),Ma(t)?En(t,Wn(e,1,!0),Y,n):[]}),Bl=ca(function(t){var e=d(t,xn);return e.length&&e[0]===t[0]?Vn(e):[]}),Vl=ca(function(t){var e=Zr(t),n=d(t,xn);return e===Zr(n)?e=Y:n.pop(),n.length&&n[0]===t[0]?Vn(n,dr(e)):[]}),Yl=ca(function(t){var e=Zr(t),n=d(t,xn);return e===Zr(n)?e=Y:n.pop(),n.length&&n[0]===t[0]?Vn(n,Y,e):[]}),Gl=ca(Jr),Xl=ca(function(t,e){e=d(Wn(e,1),String);var n=bn(t,e);return fi(t,e.sort(A)),n}),Kl=ca(function(t){return $i(Wn(t,1,!0))}),Zl=ca(function(t){var e=Zr(t);return Ma(e)&&(e=Y),$i(Wn(t,1,!0),dr(e))}),Ql=ca(function(t){var e=Zr(t);return Ma(e)&&(e=Y),$i(Wn(t,1,!0),Y,e)}),Jl=ca(function(t,e){return Ma(t)?En(t,e):[]}),tc=ca(function(t){return Di(u(t,Ma))}),ec=ca(function(t){var e=Zr(t);return Ma(e)&&(e=Y),Di(u(t,Ma),dr(e))}),nc=ca(function(t){var e=Zr(t);return Ma(e)&&(e=Y),Di(u(t,Ma),Y,e)}),ic=ca(wo),rc=ca(function(t){var e=t.length,n=e>1?t[e-1]:Y;return n="function"==typeof n?(t.pop(),n):Y,_o(t,n)}),oc=ca(function(t){t=Wn(t,1);var e=t.length,n=e?t[0]:0,i=this.__wrapped__,r=function(e){return bn(e,t)};return!(e>1||this.__actions__.length)&&i instanceof Te&&H(n)?(i=i.slice(n,+n+(e?1:0)),i.__actions__.push({func:Do,args:[r],thisArg:Y}),new Se(i,this.__chain__).thru(function(t){return e&&!t.length&&t.push(Y),t})):this.thru(r)}),ac=Ri(function(t,e,n){qu.call(t,n)?++t[n]:t[n]=1}),sc=Ri(function(t,e,n){qu.call(t,n)?t[n].push(e):t[n]=[e]}),uc=ca(function(t,e,i){var r=-1,o="function"==typeof e,a=$r(e),s=Ca(t)?Array(t.length):[];return El(t,function(t){var u=o?e:a&&null!=t?t[e]:Y;s[++r]=u?n(u,t,i):Gn(t,e,i)}),s}),lc=Ri(function(t,e,n){t[n]=e}),cc=Ri(function(t,e,n){t[n?0:1].push(e)},function(){return[[],[]]}),dc=ca(function(t,e){if(null==t)return[];var n=e.length;return n>1&&_r(t,e[0],e[1])?e=[]:n>2&&_r(e[0],e[1],e[2])&&(e.length=1),ai(t,Wn(e,1),[])}),hc=Fu.now,fc=ca(function(t,e,n){var i=X;if(n.length){var r=j(n,pr(fc));i|=tt}return ar(t,i,e,n,r)}),pc=ca(function(t,e,n){var i=X|K;if(n.length){var r=j(n,pr(pc));i|=tt}return ar(e,i,t,n,r)}),gc=ca(function(t,e){return An(t,1,e)}),mc=ca(function(t,e,n){return An(t,ls(e)||0,n)}),vc=ca(function(t,e){e=d(Wn(e,1),dr());var i=e.length;return ca(function(r){for(var o=-1,a=gl(r.length,i);++o<a;)r[o]=e[o].call(this,r[o]);return n(t,this,r)})}),yc=ca(function(t,e){var n=j(e,pr(yc));return ar(t,tt,Y,e,n)}),bc=ca(function(t,e){var n=j(e,pr(bc));return ar(t,et,Y,e,n)}),xc=ca(function(t,e){return ar(t,it,Y,Y,Y,Wn(e,1))}),wc=Array.isArray,_c=Ku?function(t){return t instanceof Ku}:fu(!1),$c=Ui(function(t,e){Li(e,Cs(e),t)}),kc=Ui(function(t,e){Li(e,Ms(e),t)}),Cc=Ui(function(t,e,n,i){zi(e,Ms(e),t,i)}),Mc=Ui(function(t,e,n,i){zi(e,Cs(e),t,i)}),Dc=ca(function(t,e){return bn(t,Wn(e,1))}),Sc=ca(function(t){return t.push(Y,on),n(Cc,Y,t)}),Tc=ca(function(t){return t.push(Y,Tr),n(Ic,Y,t)}),Ac=Ji(function(t,e,n){t[e]=n},fu(pu)),Ec=Ji(function(t,e,n){qu.call(t,e)?t[e].push(n):t[e]=[n]},dr),Oc=ca(Gn),Nc=Ui(function(t,e,n){ri(t,e,n)}),Ic=Ui(function(t,e,n,i){ri(t,e,n,i)}),Pc=ca(function(t,e){return null==t?{}:(e=d(Wn(e,1),String),si(t,En(Ms(t),e)))}),Fc=ca(function(t,e){return null==t?{}:si(t,Wn(e,1))}),Wc=Gi(function(t,e,n){return e=e.toLowerCase(),t+(n?Us(e):e)}),Hc=Gi(function(t,e,n){return t+(n?"-":"")+e.toLowerCase()}),Lc=Gi(function(t,e,n){return t+(n?" ":"")+e.toLowerCase()}),zc=Yi("toLowerCase"),jc=Yi("toUpperCase"),Rc=Gi(function(t,e,n){return t+(n?"_":"")+e.toLowerCase()}),Uc=Gi(function(t,e,n){return t+(n?" ":"")+Us(e)}),qc=Gi(function(t,e,n){return t+(n?" ":"")+e.toUpperCase()}),Bc=ca(function(t,e){try{return n(t,Y,e)}catch(i){return Na(i)?i:new Wu(i)}}),Vc=ca(function(t,e){return o(Wn(e,1),function(e){t[e]=fc(t[e],t)}),t}),Yc=Zi(),Gc=Zi(!0),Xc=ca(function(t,e){return function(n){return Gn(n,t,e)}}),Kc=ca(function(t,e){return function(n){return Gn(t,n,e)}}),Zc=tr(d),Qc=tr(s),Jc=tr(g),td=ir(),ed=ir(!0),nd=or("ceil"),id=or("floor"),rd=or("round");return $e.prototype=De.prototype,Se.prototype=Tn(De.prototype),Se.prototype.constructor=Se,Te.prototype=Tn(De.prototype),Te.prototype.constructor=Te,Ne.prototype=_l?_l(null):Ru,He.prototype.clear=Le,He.prototype["delete"]=ze,He.prototype.get=je,He.prototype.has=Re,He.prototype.set=Ue,qe.prototype.push=Ve,Ye.prototype.clear=Ge,Ye.prototype["delete"]=Xe,Ye.prototype.get=Ke,Ye.prototype.has=Ze,Ye.prototype.set=Qe,sa.Cache=He,$e.after=ta,$e.ary=ea,$e.assign=$c,$e.assignIn=kc,$e.assignInWith=Cc,$e.assignWith=Mc,$e.at=Dc,$e.before=na,$e.bind=fc,$e.bindAll=Vc,$e.bindKey=pc,$e.castArray=ga,$e.chain=Co,$e.chunk=Ir,$e.compact=Pr,$e.concat=jl,$e.cond=du,$e.conforms=hu,$e.constant=fu,$e.countBy=ac,$e.create=fs,$e.curry=ia,$e.curryRight=ra,$e.debounce=oa,$e.defaults=Sc,$e.defaultsDeep=Tc,$e.defer=gc,$e.delay=mc,$e.difference=Rl,$e.differenceBy=Ul,$e.differenceWith=ql,$e.drop=Fr,$e.dropRight=Wr,$e.dropRightWhile=Hr,$e.dropWhile=Lr,$e.fill=zr,$e.filter=Wo,$e.flatMap=zo,$e.flatten=Ur,$e.flattenDeep=qr,$e.flattenDepth=Br,$e.flip=aa,$e.flow=Yc,$e.flowRight=Gc,$e.fromPairs=Vr,$e.functions=xs,$e.functionsIn=ws,$e.groupBy=sc,$e.initial=Xr,$e.intersection=Bl,$e.intersectionBy=Vl,$e.intersectionWith=Yl,$e.invert=Ac,$e.invertBy=Ec,$e.invokeMap=uc,$e.iteratee=gu,$e.keyBy=lc,$e.keys=Cs,$e.keysIn=Ms,$e.map=qo,$e.mapKeys=Ds,$e.mapValues=Ss,$e.matches=mu,$e.matchesProperty=vu,$e.memoize=sa,$e.merge=Nc,$e.mergeWith=Ic,$e.method=Xc,$e.methodOf=Kc,$e.mixin=yu,$e.negate=ua,$e.nthArg=wu,$e.omit=Pc,$e.omitBy=Ts,$e.once=la,$e.orderBy=Bo,$e.over=Zc,$e.overArgs=vc,$e.overEvery=Qc,$e.overSome=Jc,$e.partial=yc,$e.partialRight=bc,$e.partition=cc,$e.pick=Fc,$e.pickBy=As,$e.property=_u,$e.propertyOf=$u,$e.pull=Gl,$e.pullAll=Jr,$e.pullAllBy=to,$e.pullAt=Xl,$e.range=td,$e.rangeRight=ed,$e.rearg=xc,$e.reject=Go,$e.remove=eo,$e.rest=ca,$e.reverse=no,$e.sampleSize=Ko,$e.set=Os,$e.setWith=Ns,$e.shuffle=Zo,$e.slice=io,$e.sortBy=dc,$e.sortedUniq=co,$e.sortedUniqBy=ho,$e.split=tu,$e.spread=da,$e.tail=fo,$e.take=po,$e.takeRight=go,$e.takeRightWhile=mo,$e.takeWhile=vo,$e.tap=Mo,$e.throttle=ha,$e.thru=Do,$e.toArray=as,$e.toPairs=Is,$e.toPairsIn=Ps,$e.toPath=Cu,$e.toPlainObject=cs,$e.transform=Fs,$e.unary=fa,$e.union=Kl,$e.unionBy=Zl,$e.unionWith=Ql,$e.uniq=yo,$e.uniqBy=bo,$e.uniqWith=xo,$e.unset=Ws,$e.unzip=wo,$e.unzipWith=_o,$e.values=Hs,$e.valuesIn=Ls,$e.without=Jl,$e.words=cu,$e.wrap=pa,$e.xor=tc,$e.xorBy=ec,$e.xorWith=nc,$e.zip=ic,$e.zipObject=$o,$e.zipObjectDeep=ko,$e.zipWith=rc,$e.extend=kc,$e.extendWith=Cc,yu($e,$e),$e.add=Du,$e.attempt=Bc,$e.camelCase=Wc,$e.capitalize=Us,$e.ceil=nd,$e.clamp=zs,$e.clone=ma,$e.cloneDeep=ya,$e.cloneDeepWith=ba,$e.cloneWith=va,$e.deburr=qs,$e.endsWith=Bs,$e.eq=xa,$e.escape=Vs,$e.escapeRegExp=Ys,$e.every=Fo,$e.find=Ho,$e.findIndex=jr,$e.findKey=ps,$e.findLast=Lo,$e.findLastIndex=Rr,$e.findLastKey=gs,$e.floor=id,$e.forEach=jo,$e.forEachRight=Ro,$e.forIn=ms,$e.forInRight=vs,$e.forOwn=ys,$e.forOwnRight=bs,$e.get=_s,$e.gt=wa,$e.gte=_a,$e.has=$s,$e.hasIn=ks,$e.head=Yr,$e.identity=pu,$e.includes=Uo,$e.indexOf=Gr,$e.inRange=js,$e.invoke=Oc,$e.isArguments=$a,$e.isArray=wc,$e.isArrayBuffer=ka,$e.isArrayLike=Ca,$e.isArrayLikeObject=Ma,$e.isBoolean=Da,$e.isBuffer=_c,$e.isDate=Sa,$e.isElement=Ta,$e.isEmpty=Aa,$e.isEqual=Ea,$e.isEqualWith=Oa,$e.isError=Na,$e.isFinite=Ia,$e.isFunction=Pa,$e.isInteger=Fa,$e.isLength=Wa,$e.isMap=za,$e.isMatch=ja,$e.isMatchWith=Ra,$e.isNaN=Ua,$e.isNative=qa,$e.isNil=Va,$e.isNull=Ba,$e.isNumber=Ya,$e.isObject=Ha,$e.isObjectLike=La,$e.isPlainObject=Ga,$e.isRegExp=Xa,$e.isSafeInteger=Ka,$e.isSet=Za,$e.isString=Qa,$e.isSymbol=Ja,$e.isTypedArray=ts,$e.isUndefined=es,$e.isWeakMap=ns,$e.isWeakSet=is,$e.join=Kr,$e.kebabCase=Hc,$e.last=Zr,$e.lastIndexOf=Qr,$e.lowerCase=Lc,$e.lowerFirst=zc,$e.lt=rs,$e.lte=os,$e.max=Su,$e.maxBy=Tu,$e.mean=Au,$e.min=Eu,$e.minBy=Ou,$e.noConflict=bu,$e.noop=xu,$e.now=hc,$e.pad=Gs,$e.padEnd=Xs,$e.padStart=Ks,$e.parseInt=Zs,$e.random=Rs,$e.reduce=Vo,$e.reduceRight=Yo,$e.repeat=Qs,$e.replace=Js,$e.result=Es,$e.round=rd,$e.runInContext=V,$e.sample=Xo,$e.size=Qo,$e.snakeCase=Rc,$e.some=Jo,$e.sortedIndex=ro,$e.sortedIndexBy=oo,$e.sortedIndexOf=ao,$e.sortedLastIndex=so,$e.sortedLastIndexBy=uo,$e.sortedLastIndexOf=lo,$e.startCase=Uc,$e.startsWith=eu,$e.subtract=Nu,$e.sum=Iu,$e.sumBy=Pu,$e.template=nu,$e.times=ku,$e.toInteger=ss,$e.toLength=us,$e.toLower=iu,$e.toNumber=ls,$e.toSafeInteger=ds,$e.toString=hs,$e.toUpper=ru,$e.trim=ou,$e.trimEnd=au,$e.trimStart=su,$e.truncate=uu,$e.unescape=lu,$e.uniqueId=Mu,$e.upperCase=qc,$e.upperFirst=jc,$e.each=jo,$e.eachRight=Ro,$e.first=Yr,yu($e,function(){var t={};return Ln($e,function(e,n){qu.call($e.prototype,n)||(t[n]=e)}),t}(),{chain:!1}),$e.VERSION=G,o(["bind","bindKey","curry","curryRight","partial","partialRight"],function(t){$e[t].placeholder=$e}),o(["drop","take"],function(t,e){Te.prototype[t]=function(n){var i=this.__filtered__;if(i&&!e)return new Te(this);n=n===Y?1:pl(ss(n),0);var r=this.clone();return i?r.__takeCount__=gl(n,r.__takeCount__):r.__views__.push({size:gl(n,wt),type:t+(r.__dir__<0?"Right":"")}),r},Te.prototype[t+"Right"]=function(e){return this.reverse()[t](e).reverse()}}),o(["filter","map","takeWhile"],function(t,e){var n=e+1,i=n==ht||n==pt;Te.prototype[t]=function(t){var e=this.clone();return e.__iteratees__.push({iteratee:dr(t,3),type:n}),e.__filtered__=e.__filtered__||i,e}}),o(["head","last"],function(t,e){var n="take"+(e?"Right":"");Te.prototype[t]=function(){return this[n](1).value()[0]}}),o(["initial","tail"],function(t,e){var n="drop"+(e?"":"Right");Te.prototype[t]=function(){return this.__filtered__?new Te(this):this[n](1)}}),Te.prototype.compact=function(){return this.filter(pu)},Te.prototype.find=function(t){return this.filter(t).head()},Te.prototype.findLast=function(t){return this.reverse().find(t)},Te.prototype.invokeMap=ca(function(t,e){return"function"==typeof t?new Te(this):this.map(function(n){return Gn(n,t,e)})}),Te.prototype.reject=function(t){return t=dr(t,3),this.filter(function(e){return!t(e)})},Te.prototype.slice=function(t,e){t=ss(t);var n=this;return n.__filtered__&&(t>0||0>e)?new Te(n):(0>t?n=n.takeRight(-t):t&&(n=n.drop(t)),e!==Y&&(e=ss(e),n=0>e?n.dropRight(-e):n.take(e-t)),n)},Te.prototype.takeRightWhile=function(t){return this.reverse().takeWhile(t).reverse()},Te.prototype.toArray=function(){return this.take(wt)},Ln(Te.prototype,function(t,e){var n=/^(?:filter|find|map|reject)|While$/.test(e),i=/^(?:head|last)$/.test(e),r=$e[i?"take"+("last"==e?"Right":""):e],o=i||/^find/.test(e);r&&($e.prototype[e]=function(){var e=this.__wrapped__,a=i?[1]:arguments,s=e instanceof Te,u=a[0],l=s||wc(e),c=function(t){var e=r.apply($e,h([t],a));return i&&d?e[0]:e};l&&n&&"function"==typeof u&&1!=u.length&&(s=l=!1);var d=this.__chain__,f=!!this.__actions__.length,p=o&&!d,g=s&&!f;if(!o&&l){e=g?e:new Te(this);var m=t.apply(e,a);return m.__actions__.push({func:Do,args:[c],thisArg:Y}),new Se(m,d)}return p&&g?t.apply(this,a):(m=this.thru(c),p?i?m.value()[0]:m.value():m)})}),o(["pop","push","shift","sort","splice","unshift"],function(t){var e=ju[t],n=/^(?:push|sort|unshift)$/.test(t)?"tap":"thru",i=/^(?:pop|shift)$/.test(t);$e.prototype[t]=function(){var t=arguments;return i&&!this.__chain__?e.apply(this.value(),t):this[n](function(n){return e.apply(n,t)})}}),Ln(Te.prototype,function(t,e){var n=$e[e];if(n){var i=n.name+"",r=Al[i]||(Al[i]=[]);r.push({name:e,func:n})}}),Al[Qi(Y,K).name]=[{name:"wrapper",func:Y}],Te.prototype.clone=Ae,Te.prototype.reverse=Ee,Te.prototype.value=Oe,$e.prototype.at=oc,$e.prototype.chain=So,$e.prototype.commit=To,$e.prototype.flatMap=Ao,$e.prototype.next=Eo,$e.prototype.plant=No,$e.prototype.reverse=Io,$e.prototype.toJSON=$e.prototype.valueOf=$e.prototype.value=Po,rl&&($e.prototype[rl]=Oo),$e}var Y,G="4.5.1",X=1,K=2,Z=4,Q=8,J=16,tt=32,et=64,nt=128,it=256,rt=512,ot=1,at=2,st=30,ut="...",lt=150,ct=16,dt=200,ht=1,ft=2,pt=3,gt="Expected a function",mt="__lodash_hash_undefined__",vt=1/0,yt=9007199254740991,bt=1.7976931348623157e308,xt=NaN,wt=4294967295,_t=wt-1,$t=wt>>>1,kt="__lodash_placeholder__",Ct="[object Arguments]",Mt="[object Array]",Dt="[object Boolean]",St="[object Date]",Tt="[object Error]",At="[object Function]",Et="[object GeneratorFunction]",Ot="[object Map]",Nt="[object Number]",It="[object Object]",Pt="[object RegExp]",Ft="[object Set]",Wt="[object String]",Ht="[object Symbol]",Lt="[object WeakMap]",zt="[object WeakSet]",jt="[object ArrayBuffer]",Rt="[object Float32Array]",Ut="[object Float64Array]",qt="[object Int8Array]",Bt="[object Int16Array]",Vt="[object Int32Array]",Yt="[object Uint8Array]",Gt="[object Uint8ClampedArray]",Xt="[object Uint16Array]",Kt="[object Uint32Array]",Zt=/\b__p \+= '';/g,Qt=/\b(__p \+=) '' \+/g,Jt=/(__e\(.*?\)|\b__t\)) \+\n'';/g,te=/&(?:amp|lt|gt|quot|#39|#96);/g,ee=/[&<>"'`]/g,ne=RegExp(te.source),ie=RegExp(ee.source),re=/<%-([\s\S]+?)%>/g,oe=/<%([\s\S]+?)%>/g,ae=/<%=([\s\S]+?)%>/g,se=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,ue=/^\w*$/,le=/[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]/g,ce=/[\\^$.*+?()[\]{}|]/g,de=RegExp(ce.source),he=/^\s+|\s+$/g,fe=/^\s+/,pe=/\s+$/,ge=/\\(\\)?/g,me=/\$\{([^\\}]*(?:\\.[^\\}]*)*)\}/g,ve=/\w*$/,ye=/^0x/i,be=/^[-+]0x[0-9a-f]+$/i,xe=/^0b[01]+$/i,we=/^\[object .+?Constructor\]$/,_e=/^0o[0-7]+$/i,$e=/^(?:0|[1-9]\d*)$/,ke=/[\xc0-\xd6\xd8-\xde\xdf-\xf6\xf8-\xff]/g,Ce=/($^)/,Me=/['\n\r\u2028\u2029\\]/g,De="\\ud800-\\udfff",Se="\\u0300-\\u036f\\ufe20-\\ufe23",Te="\\u20d0-\\u20f0",Ae="\\u2700-\\u27bf",Ee="a-z\\xdf-\\xf6\\xf8-\\xff",Oe="\\xac\\xb1\\xd7\\xf7",Ne="\\x00-\\x2f\\x3a-\\x40\\x5b-\\x60\\x7b-\\xbf",Ie="\\u2018\\u2019\\u201c\\u201d",Pe=" \\t\\x0b\\f\\xa0\\ufeff\\n\\r\\u2028\\u2029\\u1680\\u180e\\u2000\\u2001\\u2002\\u2003\\u2004\\u2005\\u2006\\u2007\\u2008\\u2009\\u200a\\u202f\\u205f\\u3000",Fe="A-Z\\xc0-\\xd6\\xd8-\\xde",We="\\ufe0e\\ufe0f",He=Oe+Ne+Ie+Pe,Le="["+De+"]",ze="["+He+"]",je="["+Se+Te+"]",Re="\\d+",Ue="["+Ae+"]",qe="["+Ee+"]",Be="[^"+De+He+Re+Ae+Ee+Fe+"]",Ve="\\ud83c[\\udffb-\\udfff]",Ye="(?:"+je+"|"+Ve+")",Ge="[^"+De+"]",Xe="(?:\\ud83c[\\udde6-\\uddff]){2}",Ke="[\\ud800-\\udbff][\\udc00-\\udfff]",Ze="["+Fe+"]",Qe="\\u200d",Je="(?:"+qe+"|"+Be+")",tn="(?:"+Ze+"|"+Be+")",en=Ye+"?",nn="["+We+"]?",rn="(?:"+Qe+"(?:"+[Ge,Xe,Ke].join("|")+")"+nn+en+")*",on=nn+en+rn,an="(?:"+[Ue,Xe,Ke].join("|")+")"+on,sn="(?:"+[Ge+je+"?",je,Xe,Ke,Le].join("|")+")",un=RegExp(je,"g"),ln=RegExp(Ve+"(?="+Ve+")|"+sn+on,"g"),cn=RegExp("["+Qe+De+Se+Te+We+"]"),dn=/[a-zA-Z0-9]+/g,hn=RegExp([Ze+"?"+qe+"+(?="+[ze,Ze,"$"].join("|")+")",tn+"+(?="+[ze,Ze+Je,"$"].join("|")+")",Ze+"?"+Je+"+",Ze+"+",Re,an].join("|"),"g"),fn=/[a-z][A-Z]|[0-9][a-zA-Z]|[a-zA-Z][0-9]|[^a-zA-Z0-9 ]/,pn=["Array","Buffer","Date","Error","Float32Array","Float64Array","Function","Int8Array","Int16Array","Int32Array","Map","Math","Object","Reflect","RegExp","Set","String","Symbol","TypeError","Uint8Array","Uint8ClampedArray","Uint16Array","Uint32Array","WeakMap","_","clearTimeout","isFinite","parseInt","setTimeout"],gn=-1,mn={};mn[Rt]=mn[Ut]=mn[qt]=mn[Bt]=mn[Vt]=mn[Yt]=mn[Gt]=mn[Xt]=mn[Kt]=!0,mn[Ct]=mn[Mt]=mn[jt]=mn[Dt]=mn[St]=mn[Tt]=mn[At]=mn[Ot]=mn[Nt]=mn[It]=mn[Pt]=mn[Ft]=mn[Wt]=mn[Lt]=!1;var vn={};vn[Ct]=vn[Mt]=vn[jt]=vn[Dt]=vn[St]=vn[Rt]=vn[Ut]=vn[qt]=vn[Bt]=vn[Vt]=vn[Ot]=vn[Nt]=vn[It]=vn[Pt]=vn[Ft]=vn[Wt]=vn[Ht]=vn[Yt]=vn[Gt]=vn[Xt]=vn[Kt]=!0,vn[Tt]=vn[At]=vn[Lt]=!1;var yn={"À":"A","Á":"A","Â":"A","Ã":"A","Ä":"A","Å":"A","à":"a","á":"a","â":"a","ã":"a","ä":"a","å":"a","Ç":"C","ç":"c","Ð":"D","ð":"d","È":"E","É":"E","Ê":"E","Ë":"E","è":"e","é":"e","ê":"e","ë":"e","Ì":"I","Í":"I","Î":"I","Ï":"I","ì":"i","í":"i","î":"i","ï":"i","Ñ":"N","ñ":"n","Ò":"O","Ó":"O","Ô":"O","Õ":"O","Ö":"O","Ø":"O","ò":"o","ó":"o","ô":"o","õ":"o","ö":"o","ø":"o","Ù":"U","Ú":"U","Û":"U","Ü":"U","ù":"u","ú":"u","û":"u","ü":"u","Ý":"Y","ý":"y","ÿ":"y","Æ":"Ae","æ":"ae","Þ":"Th","þ":"th","ß":"ss"},bn={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","`":"&#96;"},xn={"&amp;":"&","&lt;":"<","&gt;":">","&quot;":'"',"&#39;":"'","&#96;":"`"},wn={"function":!0,object:!0},_n={"\\":"\\","'":"'","\n":"n","\r":"r","\u2028":"u2028","\u2029":"u2029"},$n=parseFloat,kn=parseInt,Cn=wn[typeof exports]&&exports&&!exports.nodeType?exports:Y,Mn=wn[typeof module]&&module&&!module.nodeType?module:Y,Dn=Mn&&Mn.exports===Cn?Cn:Y,Sn=T(Cn&&Mn&&"object"==typeof global&&global),Tn=T(wn[typeof self]&&self),An=T(wn[typeof window]&&window),En=T(wn[typeof this]&&this),On=Sn||An!==(En&&En.window)&&An||Tn||En||Function("return this")(),Nn=V();(An||Tn||{})._=Nn,"function"==typeof define&&"object"==typeof define.amd&&define.amd?define(function(){return Nn}):Cn&&Mn?(Dn&&((Mn.exports=Nn)._=Nn),Cn._=Nn):On._=Nn}.call(this),function(){"use strict";function t(t,e,n,i,r,o,a){function s(t){if(1!==arguments.length||t)if(t)h(t.toastId);else for(var e=0;e<b.length;e++)h(b[e].toastId)}function u(t,e,n){var i=p().iconClasses.error;return f(i,t,e,n)}function l(t,e,n){var i=p().iconClasses.info;return f(i,t,e,n)}function c(t,e,n){var i=p().iconClasses.success;return f(i,t,e,n)}function d(t,e,n){var i=p().iconClasses.warning;return f(i,t,e,n)}function h(e,n){function i(t){for(var e=0;e<b.length;e++)if(b[e].toastId===t)return b[e]}function r(){return!b.length}var s=i(e);s&&!s.deleting&&(s.deleting=!0,s.isOpened=!1,t.leave(s.el).then(function(){s.scope.options.onHidden&&s.scope.options.onHidden(n),s.scope.$destroy();var t=b.indexOf(s);delete w[s.scope.message],b.splice(t,1);var e=o.maxOpened;e&&b.length>=e&&b[e-1].open.resolve(),r()&&(v.remove(),v=null,_=a.defer())}))}function f(t,e,n,i){return angular.isObject(n)&&(i=n,n=null),m({iconClass:t,message:e,optionsOverride:i,title:n})}function p(){return angular.extend({},o)}function g(e){if(v)return _.promise;v=angular.element("<div></div>"),v.attr("id",e.containerId),v.addClass(e.positionClass),v.css({"pointer-events":"auto"});var n=angular.element(document.querySelector(e.target));if(!n||!n.length)throw"Target for toasts doesn't exist";return t.enter(v,n).then(function(){_.resolve()}),_.promise}function m(n){function o(){return f.autoDismiss&&f.maxOpened&&b.length>f.maxOpened}function s(t,e,n){n.allowHtml?(t.scope.allowHtml=!0,t.scope.title=r.trustAsHtml(e.title),t.scope.message=r.trustAsHtml(e.message)):(t.scope.title=e.title,t.scope.message=e.message),t.scope.toastType=t.iconClass,t.scope.toastId=t.toastId,t.scope.extraData=n.extraData,t.scope.options={extendedTimeOut:n.extendedTimeOut,messageClass:n.messageClass,onHidden:n.onHidden,onShown:n.onShown,onTap:n.onTap,progressBar:n.progressBar,tapToDismiss:n.tapToDismiss,timeOut:n.timeOut,titleClass:n.titleClass,toastClass:n.toastClass},n.closeButton&&(t.scope.options.closeHtml=n.closeHtml)}function u(){function t(t){for(var e=["containerId","iconClasses","maxOpened","newestOnTop","positionClass","preventDuplicates","preventOpenDuplicates","templates"],n=0,i=e.length;i>n;n++)delete t[e[n]];return t}var e={toastId:y++,isOpened:!1,scope:i.$new(),open:a.defer()};return e.iconClass=n.iconClass,n.optionsOverride&&(angular.extend(f,t(n.optionsOverride)),e.iconClass=n.optionsOverride.iconClass||e.iconClass),s(e,n,f),e.el=l(e.scope),e}function l(t){var n=angular.element("<div toast></div>"),i=e.get("$compile");return i(n)(t)}function c(){return f.maxOpened&&b.length<=f.maxOpened||!f.maxOpened}function d(){var t=f.preventDuplicates&&n.message===x,e=f.preventOpenDuplicates&&w[n.message];return t||e?!0:(x=n.message,w[n.message]=!0,!1)}var f=p();if(!d()){var m=u();if(b.push(m),o())for(var _=b.slice(0,b.length-f.maxOpened),$=0,k=_.length;k>$;$++)h(_[$].toastId);return c()&&m.open.resolve(),m.open.promise.then(function(){g(f).then(function(){if(m.isOpened=!0,f.newestOnTop)t.enter(m.el,v).then(function(){m.scope.init()});else{var e=v[0].lastChild?angular.element(v[0].lastChild):null;t.enter(m.el,v,e).then(function(){m.scope.init()})}})}),m}}var v,y=0,b=[],x="",w={},_=a.defer(),$={clear:s,error:u,info:l,remove:h,success:c,warning:d};return $}angular.module("toastr",[]).factory("toastr",t),t.$inject=["$animate","$injector","$document","$rootScope","$sce","toastrConfig","$q"]}(),function(){"use strict";angular.module("toastr").constant("toastrConfig",{allowHtml:!1,autoDismiss:!1,closeButton:!1,closeHtml:"<button>&times;</button>",containerId:"toast-container",extendedTimeOut:1e3,iconClasses:{error:"toast-error",info:"toast-info",success:"toast-success",warning:"toast-warning"},maxOpened:0,messageClass:"toast-message",newestOnTop:!0,onHidden:null,onShown:null,onTap:null,positionClass:"toast-top-right",preventDuplicates:!1,preventOpenDuplicates:!1,progressBar:!1,tapToDismiss:!0,target:"body",templates:{toast:"directives/toast/toast.html",progressbar:"directives/progressbar/progressbar.html"},timeOut:5e3,titleClass:"toast-title",toastClass:"toast"})}(),function(){"use strict";function t(t){function e(t,e,n,i){function r(){var t=(s-(new Date).getTime())/a*100;e.css("width",t+"%")}var o,a,s;i.progressBar=t,t.start=function(t){o&&clearInterval(o),a=parseFloat(t),s=(new Date).getTime()+a,o=setInterval(r,10)},t.stop=function(){o&&clearInterval(o)},t.$on("$destroy",function(){clearInterval(o)})}return{replace:!0,require:"^toast",templateUrl:function(){return t.templates.progressbar},link:e}}angular.module("toastr").directive("progressBar",t),t.$inject=["toastrConfig"]}(),function(){"use strict";function t(){this.progressBar=null,this.startProgressBar=function(t){this.progressBar&&this.progressBar.start(t)},this.stopProgressBar=function(){this.progressBar&&this.progressBar.stop()}}angular.module("toastr").controller("ToastController",t)}(),function(){"use strict";function t(t,e,n,i){function r(n,r,o,a){function s(t){return a.startProgressBar(t),e(function(){a.stopProgressBar(),i.remove(n.toastId)},t,1)}function u(){n.progressBar=!1,a.stopProgressBar()}function l(){return n.options.closeHtml}var c;if(n.toastClass=n.options.toastClass,n.titleClass=n.options.titleClass,n.messageClass=n.options.messageClass,n.progressBar=n.options.progressBar,l()){var d=angular.element(n.options.closeHtml),h=t.get("$compile");d.addClass("toast-close-button"),d.attr("ng-click","close(true, $event)"),h(d)(n),r.prepend(d)}n.init=function(){n.options.timeOut&&(c=s(n.options.timeOut)),n.options.onShown&&n.options.onShown()},r.on("mouseenter",function(){u(),c&&e.cancel(c)}),n.tapToast=function(){angular.isFunction(n.options.onTap)&&n.options.onTap(),n.options.tapToDismiss&&n.close(!0)},n.close=function(t,e){e&&angular.isFunction(e.stopPropagation)&&e.stopPropagation(),i.remove(n.toastId,t)},r.on("mouseleave",function(){(0!==n.options.timeOut||0!==n.options.extendedTimeOut)&&(n.$apply(function(){n.progressBar=n.options.progressBar}),c=s(n.options.extendedTimeOut))})}return{replace:!0,templateUrl:function(){return n.templates.toast},controller:"ToastController",link:r}}angular.module("toastr").directive("toast",t),t.$inject=["$injector","$interval","toastrConfig","toastr"]}(),angular.module("toastr").run(["$templateCache",function(t){t.put("directives/progressbar/progressbar.html",'<div class="toast-progress"></div>\n'),t.put("directives/toast/toast.html",'<div class="{{toastClass}} {{toastType}}" ng-click="tapToast()">\n  <div ng-switch on="allowHtml">\n    <div ng-switch-default ng-if="title" class="{{titleClass}}" aria-label="{{title}}">{{title}}</div>\n    <div ng-switch-default class="{{messageClass}}" aria-label="{{message}}">{{message}}</div>\n    <div ng-switch-when="true" ng-if="title" class="{{titleClass}}" ng-bind-html="title"></div>\n    <div ng-switch-when="true" class="{{messageClass}}" ng-bind-html="message"></div>\n  </div>\n  <progress-bar ng-if="progressBar"></progress-bar>\n</div>\n')}]),
//! license : MIT
//! momentjs.com
function(t,e){"object"==typeof exports&&"undefined"!=typeof module?module.exports=e():"function"==typeof define&&define.amd?define(e):t.moment=e()}(this,function(){"use strict";function t(){return In.apply(null,arguments)}function e(t){In=t}function n(t){return"[object Array]"===Object.prototype.toString.call(t)}function i(t){return t instanceof Date||"[object Date]"===Object.prototype.toString.call(t)}function r(t,e){var n,i=[];for(n=0;n<t.length;++n)i.push(e(t[n],n));return i}function o(t,e){return Object.prototype.hasOwnProperty.call(t,e)}function a(t,e){for(var n in e)o(e,n)&&(t[n]=e[n]);return o(e,"toString")&&(t.toString=e.toString),o(e,"valueOf")&&(t.valueOf=e.valueOf),t}function s(t,e,n,i){return St(t,e,n,i,!0).utc()}function u(){return{empty:!1,unusedTokens:[],unusedInput:[],overflow:-2,charsLeftOver:0,nullInput:!1,invalidMonth:null,invalidFormat:!1,userInvalidated:!1,iso:!1}}function l(t){return null==t._pf&&(t._pf=u()),t._pf}function c(t){if(null==t._isValid){var e=l(t);t._isValid=!(isNaN(t._d.getTime())||!(e.overflow<0)||e.empty||e.invalidMonth||e.invalidWeekday||e.nullInput||e.invalidFormat||e.userInvalidated),t._strict&&(t._isValid=t._isValid&&0===e.charsLeftOver&&0===e.unusedTokens.length&&void 0===e.bigHour)}return t._isValid}function d(t){var e=s(NaN);return null!=t?a(l(e),t):l(e).userInvalidated=!0,e}function h(t,e){var n,i,r;if("undefined"!=typeof e._isAMomentObject&&(t._isAMomentObject=e._isAMomentObject),"undefined"!=typeof e._i&&(t._i=e._i),"undefined"!=typeof e._f&&(t._f=e._f),"undefined"!=typeof e._l&&(t._l=e._l),"undefined"!=typeof e._strict&&(t._strict=e._strict),"undefined"!=typeof e._tzm&&(t._tzm=e._tzm),"undefined"!=typeof e._isUTC&&(t._isUTC=e._isUTC),"undefined"!=typeof e._offset&&(t._offset=e._offset),"undefined"!=typeof e._pf&&(t._pf=l(e)),"undefined"!=typeof e._locale&&(t._locale=e._locale),Fn.length>0)for(n in Fn)i=Fn[n],r=e[i],"undefined"!=typeof r&&(t[i]=r);return t}function f(e){h(this,e),this._d=new Date(null!=e._d?e._d.getTime():NaN),Wn===!1&&(Wn=!0,t.updateOffset(this),Wn=!1)}function p(t){return t instanceof f||null!=t&&null!=t._isAMomentObject}function g(t){return 0>t?Math.ceil(t):Math.floor(t)}function m(t){var e=+t,n=0;return 0!==e&&isFinite(e)&&(n=g(e)),n}function v(t,e,n){var i,r=Math.min(t.length,e.length),o=Math.abs(t.length-e.length),a=0;for(i=0;r>i;i++)(n&&t[i]!==e[i]||!n&&m(t[i])!==m(e[i]))&&a++;return a+o}function y(){}function b(t){return t?t.toLowerCase().replace("_","-"):t}function x(t){for(var e,n,i,r,o=0;o<t.length;){for(r=b(t[o]).split("-"),e=r.length,n=b(t[o+1]),n=n?n.split("-"):null;e>0;){if(i=w(r.slice(0,e).join("-")))return i;if(n&&n.length>=e&&v(r,n,!0)>=e-1)break;e--}o++}return null}function w(t){var e=null;if(!Hn[t]&&"undefined"!=typeof module&&module&&module.exports)try{e=Pn._abbr,require("./locale/"+t),_(e)}catch(n){}return Hn[t]}function _(t,e){var n;return t&&(n="undefined"==typeof e?k(t):$(t,e),n&&(Pn=n)),Pn._abbr}function $(t,e){return null!==e?(e.abbr=t,Hn[t]=Hn[t]||new y,Hn[t].set(e),_(t),Hn[t]):(delete Hn[t],null)}function k(t){var e;if(t&&t._locale&&t._locale._abbr&&(t=t._locale._abbr),!t)return Pn;if(!n(t)){if(e=w(t))return e;t=[t]}return x(t)}function C(t,e){var n=t.toLowerCase();Ln[n]=Ln[n+"s"]=Ln[e]=t}function M(t){return"string"==typeof t?Ln[t]||Ln[t.toLowerCase()]:void 0}function D(t){var e,n,i={};for(n in t)o(t,n)&&(e=M(n),e&&(i[e]=t[n]));return i}function S(e,n){return function(i){return null!=i?(A(this,e,i),t.updateOffset(this,n),this):T(this,e)}}function T(t,e){return t._d["get"+(t._isUTC?"UTC":"")+e]()}function A(t,e,n){return t._d["set"+(t._isUTC?"UTC":"")+e](n)}function E(t,e){var n;if("object"==typeof t)for(n in t)this.set(n,t[n]);else if(t=M(t),"function"==typeof this[t])return this[t](e);return this}function O(t,e,n){var i=""+Math.abs(t),r=e-i.length,o=t>=0;return(o?n?"+":"":"-")+Math.pow(10,Math.max(0,r)).toString().substr(1)+i}function N(t,e,n,i){var r=i;"string"==typeof i&&(r=function(){return this[i]()}),t&&(Un[t]=r),e&&(Un[e[0]]=function(){return O(r.apply(this,arguments),e[1],e[2])}),n&&(Un[n]=function(){return this.localeData().ordinal(r.apply(this,arguments),t)})}function I(t){return t.match(/\[[\s\S]/)?t.replace(/^\[|\]$/g,""):t.replace(/\\/g,"")}function P(t){var e,n,i=t.match(zn);for(e=0,n=i.length;n>e;e++)Un[i[e]]?i[e]=Un[i[e]]:i[e]=I(i[e]);return function(r){var o="";for(e=0;n>e;e++)o+=i[e]instanceof Function?i[e].call(r,t):i[e];return o}}function F(t,e){return t.isValid()?(e=W(e,t.localeData()),Rn[e]=Rn[e]||P(e),Rn[e](t)):t.localeData().invalidDate()}function W(t,e){function n(t){return e.longDateFormat(t)||t}var i=5;for(jn.lastIndex=0;i>=0&&jn.test(t);)t=t.replace(jn,n),jn.lastIndex=0,i-=1;return t}function H(t){return"function"==typeof t&&"[object Function]"===Object.prototype.toString.call(t)}function L(t,e,n){ri[t]=H(e)?e:function(t){return t&&n?n:e}}function z(t,e){return o(ri,t)?ri[t](e._strict,e._locale):new RegExp(j(t))}function j(t){return t.replace("\\","").replace(/\\(\[)|\\(\])|\[([^\]\[]*)\]|\\(.)/g,function(t,e,n,i,r){return e||n||i||r}).replace(/[-\/\\^$*+?.()|[\]{}]/g,"\\$&")}function R(t,e){var n,i=e;for("string"==typeof t&&(t=[t]),"number"==typeof e&&(i=function(t,n){n[e]=m(t)}),n=0;n<t.length;n++)oi[t[n]]=i}function U(t,e){R(t,function(t,n,i,r){i._w=i._w||{},e(t,i._w,i,r)})}function q(t,e,n){null!=e&&o(oi,t)&&oi[t](e,n._a,n,t)}function B(t,e){return new Date(Date.UTC(t,e+1,0)).getUTCDate()}function V(t){return this._months[t.month()]}function Y(t){return this._monthsShort[t.month()]}function G(t,e,n){var i,r,o;for(this._monthsParse||(this._monthsParse=[],this._longMonthsParse=[],this._shortMonthsParse=[]),i=0;12>i;i++){if(r=s([2e3,i]),n&&!this._longMonthsParse[i]&&(this._longMonthsParse[i]=new RegExp("^"+this.months(r,"").replace(".","")+"$","i"),this._shortMonthsParse[i]=new RegExp("^"+this.monthsShort(r,"").replace(".","")+"$","i")),n||this._monthsParse[i]||(o="^"+this.months(r,"")+"|^"+this.monthsShort(r,""),this._monthsParse[i]=new RegExp(o.replace(".",""),"i")),n&&"MMMM"===e&&this._longMonthsParse[i].test(t))return i;if(n&&"MMM"===e&&this._shortMonthsParse[i].test(t))return i;if(!n&&this._monthsParse[i].test(t))return i}}function X(t,e){var n;return"string"==typeof e&&(e=t.localeData().monthsParse(e),"number"!=typeof e)?t:(n=Math.min(t.date(),B(t.year(),e)),t._d["set"+(t._isUTC?"UTC":"")+"Month"](e,n),t)}function K(e){return null!=e?(X(this,e),t.updateOffset(this,!0),this):T(this,"Month")}function Z(){return B(this.year(),this.month())}function Q(t){var e,n=t._a;return n&&-2===l(t).overflow&&(e=n[si]<0||n[si]>11?si:n[ui]<1||n[ui]>B(n[ai],n[si])?ui:n[li]<0||n[li]>24||24===n[li]&&(0!==n[ci]||0!==n[di]||0!==n[hi])?li:n[ci]<0||n[ci]>59?ci:n[di]<0||n[di]>59?di:n[hi]<0||n[hi]>999?hi:-1,l(t)._overflowDayOfYear&&(ai>e||e>ui)&&(e=ui),l(t).overflow=e),t}function J(e){t.suppressDeprecationWarnings===!1&&"undefined"!=typeof console&&console.warn&&console.warn("Deprecation warning: "+e)}function tt(t,e){var n=!0;return a(function(){return n&&(J(t+"\n"+(new Error).stack),n=!1),e.apply(this,arguments)},e)}function et(t,e){gi[t]||(J(e),gi[t]=!0)}function nt(t){var e,n,i=t._i,r=mi.exec(i);if(r){for(l(t).iso=!0,e=0,n=vi.length;n>e;e++)if(vi[e][1].exec(i)){t._f=vi[e][0];break}for(e=0,n=yi.length;n>e;e++)if(yi[e][1].exec(i)){t._f+=(r[6]||" ")+yi[e][0];break}i.match(ei)&&(t._f+="Z"),wt(t)}else t._isValid=!1}function it(e){var n=bi.exec(e._i);return null!==n?void(e._d=new Date(+n[1])):(nt(e),void(e._isValid===!1&&(delete e._isValid,t.createFromInputFallback(e))))}function rt(t,e,n,i,r,o,a){var s=new Date(t,e,n,i,r,o,a);return 1970>t&&s.setFullYear(t),s}function ot(t){var e=new Date(Date.UTC.apply(null,arguments));return 1970>t&&e.setUTCFullYear(t),e}function at(t){return st(t)?366:365}function st(t){return t%4===0&&t%100!==0||t%400===0}function ut(){return st(this.year())}function lt(t,e,n){var i,r=n-e,o=n-t.day();return o>r&&(o-=7),r-7>o&&(o+=7),i=Tt(t).add(o,"d"),{week:Math.ceil(i.dayOfYear()/7),year:i.year()}}function ct(t){return lt(t,this._week.dow,this._week.doy).week}function dt(){return this._week.dow}function ht(){return this._week.doy}function ft(t){var e=this.localeData().week(this);return null==t?e:this.add(7*(t-e),"d")}function pt(t){var e=lt(this,1,4).week;return null==t?e:this.add(7*(t-e),"d")}function gt(t,e,n,i,r){var o,a=6+r-i,s=ot(t,0,1+a),u=s.getUTCDay();return r>u&&(u+=7),n=null!=n?1*n:r,o=1+a+7*(e-1)-u+n,{year:o>0?t:t-1,dayOfYear:o>0?o:at(t-1)+o}}function mt(t){var e=Math.round((this.clone().startOf("day")-this.clone().startOf("year"))/864e5)+1;return null==t?e:this.add(t-e,"d")}function vt(t,e,n){return null!=t?t:null!=e?e:n}function yt(t){var e=new Date;return t._useUTC?[e.getUTCFullYear(),e.getUTCMonth(),e.getUTCDate()]:[e.getFullYear(),e.getMonth(),e.getDate()]}function bt(t){var e,n,i,r,o=[];if(!t._d){for(i=yt(t),t._w&&null==t._a[ui]&&null==t._a[si]&&xt(t),t._dayOfYear&&(r=vt(t._a[ai],i[ai]),t._dayOfYear>at(r)&&(l(t)._overflowDayOfYear=!0),n=ot(r,0,t._dayOfYear),t._a[si]=n.getUTCMonth(),t._a[ui]=n.getUTCDate()),e=0;3>e&&null==t._a[e];++e)t._a[e]=o[e]=i[e];for(;7>e;e++)t._a[e]=o[e]=null==t._a[e]?2===e?1:0:t._a[e];24===t._a[li]&&0===t._a[ci]&&0===t._a[di]&&0===t._a[hi]&&(t._nextDay=!0,t._a[li]=0),t._d=(t._useUTC?ot:rt).apply(null,o),null!=t._tzm&&t._d.setUTCMinutes(t._d.getUTCMinutes()-t._tzm),t._nextDay&&(t._a[li]=24)}}function xt(t){var e,n,i,r,o,a,s;e=t._w,null!=e.GG||null!=e.W||null!=e.E?(o=1,a=4,n=vt(e.GG,t._a[ai],lt(Tt(),1,4).year),i=vt(e.W,1),r=vt(e.E,1)):(o=t._locale._week.dow,a=t._locale._week.doy,n=vt(e.gg,t._a[ai],lt(Tt(),o,a).year),i=vt(e.w,1),null!=e.d?(r=e.d,o>r&&++i):r=null!=e.e?e.e+o:o),s=gt(n,i,r,a,o),t._a[ai]=s.year,t._dayOfYear=s.dayOfYear}function wt(e){if(e._f===t.ISO_8601)return void nt(e);e._a=[],l(e).empty=!0;var n,i,r,o,a,s=""+e._i,u=s.length,c=0;for(r=W(e._f,e._locale).match(zn)||[],n=0;n<r.length;n++)o=r[n],i=(s.match(z(o,e))||[])[0],i&&(a=s.substr(0,s.indexOf(i)),a.length>0&&l(e).unusedInput.push(a),s=s.slice(s.indexOf(i)+i.length),c+=i.length),Un[o]?(i?l(e).empty=!1:l(e).unusedTokens.push(o),q(o,i,e)):e._strict&&!i&&l(e).unusedTokens.push(o);l(e).charsLeftOver=u-c,s.length>0&&l(e).unusedInput.push(s),l(e).bigHour===!0&&e._a[li]<=12&&e._a[li]>0&&(l(e).bigHour=void 0),e._a[li]=_t(e._locale,e._a[li],e._meridiem),bt(e),Q(e)}function _t(t,e,n){var i;return null==n?e:null!=t.meridiemHour?t.meridiemHour(e,n):null!=t.isPM?(i=t.isPM(n),i&&12>e&&(e+=12),i||12!==e||(e=0),e):e}function $t(t){var e,n,i,r,o;if(0===t._f.length)return l(t).invalidFormat=!0,void(t._d=new Date(NaN));for(r=0;r<t._f.length;r++)o=0,e=h({},t),null!=t._useUTC&&(e._useUTC=t._useUTC),e._f=t._f[r],wt(e),c(e)&&(o+=l(e).charsLeftOver,o+=10*l(e).unusedTokens.length,l(e).score=o,(null==i||i>o)&&(i=o,n=e));a(t,n||e)}function kt(t){if(!t._d){var e=D(t._i);t._a=[e.year,e.month,e.day||e.date,e.hour,e.minute,e.second,e.millisecond],bt(t)}}function Ct(t){var e=new f(Q(Mt(t)));return e._nextDay&&(e.add(1,"d"),e._nextDay=void 0),e}function Mt(t){var e=t._i,r=t._f;return t._locale=t._locale||k(t._l),null===e||void 0===r&&""===e?d({nullInput:!0}):("string"==typeof e&&(t._i=e=t._locale.preparse(e)),p(e)?new f(Q(e)):(n(r)?$t(t):r?wt(t):i(e)?t._d=e:Dt(t),t))}function Dt(e){var o=e._i;void 0===o?e._d=new Date:i(o)?e._d=new Date(+o):"string"==typeof o?it(e):n(o)?(e._a=r(o.slice(0),function(t){return parseInt(t,10)}),bt(e)):"object"==typeof o?kt(e):"number"==typeof o?e._d=new Date(o):t.createFromInputFallback(e)}function St(t,e,n,i,r){var o={};return"boolean"==typeof n&&(i=n,n=void 0),o._isAMomentObject=!0,o._useUTC=o._isUTC=r,o._l=n,o._i=t,o._f=e,o._strict=i,Ct(o)}function Tt(t,e,n,i){return St(t,e,n,i,!1)}function At(t,e){var i,r;if(1===e.length&&n(e[0])&&(e=e[0]),!e.length)return Tt();for(i=e[0],r=1;r<e.length;++r)(!e[r].isValid()||e[r][t](i))&&(i=e[r]);return i}function Et(){var t=[].slice.call(arguments,0);return At("isBefore",t)}function Ot(){var t=[].slice.call(arguments,0);return At("isAfter",t)}function Nt(t){var e=D(t),n=e.year||0,i=e.quarter||0,r=e.month||0,o=e.week||0,a=e.day||0,s=e.hour||0,u=e.minute||0,l=e.second||0,c=e.millisecond||0;this._milliseconds=+c+1e3*l+6e4*u+36e5*s,this._days=+a+7*o,this._months=+r+3*i+12*n,this._data={},this._locale=k(),this._bubble()}function It(t){return t instanceof Nt}function Pt(t,e){N(t,0,0,function(){var t=this.utcOffset(),n="+";return 0>t&&(t=-t,n="-"),n+O(~~(t/60),2)+e+O(~~t%60,2)})}function Ft(t){var e=(t||"").match(ei)||[],n=e[e.length-1]||[],i=(n+"").match(ki)||["-",0,0],r=+(60*i[1])+m(i[2]);return"+"===i[0]?r:-r}function Wt(e,n){var r,o;return n._isUTC?(r=n.clone(),o=(p(e)||i(e)?+e:+Tt(e))-+r,r._d.setTime(+r._d+o),t.updateOffset(r,!1),r):Tt(e).local()}function Ht(t){return 15*-Math.round(t._d.getTimezoneOffset()/15)}function Lt(e,n){var i,r=this._offset||0;return null!=e?("string"==typeof e&&(e=Ft(e)),Math.abs(e)<16&&(e=60*e),!this._isUTC&&n&&(i=Ht(this)),this._offset=e,this._isUTC=!0,null!=i&&this.add(i,"m"),r!==e&&(!n||this._changeInProgress?ee(this,Kt(e-r,"m"),1,!1):this._changeInProgress||(this._changeInProgress=!0,t.updateOffset(this,!0),this._changeInProgress=null)),this):this._isUTC?r:Ht(this)}function zt(t,e){return null!=t?("string"!=typeof t&&(t=-t),this.utcOffset(t,e),this):-this.utcOffset()}function jt(t){return this.utcOffset(0,t)}function Rt(t){return this._isUTC&&(this.utcOffset(0,t),this._isUTC=!1,t&&this.subtract(Ht(this),"m")),this}function Ut(){return this._tzm?this.utcOffset(this._tzm):"string"==typeof this._i&&this.utcOffset(Ft(this._i)),this}function qt(t){return t=t?Tt(t).utcOffset():0,(this.utcOffset()-t)%60===0}function Bt(){return this.utcOffset()>this.clone().month(0).utcOffset()||this.utcOffset()>this.clone().month(5).utcOffset()}function Vt(){if("undefined"!=typeof this._isDSTShifted)return this._isDSTShifted;var t={};if(h(t,this),t=Mt(t),t._a){var e=t._isUTC?s(t._a):Tt(t._a);this._isDSTShifted=this.isValid()&&v(t._a,e.toArray())>0}else this._isDSTShifted=!1;return this._isDSTShifted}function Yt(){return!this._isUTC}function Gt(){return this._isUTC}function Xt(){return this._isUTC&&0===this._offset}function Kt(t,e){var n,i,r,a=t,s=null;return It(t)?a={ms:t._milliseconds,d:t._days,M:t._months}:"number"==typeof t?(a={},e?a[e]=t:a.milliseconds=t):(s=Ci.exec(t))?(n="-"===s[1]?-1:1,a={y:0,d:m(s[ui])*n,h:m(s[li])*n,m:m(s[ci])*n,s:m(s[di])*n,ms:m(s[hi])*n}):(s=Mi.exec(t))?(n="-"===s[1]?-1:1,a={y:Zt(s[2],n),M:Zt(s[3],n),d:Zt(s[4],n),h:Zt(s[5],n),m:Zt(s[6],n),s:Zt(s[7],n),w:Zt(s[8],n)}):null==a?a={}:"object"==typeof a&&("from"in a||"to"in a)&&(r=Jt(Tt(a.from),Tt(a.to)),a={},a.ms=r.milliseconds,a.M=r.months),i=new Nt(a),It(t)&&o(t,"_locale")&&(i._locale=t._locale),i}function Zt(t,e){var n=t&&parseFloat(t.replace(",","."));return(isNaN(n)?0:n)*e}function Qt(t,e){var n={milliseconds:0,months:0};return n.months=e.month()-t.month()+12*(e.year()-t.year()),t.clone().add(n.months,"M").isAfter(e)&&--n.months,n.milliseconds=+e-+t.clone().add(n.months,"M"),n}function Jt(t,e){var n;return e=Wt(e,t),t.isBefore(e)?n=Qt(t,e):(n=Qt(e,t),n.milliseconds=-n.milliseconds,n.months=-n.months),n}function te(t,e){return function(n,i){var r,o;return null===i||isNaN(+i)||(et(e,"moment()."+e+"(period, number) is deprecated. Please use moment()."+e+"(number, period)."),o=n,n=i,i=o),n="string"==typeof n?+n:n,r=Kt(n,i),ee(this,r,t),this}}function ee(e,n,i,r){var o=n._milliseconds,a=n._days,s=n._months;r=null==r?!0:r,o&&e._d.setTime(+e._d+o*i),a&&A(e,"Date",T(e,"Date")+a*i),s&&X(e,T(e,"Month")+s*i),r&&t.updateOffset(e,a||s)}function ne(t,e){var n=t||Tt(),i=Wt(n,this).startOf("day"),r=this.diff(i,"days",!0),o=-6>r?"sameElse":-1>r?"lastWeek":0>r?"lastDay":1>r?"sameDay":2>r?"nextDay":7>r?"nextWeek":"sameElse";return this.format(e&&e[o]||this.localeData().calendar(o,this,Tt(n)))}function ie(){return new f(this)}function re(t,e){var n;return e=M("undefined"!=typeof e?e:"millisecond"),"millisecond"===e?(t=p(t)?t:Tt(t),+this>+t):(n=p(t)?+t:+Tt(t),n<+this.clone().startOf(e))}function oe(t,e){var n;return e=M("undefined"!=typeof e?e:"millisecond"),"millisecond"===e?(t=p(t)?t:Tt(t),+t>+this):(n=p(t)?+t:+Tt(t),+this.clone().endOf(e)<n)}function ae(t,e,n){return this.isAfter(t,n)&&this.isBefore(e,n)}function se(t,e){var n;return e=M(e||"millisecond"),"millisecond"===e?(t=p(t)?t:Tt(t),+this===+t):(n=+Tt(t),+this.clone().startOf(e)<=n&&n<=+this.clone().endOf(e))}function ue(t,e,n){var i,r,o=Wt(t,this),a=6e4*(o.utcOffset()-this.utcOffset());return e=M(e),"year"===e||"month"===e||"quarter"===e?(r=le(this,o),"quarter"===e?r/=3:"year"===e&&(r/=12)):(i=this-o,r="second"===e?i/1e3:"minute"===e?i/6e4:"hour"===e?i/36e5:"day"===e?(i-a)/864e5:"week"===e?(i-a)/6048e5:i),n?r:g(r)}function le(t,e){var n,i,r=12*(e.year()-t.year())+(e.month()-t.month()),o=t.clone().add(r,"months");return 0>e-o?(n=t.clone().add(r-1,"months"),i=(e-o)/(o-n)):(n=t.clone().add(r+1,"months"),i=(e-o)/(n-o)),-(r+i)}function ce(){return this.clone().locale("en").format("ddd MMM DD YYYY HH:mm:ss [GMT]ZZ")}function de(){var t=this.clone().utc();return 0<t.year()&&t.year()<=9999?"function"==typeof Date.prototype.toISOString?this.toDate().toISOString():F(t,"YYYY-MM-DD[T]HH:mm:ss.SSS[Z]"):F(t,"YYYYYY-MM-DD[T]HH:mm:ss.SSS[Z]")}function he(e){var n=F(this,e||t.defaultFormat);return this.localeData().postformat(n)}function fe(t,e){return this.isValid()?Kt({to:this,from:t}).locale(this.locale()).humanize(!e):this.localeData().invalidDate()}function pe(t){return this.from(Tt(),t)}function ge(t,e){return this.isValid()?Kt({from:this,to:t}).locale(this.locale()).humanize(!e):this.localeData().invalidDate()}function me(t){return this.to(Tt(),t)}function ve(t){var e;return void 0===t?this._locale._abbr:(e=k(t),null!=e&&(this._locale=e),this)}function ye(){return this._locale}function be(t){switch(t=M(t)){case"year":this.month(0);case"quarter":case"month":this.date(1);case"week":case"isoWeek":case"day":this.hours(0);case"hour":this.minutes(0);case"minute":this.seconds(0);case"second":this.milliseconds(0)}return"week"===t&&this.weekday(0),"isoWeek"===t&&this.isoWeekday(1),"quarter"===t&&this.month(3*Math.floor(this.month()/3)),this}function xe(t){return t=M(t),void 0===t||"millisecond"===t?this:this.startOf(t).add(1,"isoWeek"===t?"week":t).subtract(1,"ms")}function we(){return+this._d-6e4*(this._offset||0)}function _e(){return Math.floor(+this/1e3)}function $e(){return this._offset?new Date(+this):this._d}function ke(){var t=this;return[t.year(),t.month(),t.date(),t.hour(),t.minute(),t.second(),t.millisecond()]}function Ce(){var t=this;return{years:t.year(),months:t.month(),date:t.date(),hours:t.hours(),minutes:t.minutes(),seconds:t.seconds(),milliseconds:t.milliseconds()}}function Me(){return c(this)}function De(){return a({},l(this))}function Se(){return l(this).overflow}function Te(t,e){N(0,[t,t.length],0,e)}function Ae(t,e,n){return lt(Tt([t,11,31+e-n]),e,n).week}function Ee(t){var e=lt(this,this.localeData()._week.dow,this.localeData()._week.doy).year;return null==t?e:this.add(t-e,"y")}function Oe(t){var e=lt(this,1,4).year;return null==t?e:this.add(t-e,"y")}function Ne(){return Ae(this.year(),1,4)}function Ie(){var t=this.localeData()._week;return Ae(this.year(),t.dow,t.doy)}function Pe(t){return null==t?Math.ceil((this.month()+1)/3):this.month(3*(t-1)+this.month()%3)}function Fe(t,e){return"string"!=typeof t?t:isNaN(t)?(t=e.weekdaysParse(t),"number"==typeof t?t:null):parseInt(t,10)}function We(t){return this._weekdays[t.day()]}function He(t){return this._weekdaysShort[t.day()]}function Le(t){return this._weekdaysMin[t.day()]}function ze(t){var e,n,i;for(this._weekdaysParse=this._weekdaysParse||[],e=0;7>e;e++)if(this._weekdaysParse[e]||(n=Tt([2e3,1]).day(e),i="^"+this.weekdays(n,"")+"|^"+this.weekdaysShort(n,"")+"|^"+this.weekdaysMin(n,""),this._weekdaysParse[e]=new RegExp(i.replace(".",""),"i")),this._weekdaysParse[e].test(t))return e}function je(t){var e=this._isUTC?this._d.getUTCDay():this._d.getDay();return null!=t?(t=Fe(t,this.localeData()),this.add(t-e,"d")):e}function Re(t){var e=(this.day()+7-this.localeData()._week.dow)%7;return null==t?e:this.add(t-e,"d")}function Ue(t){return null==t?this.day()||7:this.day(this.day()%7?t:t-7)}function qe(t,e){N(t,0,0,function(){return this.localeData().meridiem(this.hours(),this.minutes(),e)})}function Be(t,e){return e._meridiemParse}function Ve(t){return"p"===(t+"").toLowerCase().charAt(0)}function Ye(t,e,n){return t>11?n?"pm":"PM":n?"am":"AM"}function Ge(t,e){e[hi]=m(1e3*("0."+t))}function Xe(){return this._isUTC?"UTC":""}function Ke(){return this._isUTC?"Coordinated Universal Time":""}function Ze(t){return Tt(1e3*t)}function Qe(){return Tt.apply(null,arguments).parseZone()}function Je(t,e,n){var i=this._calendar[t];return"function"==typeof i?i.call(e,n):i}function tn(t){var e=this._longDateFormat[t],n=this._longDateFormat[t.toUpperCase()];return e||!n?e:(this._longDateFormat[t]=n.replace(/MMMM|MM|DD|dddd/g,function(t){return t.slice(1)}),this._longDateFormat[t])}function en(){return this._invalidDate}function nn(t){return this._ordinal.replace("%d",t)}function rn(t){return t}function on(t,e,n,i){var r=this._relativeTime[n];return"function"==typeof r?r(t,e,n,i):r.replace(/%d/i,t)}function an(t,e){var n=this._relativeTime[t>0?"future":"past"];return"function"==typeof n?n(e):n.replace(/%s/i,e)}function sn(t){var e,n;for(n in t)e=t[n],"function"==typeof e?this[n]=e:this["_"+n]=e;this._ordinalParseLenient=new RegExp(this._ordinalParse.source+"|"+/\d{1,2}/.source)}function un(t,e,n,i){var r=k(),o=s().set(i,e);return r[n](o,t)}function ln(t,e,n,i,r){if("number"==typeof t&&(e=t,t=void 0),t=t||"",null!=e)return un(t,e,n,r);var o,a=[];for(o=0;i>o;o++)a[o]=un(t,o,n,r);return a}function cn(t,e){return ln(t,e,"months",12,"month")}function dn(t,e){return ln(t,e,"monthsShort",12,"month")}function hn(t,e){return ln(t,e,"weekdays",7,"day")}function fn(t,e){return ln(t,e,"weekdaysShort",7,"day")}function pn(t,e){return ln(t,e,"weekdaysMin",7,"day")}function gn(){var t=this._data;return this._milliseconds=Xi(this._milliseconds),this._days=Xi(this._days),this._months=Xi(this._months),t.milliseconds=Xi(t.milliseconds),t.seconds=Xi(t.seconds),t.minutes=Xi(t.minutes),t.hours=Xi(t.hours),t.months=Xi(t.months),t.years=Xi(t.years),this}function mn(t,e,n,i){var r=Kt(e,n);return t._milliseconds+=i*r._milliseconds,t._days+=i*r._days,t._months+=i*r._months,t._bubble()}function vn(t,e){return mn(this,t,e,1)}function yn(t,e){return mn(this,t,e,-1)}function bn(t){return 0>t?Math.floor(t):Math.ceil(t)}function xn(){var t,e,n,i,r,o=this._milliseconds,a=this._days,s=this._months,u=this._data;return o>=0&&a>=0&&s>=0||0>=o&&0>=a&&0>=s||(o+=864e5*bn(_n(s)+a),a=0,s=0),u.milliseconds=o%1e3,t=g(o/1e3),u.seconds=t%60,e=g(t/60),u.minutes=e%60,n=g(e/60),u.hours=n%24,a+=g(n/24),r=g(wn(a)),s+=r,a-=bn(_n(r)),i=g(s/12),s%=12,u.days=a,u.months=s,u.years=i,this}function wn(t){return 4800*t/146097}function _n(t){return 146097*t/4800}function $n(t){var e,n,i=this._milliseconds;if(t=M(t),"month"===t||"year"===t)return e=this._days+i/864e5,n=this._months+wn(e),"month"===t?n:n/12;switch(e=this._days+Math.round(_n(this._months)),t){case"week":return e/7+i/6048e5;case"day":return e+i/864e5;case"hour":return 24*e+i/36e5;case"minute":return 1440*e+i/6e4;case"second":return 86400*e+i/1e3;case"millisecond":return Math.floor(864e5*e)+i;default:throw new Error("Unknown unit "+t)}}function kn(){return this._milliseconds+864e5*this._days+this._months%12*2592e6+31536e6*m(this._months/12)}function Cn(t){return function(){return this.as(t)}}function Mn(t){return t=M(t),this[t+"s"]()}function Dn(t){return function(){return this._data[t]}}function Sn(){return g(this.days()/7)}function Tn(t,e,n,i,r){return r.relativeTime(e||1,!!n,t,i)}function An(t,e,n){var i=Kt(t).abs(),r=dr(i.as("s")),o=dr(i.as("m")),a=dr(i.as("h")),s=dr(i.as("d")),u=dr(i.as("M")),l=dr(i.as("y")),c=r<hr.s&&["s",r]||1===o&&["m"]||o<hr.m&&["mm",o]||1===a&&["h"]||a<hr.h&&["hh",a]||1===s&&["d"]||s<hr.d&&["dd",s]||1===u&&["M"]||u<hr.M&&["MM",u]||1===l&&["y"]||["yy",l];return c[2]=e,c[3]=+t>0,c[4]=n,Tn.apply(null,c)}function En(t,e){return void 0===hr[t]?!1:void 0===e?hr[t]:(hr[t]=e,!0)}function On(t){var e=this.localeData(),n=An(this,!t,e);return t&&(n=e.pastFuture(+this,n)),e.postformat(n)}function Nn(){var t,e,n,i=fr(this._milliseconds)/1e3,r=fr(this._days),o=fr(this._months);t=g(i/60),e=g(t/60),i%=60,t%=60,n=g(o/12),o%=12;var a=n,s=o,u=r,l=e,c=t,d=i,h=this.asSeconds();return h?(0>h?"-":"")+"P"+(a?a+"Y":"")+(s?s+"M":"")+(u?u+"D":"")+(l||c||d?"T":"")+(l?l+"H":"")+(c?c+"M":"")+(d?d+"S":""):"P0D"}var In,Pn,Fn=t.momentProperties=[],Wn=!1,Hn={},Ln={},zn=/(\[[^\[]*\])|(\\)?(Mo|MM?M?M?|Do|DDDo|DD?D?D?|ddd?d?|do?|w[o|w]?|W[o|W]?|Q|YYYYYY|YYYYY|YYYY|YY|gg(ggg?)?|GG(GGG?)?|e|E|a|A|hh?|HH?|mm?|ss?|S{1,9}|x|X|zz?|ZZ?|.)/g,jn=/(\[[^\[]*\])|(\\)?(LTS|LT|LL?L?L?|l{1,4})/g,Rn={},Un={},qn=/\d/,Bn=/\d\d/,Vn=/\d{3}/,Yn=/\d{4}/,Gn=/[+-]?\d{6}/,Xn=/\d\d?/,Kn=/\d{1,3}/,Zn=/\d{1,4}/,Qn=/[+-]?\d{1,6}/,Jn=/\d+/,ti=/[+-]?\d+/,ei=/Z|[+-]\d\d:?\d\d/gi,ni=/[+-]?\d+(\.\d{1,3})?/,ii=/[0-9]*['a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+|[\u0600-\u06FF\/]+(\s*?[\u0600-\u06FF]+){1,2}/i,ri={},oi={},ai=0,si=1,ui=2,li=3,ci=4,di=5,hi=6;N("M",["MM",2],"Mo",function(){return this.month()+1}),N("MMM",0,0,function(t){return this.localeData().monthsShort(this,t)}),N("MMMM",0,0,function(t){return this.localeData().months(this,t)}),C("month","M"),L("M",Xn),L("MM",Xn,Bn),L("MMM",ii),L("MMMM",ii),R(["M","MM"],function(t,e){e[si]=m(t)-1}),R(["MMM","MMMM"],function(t,e,n,i){var r=n._locale.monthsParse(t,i,n._strict);null!=r?e[si]=r:l(n).invalidMonth=t});var fi="January_February_March_April_May_June_July_August_September_October_November_December".split("_"),pi="Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),gi={};t.suppressDeprecationWarnings=!1;var mi=/^\s*(?:[+-]\d{6}|\d{4})-(?:(\d\d-\d\d)|(W\d\d$)|(W\d\d-\d)|(\d\d\d))((T| )(\d\d(:\d\d(:\d\d(\.\d+)?)?)?)?([\+\-]\d\d(?::?\d\d)?|\s*Z)?)?$/,vi=[["YYYYYY-MM-DD",/[+-]\d{6}-\d{2}-\d{2}/],["YYYY-MM-DD",/\d{4}-\d{2}-\d{2}/],["GGGG-[W]WW-E",/\d{4}-W\d{2}-\d/],["GGGG-[W]WW",/\d{4}-W\d{2}/],["YYYY-DDD",/\d{4}-\d{3}/]],yi=[["HH:mm:ss.SSSS",/(T| )\d\d:\d\d:\d\d\.\d+/],["HH:mm:ss",/(T| )\d\d:\d\d:\d\d/],["HH:mm",/(T| )\d\d:\d\d/],["HH",/(T| )\d\d/]],bi=/^\/?Date\((\-?\d+)/i;t.createFromInputFallback=tt("moment construction falls back to js Date. This is discouraged and will be removed in upcoming major release. Please refer to https://github.com/moment/moment/issues/1407 for more info.",function(t){t._d=new Date(t._i+(t._useUTC?" UTC":""))}),N(0,["YY",2],0,function(){return this.year()%100}),N(0,["YYYY",4],0,"year"),N(0,["YYYYY",5],0,"year"),N(0,["YYYYYY",6,!0],0,"year"),C("year","y"),L("Y",ti),L("YY",Xn,Bn),L("YYYY",Zn,Yn),L("YYYYY",Qn,Gn),L("YYYYYY",Qn,Gn),R(["YYYYY","YYYYYY"],ai),R("YYYY",function(e,n){n[ai]=2===e.length?t.parseTwoDigitYear(e):m(e)}),R("YY",function(e,n){n[ai]=t.parseTwoDigitYear(e)}),t.parseTwoDigitYear=function(t){return m(t)+(m(t)>68?1900:2e3)};var xi=S("FullYear",!1);N("w",["ww",2],"wo","week"),N("W",["WW",2],"Wo","isoWeek"),C("week","w"),C("isoWeek","W"),L("w",Xn),L("ww",Xn,Bn),L("W",Xn),L("WW",Xn,Bn),U(["w","ww","W","WW"],function(t,e,n,i){e[i.substr(0,1)]=m(t)});var wi={dow:0,doy:6};N("DDD",["DDDD",3],"DDDo","dayOfYear"),C("dayOfYear","DDD"),L("DDD",Kn),L("DDDD",Vn),R(["DDD","DDDD"],function(t,e,n){n._dayOfYear=m(t)}),t.ISO_8601=function(){};var _i=tt("moment().min is deprecated, use moment.min instead. https://github.com/moment/moment/issues/1548",function(){var t=Tt.apply(null,arguments);return this>t?this:t}),$i=tt("moment().max is deprecated, use moment.max instead. https://github.com/moment/moment/issues/1548",function(){var t=Tt.apply(null,arguments);return t>this?this:t});Pt("Z",":"),Pt("ZZ",""),L("Z",ei),L("ZZ",ei),R(["Z","ZZ"],function(t,e,n){n._useUTC=!0,n._tzm=Ft(t)});var ki=/([\+\-]|\d\d)/gi;t.updateOffset=function(){};var Ci=/(\-)?(?:(\d*)\.)?(\d+)\:(\d+)(?:\:(\d+)\.?(\d{3})?)?/,Mi=/^(-)?P(?:(?:([0-9,.]*)Y)?(?:([0-9,.]*)M)?(?:([0-9,.]*)D)?(?:T(?:([0-9,.]*)H)?(?:([0-9,.]*)M)?(?:([0-9,.]*)S)?)?|([0-9,.]*)W)$/;Kt.fn=Nt.prototype;var Di=te(1,"add"),Si=te(-1,"subtract");t.defaultFormat="YYYY-MM-DDTHH:mm:ssZ";var Ti=tt("moment().lang() is deprecated. Instead, use moment().localeData() to get the language configuration. Use moment().locale() to change languages.",function(t){return void 0===t?this.localeData():this.locale(t)});N(0,["gg",2],0,function(){return this.weekYear()%100}),N(0,["GG",2],0,function(){return this.isoWeekYear()%100}),Te("gggg","weekYear"),Te("ggggg","weekYear"),Te("GGGG","isoWeekYear"),Te("GGGGG","isoWeekYear"),C("weekYear","gg"),C("isoWeekYear","GG"),L("G",ti),L("g",ti),L("GG",Xn,Bn),L("gg",Xn,Bn),L("GGGG",Zn,Yn),L("gggg",Zn,Yn),L("GGGGG",Qn,Gn),L("ggggg",Qn,Gn),U(["gggg","ggggg","GGGG","GGGGG"],function(t,e,n,i){e[i.substr(0,2)]=m(t)}),U(["gg","GG"],function(e,n,i,r){n[r]=t.parseTwoDigitYear(e)}),N("Q",0,0,"quarter"),C("quarter","Q"),L("Q",qn),R("Q",function(t,e){e[si]=3*(m(t)-1)}),N("D",["DD",2],"Do","date"),C("date","D"),L("D",Xn),L("DD",Xn,Bn),L("Do",function(t,e){return t?e._ordinalParse:e._ordinalParseLenient}),R(["D","DD"],ui),R("Do",function(t,e){e[ui]=m(t.match(Xn)[0],10)});var Ai=S("Date",!0);N("d",0,"do","day"),N("dd",0,0,function(t){return this.localeData().weekdaysMin(this,t)}),N("ddd",0,0,function(t){return this.localeData().weekdaysShort(this,t)}),N("dddd",0,0,function(t){return this.localeData().weekdays(this,t)}),N("e",0,0,"weekday"),N("E",0,0,"isoWeekday"),C("day","d"),C("weekday","e"),C("isoWeekday","E"),L("d",Xn),L("e",Xn),L("E",Xn),L("dd",ii),L("ddd",ii),L("dddd",ii),U(["dd","ddd","dddd"],function(t,e,n){var i=n._locale.weekdaysParse(t);null!=i?e.d=i:l(n).invalidWeekday=t}),U(["d","e","E"],function(t,e,n,i){e[i]=m(t)});var Ei="Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),Oi="Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),Ni="Su_Mo_Tu_We_Th_Fr_Sa".split("_");N("H",["HH",2],0,"hour"),N("h",["hh",2],0,function(){return this.hours()%12||12}),qe("a",!0),qe("A",!1),C("hour","h"),L("a",Be),L("A",Be),L("H",Xn),L("h",Xn),L("HH",Xn,Bn),L("hh",Xn,Bn),R(["H","HH"],li),R(["a","A"],function(t,e,n){n._isPm=n._locale.isPM(t),n._meridiem=t}),R(["h","hh"],function(t,e,n){e[li]=m(t),l(n).bigHour=!0});var Ii=/[ap]\.?m?\.?/i,Pi=S("Hours",!0);N("m",["mm",2],0,"minute"),C("minute","m"),L("m",Xn),L("mm",Xn,Bn),R(["m","mm"],ci);var Fi=S("Minutes",!1);N("s",["ss",2],0,"second"),C("second","s"),L("s",Xn),L("ss",Xn,Bn),R(["s","ss"],di);var Wi=S("Seconds",!1);N("S",0,0,function(){return~~(this.millisecond()/100)}),N(0,["SS",2],0,function(){return~~(this.millisecond()/10)}),N(0,["SSS",3],0,"millisecond"),N(0,["SSSS",4],0,function(){return 10*this.millisecond()}),N(0,["SSSSS",5],0,function(){return 100*this.millisecond()}),N(0,["SSSSSS",6],0,function(){return 1e3*this.millisecond()}),N(0,["SSSSSSS",7],0,function(){return 1e4*this.millisecond()}),N(0,["SSSSSSSS",8],0,function(){return 1e5*this.millisecond()}),N(0,["SSSSSSSSS",9],0,function(){return 1e6*this.millisecond()}),C("millisecond","ms"),L("S",Kn,qn),L("SS",Kn,Bn),L("SSS",Kn,Vn);var Hi;for(Hi="SSSS";Hi.length<=9;Hi+="S")L(Hi,Jn);for(Hi="S";Hi.length<=9;Hi+="S")R(Hi,Ge);var Li=S("Milliseconds",!1);N("z",0,0,"zoneAbbr"),N("zz",0,0,"zoneName");var zi=f.prototype;zi.add=Di,zi.calendar=ne,zi.clone=ie,zi.diff=ue,zi.endOf=xe,zi.format=he,zi.from=fe,zi.fromNow=pe,zi.to=ge,zi.toNow=me,zi.get=E,zi.invalidAt=Se,zi.isAfter=re,zi.isBefore=oe,zi.isBetween=ae,zi.isSame=se,zi.isValid=Me,zi.lang=Ti,zi.locale=ve,zi.localeData=ye,zi.max=$i,zi.min=_i,zi.parsingFlags=De,zi.set=E,zi.startOf=be,zi.subtract=Si,zi.toArray=ke,zi.toObject=Ce,zi.toDate=$e,zi.toISOString=de,zi.toJSON=de,zi.toString=ce,zi.unix=_e,zi.valueOf=we,zi.year=xi,zi.isLeapYear=ut,zi.weekYear=Ee,zi.isoWeekYear=Oe,zi.quarter=zi.quarters=Pe,zi.month=K,zi.daysInMonth=Z,zi.week=zi.weeks=ft,zi.isoWeek=zi.isoWeeks=pt,zi.weeksInYear=Ie,zi.isoWeeksInYear=Ne,zi.date=Ai,zi.day=zi.days=je,zi.weekday=Re,zi.isoWeekday=Ue,zi.dayOfYear=mt,zi.hour=zi.hours=Pi,zi.minute=zi.minutes=Fi,zi.second=zi.seconds=Wi,
zi.millisecond=zi.milliseconds=Li,zi.utcOffset=Lt,zi.utc=jt,zi.local=Rt,zi.parseZone=Ut,zi.hasAlignedHourOffset=qt,zi.isDST=Bt,zi.isDSTShifted=Vt,zi.isLocal=Yt,zi.isUtcOffset=Gt,zi.isUtc=Xt,zi.isUTC=Xt,zi.zoneAbbr=Xe,zi.zoneName=Ke,zi.dates=tt("dates accessor is deprecated. Use date instead.",Ai),zi.months=tt("months accessor is deprecated. Use month instead",K),zi.years=tt("years accessor is deprecated. Use year instead",xi),zi.zone=tt("moment().zone is deprecated, use moment().utcOffset instead. https://github.com/moment/moment/issues/1779",zt);var ji=zi,Ri={sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},Ui={LTS:"h:mm:ss A",LT:"h:mm A",L:"MM/DD/YYYY",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY h:mm A",LLLL:"dddd, MMMM D, YYYY h:mm A"},qi="Invalid date",Bi="%d",Vi=/\d{1,2}/,Yi={future:"in %s",past:"%s ago",s:"a few seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},Gi=y.prototype;Gi._calendar=Ri,Gi.calendar=Je,Gi._longDateFormat=Ui,Gi.longDateFormat=tn,Gi._invalidDate=qi,Gi.invalidDate=en,Gi._ordinal=Bi,Gi.ordinal=nn,Gi._ordinalParse=Vi,Gi.preparse=rn,Gi.postformat=rn,Gi._relativeTime=Yi,Gi.relativeTime=on,Gi.pastFuture=an,Gi.set=sn,Gi.months=V,Gi._months=fi,Gi.monthsShort=Y,Gi._monthsShort=pi,Gi.monthsParse=G,Gi.week=ct,Gi._week=wi,Gi.firstDayOfYear=ht,Gi.firstDayOfWeek=dt,Gi.weekdays=We,Gi._weekdays=Ei,Gi.weekdaysMin=Le,Gi._weekdaysMin=Ni,Gi.weekdaysShort=He,Gi._weekdaysShort=Oi,Gi.weekdaysParse=ze,Gi.isPM=Ve,Gi._meridiemParse=Ii,Gi.meridiem=Ye,_("en",{ordinalParse:/\d{1,2}(th|st|nd|rd)/,ordinal:function(t){var e=t%10,n=1===m(t%100/10)?"th":1===e?"st":2===e?"nd":3===e?"rd":"th";return t+n}}),t.lang=tt("moment.lang is deprecated. Use moment.locale instead.",_),t.langData=tt("moment.langData is deprecated. Use moment.localeData instead.",k);var Xi=Math.abs,Ki=Cn("ms"),Zi=Cn("s"),Qi=Cn("m"),Ji=Cn("h"),tr=Cn("d"),er=Cn("w"),nr=Cn("M"),ir=Cn("y"),rr=Dn("milliseconds"),or=Dn("seconds"),ar=Dn("minutes"),sr=Dn("hours"),ur=Dn("days"),lr=Dn("months"),cr=Dn("years"),dr=Math.round,hr={s:45,m:45,h:22,d:26,M:11},fr=Math.abs,pr=Nt.prototype;pr.abs=gn,pr.add=vn,pr.subtract=yn,pr.as=$n,pr.asMilliseconds=Ki,pr.asSeconds=Zi,pr.asMinutes=Qi,pr.asHours=Ji,pr.asDays=tr,pr.asWeeks=er,pr.asMonths=nr,pr.asYears=ir,pr.valueOf=kn,pr._bubble=xn,pr.get=Mn,pr.milliseconds=rr,pr.seconds=or,pr.minutes=ar,pr.hours=sr,pr.days=ur,pr.weeks=Sn,pr.months=lr,pr.years=cr,pr.humanize=On,pr.toISOString=Nn,pr.toString=Nn,pr.toJSON=Nn,pr.locale=ve,pr.localeData=ye,pr.toIsoString=tt("toIsoString() is deprecated. Please use toISOString() instead (notice the capitals)",Nn),pr.lang=Ti,N("X",0,0,"unix"),N("x",0,0,"valueOf"),L("x",ti),L("X",ni),R("X",function(t,e,n){n._d=new Date(1e3*parseFloat(t,10))}),R("x",function(t,e,n){n._d=new Date(m(t))}),t.version="2.10.6",e(Tt),t.fn=ji,t.min=Et,t.max=Ot,t.utc=s,t.unix=Ze,t.months=cn,t.isDate=i,t.locale=_,t.invalid=d,t.duration=Kt,t.isMoment=p,t.weekdays=hn,t.parseZone=Qe,t.localeData=k,t.isDuration=It,t.monthsShort=dn,t.weekdaysMin=pn,t.defineLocale=$,t.weekdaysShort=fn,t.normalizeUnits=M,t.relativeTimeThreshold=En;var gr=t;return gr}),/*! jQuery UI - v1.11.4 - 2015-03-11
* http://jqueryui.com
* Includes: core.js, widget.js, mouse.js, position.js, accordion.js, autocomplete.js, button.js, datepicker.js, dialog.js, draggable.js, droppable.js, effect.js, effect-blind.js, effect-bounce.js, effect-clip.js, effect-drop.js, effect-explode.js, effect-fade.js, effect-fold.js, effect-highlight.js, effect-puff.js, effect-pulsate.js, effect-scale.js, effect-shake.js, effect-size.js, effect-slide.js, effect-transfer.js, menu.js, progressbar.js, resizable.js, selectable.js, selectmenu.js, slider.js, sortable.js, spinner.js, tabs.js, tooltip.js
* Copyright 2015 jQuery Foundation and other contributors; Licensed MIT */
function(t){"function"==typeof define&&define.amd?define(["jquery"],t):t(jQuery)}(function(t){function e(e,i){var r,o,a,s=e.nodeName.toLowerCase();return"area"===s?(r=e.parentNode,o=r.name,e.href&&o&&"map"===r.nodeName.toLowerCase()?(a=t("img[usemap='#"+o+"']")[0],!!a&&n(a)):!1):(/^(input|select|textarea|button|object)$/.test(s)?!e.disabled:"a"===s?e.href||i:i)&&n(e)}function n(e){return t.expr.filters.visible(e)&&!t(e).parents().addBack().filter(function(){return"hidden"===t.css(this,"visibility")}).length}function i(t){for(var e,n;t.length&&t[0]!==document;){if(e=t.css("position"),("absolute"===e||"relative"===e||"fixed"===e)&&(n=parseInt(t.css("zIndex"),10),!isNaN(n)&&0!==n))return n;t=t.parent()}return 0}function r(){this._curInst=null,this._keyEvent=!1,this._disabledInputs=[],this._datepickerShowing=!1,this._inDialog=!1,this._mainDivId="ui-datepicker-div",this._inlineClass="ui-datepicker-inline",this._appendClass="ui-datepicker-append",this._triggerClass="ui-datepicker-trigger",this._dialogClass="ui-datepicker-dialog",this._disableClass="ui-datepicker-disabled",this._unselectableClass="ui-datepicker-unselectable",this._currentClass="ui-datepicker-current-day",this._dayOverClass="ui-datepicker-days-cell-over",this.regional=[],this.regional[""]={closeText:"Done",prevText:"Prev",nextText:"Next",currentText:"Today",monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],weekHeader:"Wk",dateFormat:"mm/dd/yy",firstDay:0,isRTL:!1,showMonthAfterYear:!1,yearSuffix:""},this._defaults={showOn:"focus",showAnim:"fadeIn",showOptions:{},defaultDate:null,appendText:"",buttonText:"...",buttonImage:"",buttonImageOnly:!1,hideIfNoPrevNext:!1,navigationAsDateFormat:!1,gotoCurrent:!1,changeMonth:!1,changeYear:!1,yearRange:"c-10:c+10",showOtherMonths:!1,selectOtherMonths:!1,showWeek:!1,calculateWeek:this.iso8601Week,shortYearCutoff:"+10",minDate:null,maxDate:null,duration:"fast",beforeShowDay:null,beforeShow:null,onSelect:null,onChangeMonthYear:null,onClose:null,numberOfMonths:1,showCurrentAtPos:0,stepMonths:1,stepBigMonths:12,altField:"",altFormat:"",constrainInput:!0,showButtonPanel:!1,autoSize:!1,disabled:!1},t.extend(this._defaults,this.regional[""]),this.regional.en=t.extend(!0,{},this.regional[""]),this.regional["en-US"]=t.extend(!0,{},this.regional.en),this.dpDiv=o(t("<div id='"+this._mainDivId+"' class='ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all'></div>"))}function o(e){var n="button, .ui-datepicker-prev, .ui-datepicker-next, .ui-datepicker-calendar td a";return e.delegate(n,"mouseout",function(){t(this).removeClass("ui-state-hover"),-1!==this.className.indexOf("ui-datepicker-prev")&&t(this).removeClass("ui-datepicker-prev-hover"),-1!==this.className.indexOf("ui-datepicker-next")&&t(this).removeClass("ui-datepicker-next-hover")}).delegate(n,"mouseover",a)}function a(){t.datepicker._isDisabledDatepicker(v.inline?v.dpDiv.parent()[0]:v.input[0])||(t(this).parents(".ui-datepicker-calendar").find("a").removeClass("ui-state-hover"),t(this).addClass("ui-state-hover"),-1!==this.className.indexOf("ui-datepicker-prev")&&t(this).addClass("ui-datepicker-prev-hover"),-1!==this.className.indexOf("ui-datepicker-next")&&t(this).addClass("ui-datepicker-next-hover"))}function s(e,n){t.extend(e,n);for(var i in n)null==n[i]&&(e[i]=n[i]);return e}/*!
 * jQuery UI Spinner 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/spinner/
 */
function u(t){return function(){var e=this.element.val();t.apply(this,arguments),this._refresh(),e!==this.element.val()&&this._trigger("change")}}/*!
 * jQuery UI Core 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/ui-core/
 */
t.ui=t.ui||{},t.extend(t.ui,{version:"1.11.4",keyCode:{BACKSPACE:8,COMMA:188,DELETE:46,DOWN:40,END:35,ENTER:13,ESCAPE:27,HOME:36,LEFT:37,PAGE_DOWN:34,PAGE_UP:33,PERIOD:190,RIGHT:39,SPACE:32,TAB:9,UP:38}}),t.fn.extend({scrollParent:function(e){var n=this.css("position"),i="absolute"===n,r=e?/(auto|scroll|hidden)/:/(auto|scroll)/,o=this.parents().filter(function(){var e=t(this);return i&&"static"===e.css("position")?!1:r.test(e.css("overflow")+e.css("overflow-y")+e.css("overflow-x"))}).eq(0);return"fixed"!==n&&o.length?o:t(this[0].ownerDocument||document)},uniqueId:function(){var t=0;return function(){return this.each(function(){this.id||(this.id="ui-id-"+ ++t)})}}(),removeUniqueId:function(){return this.each(function(){/^ui-id-\d+$/.test(this.id)&&t(this).removeAttr("id")})}}),t.extend(t.expr[":"],{data:t.expr.createPseudo?t.expr.createPseudo(function(e){return function(n){return!!t.data(n,e)}}):function(e,n,i){return!!t.data(e,i[3])},focusable:function(n){return e(n,!isNaN(t.attr(n,"tabindex")))},tabbable:function(n){var i=t.attr(n,"tabindex"),r=isNaN(i);return(r||i>=0)&&e(n,!r)}}),t("<a>").outerWidth(1).jquery||t.each(["Width","Height"],function(e,n){function i(e,n,i,o){return t.each(r,function(){n-=parseFloat(t.css(e,"padding"+this))||0,i&&(n-=parseFloat(t.css(e,"border"+this+"Width"))||0),o&&(n-=parseFloat(t.css(e,"margin"+this))||0)}),n}var r="Width"===n?["Left","Right"]:["Top","Bottom"],o=n.toLowerCase(),a={innerWidth:t.fn.innerWidth,innerHeight:t.fn.innerHeight,outerWidth:t.fn.outerWidth,outerHeight:t.fn.outerHeight};t.fn["inner"+n]=function(e){return void 0===e?a["inner"+n].call(this):this.each(function(){t(this).css(o,i(this,e)+"px")})},t.fn["outer"+n]=function(e,r){return"number"!=typeof e?a["outer"+n].call(this,e):this.each(function(){t(this).css(o,i(this,e,!0,r)+"px")})}}),t.fn.addBack||(t.fn.addBack=function(t){return this.add(null==t?this.prevObject:this.prevObject.filter(t))}),t("<a>").data("a-b","a").removeData("a-b").data("a-b")&&(t.fn.removeData=function(e){return function(n){return arguments.length?e.call(this,t.camelCase(n)):e.call(this)}}(t.fn.removeData)),t.ui.ie=!!/msie [\w.]+/.exec(navigator.userAgent.toLowerCase()),t.fn.extend({focus:function(e){return function(n,i){return"number"==typeof n?this.each(function(){var e=this;setTimeout(function(){t(e).focus(),i&&i.call(e)},n)}):e.apply(this,arguments)}}(t.fn.focus),disableSelection:function(){var t="onselectstart"in document.createElement("div")?"selectstart":"mousedown";return function(){return this.bind(t+".ui-disableSelection",function(t){t.preventDefault()})}}(),enableSelection:function(){return this.unbind(".ui-disableSelection")},zIndex:function(e){if(void 0!==e)return this.css("zIndex",e);if(this.length)for(var n,i,r=t(this[0]);r.length&&r[0]!==document;){if(n=r.css("position"),("absolute"===n||"relative"===n||"fixed"===n)&&(i=parseInt(r.css("zIndex"),10),!isNaN(i)&&0!==i))return i;r=r.parent()}return 0}}),t.ui.plugin={add:function(e,n,i){var r,o=t.ui[e].prototype;for(r in i)o.plugins[r]=o.plugins[r]||[],o.plugins[r].push([n,i[r]])},call:function(t,e,n,i){var r,o=t.plugins[e];if(o&&(i||t.element[0].parentNode&&11!==t.element[0].parentNode.nodeType))for(r=0;r<o.length;r++)t.options[o[r][0]]&&o[r][1].apply(t.element,n)}};/*!
 * jQuery UI Widget 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/jQuery.widget/
 */
var l=0,c=Array.prototype.slice;t.cleanData=function(e){return function(n){var i,r,o;for(o=0;null!=(r=n[o]);o++)try{i=t._data(r,"events"),i&&i.remove&&t(r).triggerHandler("remove")}catch(a){}e(n)}}(t.cleanData),t.widget=function(e,n,i){var r,o,a,s,u={},l=e.split(".")[0];return e=e.split(".")[1],r=l+"-"+e,i||(i=n,n=t.Widget),t.expr[":"][r.toLowerCase()]=function(e){return!!t.data(e,r)},t[l]=t[l]||{},o=t[l][e],a=t[l][e]=function(t,e){return this._createWidget?void(arguments.length&&this._createWidget(t,e)):new a(t,e)},t.extend(a,o,{version:i.version,_proto:t.extend({},i),_childConstructors:[]}),s=new n,s.options=t.widget.extend({},s.options),t.each(i,function(e,i){return t.isFunction(i)?void(u[e]=function(){var t=function(){return n.prototype[e].apply(this,arguments)},r=function(t){return n.prototype[e].apply(this,t)};return function(){var e,n=this._super,o=this._superApply;return this._super=t,this._superApply=r,e=i.apply(this,arguments),this._super=n,this._superApply=o,e}}()):void(u[e]=i)}),a.prototype=t.widget.extend(s,{widgetEventPrefix:o?s.widgetEventPrefix||e:e},u,{constructor:a,namespace:l,widgetName:e,widgetFullName:r}),o?(t.each(o._childConstructors,function(e,n){var i=n.prototype;t.widget(i.namespace+"."+i.widgetName,a,n._proto)}),delete o._childConstructors):n._childConstructors.push(a),t.widget.bridge(e,a),a},t.widget.extend=function(e){for(var n,i,r=c.call(arguments,1),o=0,a=r.length;a>o;o++)for(n in r[o])i=r[o][n],r[o].hasOwnProperty(n)&&void 0!==i&&(t.isPlainObject(i)?e[n]=t.isPlainObject(e[n])?t.widget.extend({},e[n],i):t.widget.extend({},i):e[n]=i);return e},t.widget.bridge=function(e,n){var i=n.prototype.widgetFullName||e;t.fn[e]=function(r){var o="string"==typeof r,a=c.call(arguments,1),s=this;return o?this.each(function(){var n,o=t.data(this,i);return"instance"===r?(s=o,!1):o?t.isFunction(o[r])&&"_"!==r.charAt(0)?(n=o[r].apply(o,a),n!==o&&void 0!==n?(s=n&&n.jquery?s.pushStack(n.get()):n,!1):void 0):t.error("no such method '"+r+"' for "+e+" widget instance"):t.error("cannot call methods on "+e+" prior to initialization; attempted to call method '"+r+"'")}):(a.length&&(r=t.widget.extend.apply(null,[r].concat(a))),this.each(function(){var e=t.data(this,i);e?(e.option(r||{}),e._init&&e._init()):t.data(this,i,new n(r,this))})),s}},t.Widget=function(){},t.Widget._childConstructors=[],t.Widget.prototype={widgetName:"widget",widgetEventPrefix:"",defaultElement:"<div>",options:{disabled:!1,create:null},_createWidget:function(e,n){n=t(n||this.defaultElement||this)[0],this.element=t(n),this.uuid=l++,this.eventNamespace="."+this.widgetName+this.uuid,this.bindings=t(),this.hoverable=t(),this.focusable=t(),n!==this&&(t.data(n,this.widgetFullName,this),this._on(!0,this.element,{remove:function(t){t.target===n&&this.destroy()}}),this.document=t(n.style?n.ownerDocument:n.document||n),this.window=t(this.document[0].defaultView||this.document[0].parentWindow)),this.options=t.widget.extend({},this.options,this._getCreateOptions(),e),this._create(),this._trigger("create",null,this._getCreateEventData()),this._init()},_getCreateOptions:t.noop,_getCreateEventData:t.noop,_create:t.noop,_init:t.noop,destroy:function(){this._destroy(),this.element.unbind(this.eventNamespace).removeData(this.widgetFullName).removeData(t.camelCase(this.widgetFullName)),this.widget().unbind(this.eventNamespace).removeAttr("aria-disabled").removeClass(this.widgetFullName+"-disabled ui-state-disabled"),this.bindings.unbind(this.eventNamespace),this.hoverable.removeClass("ui-state-hover"),this.focusable.removeClass("ui-state-focus")},_destroy:t.noop,widget:function(){return this.element},option:function(e,n){var i,r,o,a=e;if(0===arguments.length)return t.widget.extend({},this.options);if("string"==typeof e)if(a={},i=e.split("."),e=i.shift(),i.length){for(r=a[e]=t.widget.extend({},this.options[e]),o=0;o<i.length-1;o++)r[i[o]]=r[i[o]]||{},r=r[i[o]];if(e=i.pop(),1===arguments.length)return void 0===r[e]?null:r[e];r[e]=n}else{if(1===arguments.length)return void 0===this.options[e]?null:this.options[e];a[e]=n}return this._setOptions(a),this},_setOptions:function(t){var e;for(e in t)this._setOption(e,t[e]);return this},_setOption:function(t,e){return this.options[t]=e,"disabled"===t&&(this.widget().toggleClass(this.widgetFullName+"-disabled",!!e),e&&(this.hoverable.removeClass("ui-state-hover"),this.focusable.removeClass("ui-state-focus"))),this},enable:function(){return this._setOptions({disabled:!1})},disable:function(){return this._setOptions({disabled:!0})},_on:function(e,n,i){var r,o=this;"boolean"!=typeof e&&(i=n,n=e,e=!1),i?(n=r=t(n),this.bindings=this.bindings.add(n)):(i=n,n=this.element,r=this.widget()),t.each(i,function(i,a){function s(){return e||o.options.disabled!==!0&&!t(this).hasClass("ui-state-disabled")?("string"==typeof a?o[a]:a).apply(o,arguments):void 0}"string"!=typeof a&&(s.guid=a.guid=a.guid||s.guid||t.guid++);var u=i.match(/^([\w:-]*)\s*(.*)$/),l=u[1]+o.eventNamespace,c=u[2];c?r.delegate(c,l,s):n.bind(l,s)})},_off:function(e,n){n=(n||"").split(" ").join(this.eventNamespace+" ")+this.eventNamespace,e.unbind(n).undelegate(n),this.bindings=t(this.bindings.not(e).get()),this.focusable=t(this.focusable.not(e).get()),this.hoverable=t(this.hoverable.not(e).get())},_delay:function(t,e){function n(){return("string"==typeof t?i[t]:t).apply(i,arguments)}var i=this;return setTimeout(n,e||0)},_hoverable:function(e){this.hoverable=this.hoverable.add(e),this._on(e,{mouseenter:function(e){t(e.currentTarget).addClass("ui-state-hover")},mouseleave:function(e){t(e.currentTarget).removeClass("ui-state-hover")}})},_focusable:function(e){this.focusable=this.focusable.add(e),this._on(e,{focusin:function(e){t(e.currentTarget).addClass("ui-state-focus")},focusout:function(e){t(e.currentTarget).removeClass("ui-state-focus")}})},_trigger:function(e,n,i){var r,o,a=this.options[e];if(i=i||{},n=t.Event(n),n.type=(e===this.widgetEventPrefix?e:this.widgetEventPrefix+e).toLowerCase(),n.target=this.element[0],o=n.originalEvent)for(r in o)r in n||(n[r]=o[r]);return this.element.trigger(n,i),!(t.isFunction(a)&&a.apply(this.element[0],[n].concat(i))===!1||n.isDefaultPrevented())}},t.each({show:"fadeIn",hide:"fadeOut"},function(e,n){t.Widget.prototype["_"+e]=function(i,r,o){"string"==typeof r&&(r={effect:r});var a,s=r?r===!0||"number"==typeof r?n:r.effect||n:e;r=r||{},"number"==typeof r&&(r={duration:r}),a=!t.isEmptyObject(r),r.complete=o,r.delay&&i.delay(r.delay),a&&t.effects&&t.effects.effect[s]?i[e](r):s!==e&&i[s]?i[s](r.duration,r.easing,o):i.queue(function(n){t(this)[e](),o&&o.call(i[0]),n()})}});var d=(t.widget,!1);t(document).mouseup(function(){d=!1});t.widget("ui.mouse",{version:"1.11.4",options:{cancel:"input,textarea,button,select,option",distance:1,delay:0},_mouseInit:function(){var e=this;this.element.bind("mousedown."+this.widgetName,function(t){return e._mouseDown(t)}).bind("click."+this.widgetName,function(n){return!0===t.data(n.target,e.widgetName+".preventClickEvent")?(t.removeData(n.target,e.widgetName+".preventClickEvent"),n.stopImmediatePropagation(),!1):void 0}),this.started=!1},_mouseDestroy:function(){this.element.unbind("."+this.widgetName),this._mouseMoveDelegate&&this.document.unbind("mousemove."+this.widgetName,this._mouseMoveDelegate).unbind("mouseup."+this.widgetName,this._mouseUpDelegate)},_mouseDown:function(e){if(!d){this._mouseMoved=!1,this._mouseStarted&&this._mouseUp(e),this._mouseDownEvent=e;var n=this,i=1===e.which,r="string"==typeof this.options.cancel&&e.target.nodeName?t(e.target).closest(this.options.cancel).length:!1;return i&&!r&&this._mouseCapture(e)?(this.mouseDelayMet=!this.options.delay,this.mouseDelayMet||(this._mouseDelayTimer=setTimeout(function(){n.mouseDelayMet=!0},this.options.delay)),this._mouseDistanceMet(e)&&this._mouseDelayMet(e)&&(this._mouseStarted=this._mouseStart(e)!==!1,!this._mouseStarted)?(e.preventDefault(),!0):(!0===t.data(e.target,this.widgetName+".preventClickEvent")&&t.removeData(e.target,this.widgetName+".preventClickEvent"),this._mouseMoveDelegate=function(t){return n._mouseMove(t)},this._mouseUpDelegate=function(t){return n._mouseUp(t)},this.document.bind("mousemove."+this.widgetName,this._mouseMoveDelegate).bind("mouseup."+this.widgetName,this._mouseUpDelegate),e.preventDefault(),d=!0,!0)):!0}},_mouseMove:function(e){if(this._mouseMoved){if(t.ui.ie&&(!document.documentMode||document.documentMode<9)&&!e.button)return this._mouseUp(e);if(!e.which)return this._mouseUp(e)}return(e.which||e.button)&&(this._mouseMoved=!0),this._mouseStarted?(this._mouseDrag(e),e.preventDefault()):(this._mouseDistanceMet(e)&&this._mouseDelayMet(e)&&(this._mouseStarted=this._mouseStart(this._mouseDownEvent,e)!==!1,this._mouseStarted?this._mouseDrag(e):this._mouseUp(e)),!this._mouseStarted)},_mouseUp:function(e){return this.document.unbind("mousemove."+this.widgetName,this._mouseMoveDelegate).unbind("mouseup."+this.widgetName,this._mouseUpDelegate),this._mouseStarted&&(this._mouseStarted=!1,e.target===this._mouseDownEvent.target&&t.data(e.target,this.widgetName+".preventClickEvent",!0),this._mouseStop(e)),d=!1,!1},_mouseDistanceMet:function(t){return Math.max(Math.abs(this._mouseDownEvent.pageX-t.pageX),Math.abs(this._mouseDownEvent.pageY-t.pageY))>=this.options.distance},_mouseDelayMet:function(){return this.mouseDelayMet},_mouseStart:function(){},_mouseDrag:function(){},_mouseStop:function(){},_mouseCapture:function(){return!0}});/*!
 * jQuery UI Position 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/position/
 */
!function(){function e(t,e,n){return[parseFloat(t[0])*(f.test(t[0])?e/100:1),parseFloat(t[1])*(f.test(t[1])?n/100:1)]}function n(e,n){return parseInt(t.css(e,n),10)||0}function i(e){var n=e[0];return 9===n.nodeType?{width:e.width(),height:e.height(),offset:{top:0,left:0}}:t.isWindow(n)?{width:e.width(),height:e.height(),offset:{top:e.scrollTop(),left:e.scrollLeft()}}:n.preventDefault?{width:0,height:0,offset:{top:n.pageY,left:n.pageX}}:{width:e.outerWidth(),height:e.outerHeight(),offset:e.offset()}}t.ui=t.ui||{};var r,o,a=Math.max,s=Math.abs,u=Math.round,l=/left|center|right/,c=/top|center|bottom/,d=/[\+\-]\d+(\.[\d]+)?%?/,h=/^\w+/,f=/%$/,p=t.fn.position;t.position={scrollbarWidth:function(){if(void 0!==r)return r;var e,n,i=t("<div style='display:block;position:absolute;width:50px;height:50px;overflow:hidden;'><div style='height:100px;width:auto;'></div></div>"),o=i.children()[0];return t("body").append(i),e=o.offsetWidth,i.css("overflow","scroll"),n=o.offsetWidth,e===n&&(n=i[0].clientWidth),i.remove(),r=e-n},getScrollInfo:function(e){var n=e.isWindow||e.isDocument?"":e.element.css("overflow-x"),i=e.isWindow||e.isDocument?"":e.element.css("overflow-y"),r="scroll"===n||"auto"===n&&e.width<e.element[0].scrollWidth,o="scroll"===i||"auto"===i&&e.height<e.element[0].scrollHeight;return{width:o?t.position.scrollbarWidth():0,height:r?t.position.scrollbarWidth():0}},getWithinInfo:function(e){var n=t(e||window),i=t.isWindow(n[0]),r=!!n[0]&&9===n[0].nodeType;return{element:n,isWindow:i,isDocument:r,offset:n.offset()||{left:0,top:0},scrollLeft:n.scrollLeft(),scrollTop:n.scrollTop(),width:i||r?n.width():n.outerWidth(),height:i||r?n.height():n.outerHeight()}}},t.fn.position=function(r){if(!r||!r.of)return p.apply(this,arguments);r=t.extend({},r);var f,g,m,v,y,b,x=t(r.of),w=t.position.getWithinInfo(r.within),_=t.position.getScrollInfo(w),$=(r.collision||"flip").split(" "),k={};return b=i(x),x[0].preventDefault&&(r.at="left top"),g=b.width,m=b.height,v=b.offset,y=t.extend({},v),t.each(["my","at"],function(){var t,e,n=(r[this]||"").split(" ");1===n.length&&(n=l.test(n[0])?n.concat(["center"]):c.test(n[0])?["center"].concat(n):["center","center"]),n[0]=l.test(n[0])?n[0]:"center",n[1]=c.test(n[1])?n[1]:"center",t=d.exec(n[0]),e=d.exec(n[1]),k[this]=[t?t[0]:0,e?e[0]:0],r[this]=[h.exec(n[0])[0],h.exec(n[1])[0]]}),1===$.length&&($[1]=$[0]),"right"===r.at[0]?y.left+=g:"center"===r.at[0]&&(y.left+=g/2),"bottom"===r.at[1]?y.top+=m:"center"===r.at[1]&&(y.top+=m/2),f=e(k.at,g,m),y.left+=f[0],y.top+=f[1],this.each(function(){var i,l,c=t(this),d=c.outerWidth(),h=c.outerHeight(),p=n(this,"marginLeft"),b=n(this,"marginTop"),C=d+p+n(this,"marginRight")+_.width,M=h+b+n(this,"marginBottom")+_.height,D=t.extend({},y),S=e(k.my,c.outerWidth(),c.outerHeight());"right"===r.my[0]?D.left-=d:"center"===r.my[0]&&(D.left-=d/2),"bottom"===r.my[1]?D.top-=h:"center"===r.my[1]&&(D.top-=h/2),D.left+=S[0],D.top+=S[1],o||(D.left=u(D.left),D.top=u(D.top)),i={marginLeft:p,marginTop:b},t.each(["left","top"],function(e,n){t.ui.position[$[e]]&&t.ui.position[$[e]][n](D,{targetWidth:g,targetHeight:m,elemWidth:d,elemHeight:h,collisionPosition:i,collisionWidth:C,collisionHeight:M,offset:[f[0]+S[0],f[1]+S[1]],my:r.my,at:r.at,within:w,elem:c})}),r.using&&(l=function(t){var e=v.left-D.left,n=e+g-d,i=v.top-D.top,o=i+m-h,u={target:{element:x,left:v.left,top:v.top,width:g,height:m},element:{element:c,left:D.left,top:D.top,width:d,height:h},horizontal:0>n?"left":e>0?"right":"center",vertical:0>o?"top":i>0?"bottom":"middle"};d>g&&s(e+n)<g&&(u.horizontal="center"),h>m&&s(i+o)<m&&(u.vertical="middle"),a(s(e),s(n))>a(s(i),s(o))?u.important="horizontal":u.important="vertical",r.using.call(this,t,u)}),c.offset(t.extend(D,{using:l}))})},t.ui.position={fit:{left:function(t,e){var n,i=e.within,r=i.isWindow?i.scrollLeft:i.offset.left,o=i.width,s=t.left-e.collisionPosition.marginLeft,u=r-s,l=s+e.collisionWidth-o-r;e.collisionWidth>o?u>0&&0>=l?(n=t.left+u+e.collisionWidth-o-r,t.left+=u-n):l>0&&0>=u?t.left=r:u>l?t.left=r+o-e.collisionWidth:t.left=r:u>0?t.left+=u:l>0?t.left-=l:t.left=a(t.left-s,t.left)},top:function(t,e){var n,i=e.within,r=i.isWindow?i.scrollTop:i.offset.top,o=e.within.height,s=t.top-e.collisionPosition.marginTop,u=r-s,l=s+e.collisionHeight-o-r;e.collisionHeight>o?u>0&&0>=l?(n=t.top+u+e.collisionHeight-o-r,t.top+=u-n):l>0&&0>=u?t.top=r:u>l?t.top=r+o-e.collisionHeight:t.top=r:u>0?t.top+=u:l>0?t.top-=l:t.top=a(t.top-s,t.top)}},flip:{left:function(t,e){var n,i,r=e.within,o=r.offset.left+r.scrollLeft,a=r.width,u=r.isWindow?r.scrollLeft:r.offset.left,l=t.left-e.collisionPosition.marginLeft,c=l-u,d=l+e.collisionWidth-a-u,h="left"===e.my[0]?-e.elemWidth:"right"===e.my[0]?e.elemWidth:0,f="left"===e.at[0]?e.targetWidth:"right"===e.at[0]?-e.targetWidth:0,p=-2*e.offset[0];0>c?(n=t.left+h+f+p+e.collisionWidth-a-o,(0>n||n<s(c))&&(t.left+=h+f+p)):d>0&&(i=t.left-e.collisionPosition.marginLeft+h+f+p-u,(i>0||s(i)<d)&&(t.left+=h+f+p))},top:function(t,e){var n,i,r=e.within,o=r.offset.top+r.scrollTop,a=r.height,u=r.isWindow?r.scrollTop:r.offset.top,l=t.top-e.collisionPosition.marginTop,c=l-u,d=l+e.collisionHeight-a-u,h="top"===e.my[1],f=h?-e.elemHeight:"bottom"===e.my[1]?e.elemHeight:0,p="top"===e.at[1]?e.targetHeight:"bottom"===e.at[1]?-e.targetHeight:0,g=-2*e.offset[1];0>c?(i=t.top+f+p+g+e.collisionHeight-a-o,(0>i||i<s(c))&&(t.top+=f+p+g)):d>0&&(n=t.top-e.collisionPosition.marginTop+f+p+g-u,(n>0||s(n)<d)&&(t.top+=f+p+g))}},flipfit:{left:function(){t.ui.position.flip.left.apply(this,arguments),t.ui.position.fit.left.apply(this,arguments)},top:function(){t.ui.position.flip.top.apply(this,arguments),t.ui.position.fit.top.apply(this,arguments)}}},function(){var e,n,i,r,a,s=document.getElementsByTagName("body")[0],u=document.createElement("div");e=document.createElement(s?"div":"body"),i={visibility:"hidden",width:0,height:0,border:0,margin:0,background:"none"},s&&t.extend(i,{position:"absolute",left:"-1000px",top:"-1000px"});for(a in i)e.style[a]=i[a];e.appendChild(u),n=s||document.documentElement,n.insertBefore(e,n.firstChild),u.style.cssText="position: absolute; left: 10.7432222px;",r=t(u).offset().left,o=r>10&&11>r,e.innerHTML="",n.removeChild(e)}()}();t.ui.position,t.widget("ui.accordion",{version:"1.11.4",options:{active:0,animate:{},collapsible:!1,event:"click",header:"> li > :first-child,> :not(li):even",heightStyle:"auto",icons:{activeHeader:"ui-icon-triangle-1-s",header:"ui-icon-triangle-1-e"},activate:null,beforeActivate:null},hideProps:{borderTopWidth:"hide",borderBottomWidth:"hide",paddingTop:"hide",paddingBottom:"hide",height:"hide"},showProps:{borderTopWidth:"show",borderBottomWidth:"show",paddingTop:"show",paddingBottom:"show",height:"show"},_create:function(){var e=this.options;this.prevShow=this.prevHide=t(),this.element.addClass("ui-accordion ui-widget ui-helper-reset").attr("role","tablist"),e.collapsible||e.active!==!1&&null!=e.active||(e.active=0),this._processPanels(),e.active<0&&(e.active+=this.headers.length),this._refresh()},_getCreateEventData:function(){return{header:this.active,panel:this.active.length?this.active.next():t()}},_createIcons:function(){var e=this.options.icons;e&&(t("<span>").addClass("ui-accordion-header-icon ui-icon "+e.header).prependTo(this.headers),this.active.children(".ui-accordion-header-icon").removeClass(e.header).addClass(e.activeHeader),this.headers.addClass("ui-accordion-icons"))},_destroyIcons:function(){this.headers.removeClass("ui-accordion-icons").children(".ui-accordion-header-icon").remove()},_destroy:function(){var t;this.element.removeClass("ui-accordion ui-widget ui-helper-reset").removeAttr("role"),this.headers.removeClass("ui-accordion-header ui-accordion-header-active ui-state-default ui-corner-all ui-state-active ui-state-disabled ui-corner-top").removeAttr("role").removeAttr("aria-expanded").removeAttr("aria-selected").removeAttr("aria-controls").removeAttr("tabIndex").removeUniqueId(),this._destroyIcons(),t=this.headers.next().removeClass("ui-helper-reset ui-widget-content ui-corner-bottom ui-accordion-content ui-accordion-content-active ui-state-disabled").css("display","").removeAttr("role").removeAttr("aria-hidden").removeAttr("aria-labelledby").removeUniqueId(),"content"!==this.options.heightStyle&&t.css("height","")},_setOption:function(t,e){return"active"===t?void this._activate(e):("event"===t&&(this.options.event&&this._off(this.headers,this.options.event),this._setupEvents(e)),this._super(t,e),"collapsible"!==t||e||this.options.active!==!1||this._activate(0),"icons"===t&&(this._destroyIcons(),e&&this._createIcons()),void("disabled"===t&&(this.element.toggleClass("ui-state-disabled",!!e).attr("aria-disabled",e),this.headers.add(this.headers.next()).toggleClass("ui-state-disabled",!!e))))},_keydown:function(e){if(!e.altKey&&!e.ctrlKey){var n=t.ui.keyCode,i=this.headers.length,r=this.headers.index(e.target),o=!1;switch(e.keyCode){case n.RIGHT:case n.DOWN:o=this.headers[(r+1)%i];break;case n.LEFT:case n.UP:o=this.headers[(r-1+i)%i];break;case n.SPACE:case n.ENTER:this._eventHandler(e);break;case n.HOME:o=this.headers[0];break;case n.END:o=this.headers[i-1]}o&&(t(e.target).attr("tabIndex",-1),t(o).attr("tabIndex",0),o.focus(),e.preventDefault())}},_panelKeyDown:function(e){e.keyCode===t.ui.keyCode.UP&&e.ctrlKey&&t(e.currentTarget).prev().focus()},refresh:function(){var e=this.options;this._processPanels(),e.active===!1&&e.collapsible===!0||!this.headers.length?(e.active=!1,this.active=t()):e.active===!1?this._activate(0):this.active.length&&!t.contains(this.element[0],this.active[0])?this.headers.length===this.headers.find(".ui-state-disabled").length?(e.active=!1,this.active=t()):this._activate(Math.max(0,e.active-1)):e.active=this.headers.index(this.active),this._destroyIcons(),this._refresh()},_processPanels:function(){var t=this.headers,e=this.panels;this.headers=this.element.find(this.options.header).addClass("ui-accordion-header ui-state-default ui-corner-all"),this.panels=this.headers.next().addClass("ui-accordion-content ui-helper-reset ui-widget-content ui-corner-bottom").filter(":not(.ui-accordion-content-active)").hide(),e&&(this._off(t.not(this.headers)),this._off(e.not(this.panels)))},_refresh:function(){var e,n=this.options,i=n.heightStyle,r=this.element.parent();this.active=this._findActive(n.active).addClass("ui-accordion-header-active ui-state-active ui-corner-top").removeClass("ui-corner-all"),this.active.next().addClass("ui-accordion-content-active").show(),this.headers.attr("role","tab").each(function(){var e=t(this),n=e.uniqueId().attr("id"),i=e.next(),r=i.uniqueId().attr("id");e.attr("aria-controls",r),i.attr("aria-labelledby",n)}).next().attr("role","tabpanel"),this.headers.not(this.active).attr({"aria-selected":"false","aria-expanded":"false",tabIndex:-1}).next().attr({"aria-hidden":"true"}).hide(),this.active.length?this.active.attr({"aria-selected":"true","aria-expanded":"true",tabIndex:0}).next().attr({"aria-hidden":"false"}):this.headers.eq(0).attr("tabIndex",0),this._createIcons(),this._setupEvents(n.event),"fill"===i?(e=r.height(),this.element.siblings(":visible").each(function(){var n=t(this),i=n.css("position");"absolute"!==i&&"fixed"!==i&&(e-=n.outerHeight(!0))}),this.headers.each(function(){e-=t(this).outerHeight(!0)}),this.headers.next().each(function(){t(this).height(Math.max(0,e-t(this).innerHeight()+t(this).height()))}).css("overflow","auto")):"auto"===i&&(e=0,this.headers.next().each(function(){e=Math.max(e,t(this).css("height","").height())}).height(e))},_activate:function(e){var n=this._findActive(e)[0];n!==this.active[0]&&(n=n||this.active[0],this._eventHandler({target:n,currentTarget:n,preventDefault:t.noop}))},_findActive:function(e){return"number"==typeof e?this.headers.eq(e):t()},_setupEvents:function(e){var n={keydown:"_keydown"};e&&t.each(e.split(" "),function(t,e){n[e]="_eventHandler"}),this._off(this.headers.add(this.headers.next())),this._on(this.headers,n),this._on(this.headers.next(),{keydown:"_panelKeyDown"}),this._hoverable(this.headers),this._focusable(this.headers)},_eventHandler:function(e){var n=this.options,i=this.active,r=t(e.currentTarget),o=r[0]===i[0],a=o&&n.collapsible,s=a?t():r.next(),u=i.next(),l={oldHeader:i,oldPanel:u,newHeader:a?t():r,newPanel:s};e.preventDefault(),o&&!n.collapsible||this._trigger("beforeActivate",e,l)===!1||(n.active=a?!1:this.headers.index(r),this.active=o?t():r,this._toggle(l),i.removeClass("ui-accordion-header-active ui-state-active"),n.icons&&i.children(".ui-accordion-header-icon").removeClass(n.icons.activeHeader).addClass(n.icons.header),o||(r.removeClass("ui-corner-all").addClass("ui-accordion-header-active ui-state-active ui-corner-top"),n.icons&&r.children(".ui-accordion-header-icon").removeClass(n.icons.header).addClass(n.icons.activeHeader),r.next().addClass("ui-accordion-content-active")))},_toggle:function(e){var n=e.newPanel,i=this.prevShow.length?this.prevShow:e.oldPanel;this.prevShow.add(this.prevHide).stop(!0,!0),this.prevShow=n,this.prevHide=i,this.options.animate?this._animate(n,i,e):(i.hide(),n.show(),this._toggleComplete(e)),i.attr({"aria-hidden":"true"}),i.prev().attr({"aria-selected":"false","aria-expanded":"false"}),n.length&&i.length?i.prev().attr({tabIndex:-1,"aria-expanded":"false"}):n.length&&this.headers.filter(function(){return 0===parseInt(t(this).attr("tabIndex"),10)}).attr("tabIndex",-1),n.attr("aria-hidden","false").prev().attr({"aria-selected":"true","aria-expanded":"true",tabIndex:0})},_animate:function(t,e,n){var i,r,o,a=this,s=0,u=t.css("box-sizing"),l=t.length&&(!e.length||t.index()<e.index()),c=this.options.animate||{},d=l&&c.down||c,h=function(){a._toggleComplete(n)};return"number"==typeof d&&(o=d),"string"==typeof d&&(r=d),r=r||d.easing||c.easing,o=o||d.duration||c.duration,e.length?t.length?(i=t.show().outerHeight(),e.animate(this.hideProps,{duration:o,easing:r,step:function(t,e){e.now=Math.round(t)}}),void t.hide().animate(this.showProps,{duration:o,easing:r,complete:h,step:function(t,n){n.now=Math.round(t),"height"!==n.prop?"content-box"===u&&(s+=n.now):"content"!==a.options.heightStyle&&(n.now=Math.round(i-e.outerHeight()-s),s=0)}})):e.animate(this.hideProps,o,r,h):t.animate(this.showProps,o,r,h)},_toggleComplete:function(t){var e=t.oldPanel;e.removeClass("ui-accordion-content-active").prev().removeClass("ui-corner-top").addClass("ui-corner-all"),e.length&&(e.parent()[0].className=e.parent()[0].className),this._trigger("activate",null,t)}}),t.widget("ui.menu",{version:"1.11.4",defaultElement:"<ul>",delay:300,options:{icons:{submenu:"ui-icon-carat-1-e"},items:"> *",menus:"ul",position:{my:"left-1 top",at:"right top"},role:"menu",blur:null,focus:null,select:null},_create:function(){this.activeMenu=this.element,this.mouseHandled=!1,this.element.uniqueId().addClass("ui-menu ui-widget ui-widget-content").toggleClass("ui-menu-icons",!!this.element.find(".ui-icon").length).attr({role:this.options.role,tabIndex:0}),this.options.disabled&&this.element.addClass("ui-state-disabled").attr("aria-disabled","true"),this._on({"mousedown .ui-menu-item":function(t){t.preventDefault()},"click .ui-menu-item":function(e){var n=t(e.target);!this.mouseHandled&&n.not(".ui-state-disabled").length&&(this.select(e),e.isPropagationStopped()||(this.mouseHandled=!0),n.has(".ui-menu").length?this.expand(e):!this.element.is(":focus")&&t(this.document[0].activeElement).closest(".ui-menu").length&&(this.element.trigger("focus",[!0]),this.active&&1===this.active.parents(".ui-menu").length&&clearTimeout(this.timer)))},"mouseenter .ui-menu-item":function(e){if(!this.previousFilter){var n=t(e.currentTarget);n.siblings(".ui-state-active").removeClass("ui-state-active"),this.focus(e,n)}},mouseleave:"collapseAll","mouseleave .ui-menu":"collapseAll",focus:function(t,e){var n=this.active||this.element.find(this.options.items).eq(0);e||this.focus(t,n)},blur:function(e){this._delay(function(){t.contains(this.element[0],this.document[0].activeElement)||this.collapseAll(e)})},keydown:"_keydown"}),this.refresh(),this._on(this.document,{click:function(t){this._closeOnDocumentClick(t)&&this.collapseAll(t),this.mouseHandled=!1}})},_destroy:function(){this.element.removeAttr("aria-activedescendant").find(".ui-menu").addBack().removeClass("ui-menu ui-widget ui-widget-content ui-menu-icons ui-front").removeAttr("role").removeAttr("tabIndex").removeAttr("aria-labelledby").removeAttr("aria-expanded").removeAttr("aria-hidden").removeAttr("aria-disabled").removeUniqueId().show(),this.element.find(".ui-menu-item").removeClass("ui-menu-item").removeAttr("role").removeAttr("aria-disabled").removeUniqueId().removeClass("ui-state-hover").removeAttr("tabIndex").removeAttr("role").removeAttr("aria-haspopup").children().each(function(){var e=t(this);e.data("ui-menu-submenu-carat")&&e.remove()}),this.element.find(".ui-menu-divider").removeClass("ui-menu-divider ui-widget-content")},_keydown:function(e){var n,i,r,o,a=!0;switch(e.keyCode){case t.ui.keyCode.PAGE_UP:this.previousPage(e);break;case t.ui.keyCode.PAGE_DOWN:this.nextPage(e);break;case t.ui.keyCode.HOME:this._move("first","first",e);break;case t.ui.keyCode.END:this._move("last","last",e);break;case t.ui.keyCode.UP:this.previous(e);break;case t.ui.keyCode.DOWN:this.next(e);break;case t.ui.keyCode.LEFT:this.collapse(e);break;case t.ui.keyCode.RIGHT:this.active&&!this.active.is(".ui-state-disabled")&&this.expand(e);break;case t.ui.keyCode.ENTER:case t.ui.keyCode.SPACE:this._activate(e);break;case t.ui.keyCode.ESCAPE:this.collapse(e);break;default:a=!1,i=this.previousFilter||"",r=String.fromCharCode(e.keyCode),o=!1,clearTimeout(this.filterTimer),r===i?o=!0:r=i+r,n=this._filterMenuItems(r),n=o&&-1!==n.index(this.active.next())?this.active.nextAll(".ui-menu-item"):n,n.length||(r=String.fromCharCode(e.keyCode),n=this._filterMenuItems(r)),n.length?(this.focus(e,n),this.previousFilter=r,this.filterTimer=this._delay(function(){delete this.previousFilter},1e3)):delete this.previousFilter}a&&e.preventDefault()},_activate:function(t){this.active.is(".ui-state-disabled")||(this.active.is("[aria-haspopup='true']")?this.expand(t):this.select(t))},refresh:function(){var e,n,i=this,r=this.options.icons.submenu,o=this.element.find(this.options.menus);this.element.toggleClass("ui-menu-icons",!!this.element.find(".ui-icon").length),o.filter(":not(.ui-menu)").addClass("ui-menu ui-widget ui-widget-content ui-front").hide().attr({role:this.options.role,"aria-hidden":"true","aria-expanded":"false"}).each(function(){var e=t(this),n=e.parent(),i=t("<span>").addClass("ui-menu-icon ui-icon "+r).data("ui-menu-submenu-carat",!0);n.attr("aria-haspopup","true").prepend(i),e.attr("aria-labelledby",n.attr("id"))}),e=o.add(this.element),n=e.find(this.options.items),n.not(".ui-menu-item").each(function(){var e=t(this);i._isDivider(e)&&e.addClass("ui-widget-content ui-menu-divider")}),n.not(".ui-menu-item, .ui-menu-divider").addClass("ui-menu-item").uniqueId().attr({tabIndex:-1,role:this._itemRole()}),n.filter(".ui-state-disabled").attr("aria-disabled","true"),this.active&&!t.contains(this.element[0],this.active[0])&&this.blur()},_itemRole:function(){return{menu:"menuitem",listbox:"option"}[this.options.role]},_setOption:function(t,e){"icons"===t&&this.element.find(".ui-menu-icon").removeClass(this.options.icons.submenu).addClass(e.submenu),"disabled"===t&&this.element.toggleClass("ui-state-disabled",!!e).attr("aria-disabled",e),this._super(t,e)},focus:function(t,e){var n,i;this.blur(t,t&&"focus"===t.type),this._scrollIntoView(e),this.active=e.first(),i=this.active.addClass("ui-state-focus").removeClass("ui-state-active"),this.options.role&&this.element.attr("aria-activedescendant",i.attr("id")),this.active.parent().closest(".ui-menu-item").addClass("ui-state-active"),t&&"keydown"===t.type?this._close():this.timer=this._delay(function(){this._close()},this.delay),n=e.children(".ui-menu"),n.length&&t&&/^mouse/.test(t.type)&&this._startOpening(n),this.activeMenu=e.parent(),this._trigger("focus",t,{item:e})},_scrollIntoView:function(e){var n,i,r,o,a,s;this._hasScroll()&&(n=parseFloat(t.css(this.activeMenu[0],"borderTopWidth"))||0,i=parseFloat(t.css(this.activeMenu[0],"paddingTop"))||0,r=e.offset().top-this.activeMenu.offset().top-n-i,o=this.activeMenu.scrollTop(),a=this.activeMenu.height(),s=e.outerHeight(),0>r?this.activeMenu.scrollTop(o+r):r+s>a&&this.activeMenu.scrollTop(o+r-a+s))},blur:function(t,e){e||clearTimeout(this.timer),this.active&&(this.active.removeClass("ui-state-focus"),this.active=null,this._trigger("blur",t,{item:this.active}))},_startOpening:function(t){clearTimeout(this.timer),"true"===t.attr("aria-hidden")&&(this.timer=this._delay(function(){this._close(),this._open(t)},this.delay))},_open:function(e){var n=t.extend({of:this.active},this.options.position);clearTimeout(this.timer),this.element.find(".ui-menu").not(e.parents(".ui-menu")).hide().attr("aria-hidden","true"),e.show().removeAttr("aria-hidden").attr("aria-expanded","true").position(n)},collapseAll:function(e,n){clearTimeout(this.timer),this.timer=this._delay(function(){var i=n?this.element:t(e&&e.target).closest(this.element.find(".ui-menu"));i.length||(i=this.element),this._close(i),this.blur(e),this.activeMenu=i},this.delay)},_close:function(t){t||(t=this.active?this.active.parent():this.element),t.find(".ui-menu").hide().attr("aria-hidden","true").attr("aria-expanded","false").end().find(".ui-state-active").not(".ui-state-focus").removeClass("ui-state-active")},_closeOnDocumentClick:function(e){return!t(e.target).closest(".ui-menu").length},_isDivider:function(t){return!/[^\-\u2014\u2013\s]/.test(t.text())},collapse:function(t){var e=this.active&&this.active.parent().closest(".ui-menu-item",this.element);e&&e.length&&(this._close(),this.focus(t,e))},expand:function(t){var e=this.active&&this.active.children(".ui-menu ").find(this.options.items).first();e&&e.length&&(this._open(e.parent()),this._delay(function(){this.focus(t,e)}))},next:function(t){this._move("next","first",t)},previous:function(t){this._move("prev","last",t)},isFirstItem:function(){return this.active&&!this.active.prevAll(".ui-menu-item").length},isLastItem:function(){return this.active&&!this.active.nextAll(".ui-menu-item").length},_move:function(t,e,n){var i;this.active&&(i="first"===t||"last"===t?this.active["first"===t?"prevAll":"nextAll"](".ui-menu-item").eq(-1):this.active[t+"All"](".ui-menu-item").eq(0)),i&&i.length&&this.active||(i=this.activeMenu.find(this.options.items)[e]()),this.focus(n,i)},nextPage:function(e){var n,i,r;return this.active?void(this.isLastItem()||(this._hasScroll()?(i=this.active.offset().top,r=this.element.height(),this.active.nextAll(".ui-menu-item").each(function(){return n=t(this),n.offset().top-i-r<0}),this.focus(e,n)):this.focus(e,this.activeMenu.find(this.options.items)[this.active?"last":"first"]()))):void this.next(e)},previousPage:function(e){var n,i,r;return this.active?void(this.isFirstItem()||(this._hasScroll()?(i=this.active.offset().top,r=this.element.height(),this.active.prevAll(".ui-menu-item").each(function(){return n=t(this),n.offset().top-i+r>0}),this.focus(e,n)):this.focus(e,this.activeMenu.find(this.options.items).first()))):void this.next(e)},_hasScroll:function(){return this.element.outerHeight()<this.element.prop("scrollHeight")},select:function(e){this.active=this.active||t(e.target).closest(".ui-menu-item");var n={item:this.active};this.active.has(".ui-menu").length||this.collapseAll(e,!0),this._trigger("select",e,n)},_filterMenuItems:function(e){var n=e.replace(/[\-\[\]{}()*+?.,\\\^$|#\s]/g,"\\$&"),i=new RegExp("^"+n,"i");return this.activeMenu.find(this.options.items).filter(".ui-menu-item").filter(function(){return i.test(t.trim(t(this).text()))})}});/*!
 * jQuery UI Autocomplete 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/autocomplete/
 */
t.widget("ui.autocomplete",{version:"1.11.4",defaultElement:"<input>",options:{appendTo:null,autoFocus:!1,delay:300,minLength:1,position:{my:"left top",at:"left bottom",collision:"none"},source:null,change:null,close:null,focus:null,open:null,response:null,search:null,select:null},requestIndex:0,pending:0,_create:function(){var e,n,i,r=this.element[0].nodeName.toLowerCase(),o="textarea"===r,a="input"===r;this.isMultiLine=o?!0:a?!1:this.element.prop("isContentEditable"),this.valueMethod=this.element[o||a?"val":"text"],this.isNewMenu=!0,this.element.addClass("ui-autocomplete-input").attr("autocomplete","off"),this._on(this.element,{keydown:function(r){if(this.element.prop("readOnly"))return e=!0,i=!0,void(n=!0);e=!1,i=!1,n=!1;var o=t.ui.keyCode;switch(r.keyCode){case o.PAGE_UP:e=!0,this._move("previousPage",r);break;case o.PAGE_DOWN:e=!0,this._move("nextPage",r);break;case o.UP:e=!0,this._keyEvent("previous",r);break;case o.DOWN:e=!0,this._keyEvent("next",r);break;case o.ENTER:this.menu.active&&(e=!0,r.preventDefault(),this.menu.select(r));break;case o.TAB:this.menu.active&&this.menu.select(r);break;case o.ESCAPE:this.menu.element.is(":visible")&&(this.isMultiLine||this._value(this.term),this.close(r),r.preventDefault());break;default:n=!0,this._searchTimeout(r)}},keypress:function(i){if(e)return e=!1,void((!this.isMultiLine||this.menu.element.is(":visible"))&&i.preventDefault());if(!n){var r=t.ui.keyCode;switch(i.keyCode){case r.PAGE_UP:this._move("previousPage",i);break;case r.PAGE_DOWN:this._move("nextPage",i);break;case r.UP:this._keyEvent("previous",i);break;case r.DOWN:this._keyEvent("next",i)}}},input:function(t){return i?(i=!1,void t.preventDefault()):void this._searchTimeout(t)},focus:function(){this.selectedItem=null,this.previous=this._value()},blur:function(t){return this.cancelBlur?void delete this.cancelBlur:(clearTimeout(this.searching),this.close(t),void this._change(t))}}),this._initSource(),this.menu=t("<ul>").addClass("ui-autocomplete ui-front").appendTo(this._appendTo()).menu({role:null}).hide().menu("instance"),this._on(this.menu.element,{mousedown:function(e){e.preventDefault(),this.cancelBlur=!0,this._delay(function(){delete this.cancelBlur});var n=this.menu.element[0];t(e.target).closest(".ui-menu-item").length||this._delay(function(){var e=this;this.document.one("mousedown",function(i){i.target===e.element[0]||i.target===n||t.contains(n,i.target)||e.close()})})},menufocus:function(e,n){var i,r;return this.isNewMenu&&(this.isNewMenu=!1,e.originalEvent&&/^mouse/.test(e.originalEvent.type))?(this.menu.blur(),void this.document.one("mousemove",function(){t(e.target).trigger(e.originalEvent)})):(r=n.item.data("ui-autocomplete-item"),!1!==this._trigger("focus",e,{item:r})&&e.originalEvent&&/^key/.test(e.originalEvent.type)&&this._value(r.value),i=n.item.attr("aria-label")||r.value,void(i&&t.trim(i).length&&(this.liveRegion.children().hide(),t("<div>").text(i).appendTo(this.liveRegion))))},menuselect:function(t,e){var n=e.item.data("ui-autocomplete-item"),i=this.previous;this.element[0]!==this.document[0].activeElement&&(this.element.focus(),this.previous=i,this._delay(function(){this.previous=i,this.selectedItem=n})),!1!==this._trigger("select",t,{item:n})&&this._value(n.value),this.term=this._value(),this.close(t),this.selectedItem=n}}),this.liveRegion=t("<span>",{role:"status","aria-live":"assertive","aria-relevant":"additions"}).addClass("ui-helper-hidden-accessible").appendTo(this.document[0].body),this._on(this.window,{beforeunload:function(){this.element.removeAttr("autocomplete")}})},_destroy:function(){clearTimeout(this.searching),this.element.removeClass("ui-autocomplete-input").removeAttr("autocomplete"),this.menu.element.remove(),this.liveRegion.remove()},_setOption:function(t,e){this._super(t,e),"source"===t&&this._initSource(),"appendTo"===t&&this.menu.element.appendTo(this._appendTo()),"disabled"===t&&e&&this.xhr&&this.xhr.abort()},_appendTo:function(){var e=this.options.appendTo;return e&&(e=e.jquery||e.nodeType?t(e):this.document.find(e).eq(0)),e&&e[0]||(e=this.element.closest(".ui-front")),e.length||(e=this.document[0].body),e},_initSource:function(){var e,n,i=this;t.isArray(this.options.source)?(e=this.options.source,this.source=function(n,i){i(t.ui.autocomplete.filter(e,n.term))}):"string"==typeof this.options.source?(n=this.options.source,this.source=function(e,r){i.xhr&&i.xhr.abort(),i.xhr=t.ajax({url:n,data:e,dataType:"json",success:function(t){r(t)},error:function(){r([])}})}):this.source=this.options.source},_searchTimeout:function(t){clearTimeout(this.searching),this.searching=this._delay(function(){var e=this.term===this._value(),n=this.menu.element.is(":visible"),i=t.altKey||t.ctrlKey||t.metaKey||t.shiftKey;(!e||e&&!n&&!i)&&(this.selectedItem=null,this.search(null,t))},this.options.delay)},search:function(t,e){return t=null!=t?t:this._value(),this.term=this._value(),t.length<this.options.minLength?this.close(e):this._trigger("search",e)!==!1?this._search(t):void 0},_search:function(t){this.pending++,this.element.addClass("ui-autocomplete-loading"),this.cancelSearch=!1,this.source({term:t},this._response())},_response:function(){var e=++this.requestIndex;return t.proxy(function(t){e===this.requestIndex&&this.__response(t),this.pending--,this.pending||this.element.removeClass("ui-autocomplete-loading")},this)},__response:function(t){t&&(t=this._normalize(t)),this._trigger("response",null,{content:t}),!this.options.disabled&&t&&t.length&&!this.cancelSearch?(this._suggest(t),this._trigger("open")):this._close()},close:function(t){this.cancelSearch=!0,this._close(t)},_close:function(t){this.menu.element.is(":visible")&&(this.menu.element.hide(),this.menu.blur(),this.isNewMenu=!0,this._trigger("close",t))},_change:function(t){this.previous!==this._value()&&this._trigger("change",t,{item:this.selectedItem})},_normalize:function(e){return e.length&&e[0].label&&e[0].value?e:t.map(e,function(e){return"string"==typeof e?{label:e,value:e}:t.extend({},e,{label:e.label||e.value,value:e.value||e.label})})},_suggest:function(e){var n=this.menu.element.empty();this._renderMenu(n,e),this.isNewMenu=!0,this.menu.refresh(),n.show(),this._resizeMenu(),n.position(t.extend({of:this.element},this.options.position)),this.options.autoFocus&&this.menu.next()},_resizeMenu:function(){var t=this.menu.element;t.outerWidth(Math.max(t.width("").outerWidth()+1,this.element.outerWidth()))},_renderMenu:function(e,n){var i=this;t.each(n,function(t,n){i._renderItemData(e,n)})},_renderItemData:function(t,e){return this._renderItem(t,e).data("ui-autocomplete-item",e)},_renderItem:function(e,n){return t("<li>").text(n.label).appendTo(e)},_move:function(t,e){return this.menu.element.is(":visible")?this.menu.isFirstItem()&&/^previous/.test(t)||this.menu.isLastItem()&&/^next/.test(t)?(this.isMultiLine||this._value(this.term),void this.menu.blur()):void this.menu[t](e):void this.search(null,e)},widget:function(){return this.menu.element},_value:function(){return this.valueMethod.apply(this.element,arguments)},_keyEvent:function(t,e){(!this.isMultiLine||this.menu.element.is(":visible"))&&(this._move(t,e),e.preventDefault())}}),t.extend(t.ui.autocomplete,{escapeRegex:function(t){return t.replace(/[\-\[\]{}()*+?.,\\\^$|#\s]/g,"\\$&")},filter:function(e,n){var i=new RegExp(t.ui.autocomplete.escapeRegex(n),"i");return t.grep(e,function(t){return i.test(t.label||t.value||t)})}}),t.widget("ui.autocomplete",t.ui.autocomplete,{options:{messages:{noResults:"No search results.",results:function(t){return t+(t>1?" results are":" result is")+" available, use up and down arrow keys to navigate."}}},__response:function(e){var n;this._superApply(arguments),this.options.disabled||this.cancelSearch||(n=e&&e.length?this.options.messages.results(e.length):this.options.messages.noResults,this.liveRegion.children().hide(),t("<div>").text(n).appendTo(this.liveRegion))}});var h,f=(t.ui.autocomplete,"ui-button ui-widget ui-state-default ui-corner-all"),p="ui-button-icons-only ui-button-icon-only ui-button-text-icons ui-button-text-icon-primary ui-button-text-icon-secondary ui-button-text-only",g=function(){var e=t(this);setTimeout(function(){e.find(":ui-button").button("refresh")},1)},m=function(e){var n=e.name,i=e.form,r=t([]);return n&&(n=n.replace(/'/g,"\\'"),r=i?t(i).find("[name='"+n+"'][type=radio]"):t("[name='"+n+"'][type=radio]",e.ownerDocument).filter(function(){return!this.form})),r};t.widget("ui.button",{version:"1.11.4",defaultElement:"<button>",options:{disabled:null,text:!0,label:null,icons:{primary:null,secondary:null}},_create:function(){this.element.closest("form").unbind("reset"+this.eventNamespace).bind("reset"+this.eventNamespace,g),"boolean"!=typeof this.options.disabled?this.options.disabled=!!this.element.prop("disabled"):this.element.prop("disabled",this.options.disabled),this._determineButtonType(),this.hasTitle=!!this.buttonElement.attr("title");var e=this,n=this.options,i="checkbox"===this.type||"radio"===this.type,r=i?"":"ui-state-active";null===n.label&&(n.label="input"===this.type?this.buttonElement.val():this.buttonElement.html()),this._hoverable(this.buttonElement),this.buttonElement.addClass(f).attr("role","button").bind("mouseenter"+this.eventNamespace,function(){n.disabled||this===h&&t(this).addClass("ui-state-active")}).bind("mouseleave"+this.eventNamespace,function(){n.disabled||t(this).removeClass(r)}).bind("click"+this.eventNamespace,function(t){n.disabled&&(t.preventDefault(),t.stopImmediatePropagation())}),this._on({focus:function(){this.buttonElement.addClass("ui-state-focus")},blur:function(){this.buttonElement.removeClass("ui-state-focus")}}),i&&this.element.bind("change"+this.eventNamespace,function(){e.refresh()}),"checkbox"===this.type?this.buttonElement.bind("click"+this.eventNamespace,function(){return n.disabled?!1:void 0}):"radio"===this.type?this.buttonElement.bind("click"+this.eventNamespace,function(){if(n.disabled)return!1;t(this).addClass("ui-state-active"),e.buttonElement.attr("aria-pressed","true");var i=e.element[0];m(i).not(i).map(function(){return t(this).button("widget")[0]}).removeClass("ui-state-active").attr("aria-pressed","false")}):(this.buttonElement.bind("mousedown"+this.eventNamespace,function(){return n.disabled?!1:(t(this).addClass("ui-state-active"),h=this,void e.document.one("mouseup",function(){h=null}))}).bind("mouseup"+this.eventNamespace,function(){return n.disabled?!1:void t(this).removeClass("ui-state-active")}).bind("keydown"+this.eventNamespace,function(e){return n.disabled?!1:void((e.keyCode===t.ui.keyCode.SPACE||e.keyCode===t.ui.keyCode.ENTER)&&t(this).addClass("ui-state-active"))}).bind("keyup"+this.eventNamespace+" blur"+this.eventNamespace,function(){t(this).removeClass("ui-state-active")}),this.buttonElement.is("a")&&this.buttonElement.keyup(function(e){e.keyCode===t.ui.keyCode.SPACE&&t(this).click()})),this._setOption("disabled",n.disabled),this._resetButton()},_determineButtonType:function(){var t,e,n;this.element.is("[type=checkbox]")?this.type="checkbox":this.element.is("[type=radio]")?this.type="radio":this.element.is("input")?this.type="input":this.type="button","checkbox"===this.type||"radio"===this.type?(t=this.element.parents().last(),e="label[for='"+this.element.attr("id")+"']",this.buttonElement=t.find(e),this.buttonElement.length||(t=t.length?t.siblings():this.element.siblings(),this.buttonElement=t.filter(e),this.buttonElement.length||(this.buttonElement=t.find(e))),this.element.addClass("ui-helper-hidden-accessible"),n=this.element.is(":checked"),n&&this.buttonElement.addClass("ui-state-active"),this.buttonElement.prop("aria-pressed",n)):this.buttonElement=this.element},widget:function(){return this.buttonElement},_destroy:function(){this.element.removeClass("ui-helper-hidden-accessible"),this.buttonElement.removeClass(f+" ui-state-active "+p).removeAttr("role").removeAttr("aria-pressed").html(this.buttonElement.find(".ui-button-text").html()),this.hasTitle||this.buttonElement.removeAttr("title")},_setOption:function(t,e){return this._super(t,e),"disabled"===t?(this.widget().toggleClass("ui-state-disabled",!!e),this.element.prop("disabled",!!e),void(e&&("checkbox"===this.type||"radio"===this.type?this.buttonElement.removeClass("ui-state-focus"):this.buttonElement.removeClass("ui-state-focus ui-state-active")))):void this._resetButton()},refresh:function(){var e=this.element.is("input, button")?this.element.is(":disabled"):this.element.hasClass("ui-button-disabled");e!==this.options.disabled&&this._setOption("disabled",e),"radio"===this.type?m(this.element[0]).each(function(){t(this).is(":checked")?t(this).button("widget").addClass("ui-state-active").attr("aria-pressed","true"):t(this).button("widget").removeClass("ui-state-active").attr("aria-pressed","false")}):"checkbox"===this.type&&(this.element.is(":checked")?this.buttonElement.addClass("ui-state-active").attr("aria-pressed","true"):this.buttonElement.removeClass("ui-state-active").attr("aria-pressed","false"))},_resetButton:function(){if("input"===this.type)return void(this.options.label&&this.element.val(this.options.label));var e=this.buttonElement.removeClass(p),n=t("<span></span>",this.document[0]).addClass("ui-button-text").html(this.options.label).appendTo(e.empty()).text(),i=this.options.icons,r=i.primary&&i.secondary,o=[];i.primary||i.secondary?(this.options.text&&o.push("ui-button-text-icon"+(r?"s":i.primary?"-primary":"-secondary")),i.primary&&e.prepend("<span class='ui-button-icon-primary ui-icon "+i.primary+"'></span>"),i.secondary&&e.append("<span class='ui-button-icon-secondary ui-icon "+i.secondary+"'></span>"),this.options.text||(o.push(r?"ui-button-icons-only":"ui-button-icon-only"),this.hasTitle||e.attr("title",t.trim(n)))):o.push("ui-button-text-only"),e.addClass(o.join(" "))}}),t.widget("ui.buttonset",{version:"1.11.4",options:{items:"button, input[type=button], input[type=submit], input[type=reset], input[type=checkbox], input[type=radio], a, :data(ui-button)"},_create:function(){this.element.addClass("ui-buttonset")},_init:function(){this.refresh()},_setOption:function(t,e){"disabled"===t&&this.buttons.button("option",t,e),this._super(t,e)},refresh:function(){var e="rtl"===this.element.css("direction"),n=this.element.find(this.options.items),i=n.filter(":ui-button");n.not(":ui-button").button(),i.button("refresh"),this.buttons=n.map(function(){return t(this).button("widget")[0]}).removeClass("ui-corner-all ui-corner-left ui-corner-right").filter(":first").addClass(e?"ui-corner-right":"ui-corner-left").end().filter(":last").addClass(e?"ui-corner-left":"ui-corner-right").end().end()},_destroy:function(){this.element.removeClass("ui-buttonset"),this.buttons.map(function(){return t(this).button("widget")[0]}).removeClass("ui-corner-left ui-corner-right").end().button("destroy")}});t.ui.button;/*!
 * jQuery UI Datepicker 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/datepicker/
 */
t.extend(t.ui,{datepicker:{version:"1.11.4"}});var v;t.extend(r.prototype,{markerClassName:"hasDatepicker",maxRows:4,_widgetDatepicker:function(){return this.dpDiv},setDefaults:function(t){return s(this._defaults,t||{}),this},_attachDatepicker:function(e,n){var i,r,o;i=e.nodeName.toLowerCase(),r="div"===i||"span"===i,e.id||(this.uuid+=1,e.id="dp"+this.uuid),o=this._newInst(t(e),r),o.settings=t.extend({},n||{}),"input"===i?this._connectDatepicker(e,o):r&&this._inlineDatepicker(e,o)},_newInst:function(e,n){var i=e[0].id.replace(/([^A-Za-z0-9_\-])/g,"\\\\$1");return{id:i,input:e,selectedDay:0,selectedMonth:0,selectedYear:0,drawMonth:0,drawYear:0,inline:n,dpDiv:n?o(t("<div class='"+this._inlineClass+" ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all'></div>")):this.dpDiv}},_connectDatepicker:function(e,n){var i=t(e);n.append=t([]),n.trigger=t([]),i.hasClass(this.markerClassName)||(this._attachments(i,n),i.addClass(this.markerClassName).keydown(this._doKeyDown).keypress(this._doKeyPress).keyup(this._doKeyUp),this._autoSize(n),t.data(e,"datepicker",n),n.settings.disabled&&this._disableDatepicker(e))},_attachments:function(e,n){var i,r,o,a=this._get(n,"appendText"),s=this._get(n,"isRTL");n.append&&n.append.remove(),a&&(n.append=t("<span class='"+this._appendClass+"'>"+a+"</span>"),e[s?"before":"after"](n.append)),e.unbind("focus",this._showDatepicker),n.trigger&&n.trigger.remove(),i=this._get(n,"showOn"),("focus"===i||"both"===i)&&e.focus(this._showDatepicker),("button"===i||"both"===i)&&(r=this._get(n,"buttonText"),o=this._get(n,"buttonImage"),n.trigger=t(this._get(n,"buttonImageOnly")?t("<img/>").addClass(this._triggerClass).attr({src:o,alt:r,title:r}):t("<button type='button'></button>").addClass(this._triggerClass).html(o?t("<img/>").attr({src:o,alt:r,title:r}):r)),e[s?"before":"after"](n.trigger),n.trigger.click(function(){return t.datepicker._datepickerShowing&&t.datepicker._lastInput===e[0]?t.datepicker._hideDatepicker():t.datepicker._datepickerShowing&&t.datepicker._lastInput!==e[0]?(t.datepicker._hideDatepicker(),t.datepicker._showDatepicker(e[0])):t.datepicker._showDatepicker(e[0]),!1}))},_autoSize:function(t){if(this._get(t,"autoSize")&&!t.inline){var e,n,i,r,o=new Date(2009,11,20),a=this._get(t,"dateFormat");a.match(/[DM]/)&&(e=function(t){for(n=0,i=0,r=0;r<t.length;r++)t[r].length>n&&(n=t[r].length,i=r);return i},o.setMonth(e(this._get(t,a.match(/MM/)?"monthNames":"monthNamesShort"))),o.setDate(e(this._get(t,a.match(/DD/)?"dayNames":"dayNamesShort"))+20-o.getDay())),t.input.attr("size",this._formatDate(t,o).length)}},_inlineDatepicker:function(e,n){var i=t(e);i.hasClass(this.markerClassName)||(i.addClass(this.markerClassName).append(n.dpDiv),t.data(e,"datepicker",n),this._setDate(n,this._getDefaultDate(n),!0),this._updateDatepicker(n),this._updateAlternate(n),n.settings.disabled&&this._disableDatepicker(e),n.dpDiv.css("display","block"))},_dialogDatepicker:function(e,n,i,r,o){var a,u,l,c,d,h=this._dialogInst;return h||(this.uuid+=1,a="dp"+this.uuid,this._dialogInput=t("<input type='text' id='"+a+"' style='position: absolute; top: -100px; width: 0px;'/>"),this._dialogInput.keydown(this._doKeyDown),t("body").append(this._dialogInput),h=this._dialogInst=this._newInst(this._dialogInput,!1),h.settings={},t.data(this._dialogInput[0],"datepicker",h)),s(h.settings,r||{}),n=n&&n.constructor===Date?this._formatDate(h,n):n,this._dialogInput.val(n),this._pos=o?o.length?o:[o.pageX,o.pageY]:null,this._pos||(u=document.documentElement.clientWidth,l=document.documentElement.clientHeight,c=document.documentElement.scrollLeft||document.body.scrollLeft,d=document.documentElement.scrollTop||document.body.scrollTop,this._pos=[u/2-100+c,l/2-150+d]),this._dialogInput.css("left",this._pos[0]+20+"px").css("top",this._pos[1]+"px"),h.settings.onSelect=i,this._inDialog=!0,this.dpDiv.addClass(this._dialogClass),this._showDatepicker(this._dialogInput[0]),t.blockUI&&t.blockUI(this.dpDiv),t.data(this._dialogInput[0],"datepicker",h),this},_destroyDatepicker:function(e){var n,i=t(e),r=t.data(e,"datepicker");i.hasClass(this.markerClassName)&&(n=e.nodeName.toLowerCase(),t.removeData(e,"datepicker"),"input"===n?(r.append.remove(),r.trigger.remove(),i.removeClass(this.markerClassName).unbind("focus",this._showDatepicker).unbind("keydown",this._doKeyDown).unbind("keypress",this._doKeyPress).unbind("keyup",this._doKeyUp)):("div"===n||"span"===n)&&i.removeClass(this.markerClassName).empty(),v===r&&(v=null))},_enableDatepicker:function(e){var n,i,r=t(e),o=t.data(e,"datepicker");r.hasClass(this.markerClassName)&&(n=e.nodeName.toLowerCase(),"input"===n?(e.disabled=!1,o.trigger.filter("button").each(function(){this.disabled=!1}).end().filter("img").css({opacity:"1.0",cursor:""})):("div"===n||"span"===n)&&(i=r.children("."+this._inlineClass),i.children().removeClass("ui-state-disabled"),i.find("select.ui-datepicker-month, select.ui-datepicker-year").prop("disabled",!1)),this._disabledInputs=t.map(this._disabledInputs,function(t){return t===e?null:t}))},_disableDatepicker:function(e){var n,i,r=t(e),o=t.data(e,"datepicker");r.hasClass(this.markerClassName)&&(n=e.nodeName.toLowerCase(),"input"===n?(e.disabled=!0,o.trigger.filter("button").each(function(){this.disabled=!0}).end().filter("img").css({opacity:"0.5",cursor:"default"})):("div"===n||"span"===n)&&(i=r.children("."+this._inlineClass),i.children().addClass("ui-state-disabled"),i.find("select.ui-datepicker-month, select.ui-datepicker-year").prop("disabled",!0)),this._disabledInputs=t.map(this._disabledInputs,function(t){return t===e?null:t}),this._disabledInputs[this._disabledInputs.length]=e)},_isDisabledDatepicker:function(t){if(!t)return!1;for(var e=0;e<this._disabledInputs.length;e++)if(this._disabledInputs[e]===t)return!0;return!1},_getInst:function(e){try{return t.data(e,"datepicker")}catch(n){throw"Missing instance data for this datepicker"}},_optionDatepicker:function(e,n,i){var r,o,a,u,l=this._getInst(e);return 2===arguments.length&&"string"==typeof n?"defaults"===n?t.extend({},t.datepicker._defaults):l?"all"===n?t.extend({},l.settings):this._get(l,n):null:(r=n||{},"string"==typeof n&&(r={},r[n]=i),void(l&&(this._curInst===l&&this._hideDatepicker(),o=this._getDateDatepicker(e,!0),a=this._getMinMaxDate(l,"min"),u=this._getMinMaxDate(l,"max"),s(l.settings,r),null!==a&&void 0!==r.dateFormat&&void 0===r.minDate&&(l.settings.minDate=this._formatDate(l,a)),null!==u&&void 0!==r.dateFormat&&void 0===r.maxDate&&(l.settings.maxDate=this._formatDate(l,u)),"disabled"in r&&(r.disabled?this._disableDatepicker(e):this._enableDatepicker(e)),this._attachments(t(e),l),this._autoSize(l),this._setDate(l,o),this._updateAlternate(l),this._updateDatepicker(l))))},_changeDatepicker:function(t,e,n){this._optionDatepicker(t,e,n)},_refreshDatepicker:function(t){var e=this._getInst(t);e&&this._updateDatepicker(e)},_setDateDatepicker:function(t,e){var n=this._getInst(t);n&&(this._setDate(n,e),this._updateDatepicker(n),this._updateAlternate(n))},_getDateDatepicker:function(t,e){var n=this._getInst(t);return n&&!n.inline&&this._setDateFromField(n,e),n?this._getDate(n):null},_doKeyDown:function(e){var n,i,r,o=t.datepicker._getInst(e.target),a=!0,s=o.dpDiv.is(".ui-datepicker-rtl");if(o._keyEvent=!0,t.datepicker._datepickerShowing)switch(e.keyCode){case 9:t.datepicker._hideDatepicker(),a=!1;break;case 13:return r=t("td."+t.datepicker._dayOverClass+":not(."+t.datepicker._currentClass+")",o.dpDiv),r[0]&&t.datepicker._selectDay(e.target,o.selectedMonth,o.selectedYear,r[0]),n=t.datepicker._get(o,"onSelect"),n?(i=t.datepicker._formatDate(o),n.apply(o.input?o.input[0]:null,[i,o])):t.datepicker._hideDatepicker(),!1;case 27:t.datepicker._hideDatepicker();break;case 33:t.datepicker._adjustDate(e.target,e.ctrlKey?-t.datepicker._get(o,"stepBigMonths"):-t.datepicker._get(o,"stepMonths"),"M");break;case 34:t.datepicker._adjustDate(e.target,e.ctrlKey?+t.datepicker._get(o,"stepBigMonths"):+t.datepicker._get(o,"stepMonths"),"M");break;case 35:(e.ctrlKey||e.metaKey)&&t.datepicker._clearDate(e.target),a=e.ctrlKey||e.metaKey;break;case 36:(e.ctrlKey||e.metaKey)&&t.datepicker._gotoToday(e.target),a=e.ctrlKey||e.metaKey;break;case 37:(e.ctrlKey||e.metaKey)&&t.datepicker._adjustDate(e.target,s?1:-1,"D"),a=e.ctrlKey||e.metaKey,e.originalEvent.altKey&&t.datepicker._adjustDate(e.target,e.ctrlKey?-t.datepicker._get(o,"stepBigMonths"):-t.datepicker._get(o,"stepMonths"),"M");break;case 38:(e.ctrlKey||e.metaKey)&&t.datepicker._adjustDate(e.target,-7,"D"),a=e.ctrlKey||e.metaKey;break;case 39:(e.ctrlKey||e.metaKey)&&t.datepicker._adjustDate(e.target,s?-1:1,"D"),a=e.ctrlKey||e.metaKey,e.originalEvent.altKey&&t.datepicker._adjustDate(e.target,e.ctrlKey?+t.datepicker._get(o,"stepBigMonths"):+t.datepicker._get(o,"stepMonths"),"M");break;case 40:(e.ctrlKey||e.metaKey)&&t.datepicker._adjustDate(e.target,7,"D"),a=e.ctrlKey||e.metaKey;break;default:a=!1}else 36===e.keyCode&&e.ctrlKey?t.datepicker._showDatepicker(this):a=!1;a&&(e.preventDefault(),e.stopPropagation())},_doKeyPress:function(e){var n,i,r=t.datepicker._getInst(e.target);return t.datepicker._get(r,"constrainInput")?(n=t.datepicker._possibleChars(t.datepicker._get(r,"dateFormat")),i=String.fromCharCode(null==e.charCode?e.keyCode:e.charCode),e.ctrlKey||e.metaKey||" ">i||!n||n.indexOf(i)>-1):void 0},_doKeyUp:function(e){var n,i=t.datepicker._getInst(e.target);if(i.input.val()!==i.lastVal)try{n=t.datepicker.parseDate(t.datepicker._get(i,"dateFormat"),i.input?i.input.val():null,t.datepicker._getFormatConfig(i)),n&&(t.datepicker._setDateFromField(i),t.datepicker._updateAlternate(i),t.datepicker._updateDatepicker(i))}catch(r){}return!0},_showDatepicker:function(e){if(e=e.target||e,"input"!==e.nodeName.toLowerCase()&&(e=t("input",e.parentNode)[0]),!t.datepicker._isDisabledDatepicker(e)&&t.datepicker._lastInput!==e){var n,r,o,a,u,l,c;n=t.datepicker._getInst(e),t.datepicker._curInst&&t.datepicker._curInst!==n&&(t.datepicker._curInst.dpDiv.stop(!0,!0),n&&t.datepicker._datepickerShowing&&t.datepicker._hideDatepicker(t.datepicker._curInst.input[0])),r=t.datepicker._get(n,"beforeShow"),o=r?r.apply(e,[e,n]):{},o!==!1&&(s(n.settings,o),n.lastVal=null,t.datepicker._lastInput=e,t.datepicker._setDateFromField(n),t.datepicker._inDialog&&(e.value=""),t.datepicker._pos||(t.datepicker._pos=t.datepicker._findPos(e),t.datepicker._pos[1]+=e.offsetHeight),a=!1,t(e).parents().each(function(){return a|="fixed"===t(this).css("position"),!a}),u={left:t.datepicker._pos[0],top:t.datepicker._pos[1]},t.datepicker._pos=null,n.dpDiv.empty(),n.dpDiv.css({position:"absolute",display:"block",top:"-1000px"}),t.datepicker._updateDatepicker(n),u=t.datepicker._checkOffset(n,u,a),n.dpDiv.css({position:t.datepicker._inDialog&&t.blockUI?"static":a?"fixed":"absolute",display:"none",left:u.left+"px",top:u.top+"px"}),n.inline||(l=t.datepicker._get(n,"showAnim"),c=t.datepicker._get(n,"duration"),n.dpDiv.css("z-index",i(t(e))+1),t.datepicker._datepickerShowing=!0,t.effects&&t.effects.effect[l]?n.dpDiv.show(l,t.datepicker._get(n,"showOptions"),c):n.dpDiv[l||"show"](l?c:null),t.datepicker._shouldFocusInput(n)&&n.input.focus(),t.datepicker._curInst=n))}},_updateDatepicker:function(e){this.maxRows=4,v=e,e.dpDiv.empty().append(this._generateHTML(e)),this._attachHandlers(e);var n,i=this._getNumberOfMonths(e),r=i[1],o=17,s=e.dpDiv.find("."+this._dayOverClass+" a");s.length>0&&a.apply(s.get(0)),e.dpDiv.removeClass("ui-datepicker-multi-2 ui-datepicker-multi-3 ui-datepicker-multi-4").width(""),r>1&&e.dpDiv.addClass("ui-datepicker-multi-"+r).css("width",o*r+"em"),e.dpDiv[(1!==i[0]||1!==i[1]?"add":"remove")+"Class"]("ui-datepicker-multi"),e.dpDiv[(this._get(e,"isRTL")?"add":"remove")+"Class"]("ui-datepicker-rtl"),e===t.datepicker._curInst&&t.datepicker._datepickerShowing&&t.datepicker._shouldFocusInput(e)&&e.input.focus(),e.yearshtml&&(n=e.yearshtml,setTimeout(function(){n===e.yearshtml&&e.yearshtml&&e.dpDiv.find("select.ui-datepicker-year:first").replaceWith(e.yearshtml),n=e.yearshtml=null},0))},_shouldFocusInput:function(t){return t.input&&t.input.is(":visible")&&!t.input.is(":disabled")&&!t.input.is(":focus")},_checkOffset:function(e,n,i){var r=e.dpDiv.outerWidth(),o=e.dpDiv.outerHeight(),a=e.input?e.input.outerWidth():0,s=e.input?e.input.outerHeight():0,u=document.documentElement.clientWidth+(i?0:t(document).scrollLeft()),l=document.documentElement.clientHeight+(i?0:t(document).scrollTop());return n.left-=this._get(e,"isRTL")?r-a:0,n.left-=i&&n.left===e.input.offset().left?t(document).scrollLeft():0,n.top-=i&&n.top===e.input.offset().top+s?t(document).scrollTop():0,n.left-=Math.min(n.left,n.left+r>u&&u>r?Math.abs(n.left+r-u):0),n.top-=Math.min(n.top,n.top+o>l&&l>o?Math.abs(o+s):0),n},_findPos:function(e){for(var n,i=this._getInst(e),r=this._get(i,"isRTL");e&&("hidden"===e.type||1!==e.nodeType||t.expr.filters.hidden(e));)e=e[r?"previousSibling":"nextSibling"];return n=t(e).offset(),[n.left,n.top]},_hideDatepicker:function(e){var n,i,r,o,a=this._curInst;!a||e&&a!==t.data(e,"datepicker")||this._datepickerShowing&&(n=this._get(a,"showAnim"),i=this._get(a,"duration"),r=function(){t.datepicker._tidyDialog(a)},t.effects&&(t.effects.effect[n]||t.effects[n])?a.dpDiv.hide(n,t.datepicker._get(a,"showOptions"),i,r):a.dpDiv["slideDown"===n?"slideUp":"fadeIn"===n?"fadeOut":"hide"](n?i:null,r),n||r(),this._datepickerShowing=!1,o=this._get(a,"onClose"),o&&o.apply(a.input?a.input[0]:null,[a.input?a.input.val():"",a]),this._lastInput=null,this._inDialog&&(this._dialogInput.css({position:"absolute",left:"0",top:"-100px"}),t.blockUI&&(t.unblockUI(),t("body").append(this.dpDiv))),this._inDialog=!1)},_tidyDialog:function(t){t.dpDiv.removeClass(this._dialogClass).unbind(".ui-datepicker-calendar")},_checkExternalClick:function(e){if(t.datepicker._curInst){var n=t(e.target),i=t.datepicker._getInst(n[0]);(n[0].id!==t.datepicker._mainDivId&&0===n.parents("#"+t.datepicker._mainDivId).length&&!n.hasClass(t.datepicker.markerClassName)&&!n.closest("."+t.datepicker._triggerClass).length&&t.datepicker._datepickerShowing&&(!t.datepicker._inDialog||!t.blockUI)||n.hasClass(t.datepicker.markerClassName)&&t.datepicker._curInst!==i)&&t.datepicker._hideDatepicker()}},_adjustDate:function(e,n,i){var r=t(e),o=this._getInst(r[0]);this._isDisabledDatepicker(r[0])||(this._adjustInstDate(o,n+("M"===i?this._get(o,"showCurrentAtPos"):0),i),this._updateDatepicker(o))},_gotoToday:function(e){var n,i=t(e),r=this._getInst(i[0]);this._get(r,"gotoCurrent")&&r.currentDay?(r.selectedDay=r.currentDay,r.drawMonth=r.selectedMonth=r.currentMonth,r.drawYear=r.selectedYear=r.currentYear):(n=new Date,r.selectedDay=n.getDate(),r.drawMonth=r.selectedMonth=n.getMonth(),r.drawYear=r.selectedYear=n.getFullYear()),this._notifyChange(r),this._adjustDate(i)},_selectMonthYear:function(e,n,i){var r=t(e),o=this._getInst(r[0]);o["selected"+("M"===i?"Month":"Year")]=o["draw"+("M"===i?"Month":"Year")]=parseInt(n.options[n.selectedIndex].value,10),this._notifyChange(o),this._adjustDate(r)},_selectDay:function(e,n,i,r){var o,a=t(e);t(r).hasClass(this._unselectableClass)||this._isDisabledDatepicker(a[0])||(o=this._getInst(a[0]),o.selectedDay=o.currentDay=t("a",r).html(),o.selectedMonth=o.currentMonth=n,o.selectedYear=o.currentYear=i,this._selectDate(e,this._formatDate(o,o.currentDay,o.currentMonth,o.currentYear)))},_clearDate:function(e){var n=t(e);this._selectDate(n,"")},_selectDate:function(e,n){var i,r=t(e),o=this._getInst(r[0]);n=null!=n?n:this._formatDate(o),o.input&&o.input.val(n),this._updateAlternate(o),i=this._get(o,"onSelect"),i?i.apply(o.input?o.input[0]:null,[n,o]):o.input&&o.input.trigger("change"),o.inline?this._updateDatepicker(o):(this._hideDatepicker(),this._lastInput=o.input[0],"object"!=typeof o.input[0]&&o.input.focus(),this._lastInput=null)},_updateAlternate:function(e){var n,i,r,o=this._get(e,"altField");o&&(n=this._get(e,"altFormat")||this._get(e,"dateFormat"),i=this._getDate(e),r=this.formatDate(n,i,this._getFormatConfig(e)),t(o).each(function(){t(this).val(r)}))},noWeekends:function(t){var e=t.getDay();return[e>0&&6>e,""]},iso8601Week:function(t){var e,n=new Date(t.getTime());return n.setDate(n.getDate()+4-(n.getDay()||7)),e=n.getTime(),n.setMonth(0),n.setDate(1),Math.floor(Math.round((e-n)/864e5)/7)+1},parseDate:function(e,n,i){if(null==e||null==n)throw"Invalid arguments";if(n="object"==typeof n?n.toString():n+"",""===n)return null;var r,o,a,s,u=0,l=(i?i.shortYearCutoff:null)||this._defaults.shortYearCutoff,c="string"!=typeof l?l:(new Date).getFullYear()%100+parseInt(l,10),d=(i?i.dayNamesShort:null)||this._defaults.dayNamesShort,h=(i?i.dayNames:null)||this._defaults.dayNames,f=(i?i.monthNamesShort:null)||this._defaults.monthNamesShort,p=(i?i.monthNames:null)||this._defaults.monthNames,g=-1,m=-1,v=-1,y=-1,b=!1,x=function(t){var n=r+1<e.length&&e.charAt(r+1)===t;return n&&r++,n},w=function(t){var e=x(t),i="@"===t?14:"!"===t?20:"y"===t&&e?4:"o"===t?3:2,r="y"===t?i:1,o=new RegExp("^\\d{"+r+","+i+"}"),a=n.substring(u).match(o);if(!a)throw"Missing number at position "+u;return u+=a[0].length,parseInt(a[0],10)},_=function(e,i,r){var o=-1,a=t.map(x(e)?r:i,function(t,e){return[[e,t]]}).sort(function(t,e){return-(t[1].length-e[1].length)});if(t.each(a,function(t,e){var i=e[1];return n.substr(u,i.length).toLowerCase()===i.toLowerCase()?(o=e[0],u+=i.length,!1):void 0}),-1!==o)return o+1;throw"Unknown name at position "+u},$=function(){if(n.charAt(u)!==e.charAt(r))throw"Unexpected literal at position "+u;u++};for(r=0;r<e.length;r++)if(b)"'"!==e.charAt(r)||x("'")?$():b=!1;else switch(e.charAt(r)){case"d":v=w("d");break;case"D":_("D",d,h);break;case"o":y=w("o");break;case"m":m=w("m");break;case"M":m=_("M",f,p);break;case"y":g=w("y");break;case"@":s=new Date(w("@")),g=s.getFullYear(),m=s.getMonth()+1,v=s.getDate();break;case"!":s=new Date((w("!")-this._ticksTo1970)/1e4),g=s.getFullYear(),m=s.getMonth()+1,v=s.getDate();break;case"'":x("'")?$():b=!0;break;default:$()}if(u<n.length&&(a=n.substr(u),!/^\s+/.test(a)))throw"Extra/unparsed characters found in date: "+a;if(-1===g?g=(new Date).getFullYear():100>g&&(g+=(new Date).getFullYear()-(new Date).getFullYear()%100+(c>=g?0:-100)),y>-1)for(m=1,v=y;;){if(o=this._getDaysInMonth(g,m-1),o>=v)break;m++,v-=o}if(s=this._daylightSavingAdjust(new Date(g,m-1,v)),s.getFullYear()!==g||s.getMonth()+1!==m||s.getDate()!==v)throw"Invalid date";return s},ATOM:"yy-mm-dd",COOKIE:"D, dd M yy",ISO_8601:"yy-mm-dd",RFC_822:"D, d M y",RFC_850:"DD, dd-M-y",RFC_1036:"D, d M y",RFC_1123:"D, d M yy",RFC_2822:"D, d M yy",RSS:"D, d M y",TICKS:"!",TIMESTAMP:"@",W3C:"yy-mm-dd",_ticksTo1970:24*(718685+Math.floor(492.5)-Math.floor(19.7)+Math.floor(4.925))*60*60*1e7,formatDate:function(t,e,n){if(!e)return"";var i,r=(n?n.dayNamesShort:null)||this._defaults.dayNamesShort,o=(n?n.dayNames:null)||this._defaults.dayNames,a=(n?n.monthNamesShort:null)||this._defaults.monthNamesShort,s=(n?n.monthNames:null)||this._defaults.monthNames,u=function(e){var n=i+1<t.length&&t.charAt(i+1)===e;return n&&i++,n},l=function(t,e,n){var i=""+e;if(u(t))for(;i.length<n;)i="0"+i;return i},c=function(t,e,n,i){return u(t)?i[e]:n[e]},d="",h=!1;if(e)for(i=0;i<t.length;i++)if(h)"'"!==t.charAt(i)||u("'")?d+=t.charAt(i):h=!1;else switch(t.charAt(i)){case"d":d+=l("d",e.getDate(),2);break;case"D":d+=c("D",e.getDay(),r,o);break;case"o":d+=l("o",Math.round((new Date(e.getFullYear(),e.getMonth(),e.getDate()).getTime()-new Date(e.getFullYear(),0,0).getTime())/864e5),3);break;case"m":d+=l("m",e.getMonth()+1,2);break;case"M":d+=c("M",e.getMonth(),a,s);break;case"y":d+=u("y")?e.getFullYear():(e.getYear()%100<10?"0":"")+e.getYear()%100;break;case"@":d+=e.getTime();break;case"!":d+=1e4*e.getTime()+this._ticksTo1970;break;case"'":u("'")?d+="'":h=!0;break;default:d+=t.charAt(i)}return d},_possibleChars:function(t){var e,n="",i=!1,r=function(n){var i=e+1<t.length&&t.charAt(e+1)===n;return i&&e++,i};for(e=0;e<t.length;e++)if(i)"'"!==t.charAt(e)||r("'")?n+=t.charAt(e):i=!1;else switch(t.charAt(e)){case"d":case"m":case"y":case"@":n+="0123456789";break;case"D":case"M":return null;case"'":r("'")?n+="'":i=!0;break;default:n+=t.charAt(e)}return n},_get:function(t,e){return void 0!==t.settings[e]?t.settings[e]:this._defaults[e]},_setDateFromField:function(t,e){if(t.input.val()!==t.lastVal){var n=this._get(t,"dateFormat"),i=t.lastVal=t.input?t.input.val():null,r=this._getDefaultDate(t),o=r,a=this._getFormatConfig(t);try{o=this.parseDate(n,i,a)||r}catch(s){i=e?"":i}t.selectedDay=o.getDate(),t.drawMonth=t.selectedMonth=o.getMonth(),t.drawYear=t.selectedYear=o.getFullYear(),t.currentDay=i?o.getDate():0,t.currentMonth=i?o.getMonth():0,t.currentYear=i?o.getFullYear():0,this._adjustInstDate(t)}},_getDefaultDate:function(t){return this._restrictMinMax(t,this._determineDate(t,this._get(t,"defaultDate"),new Date))},_determineDate:function(e,n,i){var r=function(t){var e=new Date;return e.setDate(e.getDate()+t),e},o=function(n){try{return t.datepicker.parseDate(t.datepicker._get(e,"dateFormat"),n,t.datepicker._getFormatConfig(e))}catch(i){}for(var r=(n.toLowerCase().match(/^c/)?t.datepicker._getDate(e):null)||new Date,o=r.getFullYear(),a=r.getMonth(),s=r.getDate(),u=/([+\-]?[0-9]+)\s*(d|D|w|W|m|M|y|Y)?/g,l=u.exec(n);l;){switch(l[2]||"d"){case"d":case"D":s+=parseInt(l[1],10);break;case"w":case"W":s+=7*parseInt(l[1],10);break;case"m":case"M":a+=parseInt(l[1],10),s=Math.min(s,t.datepicker._getDaysInMonth(o,a));break;case"y":case"Y":o+=parseInt(l[1],10),s=Math.min(s,t.datepicker._getDaysInMonth(o,a))}l=u.exec(n)}return new Date(o,a,s)},a=null==n||""===n?i:"string"==typeof n?o(n):"number"==typeof n?isNaN(n)?i:r(n):new Date(n.getTime());return a=a&&"Invalid Date"===a.toString()?i:a,a&&(a.setHours(0),a.setMinutes(0),a.setSeconds(0),a.setMilliseconds(0)),this._daylightSavingAdjust(a)},_daylightSavingAdjust:function(t){return t?(t.setHours(t.getHours()>12?t.getHours()+2:0),t):null},_setDate:function(t,e,n){var i=!e,r=t.selectedMonth,o=t.selectedYear,a=this._restrictMinMax(t,this._determineDate(t,e,new Date));t.selectedDay=t.currentDay=a.getDate(),t.drawMonth=t.selectedMonth=t.currentMonth=a.getMonth(),t.drawYear=t.selectedYear=t.currentYear=a.getFullYear(),r===t.selectedMonth&&o===t.selectedYear||n||this._notifyChange(t),this._adjustInstDate(t),t.input&&t.input.val(i?"":this._formatDate(t))},_getDate:function(t){var e=!t.currentYear||t.input&&""===t.input.val()?null:this._daylightSavingAdjust(new Date(t.currentYear,t.currentMonth,t.currentDay));return e},_attachHandlers:function(e){var n=this._get(e,"stepMonths"),i="#"+e.id.replace(/\\\\/g,"\\");e.dpDiv.find("[data-handler]").map(function(){var e={prev:function(){t.datepicker._adjustDate(i,-n,"M")},next:function(){t.datepicker._adjustDate(i,+n,"M")},hide:function(){t.datepicker._hideDatepicker()},today:function(){t.datepicker._gotoToday(i)},selectDay:function(){return t.datepicker._selectDay(i,+this.getAttribute("data-month"),+this.getAttribute("data-year"),this),!1},selectMonth:function(){return t.datepicker._selectMonthYear(i,this,"M"),!1},selectYear:function(){return t.datepicker._selectMonthYear(i,this,"Y"),!1}};t(this).bind(this.getAttribute("data-event"),e[this.getAttribute("data-handler")])})},_generateHTML:function(t){var e,n,i,r,o,a,s,u,l,c,d,h,f,p,g,m,v,y,b,x,w,_,$,k,C,M,D,S,T,A,E,O,N,I,P,F,W,H,L,z=new Date,j=this._daylightSavingAdjust(new Date(z.getFullYear(),z.getMonth(),z.getDate())),R=this._get(t,"isRTL"),U=this._get(t,"showButtonPanel"),q=this._get(t,"hideIfNoPrevNext"),B=this._get(t,"navigationAsDateFormat"),V=this._getNumberOfMonths(t),Y=this._get(t,"showCurrentAtPos"),G=this._get(t,"stepMonths"),X=1!==V[0]||1!==V[1],K=this._daylightSavingAdjust(t.currentDay?new Date(t.currentYear,t.currentMonth,t.currentDay):new Date(9999,9,9)),Z=this._getMinMaxDate(t,"min"),Q=this._getMinMaxDate(t,"max"),J=t.drawMonth-Y,tt=t.drawYear;if(0>J&&(J+=12,tt--),Q)for(e=this._daylightSavingAdjust(new Date(Q.getFullYear(),Q.getMonth()-V[0]*V[1]+1,Q.getDate())),e=Z&&Z>e?Z:e;this._daylightSavingAdjust(new Date(tt,J,1))>e;)J--,0>J&&(J=11,tt--);for(t.drawMonth=J,t.drawYear=tt,n=this._get(t,"prevText"),n=B?this.formatDate(n,this._daylightSavingAdjust(new Date(tt,J-G,1)),this._getFormatConfig(t)):n,i=this._canAdjustMonth(t,-1,tt,J)?"<a class='ui-datepicker-prev ui-corner-all' data-handler='prev' data-event='click' title='"+n+"'><span class='ui-icon ui-icon-circle-triangle-"+(R?"e":"w")+"'>"+n+"</span></a>":q?"":"<a class='ui-datepicker-prev ui-corner-all ui-state-disabled' title='"+n+"'><span class='ui-icon ui-icon-circle-triangle-"+(R?"e":"w")+"'>"+n+"</span></a>",r=this._get(t,"nextText"),r=B?this.formatDate(r,this._daylightSavingAdjust(new Date(tt,J+G,1)),this._getFormatConfig(t)):r,o=this._canAdjustMonth(t,1,tt,J)?"<a class='ui-datepicker-next ui-corner-all' data-handler='next' data-event='click' title='"+r+"'><span class='ui-icon ui-icon-circle-triangle-"+(R?"w":"e")+"'>"+r+"</span></a>":q?"":"<a class='ui-datepicker-next ui-corner-all ui-state-disabled' title='"+r+"'><span class='ui-icon ui-icon-circle-triangle-"+(R?"w":"e")+"'>"+r+"</span></a>",a=this._get(t,"currentText"),s=this._get(t,"gotoCurrent")&&t.currentDay?K:j,a=B?this.formatDate(a,s,this._getFormatConfig(t)):a,u=t.inline?"":"<button type='button' class='ui-datepicker-close ui-state-default ui-priority-primary ui-corner-all' data-handler='hide' data-event='click'>"+this._get(t,"closeText")+"</button>",l=U?"<div class='ui-datepicker-buttonpane ui-widget-content'>"+(R?u:"")+(this._isInRange(t,s)?"<button type='button' class='ui-datepicker-current ui-state-default ui-priority-secondary ui-corner-all' data-handler='today' data-event='click'>"+a+"</button>":"")+(R?"":u)+"</div>":"",c=parseInt(this._get(t,"firstDay"),10),c=isNaN(c)?0:c,d=this._get(t,"showWeek"),h=this._get(t,"dayNames"),f=this._get(t,"dayNamesMin"),p=this._get(t,"monthNames"),g=this._get(t,"monthNamesShort"),m=this._get(t,"beforeShowDay"),v=this._get(t,"showOtherMonths"),y=this._get(t,"selectOtherMonths"),b=this._getDefaultDate(t),x="",_=0;_<V[0];_++){for($="",this.maxRows=4,k=0;k<V[1];k++){if(C=this._daylightSavingAdjust(new Date(tt,J,t.selectedDay)),M=" ui-corner-all",D="",X){if(D+="<div class='ui-datepicker-group",V[1]>1)switch(k){case 0:D+=" ui-datepicker-group-first",M=" ui-corner-"+(R?"right":"left");break;case V[1]-1:D+=" ui-datepicker-group-last",M=" ui-corner-"+(R?"left":"right");break;default:D+=" ui-datepicker-group-middle",M=""}D+="'>"}for(D+="<div class='ui-datepicker-header ui-widget-header ui-helper-clearfix"+M+"'>"+(/all|left/.test(M)&&0===_?R?o:i:"")+(/all|right/.test(M)&&0===_?R?i:o:"")+this._generateMonthYearHeader(t,J,tt,Z,Q,_>0||k>0,p,g)+"</div><table class='ui-datepicker-calendar'><thead><tr>",S=d?"<th class='ui-datepicker-week-col'>"+this._get(t,"weekHeader")+"</th>":"",w=0;7>w;w++)T=(w+c)%7,S+="<th scope='col'"+((w+c+6)%7>=5?" class='ui-datepicker-week-end'":"")+"><span title='"+h[T]+"'>"+f[T]+"</span></th>";for(D+=S+"</tr></thead><tbody>",A=this._getDaysInMonth(tt,J),tt===t.selectedYear&&J===t.selectedMonth&&(t.selectedDay=Math.min(t.selectedDay,A)),E=(this._getFirstDayOfMonth(tt,J)-c+7)%7,O=Math.ceil((E+A)/7),N=X&&this.maxRows>O?this.maxRows:O,this.maxRows=N,I=this._daylightSavingAdjust(new Date(tt,J,1-E)),P=0;N>P;P++){for(D+="<tr>",F=d?"<td class='ui-datepicker-week-col'>"+this._get(t,"calculateWeek")(I)+"</td>":"",w=0;7>w;w++)W=m?m.apply(t.input?t.input[0]:null,[I]):[!0,""],H=I.getMonth()!==J,L=H&&!y||!W[0]||Z&&Z>I||Q&&I>Q,F+="<td class='"+((w+c+6)%7>=5?" ui-datepicker-week-end":"")+(H?" ui-datepicker-other-month":"")+(I.getTime()===C.getTime()&&J===t.selectedMonth&&t._keyEvent||b.getTime()===I.getTime()&&b.getTime()===C.getTime()?" "+this._dayOverClass:"")+(L?" "+this._unselectableClass+" ui-state-disabled":"")+(H&&!v?"":" "+W[1]+(I.getTime()===K.getTime()?" "+this._currentClass:"")+(I.getTime()===j.getTime()?" ui-datepicker-today":""))+"'"+(H&&!v||!W[2]?"":" title='"+W[2].replace(/'/g,"&#39;")+"'")+(L?"":" data-handler='selectDay' data-event='click' data-month='"+I.getMonth()+"' data-year='"+I.getFullYear()+"'")+">"+(H&&!v?"&#xa0;":L?"<span class='ui-state-default'>"+I.getDate()+"</span>":"<a class='ui-state-default"+(I.getTime()===j.getTime()?" ui-state-highlight":"")+(I.getTime()===K.getTime()?" ui-state-active":"")+(H?" ui-priority-secondary":"")+"' href='#'>"+I.getDate()+"</a>")+"</td>",I.setDate(I.getDate()+1),I=this._daylightSavingAdjust(I);D+=F+"</tr>"}J++,J>11&&(J=0,tt++),D+="</tbody></table>"+(X?"</div>"+(V[0]>0&&k===V[1]-1?"<div class='ui-datepicker-row-break'></div>":""):""),$+=D}x+=$}return x+=l,t._keyEvent=!1,x},_generateMonthYearHeader:function(t,e,n,i,r,o,a,s){var u,l,c,d,h,f,p,g,m=this._get(t,"changeMonth"),v=this._get(t,"changeYear"),y=this._get(t,"showMonthAfterYear"),b="<div class='ui-datepicker-title'>",x="";if(o||!m)x+="<span class='ui-datepicker-month'>"+a[e]+"</span>";else{for(u=i&&i.getFullYear()===n,l=r&&r.getFullYear()===n,x+="<select class='ui-datepicker-month' data-handler='selectMonth' data-event='change'>",c=0;12>c;c++)(!u||c>=i.getMonth())&&(!l||c<=r.getMonth())&&(x+="<option value='"+c+"'"+(c===e?" selected='selected'":"")+">"+s[c]+"</option>");x+="</select>"}if(y||(b+=x+(!o&&m&&v?"":"&#xa0;")),!t.yearshtml)if(t.yearshtml="",o||!v)b+="<span class='ui-datepicker-year'>"+n+"</span>";else{for(d=this._get(t,"yearRange").split(":"),h=(new Date).getFullYear(),f=function(t){var e=t.match(/c[+\-].*/)?n+parseInt(t.substring(1),10):t.match(/[+\-].*/)?h+parseInt(t,10):parseInt(t,10);return isNaN(e)?h:e},p=f(d[0]),g=Math.max(p,f(d[1]||"")),p=i?Math.max(p,i.getFullYear()):p,g=r?Math.min(g,r.getFullYear()):g,t.yearshtml+="<select class='ui-datepicker-year' data-handler='selectYear' data-event='change'>";g>=p;p++)t.yearshtml+="<option value='"+p+"'"+(p===n?" selected='selected'":"")+">"+p+"</option>";t.yearshtml+="</select>",b+=t.yearshtml,t.yearshtml=null}return b+=this._get(t,"yearSuffix"),y&&(b+=(!o&&m&&v?"":"&#xa0;")+x),b+="</div>"},_adjustInstDate:function(t,e,n){var i=t.drawYear+("Y"===n?e:0),r=t.drawMonth+("M"===n?e:0),o=Math.min(t.selectedDay,this._getDaysInMonth(i,r))+("D"===n?e:0),a=this._restrictMinMax(t,this._daylightSavingAdjust(new Date(i,r,o)));t.selectedDay=a.getDate(),t.drawMonth=t.selectedMonth=a.getMonth(),t.drawYear=t.selectedYear=a.getFullYear(),("M"===n||"Y"===n)&&this._notifyChange(t)},_restrictMinMax:function(t,e){var n=this._getMinMaxDate(t,"min"),i=this._getMinMaxDate(t,"max"),r=n&&n>e?n:e;return i&&r>i?i:r},_notifyChange:function(t){var e=this._get(t,"onChangeMonthYear");e&&e.apply(t.input?t.input[0]:null,[t.selectedYear,t.selectedMonth+1,t])},_getNumberOfMonths:function(t){var e=this._get(t,"numberOfMonths");return null==e?[1,1]:"number"==typeof e?[1,e]:e},_getMinMaxDate:function(t,e){return this._determineDate(t,this._get(t,e+"Date"),null)},_getDaysInMonth:function(t,e){return 32-this._daylightSavingAdjust(new Date(t,e,32)).getDate()},_getFirstDayOfMonth:function(t,e){return new Date(t,e,1).getDay()},_canAdjustMonth:function(t,e,n,i){var r=this._getNumberOfMonths(t),o=this._daylightSavingAdjust(new Date(n,i+(0>e?e:r[0]*r[1]),1));return 0>e&&o.setDate(this._getDaysInMonth(o.getFullYear(),o.getMonth())),this._isInRange(t,o)},_isInRange:function(t,e){var n,i,r=this._getMinMaxDate(t,"min"),o=this._getMinMaxDate(t,"max"),a=null,s=null,u=this._get(t,"yearRange");return u&&(n=u.split(":"),i=(new Date).getFullYear(),a=parseInt(n[0],10),s=parseInt(n[1],10),n[0].match(/[+\-].*/)&&(a+=i),n[1].match(/[+\-].*/)&&(s+=i)),(!r||e.getTime()>=r.getTime())&&(!o||e.getTime()<=o.getTime())&&(!a||e.getFullYear()>=a)&&(!s||e.getFullYear()<=s)},_getFormatConfig:function(t){var e=this._get(t,"shortYearCutoff");return e="string"!=typeof e?e:(new Date).getFullYear()%100+parseInt(e,10),{shortYearCutoff:e,dayNamesShort:this._get(t,"dayNamesShort"),dayNames:this._get(t,"dayNames"),monthNamesShort:this._get(t,"monthNamesShort"),monthNames:this._get(t,"monthNames")}},_formatDate:function(t,e,n,i){e||(t.currentDay=t.selectedDay,t.currentMonth=t.selectedMonth,t.currentYear=t.selectedYear);var r=e?"object"==typeof e?e:this._daylightSavingAdjust(new Date(i,n,e)):this._daylightSavingAdjust(new Date(t.currentYear,t.currentMonth,t.currentDay));
return this.formatDate(this._get(t,"dateFormat"),r,this._getFormatConfig(t))}}),t.fn.datepicker=function(e){if(!this.length)return this;t.datepicker.initialized||(t(document).mousedown(t.datepicker._checkExternalClick),t.datepicker.initialized=!0),0===t("#"+t.datepicker._mainDivId).length&&t("body").append(t.datepicker.dpDiv);var n=Array.prototype.slice.call(arguments,1);return"string"!=typeof e||"isDisabled"!==e&&"getDate"!==e&&"widget"!==e?"option"===e&&2===arguments.length&&"string"==typeof arguments[1]?t.datepicker["_"+e+"Datepicker"].apply(t.datepicker,[this[0]].concat(n)):this.each(function(){"string"==typeof e?t.datepicker["_"+e+"Datepicker"].apply(t.datepicker,[this].concat(n)):t.datepicker._attachDatepicker(this,e)}):t.datepicker["_"+e+"Datepicker"].apply(t.datepicker,[this[0]].concat(n))},t.datepicker=new r,t.datepicker.initialized=!1,t.datepicker.uuid=(new Date).getTime(),t.datepicker.version="1.11.4";t.datepicker;/*!
 * jQuery UI Draggable 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/draggable/
 */
t.widget("ui.draggable",t.ui.mouse,{version:"1.11.4",widgetEventPrefix:"drag",options:{addClasses:!0,appendTo:"parent",axis:!1,connectToSortable:!1,containment:!1,cursor:"auto",cursorAt:!1,grid:!1,handle:!1,helper:"original",iframeFix:!1,opacity:!1,refreshPositions:!1,revert:!1,revertDuration:500,scope:"default",scroll:!0,scrollSensitivity:20,scrollSpeed:20,snap:!1,snapMode:"both",snapTolerance:20,stack:!1,zIndex:!1,drag:null,start:null,stop:null},_create:function(){"original"===this.options.helper&&this._setPositionRelative(),this.options.addClasses&&this.element.addClass("ui-draggable"),this.options.disabled&&this.element.addClass("ui-draggable-disabled"),this._setHandleClassName(),this._mouseInit()},_setOption:function(t,e){this._super(t,e),"handle"===t&&(this._removeHandleClassName(),this._setHandleClassName())},_destroy:function(){return(this.helper||this.element).is(".ui-draggable-dragging")?void(this.destroyOnClear=!0):(this.element.removeClass("ui-draggable ui-draggable-dragging ui-draggable-disabled"),this._removeHandleClassName(),void this._mouseDestroy())},_mouseCapture:function(e){var n=this.options;return this._blurActiveElement(e),this.helper||n.disabled||t(e.target).closest(".ui-resizable-handle").length>0?!1:(this.handle=this._getHandle(e),this.handle?(this._blockFrames(n.iframeFix===!0?"iframe":n.iframeFix),!0):!1)},_blockFrames:function(e){this.iframeBlocks=this.document.find(e).map(function(){var e=t(this);return t("<div>").css("position","absolute").appendTo(e.parent()).outerWidth(e.outerWidth()).outerHeight(e.outerHeight()).offset(e.offset())[0]})},_unblockFrames:function(){this.iframeBlocks&&(this.iframeBlocks.remove(),delete this.iframeBlocks)},_blurActiveElement:function(e){var n=this.document[0];if(this.handleElement.is(e.target))try{n.activeElement&&"body"!==n.activeElement.nodeName.toLowerCase()&&t(n.activeElement).blur()}catch(i){}},_mouseStart:function(e){var n=this.options;return this.helper=this._createHelper(e),this.helper.addClass("ui-draggable-dragging"),this._cacheHelperProportions(),t.ui.ddmanager&&(t.ui.ddmanager.current=this),this._cacheMargins(),this.cssPosition=this.helper.css("position"),this.scrollParent=this.helper.scrollParent(!0),this.offsetParent=this.helper.offsetParent(),this.hasFixedAncestor=this.helper.parents().filter(function(){return"fixed"===t(this).css("position")}).length>0,this.positionAbs=this.element.offset(),this._refreshOffsets(e),this.originalPosition=this.position=this._generatePosition(e,!1),this.originalPageX=e.pageX,this.originalPageY=e.pageY,n.cursorAt&&this._adjustOffsetFromHelper(n.cursorAt),this._setContainment(),this._trigger("start",e)===!1?(this._clear(),!1):(this._cacheHelperProportions(),t.ui.ddmanager&&!n.dropBehaviour&&t.ui.ddmanager.prepareOffsets(this,e),this._normalizeRightBottom(),this._mouseDrag(e,!0),t.ui.ddmanager&&t.ui.ddmanager.dragStart(this,e),!0)},_refreshOffsets:function(t){this.offset={top:this.positionAbs.top-this.margins.top,left:this.positionAbs.left-this.margins.left,scroll:!1,parent:this._getParentOffset(),relative:this._getRelativeOffset()},this.offset.click={left:t.pageX-this.offset.left,top:t.pageY-this.offset.top}},_mouseDrag:function(e,n){if(this.hasFixedAncestor&&(this.offset.parent=this._getParentOffset()),this.position=this._generatePosition(e,!0),this.positionAbs=this._convertPositionTo("absolute"),!n){var i=this._uiHash();if(this._trigger("drag",e,i)===!1)return this._mouseUp({}),!1;this.position=i.position}return this.helper[0].style.left=this.position.left+"px",this.helper[0].style.top=this.position.top+"px",t.ui.ddmanager&&t.ui.ddmanager.drag(this,e),!1},_mouseStop:function(e){var n=this,i=!1;return t.ui.ddmanager&&!this.options.dropBehaviour&&(i=t.ui.ddmanager.drop(this,e)),this.dropped&&(i=this.dropped,this.dropped=!1),"invalid"===this.options.revert&&!i||"valid"===this.options.revert&&i||this.options.revert===!0||t.isFunction(this.options.revert)&&this.options.revert.call(this.element,i)?t(this.helper).animate(this.originalPosition,parseInt(this.options.revertDuration,10),function(){n._trigger("stop",e)!==!1&&n._clear()}):this._trigger("stop",e)!==!1&&this._clear(),!1},_mouseUp:function(e){return this._unblockFrames(),t.ui.ddmanager&&t.ui.ddmanager.dragStop(this,e),this.handleElement.is(e.target)&&this.element.focus(),t.ui.mouse.prototype._mouseUp.call(this,e)},cancel:function(){return this.helper.is(".ui-draggable-dragging")?this._mouseUp({}):this._clear(),this},_getHandle:function(e){return this.options.handle?!!t(e.target).closest(this.element.find(this.options.handle)).length:!0},_setHandleClassName:function(){this.handleElement=this.options.handle?this.element.find(this.options.handle):this.element,this.handleElement.addClass("ui-draggable-handle")},_removeHandleClassName:function(){this.handleElement.removeClass("ui-draggable-handle")},_createHelper:function(e){var n=this.options,i=t.isFunction(n.helper),r=i?t(n.helper.apply(this.element[0],[e])):"clone"===n.helper?this.element.clone().removeAttr("id"):this.element;return r.parents("body").length||r.appendTo("parent"===n.appendTo?this.element[0].parentNode:n.appendTo),i&&r[0]===this.element[0]&&this._setPositionRelative(),r[0]===this.element[0]||/(fixed|absolute)/.test(r.css("position"))||r.css("position","absolute"),r},_setPositionRelative:function(){/^(?:r|a|f)/.test(this.element.css("position"))||(this.element[0].style.position="relative")},_adjustOffsetFromHelper:function(e){"string"==typeof e&&(e=e.split(" ")),t.isArray(e)&&(e={left:+e[0],top:+e[1]||0}),"left"in e&&(this.offset.click.left=e.left+this.margins.left),"right"in e&&(this.offset.click.left=this.helperProportions.width-e.right+this.margins.left),"top"in e&&(this.offset.click.top=e.top+this.margins.top),"bottom"in e&&(this.offset.click.top=this.helperProportions.height-e.bottom+this.margins.top)},_isRootNode:function(t){return/(html|body)/i.test(t.tagName)||t===this.document[0]},_getParentOffset:function(){var e=this.offsetParent.offset(),n=this.document[0];return"absolute"===this.cssPosition&&this.scrollParent[0]!==n&&t.contains(this.scrollParent[0],this.offsetParent[0])&&(e.left+=this.scrollParent.scrollLeft(),e.top+=this.scrollParent.scrollTop()),this._isRootNode(this.offsetParent[0])&&(e={top:0,left:0}),{top:e.top+(parseInt(this.offsetParent.css("borderTopWidth"),10)||0),left:e.left+(parseInt(this.offsetParent.css("borderLeftWidth"),10)||0)}},_getRelativeOffset:function(){if("relative"!==this.cssPosition)return{top:0,left:0};var t=this.element.position(),e=this._isRootNode(this.scrollParent[0]);return{top:t.top-(parseInt(this.helper.css("top"),10)||0)+(e?0:this.scrollParent.scrollTop()),left:t.left-(parseInt(this.helper.css("left"),10)||0)+(e?0:this.scrollParent.scrollLeft())}},_cacheMargins:function(){this.margins={left:parseInt(this.element.css("marginLeft"),10)||0,top:parseInt(this.element.css("marginTop"),10)||0,right:parseInt(this.element.css("marginRight"),10)||0,bottom:parseInt(this.element.css("marginBottom"),10)||0}},_cacheHelperProportions:function(){this.helperProportions={width:this.helper.outerWidth(),height:this.helper.outerHeight()}},_setContainment:function(){var e,n,i,r=this.options,o=this.document[0];return this.relativeContainer=null,r.containment?"window"===r.containment?void(this.containment=[t(window).scrollLeft()-this.offset.relative.left-this.offset.parent.left,t(window).scrollTop()-this.offset.relative.top-this.offset.parent.top,t(window).scrollLeft()+t(window).width()-this.helperProportions.width-this.margins.left,t(window).scrollTop()+(t(window).height()||o.body.parentNode.scrollHeight)-this.helperProportions.height-this.margins.top]):"document"===r.containment?void(this.containment=[0,0,t(o).width()-this.helperProportions.width-this.margins.left,(t(o).height()||o.body.parentNode.scrollHeight)-this.helperProportions.height-this.margins.top]):r.containment.constructor===Array?void(this.containment=r.containment):("parent"===r.containment&&(r.containment=this.helper[0].parentNode),n=t(r.containment),i=n[0],void(i&&(e=/(scroll|auto)/.test(n.css("overflow")),this.containment=[(parseInt(n.css("borderLeftWidth"),10)||0)+(parseInt(n.css("paddingLeft"),10)||0),(parseInt(n.css("borderTopWidth"),10)||0)+(parseInt(n.css("paddingTop"),10)||0),(e?Math.max(i.scrollWidth,i.offsetWidth):i.offsetWidth)-(parseInt(n.css("borderRightWidth"),10)||0)-(parseInt(n.css("paddingRight"),10)||0)-this.helperProportions.width-this.margins.left-this.margins.right,(e?Math.max(i.scrollHeight,i.offsetHeight):i.offsetHeight)-(parseInt(n.css("borderBottomWidth"),10)||0)-(parseInt(n.css("paddingBottom"),10)||0)-this.helperProportions.height-this.margins.top-this.margins.bottom],this.relativeContainer=n))):void(this.containment=null)},_convertPositionTo:function(t,e){e||(e=this.position);var n="absolute"===t?1:-1,i=this._isRootNode(this.scrollParent[0]);return{top:e.top+this.offset.relative.top*n+this.offset.parent.top*n-("fixed"===this.cssPosition?-this.offset.scroll.top:i?0:this.offset.scroll.top)*n,left:e.left+this.offset.relative.left*n+this.offset.parent.left*n-("fixed"===this.cssPosition?-this.offset.scroll.left:i?0:this.offset.scroll.left)*n}},_generatePosition:function(t,e){var n,i,r,o,a=this.options,s=this._isRootNode(this.scrollParent[0]),u=t.pageX,l=t.pageY;return s&&this.offset.scroll||(this.offset.scroll={top:this.scrollParent.scrollTop(),left:this.scrollParent.scrollLeft()}),e&&(this.containment&&(this.relativeContainer?(i=this.relativeContainer.offset(),n=[this.containment[0]+i.left,this.containment[1]+i.top,this.containment[2]+i.left,this.containment[3]+i.top]):n=this.containment,t.pageX-this.offset.click.left<n[0]&&(u=n[0]+this.offset.click.left),t.pageY-this.offset.click.top<n[1]&&(l=n[1]+this.offset.click.top),t.pageX-this.offset.click.left>n[2]&&(u=n[2]+this.offset.click.left),t.pageY-this.offset.click.top>n[3]&&(l=n[3]+this.offset.click.top)),a.grid&&(r=a.grid[1]?this.originalPageY+Math.round((l-this.originalPageY)/a.grid[1])*a.grid[1]:this.originalPageY,l=n?r-this.offset.click.top>=n[1]||r-this.offset.click.top>n[3]?r:r-this.offset.click.top>=n[1]?r-a.grid[1]:r+a.grid[1]:r,o=a.grid[0]?this.originalPageX+Math.round((u-this.originalPageX)/a.grid[0])*a.grid[0]:this.originalPageX,u=n?o-this.offset.click.left>=n[0]||o-this.offset.click.left>n[2]?o:o-this.offset.click.left>=n[0]?o-a.grid[0]:o+a.grid[0]:o),"y"===a.axis&&(u=this.originalPageX),"x"===a.axis&&(l=this.originalPageY)),{top:l-this.offset.click.top-this.offset.relative.top-this.offset.parent.top+("fixed"===this.cssPosition?-this.offset.scroll.top:s?0:this.offset.scroll.top),left:u-this.offset.click.left-this.offset.relative.left-this.offset.parent.left+("fixed"===this.cssPosition?-this.offset.scroll.left:s?0:this.offset.scroll.left)}},_clear:function(){this.helper.removeClass("ui-draggable-dragging"),this.helper[0]===this.element[0]||this.cancelHelperRemoval||this.helper.remove(),this.helper=null,this.cancelHelperRemoval=!1,this.destroyOnClear&&this.destroy()},_normalizeRightBottom:function(){"y"!==this.options.axis&&"auto"!==this.helper.css("right")&&(this.helper.width(this.helper.width()),this.helper.css("right","auto")),"x"!==this.options.axis&&"auto"!==this.helper.css("bottom")&&(this.helper.height(this.helper.height()),this.helper.css("bottom","auto"))},_trigger:function(e,n,i){return i=i||this._uiHash(),t.ui.plugin.call(this,e,[n,i,this],!0),/^(drag|start|stop)/.test(e)&&(this.positionAbs=this._convertPositionTo("absolute"),i.offset=this.positionAbs),t.Widget.prototype._trigger.call(this,e,n,i)},plugins:{},_uiHash:function(){return{helper:this.helper,position:this.position,originalPosition:this.originalPosition,offset:this.positionAbs}}}),t.ui.plugin.add("draggable","connectToSortable",{start:function(e,n,i){var r=t.extend({},n,{item:i.element});i.sortables=[],t(i.options.connectToSortable).each(function(){var n=t(this).sortable("instance");n&&!n.options.disabled&&(i.sortables.push(n),n.refreshPositions(),n._trigger("activate",e,r))})},stop:function(e,n,i){var r=t.extend({},n,{item:i.element});i.cancelHelperRemoval=!1,t.each(i.sortables,function(){var t=this;t.isOver?(t.isOver=0,i.cancelHelperRemoval=!0,t.cancelHelperRemoval=!1,t._storedCSS={position:t.placeholder.css("position"),top:t.placeholder.css("top"),left:t.placeholder.css("left")},t._mouseStop(e),t.options.helper=t.options._helper):(t.cancelHelperRemoval=!0,t._trigger("deactivate",e,r))})},drag:function(e,n,i){t.each(i.sortables,function(){var r=!1,o=this;o.positionAbs=i.positionAbs,o.helperProportions=i.helperProportions,o.offset.click=i.offset.click,o._intersectsWith(o.containerCache)&&(r=!0,t.each(i.sortables,function(){return this.positionAbs=i.positionAbs,this.helperProportions=i.helperProportions,this.offset.click=i.offset.click,this!==o&&this._intersectsWith(this.containerCache)&&t.contains(o.element[0],this.element[0])&&(r=!1),r})),r?(o.isOver||(o.isOver=1,i._parent=n.helper.parent(),o.currentItem=n.helper.appendTo(o.element).data("ui-sortable-item",!0),o.options._helper=o.options.helper,o.options.helper=function(){return n.helper[0]},e.target=o.currentItem[0],o._mouseCapture(e,!0),o._mouseStart(e,!0,!0),o.offset.click.top=i.offset.click.top,o.offset.click.left=i.offset.click.left,o.offset.parent.left-=i.offset.parent.left-o.offset.parent.left,o.offset.parent.top-=i.offset.parent.top-o.offset.parent.top,i._trigger("toSortable",e),i.dropped=o.element,t.each(i.sortables,function(){this.refreshPositions()}),i.currentItem=i.element,o.fromOutside=i),o.currentItem&&(o._mouseDrag(e),n.position=o.position)):o.isOver&&(o.isOver=0,o.cancelHelperRemoval=!0,o.options._revert=o.options.revert,o.options.revert=!1,o._trigger("out",e,o._uiHash(o)),o._mouseStop(e,!0),o.options.revert=o.options._revert,o.options.helper=o.options._helper,o.placeholder&&o.placeholder.remove(),n.helper.appendTo(i._parent),i._refreshOffsets(e),n.position=i._generatePosition(e,!0),i._trigger("fromSortable",e),i.dropped=!1,t.each(i.sortables,function(){this.refreshPositions()}))})}}),t.ui.plugin.add("draggable","cursor",{start:function(e,n,i){var r=t("body"),o=i.options;r.css("cursor")&&(o._cursor=r.css("cursor")),r.css("cursor",o.cursor)},stop:function(e,n,i){var r=i.options;r._cursor&&t("body").css("cursor",r._cursor)}}),t.ui.plugin.add("draggable","opacity",{start:function(e,n,i){var r=t(n.helper),o=i.options;r.css("opacity")&&(o._opacity=r.css("opacity")),r.css("opacity",o.opacity)},stop:function(e,n,i){var r=i.options;r._opacity&&t(n.helper).css("opacity",r._opacity)}}),t.ui.plugin.add("draggable","scroll",{start:function(t,e,n){n.scrollParentNotHidden||(n.scrollParentNotHidden=n.helper.scrollParent(!1)),n.scrollParentNotHidden[0]!==n.document[0]&&"HTML"!==n.scrollParentNotHidden[0].tagName&&(n.overflowOffset=n.scrollParentNotHidden.offset())},drag:function(e,n,i){var r=i.options,o=!1,a=i.scrollParentNotHidden[0],s=i.document[0];a!==s&&"HTML"!==a.tagName?(r.axis&&"x"===r.axis||(i.overflowOffset.top+a.offsetHeight-e.pageY<r.scrollSensitivity?a.scrollTop=o=a.scrollTop+r.scrollSpeed:e.pageY-i.overflowOffset.top<r.scrollSensitivity&&(a.scrollTop=o=a.scrollTop-r.scrollSpeed)),r.axis&&"y"===r.axis||(i.overflowOffset.left+a.offsetWidth-e.pageX<r.scrollSensitivity?a.scrollLeft=o=a.scrollLeft+r.scrollSpeed:e.pageX-i.overflowOffset.left<r.scrollSensitivity&&(a.scrollLeft=o=a.scrollLeft-r.scrollSpeed))):(r.axis&&"x"===r.axis||(e.pageY-t(s).scrollTop()<r.scrollSensitivity?o=t(s).scrollTop(t(s).scrollTop()-r.scrollSpeed):t(window).height()-(e.pageY-t(s).scrollTop())<r.scrollSensitivity&&(o=t(s).scrollTop(t(s).scrollTop()+r.scrollSpeed))),r.axis&&"y"===r.axis||(e.pageX-t(s).scrollLeft()<r.scrollSensitivity?o=t(s).scrollLeft(t(s).scrollLeft()-r.scrollSpeed):t(window).width()-(e.pageX-t(s).scrollLeft())<r.scrollSensitivity&&(o=t(s).scrollLeft(t(s).scrollLeft()+r.scrollSpeed)))),o!==!1&&t.ui.ddmanager&&!r.dropBehaviour&&t.ui.ddmanager.prepareOffsets(i,e)}}),t.ui.plugin.add("draggable","snap",{start:function(e,n,i){var r=i.options;i.snapElements=[],t(r.snap.constructor!==String?r.snap.items||":data(ui-draggable)":r.snap).each(function(){var e=t(this),n=e.offset();this!==i.element[0]&&i.snapElements.push({item:this,width:e.outerWidth(),height:e.outerHeight(),top:n.top,left:n.left})})},drag:function(e,n,i){var r,o,a,s,u,l,c,d,h,f,p=i.options,g=p.snapTolerance,m=n.offset.left,v=m+i.helperProportions.width,y=n.offset.top,b=y+i.helperProportions.height;for(h=i.snapElements.length-1;h>=0;h--)u=i.snapElements[h].left-i.margins.left,l=u+i.snapElements[h].width,c=i.snapElements[h].top-i.margins.top,d=c+i.snapElements[h].height,u-g>v||m>l+g||c-g>b||y>d+g||!t.contains(i.snapElements[h].item.ownerDocument,i.snapElements[h].item)?(i.snapElements[h].snapping&&i.options.snap.release&&i.options.snap.release.call(i.element,e,t.extend(i._uiHash(),{snapItem:i.snapElements[h].item})),i.snapElements[h].snapping=!1):("inner"!==p.snapMode&&(r=Math.abs(c-b)<=g,o=Math.abs(d-y)<=g,a=Math.abs(u-v)<=g,s=Math.abs(l-m)<=g,r&&(n.position.top=i._convertPositionTo("relative",{top:c-i.helperProportions.height,left:0}).top),o&&(n.position.top=i._convertPositionTo("relative",{top:d,left:0}).top),a&&(n.position.left=i._convertPositionTo("relative",{top:0,left:u-i.helperProportions.width}).left),s&&(n.position.left=i._convertPositionTo("relative",{top:0,left:l}).left)),f=r||o||a||s,"outer"!==p.snapMode&&(r=Math.abs(c-y)<=g,o=Math.abs(d-b)<=g,a=Math.abs(u-m)<=g,s=Math.abs(l-v)<=g,r&&(n.position.top=i._convertPositionTo("relative",{top:c,left:0}).top),o&&(n.position.top=i._convertPositionTo("relative",{top:d-i.helperProportions.height,left:0}).top),a&&(n.position.left=i._convertPositionTo("relative",{top:0,left:u}).left),s&&(n.position.left=i._convertPositionTo("relative",{top:0,left:l-i.helperProportions.width}).left)),!i.snapElements[h].snapping&&(r||o||a||s||f)&&i.options.snap.snap&&i.options.snap.snap.call(i.element,e,t.extend(i._uiHash(),{snapItem:i.snapElements[h].item})),i.snapElements[h].snapping=r||o||a||s||f)}}),t.ui.plugin.add("draggable","stack",{start:function(e,n,i){var r,o=i.options,a=t.makeArray(t(o.stack)).sort(function(e,n){return(parseInt(t(e).css("zIndex"),10)||0)-(parseInt(t(n).css("zIndex"),10)||0)});a.length&&(r=parseInt(t(a[0]).css("zIndex"),10)||0,t(a).each(function(e){t(this).css("zIndex",r+e)}),this.css("zIndex",r+a.length))}}),t.ui.plugin.add("draggable","zIndex",{start:function(e,n,i){var r=t(n.helper),o=i.options;r.css("zIndex")&&(o._zIndex=r.css("zIndex")),r.css("zIndex",o.zIndex)},stop:function(e,n,i){var r=i.options;r._zIndex&&t(n.helper).css("zIndex",r._zIndex)}});t.ui.draggable;/*!
 * jQuery UI Resizable 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/resizable/
 */
t.widget("ui.resizable",t.ui.mouse,{version:"1.11.4",widgetEventPrefix:"resize",options:{alsoResize:!1,animate:!1,animateDuration:"slow",animateEasing:"swing",aspectRatio:!1,autoHide:!1,containment:!1,ghost:!1,grid:!1,handles:"e,s,se",helper:!1,maxHeight:null,maxWidth:null,minHeight:10,minWidth:10,zIndex:90,resize:null,start:null,stop:null},_num:function(t){return parseInt(t,10)||0},_isNumber:function(t){return!isNaN(parseInt(t,10))},_hasScroll:function(e,n){if("hidden"===t(e).css("overflow"))return!1;var i=n&&"left"===n?"scrollLeft":"scrollTop",r=!1;return e[i]>0?!0:(e[i]=1,r=e[i]>0,e[i]=0,r)},_create:function(){var e,n,i,r,o,a=this,s=this.options;if(this.element.addClass("ui-resizable"),t.extend(this,{_aspectRatio:!!s.aspectRatio,aspectRatio:s.aspectRatio,originalElement:this.element,_proportionallyResizeElements:[],_helper:s.helper||s.ghost||s.animate?s.helper||"ui-resizable-helper":null}),this.element[0].nodeName.match(/^(canvas|textarea|input|select|button|img)$/i)&&(this.element.wrap(t("<div class='ui-wrapper' style='overflow: hidden;'></div>").css({position:this.element.css("position"),width:this.element.outerWidth(),height:this.element.outerHeight(),top:this.element.css("top"),left:this.element.css("left")})),this.element=this.element.parent().data("ui-resizable",this.element.resizable("instance")),this.elementIsWrapper=!0,this.element.css({marginLeft:this.originalElement.css("marginLeft"),marginTop:this.originalElement.css("marginTop"),marginRight:this.originalElement.css("marginRight"),marginBottom:this.originalElement.css("marginBottom")}),this.originalElement.css({marginLeft:0,marginTop:0,marginRight:0,marginBottom:0}),this.originalResizeStyle=this.originalElement.css("resize"),this.originalElement.css("resize","none"),this._proportionallyResizeElements.push(this.originalElement.css({position:"static",zoom:1,display:"block"})),this.originalElement.css({margin:this.originalElement.css("margin")}),this._proportionallyResize()),this.handles=s.handles||(t(".ui-resizable-handle",this.element).length?{n:".ui-resizable-n",e:".ui-resizable-e",s:".ui-resizable-s",w:".ui-resizable-w",se:".ui-resizable-se",sw:".ui-resizable-sw",ne:".ui-resizable-ne",nw:".ui-resizable-nw"}:"e,s,se"),this._handles=t(),this.handles.constructor===String)for("all"===this.handles&&(this.handles="n,e,s,w,se,sw,ne,nw"),e=this.handles.split(","),this.handles={},n=0;n<e.length;n++)i=t.trim(e[n]),o="ui-resizable-"+i,r=t("<div class='ui-resizable-handle "+o+"'></div>"),r.css({zIndex:s.zIndex}),"se"===i&&r.addClass("ui-icon ui-icon-gripsmall-diagonal-se"),this.handles[i]=".ui-resizable-"+i,this.element.append(r);this._renderAxis=function(e){var n,i,r,o;e=e||this.element;for(n in this.handles)this.handles[n].constructor===String?this.handles[n]=this.element.children(this.handles[n]).first().show():(this.handles[n].jquery||this.handles[n].nodeType)&&(this.handles[n]=t(this.handles[n]),this._on(this.handles[n],{mousedown:a._mouseDown})),this.elementIsWrapper&&this.originalElement[0].nodeName.match(/^(textarea|input|select|button)$/i)&&(i=t(this.handles[n],this.element),o=/sw|ne|nw|se|n|s/.test(n)?i.outerHeight():i.outerWidth(),r=["padding",/ne|nw|n/.test(n)?"Top":/se|sw|s/.test(n)?"Bottom":/^e$/.test(n)?"Right":"Left"].join(""),e.css(r,o),this._proportionallyResize()),this._handles=this._handles.add(this.handles[n])},this._renderAxis(this.element),this._handles=this._handles.add(this.element.find(".ui-resizable-handle")),this._handles.disableSelection(),this._handles.mouseover(function(){a.resizing||(this.className&&(r=this.className.match(/ui-resizable-(se|sw|ne|nw|n|e|s|w)/i)),a.axis=r&&r[1]?r[1]:"se")}),s.autoHide&&(this._handles.hide(),t(this.element).addClass("ui-resizable-autohide").mouseenter(function(){s.disabled||(t(this).removeClass("ui-resizable-autohide"),a._handles.show())}).mouseleave(function(){s.disabled||a.resizing||(t(this).addClass("ui-resizable-autohide"),a._handles.hide())})),this._mouseInit()},_destroy:function(){this._mouseDestroy();var e,n=function(e){t(e).removeClass("ui-resizable ui-resizable-disabled ui-resizable-resizing").removeData("resizable").removeData("ui-resizable").unbind(".resizable").find(".ui-resizable-handle").remove()};return this.elementIsWrapper&&(n(this.element),e=this.element,this.originalElement.css({position:e.css("position"),width:e.outerWidth(),height:e.outerHeight(),top:e.css("top"),left:e.css("left")}).insertAfter(e),e.remove()),this.originalElement.css("resize",this.originalResizeStyle),n(this.originalElement),this},_mouseCapture:function(e){var n,i,r=!1;for(n in this.handles)i=t(this.handles[n])[0],(i===e.target||t.contains(i,e.target))&&(r=!0);return!this.options.disabled&&r},_mouseStart:function(e){var n,i,r,o=this.options,a=this.element;return this.resizing=!0,this._renderProxy(),n=this._num(this.helper.css("left")),i=this._num(this.helper.css("top")),o.containment&&(n+=t(o.containment).scrollLeft()||0,i+=t(o.containment).scrollTop()||0),this.offset=this.helper.offset(),this.position={left:n,top:i},this.size=this._helper?{width:this.helper.width(),height:this.helper.height()}:{width:a.width(),height:a.height()},this.originalSize=this._helper?{width:a.outerWidth(),height:a.outerHeight()}:{width:a.width(),height:a.height()},this.sizeDiff={width:a.outerWidth()-a.width(),height:a.outerHeight()-a.height()},this.originalPosition={left:n,top:i},this.originalMousePosition={left:e.pageX,top:e.pageY},this.aspectRatio="number"==typeof o.aspectRatio?o.aspectRatio:this.originalSize.width/this.originalSize.height||1,r=t(".ui-resizable-"+this.axis).css("cursor"),t("body").css("cursor","auto"===r?this.axis+"-resize":r),a.addClass("ui-resizable-resizing"),this._propagate("start",e),!0},_mouseDrag:function(e){var n,i,r=this.originalMousePosition,o=this.axis,a=e.pageX-r.left||0,s=e.pageY-r.top||0,u=this._change[o];return this._updatePrevProperties(),u?(n=u.apply(this,[e,a,s]),this._updateVirtualBoundaries(e.shiftKey),(this._aspectRatio||e.shiftKey)&&(n=this._updateRatio(n,e)),n=this._respectSize(n,e),this._updateCache(n),this._propagate("resize",e),i=this._applyChanges(),!this._helper&&this._proportionallyResizeElements.length&&this._proportionallyResize(),t.isEmptyObject(i)||(this._updatePrevProperties(),this._trigger("resize",e,this.ui()),this._applyChanges()),!1):!1},_mouseStop:function(e){this.resizing=!1;var n,i,r,o,a,s,u,l=this.options,c=this;return this._helper&&(n=this._proportionallyResizeElements,i=n.length&&/textarea/i.test(n[0].nodeName),r=i&&this._hasScroll(n[0],"left")?0:c.sizeDiff.height,o=i?0:c.sizeDiff.width,a={width:c.helper.width()-o,height:c.helper.height()-r},s=parseInt(c.element.css("left"),10)+(c.position.left-c.originalPosition.left)||null,u=parseInt(c.element.css("top"),10)+(c.position.top-c.originalPosition.top)||null,l.animate||this.element.css(t.extend(a,{top:u,left:s})),c.helper.height(c.size.height),c.helper.width(c.size.width),this._helper&&!l.animate&&this._proportionallyResize()),t("body").css("cursor","auto"),this.element.removeClass("ui-resizable-resizing"),this._propagate("stop",e),this._helper&&this.helper.remove(),!1},_updatePrevProperties:function(){this.prevPosition={top:this.position.top,left:this.position.left},this.prevSize={width:this.size.width,height:this.size.height}},_applyChanges:function(){var t={};return this.position.top!==this.prevPosition.top&&(t.top=this.position.top+"px"),this.position.left!==this.prevPosition.left&&(t.left=this.position.left+"px"),this.size.width!==this.prevSize.width&&(t.width=this.size.width+"px"),this.size.height!==this.prevSize.height&&(t.height=this.size.height+"px"),this.helper.css(t),t},_updateVirtualBoundaries:function(t){var e,n,i,r,o,a=this.options;o={minWidth:this._isNumber(a.minWidth)?a.minWidth:0,maxWidth:this._isNumber(a.maxWidth)?a.maxWidth:1/0,minHeight:this._isNumber(a.minHeight)?a.minHeight:0,maxHeight:this._isNumber(a.maxHeight)?a.maxHeight:1/0},(this._aspectRatio||t)&&(e=o.minHeight*this.aspectRatio,i=o.minWidth/this.aspectRatio,n=o.maxHeight*this.aspectRatio,r=o.maxWidth/this.aspectRatio,e>o.minWidth&&(o.minWidth=e),i>o.minHeight&&(o.minHeight=i),n<o.maxWidth&&(o.maxWidth=n),r<o.maxHeight&&(o.maxHeight=r)),this._vBoundaries=o},_updateCache:function(t){this.offset=this.helper.offset(),this._isNumber(t.left)&&(this.position.left=t.left),this._isNumber(t.top)&&(this.position.top=t.top),this._isNumber(t.height)&&(this.size.height=t.height),this._isNumber(t.width)&&(this.size.width=t.width)},_updateRatio:function(t){var e=this.position,n=this.size,i=this.axis;return this._isNumber(t.height)?t.width=t.height*this.aspectRatio:this._isNumber(t.width)&&(t.height=t.width/this.aspectRatio),"sw"===i&&(t.left=e.left+(n.width-t.width),t.top=null),"nw"===i&&(t.top=e.top+(n.height-t.height),t.left=e.left+(n.width-t.width)),t},_respectSize:function(t){var e=this._vBoundaries,n=this.axis,i=this._isNumber(t.width)&&e.maxWidth&&e.maxWidth<t.width,r=this._isNumber(t.height)&&e.maxHeight&&e.maxHeight<t.height,o=this._isNumber(t.width)&&e.minWidth&&e.minWidth>t.width,a=this._isNumber(t.height)&&e.minHeight&&e.minHeight>t.height,s=this.originalPosition.left+this.originalSize.width,u=this.position.top+this.size.height,l=/sw|nw|w/.test(n),c=/nw|ne|n/.test(n);return o&&(t.width=e.minWidth),a&&(t.height=e.minHeight),i&&(t.width=e.maxWidth),r&&(t.height=e.maxHeight),o&&l&&(t.left=s-e.minWidth),i&&l&&(t.left=s-e.maxWidth),a&&c&&(t.top=u-e.minHeight),r&&c&&(t.top=u-e.maxHeight),t.width||t.height||t.left||!t.top?t.width||t.height||t.top||!t.left||(t.left=null):t.top=null,t},_getPaddingPlusBorderDimensions:function(t){for(var e=0,n=[],i=[t.css("borderTopWidth"),t.css("borderRightWidth"),t.css("borderBottomWidth"),t.css("borderLeftWidth")],r=[t.css("paddingTop"),t.css("paddingRight"),t.css("paddingBottom"),t.css("paddingLeft")];4>e;e++)n[e]=parseInt(i[e],10)||0,n[e]+=parseInt(r[e],10)||0;return{height:n[0]+n[2],width:n[1]+n[3]}},_proportionallyResize:function(){if(this._proportionallyResizeElements.length)for(var t,e=0,n=this.helper||this.element;e<this._proportionallyResizeElements.length;e++)t=this._proportionallyResizeElements[e],this.outerDimensions||(this.outerDimensions=this._getPaddingPlusBorderDimensions(t)),t.css({height:n.height()-this.outerDimensions.height||0,width:n.width()-this.outerDimensions.width||0})},_renderProxy:function(){var e=this.element,n=this.options;this.elementOffset=e.offset(),this._helper?(this.helper=this.helper||t("<div style='overflow:hidden;'></div>"),this.helper.addClass(this._helper).css({width:this.element.outerWidth()-1,height:this.element.outerHeight()-1,position:"absolute",left:this.elementOffset.left+"px",top:this.elementOffset.top+"px",zIndex:++n.zIndex}),this.helper.appendTo("body").disableSelection()):this.helper=this.element},_change:{e:function(t,e){return{width:this.originalSize.width+e}},w:function(t,e){var n=this.originalSize,i=this.originalPosition;return{left:i.left+e,width:n.width-e}},n:function(t,e,n){var i=this.originalSize,r=this.originalPosition;return{top:r.top+n,height:i.height-n}},s:function(t,e,n){return{height:this.originalSize.height+n}},se:function(e,n,i){return t.extend(this._change.s.apply(this,arguments),this._change.e.apply(this,[e,n,i]))},sw:function(e,n,i){return t.extend(this._change.s.apply(this,arguments),this._change.w.apply(this,[e,n,i]))},ne:function(e,n,i){return t.extend(this._change.n.apply(this,arguments),this._change.e.apply(this,[e,n,i]))},nw:function(e,n,i){return t.extend(this._change.n.apply(this,arguments),this._change.w.apply(this,[e,n,i]))}},_propagate:function(e,n){t.ui.plugin.call(this,e,[n,this.ui()]),"resize"!==e&&this._trigger(e,n,this.ui())},plugins:{},ui:function(){return{originalElement:this.originalElement,element:this.element,helper:this.helper,position:this.position,size:this.size,originalSize:this.originalSize,originalPosition:this.originalPosition}}}),t.ui.plugin.add("resizable","animate",{stop:function(e){var n=t(this).resizable("instance"),i=n.options,r=n._proportionallyResizeElements,o=r.length&&/textarea/i.test(r[0].nodeName),a=o&&n._hasScroll(r[0],"left")?0:n.sizeDiff.height,s=o?0:n.sizeDiff.width,u={width:n.size.width-s,height:n.size.height-a},l=parseInt(n.element.css("left"),10)+(n.position.left-n.originalPosition.left)||null,c=parseInt(n.element.css("top"),10)+(n.position.top-n.originalPosition.top)||null;n.element.animate(t.extend(u,c&&l?{top:c,left:l}:{}),{duration:i.animateDuration,easing:i.animateEasing,step:function(){var i={width:parseInt(n.element.css("width"),10),height:parseInt(n.element.css("height"),10),top:parseInt(n.element.css("top"),10),left:parseInt(n.element.css("left"),10)};r&&r.length&&t(r[0]).css({width:i.width,height:i.height}),n._updateCache(i),n._propagate("resize",e)}})}}),t.ui.plugin.add("resizable","containment",{start:function(){var e,n,i,r,o,a,s,u=t(this).resizable("instance"),l=u.options,c=u.element,d=l.containment,h=d instanceof t?d.get(0):/parent/.test(d)?c.parent().get(0):d;h&&(u.containerElement=t(h),/document/.test(d)||d===document?(u.containerOffset={left:0,top:0},u.containerPosition={left:0,top:0},u.parentData={element:t(document),left:0,top:0,width:t(document).width(),height:t(document).height()||document.body.parentNode.scrollHeight}):(e=t(h),n=[],t(["Top","Right","Left","Bottom"]).each(function(t,i){n[t]=u._num(e.css("padding"+i))}),u.containerOffset=e.offset(),u.containerPosition=e.position(),u.containerSize={height:e.innerHeight()-n[3],width:e.innerWidth()-n[1]},i=u.containerOffset,r=u.containerSize.height,o=u.containerSize.width,a=u._hasScroll(h,"left")?h.scrollWidth:o,s=u._hasScroll(h)?h.scrollHeight:r,u.parentData={element:h,left:i.left,top:i.top,width:a,height:s}))},resize:function(e){var n,i,r,o,a=t(this).resizable("instance"),s=a.options,u=a.containerOffset,l=a.position,c=a._aspectRatio||e.shiftKey,d={top:0,left:0},h=a.containerElement,f=!0;h[0]!==document&&/static/.test(h.css("position"))&&(d=u),l.left<(a._helper?u.left:0)&&(a.size.width=a.size.width+(a._helper?a.position.left-u.left:a.position.left-d.left),c&&(a.size.height=a.size.width/a.aspectRatio,f=!1),a.position.left=s.helper?u.left:0),l.top<(a._helper?u.top:0)&&(a.size.height=a.size.height+(a._helper?a.position.top-u.top:a.position.top),c&&(a.size.width=a.size.height*a.aspectRatio,f=!1),a.position.top=a._helper?u.top:0),r=a.containerElement.get(0)===a.element.parent().get(0),o=/relative|absolute/.test(a.containerElement.css("position")),r&&o?(a.offset.left=a.parentData.left+a.position.left,a.offset.top=a.parentData.top+a.position.top):(a.offset.left=a.element.offset().left,a.offset.top=a.element.offset().top),n=Math.abs(a.sizeDiff.width+(a._helper?a.offset.left-d.left:a.offset.left-u.left)),i=Math.abs(a.sizeDiff.height+(a._helper?a.offset.top-d.top:a.offset.top-u.top)),n+a.size.width>=a.parentData.width&&(a.size.width=a.parentData.width-n,c&&(a.size.height=a.size.width/a.aspectRatio,f=!1)),i+a.size.height>=a.parentData.height&&(a.size.height=a.parentData.height-i,c&&(a.size.width=a.size.height*a.aspectRatio,f=!1)),f||(a.position.left=a.prevPosition.left,a.position.top=a.prevPosition.top,a.size.width=a.prevSize.width,a.size.height=a.prevSize.height)},stop:function(){var e=t(this).resizable("instance"),n=e.options,i=e.containerOffset,r=e.containerPosition,o=e.containerElement,a=t(e.helper),s=a.offset(),u=a.outerWidth()-e.sizeDiff.width,l=a.outerHeight()-e.sizeDiff.height;e._helper&&!n.animate&&/relative/.test(o.css("position"))&&t(this).css({left:s.left-r.left-i.left,width:u,height:l}),e._helper&&!n.animate&&/static/.test(o.css("position"))&&t(this).css({left:s.left-r.left-i.left,width:u,height:l})}}),t.ui.plugin.add("resizable","alsoResize",{start:function(){var e=t(this).resizable("instance"),n=e.options;t(n.alsoResize).each(function(){var e=t(this);e.data("ui-resizable-alsoresize",{width:parseInt(e.width(),10),height:parseInt(e.height(),10),left:parseInt(e.css("left"),10),top:parseInt(e.css("top"),10)})})},resize:function(e,n){var i=t(this).resizable("instance"),r=i.options,o=i.originalSize,a=i.originalPosition,s={height:i.size.height-o.height||0,width:i.size.width-o.width||0,top:i.position.top-a.top||0,left:i.position.left-a.left||0};t(r.alsoResize).each(function(){var e=t(this),i=t(this).data("ui-resizable-alsoresize"),r={},o=e.parents(n.originalElement[0]).length?["width","height"]:["width","height","top","left"];t.each(o,function(t,e){var n=(i[e]||0)+(s[e]||0);n&&n>=0&&(r[e]=n||null)}),e.css(r)})},stop:function(){t(this).removeData("resizable-alsoresize")}}),t.ui.plugin.add("resizable","ghost",{start:function(){var e=t(this).resizable("instance"),n=e.options,i=e.size;e.ghost=e.originalElement.clone(),e.ghost.css({opacity:.25,display:"block",position:"relative",height:i.height,width:i.width,margin:0,left:0,top:0}).addClass("ui-resizable-ghost").addClass("string"==typeof n.ghost?n.ghost:""),e.ghost.appendTo(e.helper)},resize:function(){var e=t(this).resizable("instance");e.ghost&&e.ghost.css({position:"relative",height:e.size.height,width:e.size.width})},stop:function(){var e=t(this).resizable("instance");e.ghost&&e.helper&&e.helper.get(0).removeChild(e.ghost.get(0))}}),t.ui.plugin.add("resizable","grid",{resize:function(){var e,n=t(this).resizable("instance"),i=n.options,r=n.size,o=n.originalSize,a=n.originalPosition,s=n.axis,u="number"==typeof i.grid?[i.grid,i.grid]:i.grid,l=u[0]||1,c=u[1]||1,d=Math.round((r.width-o.width)/l)*l,h=Math.round((r.height-o.height)/c)*c,f=o.width+d,p=o.height+h,g=i.maxWidth&&i.maxWidth<f,m=i.maxHeight&&i.maxHeight<p,v=i.minWidth&&i.minWidth>f,y=i.minHeight&&i.minHeight>p;i.grid=u,v&&(f+=l),y&&(p+=c),g&&(f-=l),m&&(p-=c),/^(se|s|e)$/.test(s)?(n.size.width=f,n.size.height=p):/^(ne)$/.test(s)?(n.size.width=f,n.size.height=p,n.position.top=a.top-h):/^(sw)$/.test(s)?(n.size.width=f,n.size.height=p,n.position.left=a.left-d):((0>=p-c||0>=f-l)&&(e=n._getPaddingPlusBorderDimensions(this)),p-c>0?(n.size.height=p,n.position.top=a.top-h):(p=c-e.height,n.size.height=p,n.position.top=a.top+o.height-p),f-l>0?(n.size.width=f,n.position.left=a.left-d):(f=l-e.width,n.size.width=f,n.position.left=a.left+o.width-f))}});t.ui.resizable,t.widget("ui.dialog",{version:"1.11.4",options:{appendTo:"body",autoOpen:!0,buttons:[],closeOnEscape:!0,closeText:"Close",dialogClass:"",draggable:!0,hide:null,height:"auto",maxHeight:null,maxWidth:null,minHeight:150,minWidth:150,modal:!1,position:{my:"center",at:"center",of:window,collision:"fit",using:function(e){var n=t(this).css(e).offset().top;0>n&&t(this).css("top",e.top-n)}},resizable:!0,show:null,title:null,width:300,beforeClose:null,close:null,drag:null,dragStart:null,dragStop:null,focus:null,open:null,resize:null,resizeStart:null,resizeStop:null},sizeRelatedOptions:{buttons:!0,height:!0,maxHeight:!0,maxWidth:!0,minHeight:!0,minWidth:!0,width:!0},resizableRelatedOptions:{maxHeight:!0,maxWidth:!0,minHeight:!0,minWidth:!0},_create:function(){this.originalCss={display:this.element[0].style.display,width:this.element[0].style.width,minHeight:this.element[0].style.minHeight,maxHeight:this.element[0].style.maxHeight,height:this.element[0].style.height},this.originalPosition={parent:this.element.parent(),index:this.element.parent().children().index(this.element)},this.originalTitle=this.element.attr("title"),this.options.title=this.options.title||this.originalTitle,this._createWrapper(),this.element.show().removeAttr("title").addClass("ui-dialog-content ui-widget-content").appendTo(this.uiDialog),this._createTitlebar(),this._createButtonPane(),this.options.draggable&&t.fn.draggable&&this._makeDraggable(),this.options.resizable&&t.fn.resizable&&this._makeResizable(),this._isOpen=!1,this._trackFocus()},_init:function(){this.options.autoOpen&&this.open()},_appendTo:function(){var e=this.options.appendTo;return e&&(e.jquery||e.nodeType)?t(e):this.document.find(e||"body").eq(0)},_destroy:function(){var t,e=this.originalPosition;this._untrackInstance(),this._destroyOverlay(),this.element.removeUniqueId().removeClass("ui-dialog-content ui-widget-content").css(this.originalCss).detach(),this.uiDialog.stop(!0,!0).remove(),this.originalTitle&&this.element.attr("title",this.originalTitle),t=e.parent.children().eq(e.index),t.length&&t[0]!==this.element[0]?t.before(this.element):e.parent.append(this.element)},widget:function(){return this.uiDialog},disable:t.noop,enable:t.noop,close:function(e){var n,i=this;if(this._isOpen&&this._trigger("beforeClose",e)!==!1){if(this._isOpen=!1,this._focusedElement=null,this._destroyOverlay(),this._untrackInstance(),!this.opener.filter(":focusable").focus().length)try{n=this.document[0].activeElement,n&&"body"!==n.nodeName.toLowerCase()&&t(n).blur()}catch(r){}this._hide(this.uiDialog,this.options.hide,function(){i._trigger("close",e)})}},isOpen:function(){return this._isOpen},moveToTop:function(){this._moveToTop()},_moveToTop:function(e,n){var i=!1,r=this.uiDialog.siblings(".ui-front:visible").map(function(){return+t(this).css("z-index")}).get(),o=Math.max.apply(null,r);return o>=+this.uiDialog.css("z-index")&&(this.uiDialog.css("z-index",o+1),i=!0),i&&!n&&this._trigger("focus",e),i},open:function(){var e=this;return this._isOpen?void(this._moveToTop()&&this._focusTabbable()):(this._isOpen=!0,this.opener=t(this.document[0].activeElement),this._size(),this._position(),this._createOverlay(),this._moveToTop(null,!0),this.overlay&&this.overlay.css("z-index",this.uiDialog.css("z-index")-1),this._show(this.uiDialog,this.options.show,function(){e._focusTabbable(),e._trigger("focus")}),this._makeFocusTarget(),void this._trigger("open"))},_focusTabbable:function(){var t=this._focusedElement;t||(t=this.element.find("[autofocus]")),t.length||(t=this.element.find(":tabbable")),t.length||(t=this.uiDialogButtonPane.find(":tabbable")),t.length||(t=this.uiDialogTitlebarClose.filter(":tabbable")),t.length||(t=this.uiDialog),t.eq(0).focus()},_keepFocus:function(e){function n(){var e=this.document[0].activeElement,n=this.uiDialog[0]===e||t.contains(this.uiDialog[0],e);n||this._focusTabbable()}e.preventDefault(),n.call(this),this._delay(n)},_createWrapper:function(){this.uiDialog=t("<div>").addClass("ui-dialog ui-widget ui-widget-content ui-corner-all ui-front "+this.options.dialogClass).hide().attr({tabIndex:-1,role:"dialog"}).appendTo(this._appendTo()),this._on(this.uiDialog,{keydown:function(e){if(this.options.closeOnEscape&&!e.isDefaultPrevented()&&e.keyCode&&e.keyCode===t.ui.keyCode.ESCAPE)return e.preventDefault(),void this.close(e);if(e.keyCode===t.ui.keyCode.TAB&&!e.isDefaultPrevented()){var n=this.uiDialog.find(":tabbable"),i=n.filter(":first"),r=n.filter(":last");e.target!==r[0]&&e.target!==this.uiDialog[0]||e.shiftKey?e.target!==i[0]&&e.target!==this.uiDialog[0]||!e.shiftKey||(this._delay(function(){r.focus()}),e.preventDefault()):(this._delay(function(){i.focus()}),e.preventDefault())}},mousedown:function(t){this._moveToTop(t)&&this._focusTabbable()}}),this.element.find("[aria-describedby]").length||this.uiDialog.attr({"aria-describedby":this.element.uniqueId().attr("id")})},_createTitlebar:function(){var e;this.uiDialogTitlebar=t("<div>").addClass("ui-dialog-titlebar ui-widget-header ui-corner-all ui-helper-clearfix").prependTo(this.uiDialog),this._on(this.uiDialogTitlebar,{mousedown:function(e){t(e.target).closest(".ui-dialog-titlebar-close")||this.uiDialog.focus()}}),this.uiDialogTitlebarClose=t("<button type='button'></button>").button({label:this.options.closeText,icons:{primary:"ui-icon-closethick"},text:!1}).addClass("ui-dialog-titlebar-close").appendTo(this.uiDialogTitlebar),this._on(this.uiDialogTitlebarClose,{click:function(t){t.preventDefault(),this.close(t)}}),e=t("<span>").uniqueId().addClass("ui-dialog-title").prependTo(this.uiDialogTitlebar),this._title(e),this.uiDialog.attr({"aria-labelledby":e.attr("id")})},_title:function(t){this.options.title||t.html("&#160;"),t.text(this.options.title)},_createButtonPane:function(){this.uiDialogButtonPane=t("<div>").addClass("ui-dialog-buttonpane ui-widget-content ui-helper-clearfix"),this.uiButtonSet=t("<div>").addClass("ui-dialog-buttonset").appendTo(this.uiDialogButtonPane),this._createButtons()},_createButtons:function(){var e=this,n=this.options.buttons;return this.uiDialogButtonPane.remove(),this.uiButtonSet.empty(),t.isEmptyObject(n)||t.isArray(n)&&!n.length?void this.uiDialog.removeClass("ui-dialog-buttons"):(t.each(n,function(n,i){var r,o;i=t.isFunction(i)?{click:i,text:n}:i,i=t.extend({type:"button"},i),r=i.click,i.click=function(){r.apply(e.element[0],arguments)},o={icons:i.icons,text:i.showText},delete i.icons,delete i.showText,t("<button></button>",i).button(o).appendTo(e.uiButtonSet)}),this.uiDialog.addClass("ui-dialog-buttons"),void this.uiDialogButtonPane.appendTo(this.uiDialog))},_makeDraggable:function(){function e(t){return{position:t.position,offset:t.offset}}var n=this,i=this.options;this.uiDialog.draggable({cancel:".ui-dialog-content, .ui-dialog-titlebar-close",handle:".ui-dialog-titlebar",containment:"document",start:function(i,r){t(this).addClass("ui-dialog-dragging"),n._blockFrames(),n._trigger("dragStart",i,e(r))},drag:function(t,i){n._trigger("drag",t,e(i))},stop:function(r,o){var a=o.offset.left-n.document.scrollLeft(),s=o.offset.top-n.document.scrollTop();i.position={my:"left top",at:"left"+(a>=0?"+":"")+a+" top"+(s>=0?"+":"")+s,of:n.window},t(this).removeClass("ui-dialog-dragging"),n._unblockFrames(),n._trigger("dragStop",r,e(o))}})},_makeResizable:function(){function e(t){return{originalPosition:t.originalPosition,originalSize:t.originalSize,position:t.position,size:t.size}}var n=this,i=this.options,r=i.resizable,o=this.uiDialog.css("position"),a="string"==typeof r?r:"n,e,s,w,se,sw,ne,nw";this.uiDialog.resizable({cancel:".ui-dialog-content",containment:"document",alsoResize:this.element,maxWidth:i.maxWidth,maxHeight:i.maxHeight,minWidth:i.minWidth,minHeight:this._minHeight(),handles:a,start:function(i,r){t(this).addClass("ui-dialog-resizing"),n._blockFrames(),n._trigger("resizeStart",i,e(r))},resize:function(t,i){n._trigger("resize",t,e(i))},stop:function(r,o){var a=n.uiDialog.offset(),s=a.left-n.document.scrollLeft(),u=a.top-n.document.scrollTop();i.height=n.uiDialog.height(),i.width=n.uiDialog.width(),i.position={my:"left top",at:"left"+(s>=0?"+":"")+s+" top"+(u>=0?"+":"")+u,of:n.window},t(this).removeClass("ui-dialog-resizing"),n._unblockFrames(),n._trigger("resizeStop",r,e(o))}}).css("position",o)},_trackFocus:function(){this._on(this.widget(),{focusin:function(e){this._makeFocusTarget(),this._focusedElement=t(e.target)}})},_makeFocusTarget:function(){this._untrackInstance(),this._trackingInstances().unshift(this)},_untrackInstance:function(){var e=this._trackingInstances(),n=t.inArray(this,e);-1!==n&&e.splice(n,1)},_trackingInstances:function(){var t=this.document.data("ui-dialog-instances");return t||(t=[],this.document.data("ui-dialog-instances",t)),t},_minHeight:function(){var t=this.options;return"auto"===t.height?t.minHeight:Math.min(t.minHeight,t.height)},_position:function(){var t=this.uiDialog.is(":visible");t||this.uiDialog.show(),this.uiDialog.position(this.options.position),t||this.uiDialog.hide()},_setOptions:function(e){var n=this,i=!1,r={};t.each(e,function(t,e){n._setOption(t,e),t in n.sizeRelatedOptions&&(i=!0),t in n.resizableRelatedOptions&&(r[t]=e)}),i&&(this._size(),this._position()),this.uiDialog.is(":data(ui-resizable)")&&this.uiDialog.resizable("option",r)},_setOption:function(t,e){var n,i,r=this.uiDialog;"dialogClass"===t&&r.removeClass(this.options.dialogClass).addClass(e),"disabled"!==t&&(this._super(t,e),"appendTo"===t&&this.uiDialog.appendTo(this._appendTo()),"buttons"===t&&this._createButtons(),"closeText"===t&&this.uiDialogTitlebarClose.button({label:""+e}),"draggable"===t&&(n=r.is(":data(ui-draggable)"),n&&!e&&r.draggable("destroy"),!n&&e&&this._makeDraggable()),"position"===t&&this._position(),"resizable"===t&&(i=r.is(":data(ui-resizable)"),i&&!e&&r.resizable("destroy"),i&&"string"==typeof e&&r.resizable("option","handles",e),i||e===!1||this._makeResizable()),"title"===t&&this._title(this.uiDialogTitlebar.find(".ui-dialog-title")))},_size:function(){var t,e,n,i=this.options;this.element.show().css({width:"auto",minHeight:0,maxHeight:"none",height:0}),i.minWidth>i.width&&(i.width=i.minWidth),t=this.uiDialog.css({height:"auto",width:i.width}).outerHeight(),e=Math.max(0,i.minHeight-t),n="number"==typeof i.maxHeight?Math.max(0,i.maxHeight-t):"none","auto"===i.height?this.element.css({minHeight:e,maxHeight:n,height:"auto"}):this.element.height(Math.max(0,i.height-t)),this.uiDialog.is(":data(ui-resizable)")&&this.uiDialog.resizable("option","minHeight",this._minHeight())},_blockFrames:function(){this.iframeBlocks=this.document.find("iframe").map(function(){var e=t(this);return t("<div>").css({position:"absolute",width:e.outerWidth(),height:e.outerHeight()}).appendTo(e.parent()).offset(e.offset())[0]})},_unblockFrames:function(){this.iframeBlocks&&(this.iframeBlocks.remove(),delete this.iframeBlocks)},_allowInteraction:function(e){return t(e.target).closest(".ui-dialog").length?!0:!!t(e.target).closest(".ui-datepicker").length},_createOverlay:function(){if(this.options.modal){var e=!0;this._delay(function(){e=!1}),this.document.data("ui-dialog-overlays")||this._on(this.document,{focusin:function(t){e||this._allowInteraction(t)||(t.preventDefault(),this._trackingInstances()[0]._focusTabbable())}}),this.overlay=t("<div>").addClass("ui-widget-overlay ui-front").appendTo(this._appendTo()),this._on(this.overlay,{mousedown:"_keepFocus"}),this.document.data("ui-dialog-overlays",(this.document.data("ui-dialog-overlays")||0)+1)}},_destroyOverlay:function(){if(this.options.modal&&this.overlay){var t=this.document.data("ui-dialog-overlays")-1;t?this.document.data("ui-dialog-overlays",t):this.document.unbind("focusin").removeData("ui-dialog-overlays"),this.overlay.remove(),this.overlay=null}}});/*!
 * jQuery UI Droppable 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/droppable/
 */
t.widget("ui.droppable",{version:"1.11.4",widgetEventPrefix:"drop",options:{accept:"*",activeClass:!1,addClasses:!0,greedy:!1,hoverClass:!1,scope:"default",tolerance:"intersect",activate:null,deactivate:null,drop:null,out:null,over:null},_create:function(){var e,n=this.options,i=n.accept;this.isover=!1,this.isout=!0,this.accept=t.isFunction(i)?i:function(t){return t.is(i)},this.proportions=function(){return arguments.length?void(e=arguments[0]):e?e:e={width:this.element[0].offsetWidth,height:this.element[0].offsetHeight}},this._addToManager(n.scope),n.addClasses&&this.element.addClass("ui-droppable")},_addToManager:function(e){t.ui.ddmanager.droppables[e]=t.ui.ddmanager.droppables[e]||[],t.ui.ddmanager.droppables[e].push(this)},_splice:function(t){for(var e=0;e<t.length;e++)t[e]===this&&t.splice(e,1)},_destroy:function(){var e=t.ui.ddmanager.droppables[this.options.scope];this._splice(e),this.element.removeClass("ui-droppable ui-droppable-disabled")},_setOption:function(e,n){if("accept"===e)this.accept=t.isFunction(n)?n:function(t){return t.is(n)};else if("scope"===e){var i=t.ui.ddmanager.droppables[this.options.scope];this._splice(i),this._addToManager(n)}this._super(e,n)},_activate:function(e){var n=t.ui.ddmanager.current;this.options.activeClass&&this.element.addClass(this.options.activeClass),n&&this._trigger("activate",e,this.ui(n))},_deactivate:function(e){var n=t.ui.ddmanager.current;this.options.activeClass&&this.element.removeClass(this.options.activeClass),n&&this._trigger("deactivate",e,this.ui(n))},_over:function(e){var n=t.ui.ddmanager.current;n&&(n.currentItem||n.element)[0]!==this.element[0]&&this.accept.call(this.element[0],n.currentItem||n.element)&&(this.options.hoverClass&&this.element.addClass(this.options.hoverClass),this._trigger("over",e,this.ui(n)))},_out:function(e){var n=t.ui.ddmanager.current;n&&(n.currentItem||n.element)[0]!==this.element[0]&&this.accept.call(this.element[0],n.currentItem||n.element)&&(this.options.hoverClass&&this.element.removeClass(this.options.hoverClass),this._trigger("out",e,this.ui(n)))},_drop:function(e,n){var i=n||t.ui.ddmanager.current,r=!1;return i&&(i.currentItem||i.element)[0]!==this.element[0]?(this.element.find(":data(ui-droppable)").not(".ui-draggable-dragging").each(function(){var n=t(this).droppable("instance");return n.options.greedy&&!n.options.disabled&&n.options.scope===i.options.scope&&n.accept.call(n.element[0],i.currentItem||i.element)&&t.ui.intersect(i,t.extend(n,{offset:n.element.offset()}),n.options.tolerance,e)?(r=!0,!1):void 0}),r?!1:this.accept.call(this.element[0],i.currentItem||i.element)?(this.options.activeClass&&this.element.removeClass(this.options.activeClass),this.options.hoverClass&&this.element.removeClass(this.options.hoverClass),this._trigger("drop",e,this.ui(i)),this.element):!1):!1},ui:function(t){return{draggable:t.currentItem||t.element,helper:t.helper,position:t.position,offset:t.positionAbs}}}),t.ui.intersect=function(){function t(t,e,n){return t>=e&&e+n>t}return function(e,n,i,r){if(!n.offset)return!1;var o=(e.positionAbs||e.position.absolute).left+e.margins.left,a=(e.positionAbs||e.position.absolute).top+e.margins.top,s=o+e.helperProportions.width,u=a+e.helperProportions.height,l=n.offset.left,c=n.offset.top,d=l+n.proportions().width,h=c+n.proportions().height;switch(i){case"fit":return o>=l&&d>=s&&a>=c&&h>=u;case"intersect":return l<o+e.helperProportions.width/2&&s-e.helperProportions.width/2<d&&c<a+e.helperProportions.height/2&&u-e.helperProportions.height/2<h;case"pointer":return t(r.pageY,c,n.proportions().height)&&t(r.pageX,l,n.proportions().width);case"touch":return(a>=c&&h>=a||u>=c&&h>=u||c>a&&u>h)&&(o>=l&&d>=o||s>=l&&d>=s||l>o&&s>d);default:return!1}}}(),t.ui.ddmanager={current:null,droppables:{"default":[]},prepareOffsets:function(e,n){var i,r,o=t.ui.ddmanager.droppables[e.options.scope]||[],a=n?n.type:null,s=(e.currentItem||e.element).find(":data(ui-droppable)").addBack();t:for(i=0;i<o.length;i++)if(!(o[i].options.disabled||e&&!o[i].accept.call(o[i].element[0],e.currentItem||e.element))){for(r=0;r<s.length;r++)if(s[r]===o[i].element[0]){o[i].proportions().height=0;continue t}o[i].visible="none"!==o[i].element.css("display"),o[i].visible&&("mousedown"===a&&o[i]._activate.call(o[i],n),o[i].offset=o[i].element.offset(),o[i].proportions({width:o[i].element[0].offsetWidth,height:o[i].element[0].offsetHeight}))}},drop:function(e,n){var i=!1;return t.each((t.ui.ddmanager.droppables[e.options.scope]||[]).slice(),function(){this.options&&(!this.options.disabled&&this.visible&&t.ui.intersect(e,this,this.options.tolerance,n)&&(i=this._drop.call(this,n)||i),!this.options.disabled&&this.visible&&this.accept.call(this.element[0],e.currentItem||e.element)&&(this.isout=!0,this.isover=!1,this._deactivate.call(this,n)))}),i},dragStart:function(e,n){e.element.parentsUntil("body").bind("scroll.droppable",function(){e.options.refreshPositions||t.ui.ddmanager.prepareOffsets(e,n)})},drag:function(e,n){e.options.refreshPositions&&t.ui.ddmanager.prepareOffsets(e,n),t.each(t.ui.ddmanager.droppables[e.options.scope]||[],function(){if(!this.options.disabled&&!this.greedyChild&&this.visible){var i,r,o,a=t.ui.intersect(e,this,this.options.tolerance,n),s=!a&&this.isover?"isout":a&&!this.isover?"isover":null;s&&(this.options.greedy&&(r=this.options.scope,o=this.element.parents(":data(ui-droppable)").filter(function(){return t(this).droppable("instance").options.scope===r}),o.length&&(i=t(o[0]).droppable("instance"),i.greedyChild="isover"===s)),i&&"isover"===s&&(i.isover=!1,i.isout=!0,i._out.call(i,n)),this[s]=!0,this["isout"===s?"isover":"isout"]=!1,this["isover"===s?"_over":"_out"].call(this,n),i&&"isout"===s&&(i.isout=!1,i.isover=!0,i._over.call(i,n)))}})},dragStop:function(e,n){e.element.parentsUntil("body").unbind("scroll.droppable"),e.options.refreshPositions||t.ui.ddmanager.prepareOffsets(e,n)}};var y=(t.ui.droppable,"ui-effects-"),b=t;t.effects={effect:{}},/*!
 * jQuery Color Animations v2.1.2
 * https://github.com/jquery/jquery-color
 *
 * Copyright 2014 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * Date: Wed Jan 16 08:47:09 2013 -0600
 */
function(t,e){function n(t,e,n){var i=d[e.type]||{};return null==t?n||!e.def?null:e.def:(t=i.floor?~~t:parseFloat(t),isNaN(t)?e.def:i.mod?(t+i.mod)%i.mod:0>t?0:i.max<t?i.max:t)}function i(e){var n=l(),i=n._rgba=[];return e=e.toLowerCase(),p(u,function(t,r){var o,a=r.re.exec(e),s=a&&r.parse(a),u=r.space||"rgba";return s?(o=n[u](s),n[c[u].cache]=o[c[u].cache],i=n._rgba=o._rgba,!1):void 0}),i.length?("0,0,0,0"===i.join()&&t.extend(i,o.transparent),n):o[e]}function r(t,e,n){return n=(n+1)%1,1>6*n?t+(e-t)*n*6:1>2*n?e:2>3*n?t+(e-t)*(2/3-n)*6:t}var o,a="backgroundColor borderBottomColor borderLeftColor borderRightColor borderTopColor color columnRuleColor outlineColor textDecorationColor textEmphasisColor",s=/^([\-+])=\s*(\d+\.?\d*)/,u=[{re:/rgba?\(\s*(\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})\s*(?:,\s*(\d?(?:\.\d+)?)\s*)?\)/,parse:function(t){return[t[1],t[2],t[3],t[4]]}},{re:/rgba?\(\s*(\d+(?:\.\d+)?)\%\s*,\s*(\d+(?:\.\d+)?)\%\s*,\s*(\d+(?:\.\d+)?)\%\s*(?:,\s*(\d?(?:\.\d+)?)\s*)?\)/,parse:function(t){return[2.55*t[1],2.55*t[2],2.55*t[3],t[4]]}},{re:/#([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2})/,parse:function(t){return[parseInt(t[1],16),parseInt(t[2],16),parseInt(t[3],16)]}},{re:/#([a-f0-9])([a-f0-9])([a-f0-9])/,parse:function(t){return[parseInt(t[1]+t[1],16),parseInt(t[2]+t[2],16),parseInt(t[3]+t[3],16)]}},{re:/hsla?\(\s*(\d+(?:\.\d+)?)\s*,\s*(\d+(?:\.\d+)?)\%\s*,\s*(\d+(?:\.\d+)?)\%\s*(?:,\s*(\d?(?:\.\d+)?)\s*)?\)/,space:"hsla",parse:function(t){return[t[1],t[2]/100,t[3]/100,t[4]]}}],l=t.Color=function(e,n,i,r){return new t.Color.fn.parse(e,n,i,r)},c={rgba:{props:{red:{idx:0,type:"byte"},green:{idx:1,type:"byte"},blue:{idx:2,type:"byte"}}},hsla:{props:{hue:{idx:0,type:"degrees"},saturation:{idx:1,type:"percent"},lightness:{idx:2,type:"percent"}}}},d={"byte":{floor:!0,max:255},percent:{max:1},degrees:{mod:360,floor:!0}},h=l.support={},f=t("<p>")[0],p=t.each;f.style.cssText="background-color:rgba(1,1,1,.5)",h.rgba=f.style.backgroundColor.indexOf("rgba")>-1,p(c,function(t,e){e.cache="_"+t,e.props.alpha={idx:3,type:"percent",def:1}}),l.fn=t.extend(l.prototype,{parse:function(r,a,s,u){if(r===e)return this._rgba=[null,null,null,null],this;(r.jquery||r.nodeType)&&(r=t(r).css(a),a=e);var d=this,h=t.type(r),f=this._rgba=[];return a!==e&&(r=[r,a,s,u],h="array"),"string"===h?this.parse(i(r)||o._default):"array"===h?(p(c.rgba.props,function(t,e){f[e.idx]=n(r[e.idx],e)}),this):"object"===h?(r instanceof l?p(c,function(t,e){r[e.cache]&&(d[e.cache]=r[e.cache].slice())}):p(c,function(e,i){var o=i.cache;p(i.props,function(t,e){if(!d[o]&&i.to){if("alpha"===t||null==r[t])return;d[o]=i.to(d._rgba)}d[o][e.idx]=n(r[t],e,!0)}),d[o]&&t.inArray(null,d[o].slice(0,3))<0&&(d[o][3]=1,i.from&&(d._rgba=i.from(d[o])))}),this):void 0},is:function(t){var e=l(t),n=!0,i=this;return p(c,function(t,r){var o,a=e[r.cache];return a&&(o=i[r.cache]||r.to&&r.to(i._rgba)||[],p(r.props,function(t,e){return null!=a[e.idx]?n=a[e.idx]===o[e.idx]:void 0})),n}),n},_space:function(){var t=[],e=this;return p(c,function(n,i){e[i.cache]&&t.push(n)}),t.pop()},transition:function(t,e){var i=l(t),r=i._space(),o=c[r],a=0===this.alpha()?l("transparent"):this,s=a[o.cache]||o.to(a._rgba),u=s.slice();return i=i[o.cache],p(o.props,function(t,r){var o=r.idx,a=s[o],l=i[o],c=d[r.type]||{};null!==l&&(null===a?u[o]=l:(c.mod&&(l-a>c.mod/2?a+=c.mod:a-l>c.mod/2&&(a-=c.mod)),u[o]=n((l-a)*e+a,r)))}),this[r](u)},blend:function(e){if(1===this._rgba[3])return this;var n=this._rgba.slice(),i=n.pop(),r=l(e)._rgba;return l(t.map(n,function(t,e){return(1-i)*r[e]+i*t}))},toRgbaString:function(){var e="rgba(",n=t.map(this._rgba,function(t,e){return null==t?e>2?1:0:t});return 1===n[3]&&(n.pop(),e="rgb("),e+n.join()+")"},toHslaString:function(){var e="hsla(",n=t.map(this.hsla(),function(t,e){return null==t&&(t=e>2?1:0),e&&3>e&&(t=Math.round(100*t)+"%"),t});return 1===n[3]&&(n.pop(),e="hsl("),e+n.join()+")"},toHexString:function(e){var n=this._rgba.slice(),i=n.pop();return e&&n.push(~~(255*i)),"#"+t.map(n,function(t){return t=(t||0).toString(16),1===t.length?"0"+t:t}).join("")},toString:function(){return 0===this._rgba[3]?"transparent":this.toRgbaString()}}),l.fn.parse.prototype=l.fn,c.hsla.to=function(t){if(null==t[0]||null==t[1]||null==t[2])return[null,null,null,t[3]];var e,n,i=t[0]/255,r=t[1]/255,o=t[2]/255,a=t[3],s=Math.max(i,r,o),u=Math.min(i,r,o),l=s-u,c=s+u,d=.5*c;return e=u===s?0:i===s?60*(r-o)/l+360:r===s?60*(o-i)/l+120:60*(i-r)/l+240,n=0===l?0:.5>=d?l/c:l/(2-c),[Math.round(e)%360,n,d,null==a?1:a]},c.hsla.from=function(t){if(null==t[0]||null==t[1]||null==t[2])return[null,null,null,t[3]];var e=t[0]/360,n=t[1],i=t[2],o=t[3],a=.5>=i?i*(1+n):i+n-i*n,s=2*i-a;return[Math.round(255*r(s,a,e+1/3)),Math.round(255*r(s,a,e)),Math.round(255*r(s,a,e-1/3)),o]},p(c,function(i,r){var o=r.props,a=r.cache,u=r.to,c=r.from;l.fn[i]=function(i){if(u&&!this[a]&&(this[a]=u(this._rgba)),i===e)return this[a].slice();var r,s=t.type(i),d="array"===s||"object"===s?i:arguments,h=this[a].slice();return p(o,function(t,e){var i=d["object"===s?t:e.idx];null==i&&(i=h[e.idx]),h[e.idx]=n(i,e)}),c?(r=l(c(h)),r[a]=h,r):l(h)},p(o,function(e,n){l.fn[e]||(l.fn[e]=function(r){var o,a=t.type(r),u="alpha"===e?this._hsla?"hsla":"rgba":i,l=this[u](),c=l[n.idx];return"undefined"===a?c:("function"===a&&(r=r.call(this,c),a=t.type(r)),null==r&&n.empty?this:("string"===a&&(o=s.exec(r),o&&(r=c+parseFloat(o[2])*("+"===o[1]?1:-1))),l[n.idx]=r,this[u](l)))})})}),l.hook=function(e){var n=e.split(" ");p(n,function(e,n){t.cssHooks[n]={set:function(e,r){var o,a,s="";if("transparent"!==r&&("string"!==t.type(r)||(o=i(r)))){if(r=l(o||r),!h.rgba&&1!==r._rgba[3]){for(a="backgroundColor"===n?e.parentNode:e;(""===s||"transparent"===s)&&a&&a.style;)try{s=t.css(a,"backgroundColor"),a=a.parentNode}catch(u){}r=r.blend(s&&"transparent"!==s?s:"_default")}r=r.toRgbaString()}try{e.style[n]=r}catch(u){}}},t.fx.step[n]=function(e){e.colorInit||(e.start=l(e.elem,n),e.end=l(e.end),e.colorInit=!0),t.cssHooks[n].set(e.elem,e.start.transition(e.end,e.pos))}})},l.hook(a),t.cssHooks.borderColor={expand:function(t){var e={};return p(["Top","Right","Bottom","Left"],function(n,i){e["border"+i+"Color"]=t}),e}},o=t.Color.names={aqua:"#00ffff",black:"#000000",blue:"#0000ff",fuchsia:"#ff00ff",gray:"#808080",green:"#008000",lime:"#00ff00",maroon:"#800000",navy:"#000080",olive:"#808000",purple:"#800080",red:"#ff0000",silver:"#c0c0c0",teal:"#008080",white:"#ffffff",yellow:"#ffff00",transparent:[null,null,null,0],_default:"#ffffff"}}(b),function(){function e(e){var n,i,r=e.ownerDocument.defaultView?e.ownerDocument.defaultView.getComputedStyle(e,null):e.currentStyle,o={};if(r&&r.length&&r[0]&&r[r[0]])for(i=r.length;i--;)n=r[i],"string"==typeof r[n]&&(o[t.camelCase(n)]=r[n]);else for(n in r)"string"==typeof r[n]&&(o[n]=r[n]);return o}function n(e,n){var i,o,a={};for(i in n)o=n[i],e[i]!==o&&(r[i]||(t.fx.step[i]||!isNaN(parseFloat(o)))&&(a[i]=o));return a}var i=["add","remove","toggle"],r={border:1,borderBottom:1,borderColor:1,borderLeft:1,borderRight:1,borderTop:1,borderWidth:1,margin:1,padding:1};t.each(["borderLeftStyle","borderRightStyle","borderBottomStyle","borderTopStyle"],function(e,n){t.fx.step[n]=function(t){("none"!==t.end&&!t.setAttr||1===t.pos&&!t.setAttr)&&(b.style(t.elem,n,t.end),t.setAttr=!0)}}),t.fn.addBack||(t.fn.addBack=function(t){return this.add(null==t?this.prevObject:this.prevObject.filter(t))}),t.effects.animateClass=function(r,o,a,s){var u=t.speed(o,a,s);return this.queue(function(){var o,a=t(this),s=a.attr("class")||"",l=u.children?a.find("*").addBack():a;l=l.map(function(){var n=t(this);return{el:n,start:e(this)}}),o=function(){t.each(i,function(t,e){r[e]&&a[e+"Class"](r[e])})},o(),l=l.map(function(){return this.end=e(this.el[0]),this.diff=n(this.start,this.end),this}),a.attr("class",s),l=l.map(function(){var e=this,n=t.Deferred(),i=t.extend({},u,{queue:!1,complete:function(){n.resolve(e)}});return this.el.animate(this.diff,i),n.promise()}),t.when.apply(t,l.get()).done(function(){o(),t.each(arguments,function(){var e=this.el;t.each(this.diff,function(t){e.css(t,"")})}),u.complete.call(a[0])})})},t.fn.extend({addClass:function(e){return function(n,i,r,o){return i?t.effects.animateClass.call(this,{add:n},i,r,o):e.apply(this,arguments)}}(t.fn.addClass),removeClass:function(e){return function(n,i,r,o){return arguments.length>1?t.effects.animateClass.call(this,{remove:n},i,r,o):e.apply(this,arguments)}}(t.fn.removeClass),toggleClass:function(e){return function(n,i,r,o,a){return"boolean"==typeof i||void 0===i?r?t.effects.animateClass.call(this,i?{add:n}:{remove:n},r,o,a):e.apply(this,arguments):t.effects.animateClass.call(this,{toggle:n},i,r,o)}}(t.fn.toggleClass),switchClass:function(e,n,i,r,o){return t.effects.animateClass.call(this,{add:n,remove:e},i,r,o)}})}(),function(){function e(e,n,i,r){return t.isPlainObject(e)&&(n=e,e=e.effect),e={effect:e},null==n&&(n={}),t.isFunction(n)&&(r=n,i=null,n={}),("number"==typeof n||t.fx.speeds[n])&&(r=i,i=n,n={}),t.isFunction(i)&&(r=i,i=null),n&&t.extend(e,n),i=i||n.duration,e.duration=t.fx.off?0:"number"==typeof i?i:i in t.fx.speeds?t.fx.speeds[i]:t.fx.speeds._default,e.complete=r||n.complete,e}function n(e){return!e||"number"==typeof e||t.fx.speeds[e]?!0:"string"!=typeof e||t.effects.effect[e]?t.isFunction(e)?!0:"object"!=typeof e||e.effect?!1:!0:!0}t.extend(t.effects,{version:"1.11.4",save:function(t,e){for(var n=0;n<e.length;n++)null!==e[n]&&t.data(y+e[n],t[0].style[e[n]])},restore:function(t,e){var n,i;for(i=0;i<e.length;i++)null!==e[i]&&(n=t.data(y+e[i]),void 0===n&&(n=""),t.css(e[i],n))},setMode:function(t,e){return"toggle"===e&&(e=t.is(":hidden")?"show":"hide"),e},getBaseline:function(t,e){var n,i;switch(t[0]){case"top":n=0;break;case"middle":n=.5;break;case"bottom":n=1;break;default:n=t[0]/e.height}switch(t[1]){case"left":i=0;break;case"center":i=.5;break;case"right":i=1;break;default:i=t[1]/e.width}return{x:i,y:n}},createWrapper:function(e){if(e.parent().is(".ui-effects-wrapper"))return e.parent();var n={width:e.outerWidth(!0),height:e.outerHeight(!0),"float":e.css("float")},i=t("<div></div>").addClass("ui-effects-wrapper").css({fontSize:"100%",background:"transparent",border:"none",margin:0,padding:0}),r={width:e.width(),height:e.height()},o=document.activeElement;try{o.id}catch(a){o=document.body}return e.wrap(i),(e[0]===o||t.contains(e[0],o))&&t(o).focus(),i=e.parent(),"static"===e.css("position")?(i.css({position:"relative"}),e.css({position:"relative"})):(t.extend(n,{position:e.css("position"),zIndex:e.css("z-index")}),t.each(["top","left","bottom","right"],function(t,i){n[i]=e.css(i),isNaN(parseInt(n[i],10))&&(n[i]="auto")}),e.css({position:"relative",top:0,left:0,right:"auto",bottom:"auto"})),e.css(r),i.css(n).show()},removeWrapper:function(e){var n=document.activeElement;return e.parent().is(".ui-effects-wrapper")&&(e.parent().replaceWith(e),(e[0]===n||t.contains(e[0],n))&&t(n).focus()),e},setTransition:function(e,n,i,r){return r=r||{},t.each(n,function(t,n){var o=e.cssUnit(n);o[0]>0&&(r[n]=o[0]*i+o[1])}),r}}),t.fn.extend({effect:function(){function n(e){function n(){t.isFunction(o)&&o.call(r[0]),t.isFunction(e)&&e()}var r=t(this),o=i.complete,s=i.mode;(r.is(":hidden")?"hide"===s:"show"===s)?(r[s](),n()):a.call(r[0],i,n)}var i=e.apply(this,arguments),r=i.mode,o=i.queue,a=t.effects.effect[i.effect];return t.fx.off||!a?r?this[r](i.duration,i.complete):this.each(function(){i.complete&&i.complete.call(this)}):o===!1?this.each(n):this.queue(o||"fx",n)},show:function(t){return function(i){if(n(i))return t.apply(this,arguments);var r=e.apply(this,arguments);return r.mode="show",this.effect.call(this,r)}}(t.fn.show),hide:function(t){return function(i){if(n(i))return t.apply(this,arguments);var r=e.apply(this,arguments);return r.mode="hide",this.effect.call(this,r)}}(t.fn.hide),toggle:function(t){return function(i){if(n(i)||"boolean"==typeof i)return t.apply(this,arguments);var r=e.apply(this,arguments);return r.mode="toggle",this.effect.call(this,r)}}(t.fn.toggle),cssUnit:function(e){var n=this.css(e),i=[];return t.each(["em","px","%","pt"],function(t,e){n.indexOf(e)>0&&(i=[parseFloat(n),e])}),i}})}(),function(){var e={};t.each(["Quad","Cubic","Quart","Quint","Expo"],function(t,n){e[n]=function(e){return Math.pow(e,t+2)}}),t.extend(e,{Sine:function(t){return 1-Math.cos(t*Math.PI/2)},Circ:function(t){return 1-Math.sqrt(1-t*t)},Elastic:function(t){return 0===t||1===t?t:-Math.pow(2,8*(t-1))*Math.sin((80*(t-1)-7.5)*Math.PI/15)},Back:function(t){return t*t*(3*t-2)},Bounce:function(t){for(var e,n=4;t<((e=Math.pow(2,--n))-1)/11;);return 1/Math.pow(4,3-n)-7.5625*Math.pow((3*e-2)/22-t,2)}}),t.each(e,function(e,n){t.easing["easeIn"+e]=n,t.easing["easeOut"+e]=function(t){return 1-n(1-t)},t.easing["easeInOut"+e]=function(t){return.5>t?n(2*t)/2:1-n(-2*t+2)/2}})}();t.effects,t.effects.effect.blind=function(e,n){var i,r,o,a=t(this),s=/up|down|vertical/,u=/up|left|vertical|horizontal/,l=["position","top","bottom","left","right","height","width"],c=t.effects.setMode(a,e.mode||"hide"),d=e.direction||"up",h=s.test(d),f=h?"height":"width",p=h?"top":"left",g=u.test(d),m={},v="show"===c;a.parent().is(".ui-effects-wrapper")?t.effects.save(a.parent(),l):t.effects.save(a,l),a.show(),i=t.effects.createWrapper(a).css({overflow:"hidden"}),r=i[f](),o=parseFloat(i.css(p))||0,m[f]=v?r:0,g||(a.css(h?"bottom":"right",0).css(h?"top":"left","auto").css({position:"absolute"}),m[p]=v?o:r+o),v&&(i.css(f,0),g||i.css(p,o+r)),i.animate(m,{duration:e.duration,easing:e.easing,queue:!1,complete:function(){"hide"===c&&a.hide(),t.effects.restore(a,l),t.effects.removeWrapper(a),n()}})},t.effects.effect.bounce=function(e,n){var i,r,o,a=t(this),s=["position","top","bottom","left","right","height","width"],u=t.effects.setMode(a,e.mode||"effect"),l="hide"===u,c="show"===u,d=e.direction||"up",h=e.distance,f=e.times||5,p=2*f+(c||l?1:0),g=e.duration/p,m=e.easing,v="up"===d||"down"===d?"top":"left",y="up"===d||"left"===d,b=a.queue(),x=b.length;for((c||l)&&s.push("opacity"),t.effects.save(a,s),a.show(),t.effects.createWrapper(a),h||(h=a["top"===v?"outerHeight":"outerWidth"]()/3),c&&(o={opacity:1},o[v]=0,a.css("opacity",0).css(v,y?2*-h:2*h).animate(o,g,m)),l&&(h/=Math.pow(2,f-1)),o={},o[v]=0,i=0;f>i;i++)r={},r[v]=(y?"-=":"+=")+h,a.animate(r,g,m).animate(o,g,m),h=l?2*h:h/2;l&&(r={opacity:0},r[v]=(y?"-=":"+=")+h,a.animate(r,g,m)),a.queue(function(){l&&a.hide(),t.effects.restore(a,s),t.effects.removeWrapper(a),n()}),x>1&&b.splice.apply(b,[1,0].concat(b.splice(x,p+1))),a.dequeue()},t.effects.effect.clip=function(e,n){var i,r,o,a=t(this),s=["position","top","bottom","left","right","height","width"],u=t.effects.setMode(a,e.mode||"hide"),l="show"===u,c=e.direction||"vertical",d="vertical"===c,h=d?"height":"width",f=d?"top":"left",p={};t.effects.save(a,s),a.show(),i=t.effects.createWrapper(a).css({overflow:"hidden"}),r="IMG"===a[0].tagName?i:a,o=r[h](),l&&(r.css(h,0),r.css(f,o/2)),p[h]=l?o:0,p[f]=l?0:o/2,r.animate(p,{queue:!1,duration:e.duration,easing:e.easing,complete:function(){l||a.hide(),t.effects.restore(a,s),t.effects.removeWrapper(a),n()}})},t.effects.effect.drop=function(e,n){var i,r=t(this),o=["position","top","bottom","left","right","opacity","height","width"],a=t.effects.setMode(r,e.mode||"hide"),s="show"===a,u=e.direction||"left",l="up"===u||"down"===u?"top":"left",c="up"===u||"left"===u?"pos":"neg",d={opacity:s?1:0};t.effects.save(r,o),r.show(),t.effects.createWrapper(r),i=e.distance||r["top"===l?"outerHeight":"outerWidth"](!0)/2,s&&r.css("opacity",0).css(l,"pos"===c?-i:i),d[l]=(s?"pos"===c?"+=":"-=":"pos"===c?"-=":"+=")+i,r.animate(d,{queue:!1,duration:e.duration,easing:e.easing,complete:function(){"hide"===a&&r.hide(),t.effects.restore(r,o),t.effects.removeWrapper(r),n()}})},t.effects.effect.explode=function(e,n){function i(){b.push(this),b.length===d*h&&r()}function r(){f.css({visibility:"visible"}),t(b).remove(),g||f.hide(),n()}var o,a,s,u,l,c,d=e.pieces?Math.round(Math.sqrt(e.pieces)):3,h=d,f=t(this),p=t.effects.setMode(f,e.mode||"hide"),g="show"===p,m=f.show().css("visibility","hidden").offset(),v=Math.ceil(f.outerWidth()/h),y=Math.ceil(f.outerHeight()/d),b=[];for(o=0;d>o;o++)for(u=m.top+o*y,c=o-(d-1)/2,a=0;h>a;a++)s=m.left+a*v,l=a-(h-1)/2,f.clone().appendTo("body").wrap("<div></div>").css({position:"absolute",visibility:"visible",left:-a*v,top:-o*y}).parent().addClass("ui-effects-explode").css({position:"absolute",overflow:"hidden",width:v,height:y,left:s+(g?l*v:0),top:u+(g?c*y:0),opacity:g?0:1}).animate({left:s+(g?0:l*v),top:u+(g?0:c*y),opacity:g?1:0},e.duration||500,e.easing,i)},t.effects.effect.fade=function(e,n){var i=t(this),r=t.effects.setMode(i,e.mode||"toggle");i.animate({opacity:r},{queue:!1,duration:e.duration,easing:e.easing,complete:n})},t.effects.effect.fold=function(e,n){var i,r,o=t(this),a=["position","top","bottom","left","right","height","width"],s=t.effects.setMode(o,e.mode||"hide"),u="show"===s,l="hide"===s,c=e.size||15,d=/([0-9]+)%/.exec(c),h=!!e.horizFirst,f=u!==h,p=f?["width","height"]:["height","width"],g=e.duration/2,m={},v={};t.effects.save(o,a),o.show(),i=t.effects.createWrapper(o).css({overflow:"hidden"}),r=f?[i.width(),i.height()]:[i.height(),i.width()],d&&(c=parseInt(d[1],10)/100*r[l?0:1]),u&&i.css(h?{height:0,width:c}:{height:c,width:0}),m[p[0]]=u?r[0]:c,v[p[1]]=u?r[1]:0,i.animate(m,g,e.easing).animate(v,g,e.easing,function(){l&&o.hide(),t.effects.restore(o,a),t.effects.removeWrapper(o),n()})},t.effects.effect.highlight=function(e,n){var i=t(this),r=["backgroundImage","backgroundColor","opacity"],o=t.effects.setMode(i,e.mode||"show"),a={backgroundColor:i.css("backgroundColor")};"hide"===o&&(a.opacity=0),t.effects.save(i,r),i.show().css({backgroundImage:"none",backgroundColor:e.color||"#ffff99"}).animate(a,{queue:!1,duration:e.duration,easing:e.easing,complete:function(){"hide"===o&&i.hide(),t.effects.restore(i,r),n()}})},t.effects.effect.size=function(e,n){var i,r,o,a=t(this),s=["position","top","bottom","left","right","width","height","overflow","opacity"],u=["position","top","bottom","left","right","overflow","opacity"],l=["width","height","overflow"],c=["fontSize"],d=["borderTopWidth","borderBottomWidth","paddingTop","paddingBottom"],h=["borderLeftWidth","borderRightWidth","paddingLeft","paddingRight"],f=t.effects.setMode(a,e.mode||"effect"),p=e.restore||"effect"!==f,g=e.scale||"both",m=e.origin||["middle","center"],v=a.css("position"),y=p?s:u,b={height:0,width:0,outerHeight:0,outerWidth:0};"show"===f&&a.show(),i={height:a.height(),width:a.width(),outerHeight:a.outerHeight(),outerWidth:a.outerWidth()},"toggle"===e.mode&&"show"===f?(a.from=e.to||b,a.to=e.from||i):(a.from=e.from||("show"===f?b:i),a.to=e.to||("hide"===f?b:i)),o={from:{y:a.from.height/i.height,x:a.from.width/i.width},to:{y:a.to.height/i.height,x:a.to.width/i.width}},("box"===g||"both"===g)&&(o.from.y!==o.to.y&&(y=y.concat(d),a.from=t.effects.setTransition(a,d,o.from.y,a.from),a.to=t.effects.setTransition(a,d,o.to.y,a.to)),o.from.x!==o.to.x&&(y=y.concat(h),a.from=t.effects.setTransition(a,h,o.from.x,a.from),a.to=t.effects.setTransition(a,h,o.to.x,a.to))),("content"===g||"both"===g)&&o.from.y!==o.to.y&&(y=y.concat(c).concat(l),a.from=t.effects.setTransition(a,c,o.from.y,a.from),a.to=t.effects.setTransition(a,c,o.to.y,a.to)),t.effects.save(a,y),a.show(),t.effects.createWrapper(a),a.css("overflow","hidden").css(a.from),m&&(r=t.effects.getBaseline(m,i),a.from.top=(i.outerHeight-a.outerHeight())*r.y,a.from.left=(i.outerWidth-a.outerWidth())*r.x,a.to.top=(i.outerHeight-a.to.outerHeight)*r.y,a.to.left=(i.outerWidth-a.to.outerWidth)*r.x),a.css(a.from),("content"===g||"both"===g)&&(d=d.concat(["marginTop","marginBottom"]).concat(c),h=h.concat(["marginLeft","marginRight"]),l=s.concat(d).concat(h),a.find("*[width]").each(function(){var n=t(this),i={height:n.height(),width:n.width(),outerHeight:n.outerHeight(),outerWidth:n.outerWidth()};p&&t.effects.save(n,l),n.from={height:i.height*o.from.y,width:i.width*o.from.x,outerHeight:i.outerHeight*o.from.y,outerWidth:i.outerWidth*o.from.x},n.to={height:i.height*o.to.y,width:i.width*o.to.x,outerHeight:i.height*o.to.y,outerWidth:i.width*o.to.x},o.from.y!==o.to.y&&(n.from=t.effects.setTransition(n,d,o.from.y,n.from),n.to=t.effects.setTransition(n,d,o.to.y,n.to)),o.from.x!==o.to.x&&(n.from=t.effects.setTransition(n,h,o.from.x,n.from),n.to=t.effects.setTransition(n,h,o.to.x,n.to)),n.css(n.from),n.animate(n.to,e.duration,e.easing,function(){p&&t.effects.restore(n,l)})})),a.animate(a.to,{queue:!1,duration:e.duration,easing:e.easing,complete:function(){0===a.to.opacity&&a.css("opacity",a.from.opacity),"hide"===f&&a.hide(),t.effects.restore(a,y),p||("static"===v?a.css({position:"relative",top:a.to.top,left:a.to.left}):t.each(["top","left"],function(t,e){a.css(e,function(e,n){var i=parseInt(n,10),r=t?a.to.left:a.to.top;return"auto"===n?r+"px":i+r+"px"})})),t.effects.removeWrapper(a),n()}})},t.effects.effect.scale=function(e,n){var i=t(this),r=t.extend(!0,{},e),o=t.effects.setMode(i,e.mode||"effect"),a=parseInt(e.percent,10)||(0===parseInt(e.percent,10)?0:"hide"===o?0:100),s=e.direction||"both",u=e.origin,l={height:i.height(),width:i.width(),outerHeight:i.outerHeight(),outerWidth:i.outerWidth()},c={y:"horizontal"!==s?a/100:1,x:"vertical"!==s?a/100:1};r.effect="size",r.queue=!1,r.complete=n,"effect"!==o&&(r.origin=u||["middle","center"],r.restore=!0),r.from=e.from||("show"===o?{height:0,width:0,outerHeight:0,outerWidth:0}:l),r.to={height:l.height*c.y,width:l.width*c.x,outerHeight:l.outerHeight*c.y,outerWidth:l.outerWidth*c.x},r.fade&&("show"===o&&(r.from.opacity=0,r.to.opacity=1),"hide"===o&&(r.from.opacity=1,r.to.opacity=0)),i.effect(r)},t.effects.effect.puff=function(e,n){var i=t(this),r=t.effects.setMode(i,e.mode||"hide"),o="hide"===r,a=parseInt(e.percent,10)||150,s=a/100,u={height:i.height(),width:i.width(),outerHeight:i.outerHeight(),outerWidth:i.outerWidth()};t.extend(e,{effect:"scale",queue:!1,fade:!0,mode:r,complete:n,percent:o?a:100,from:o?u:{height:u.height*s,width:u.width*s,outerHeight:u.outerHeight*s,outerWidth:u.outerWidth*s}}),i.effect(e)},t.effects.effect.pulsate=function(e,n){var i,r=t(this),o=t.effects.setMode(r,e.mode||"show"),a="show"===o,s="hide"===o,u=a||"hide"===o,l=2*(e.times||5)+(u?1:0),c=e.duration/l,d=0,h=r.queue(),f=h.length;for((a||!r.is(":visible"))&&(r.css("opacity",0).show(),d=1),i=1;l>i;i++)r.animate({opacity:d},c,e.easing),d=1-d;r.animate({opacity:d},c,e.easing),r.queue(function(){s&&r.hide(),n()}),f>1&&h.splice.apply(h,[1,0].concat(h.splice(f,l+1))),r.dequeue()},t.effects.effect.shake=function(e,n){var i,r=t(this),o=["position","top","bottom","left","right","height","width"],a=t.effects.setMode(r,e.mode||"effect"),s=e.direction||"left",u=e.distance||20,l=e.times||3,c=2*l+1,d=Math.round(e.duration/c),h="up"===s||"down"===s?"top":"left",f="up"===s||"left"===s,p={},g={},m={},v=r.queue(),y=v.length;for(t.effects.save(r,o),r.show(),t.effects.createWrapper(r),p[h]=(f?"-=":"+=")+u,g[h]=(f?"+=":"-=")+2*u,m[h]=(f?"-=":"+=")+2*u,r.animate(p,d,e.easing),i=1;l>i;i++)r.animate(g,d,e.easing).animate(m,d,e.easing);r.animate(g,d,e.easing).animate(p,d/2,e.easing).queue(function(){"hide"===a&&r.hide(),t.effects.restore(r,o),t.effects.removeWrapper(r),n()}),y>1&&v.splice.apply(v,[1,0].concat(v.splice(y,c+1))),r.dequeue()},t.effects.effect.slide=function(e,n){var i,r=t(this),o=["position","top","bottom","left","right","width","height"],a=t.effects.setMode(r,e.mode||"show"),s="show"===a,u=e.direction||"left",l="up"===u||"down"===u?"top":"left",c="up"===u||"left"===u,d={};t.effects.save(r,o),r.show(),i=e.distance||r["top"===l?"outerHeight":"outerWidth"](!0),t.effects.createWrapper(r).css({overflow:"hidden"}),s&&r.css(l,c?isNaN(i)?"-"+i:-i:i),d[l]=(s?c?"+=":"-=":c?"-=":"+=")+i,r.animate(d,{queue:!1,duration:e.duration,easing:e.easing,complete:function(){"hide"===a&&r.hide(),t.effects.restore(r,o),t.effects.removeWrapper(r),n()}})},t.effects.effect.transfer=function(e,n){var i=t(this),r=t(e.to),o="fixed"===r.css("position"),a=t("body"),s=o?a.scrollTop():0,u=o?a.scrollLeft():0,l=r.offset(),c={top:l.top-s,left:l.left-u,height:r.innerHeight(),width:r.innerWidth()},d=i.offset(),h=t("<div class='ui-effects-transfer'></div>").appendTo(document.body).addClass(e.className).css({top:d.top-s,left:d.left-u,height:i.innerHeight(),width:i.innerWidth(),position:o?"fixed":"absolute"}).animate(c,e.duration,e.easing,function(){h.remove(),n()})},t.widget("ui.progressbar",{version:"1.11.4",options:{max:100,value:0,change:null,complete:null},min:0,_create:function(){this.oldValue=this.options.value=this._constrainedValue(),this.element.addClass("ui-progressbar ui-widget ui-widget-content ui-corner-all").attr({role:"progressbar","aria-valuemin":this.min}),this.valueDiv=t("<div class='ui-progressbar-value ui-widget-header ui-corner-left'></div>").appendTo(this.element),this._refreshValue()},_destroy:function(){this.element.removeClass("ui-progressbar ui-widget ui-widget-content ui-corner-all").removeAttr("role").removeAttr("aria-valuemin").removeAttr("aria-valuemax").removeAttr("aria-valuenow"),this.valueDiv.remove()},value:function(t){return void 0===t?this.options.value:(this.options.value=this._constrainedValue(t),void this._refreshValue())},_constrainedValue:function(t){return void 0===t&&(t=this.options.value),this.indeterminate=t===!1,"number"!=typeof t&&(t=0),this.indeterminate?!1:Math.min(this.options.max,Math.max(this.min,t))},_setOptions:function(t){var e=t.value;delete t.value,this._super(t),this.options.value=this._constrainedValue(e),this._refreshValue()},_setOption:function(t,e){"max"===t&&(e=Math.max(this.min,e)),"disabled"===t&&this.element.toggleClass("ui-state-disabled",!!e).attr("aria-disabled",e),this._super(t,e)},_percentage:function(){return this.indeterminate?100:100*(this.options.value-this.min)/(this.options.max-this.min)},_refreshValue:function(){var e=this.options.value,n=this._percentage();this.valueDiv.toggle(this.indeterminate||e>this.min).toggleClass("ui-corner-right",e===this.options.max).width(n.toFixed(0)+"%"),this.element.toggleClass("ui-progressbar-indeterminate",this.indeterminate),this.indeterminate?(this.element.removeAttr("aria-valuenow"),this.overlayDiv||(this.overlayDiv=t("<div class='ui-progressbar-overlay'></div>").appendTo(this.valueDiv))):(this.element.attr({"aria-valuemax":this.options.max,"aria-valuenow":e}),this.overlayDiv&&(this.overlayDiv.remove(),this.overlayDiv=null)),this.oldValue!==e&&(this.oldValue=e,this._trigger("change")),e===this.options.max&&this._trigger("complete")}}),t.widget("ui.selectable",t.ui.mouse,{version:"1.11.4",options:{appendTo:"body",autoRefresh:!0,distance:0,filter:"*",tolerance:"touch",selected:null,selecting:null,start:null,stop:null,unselected:null,unselecting:null},_create:function(){var e,n=this;this.element.addClass("ui-selectable"),this.dragged=!1,this.refresh=function(){e=t(n.options.filter,n.element[0]),e.addClass("ui-selectee"),e.each(function(){var e=t(this),n=e.offset();t.data(this,"selectable-item",{element:this,$element:e,left:n.left,top:n.top,right:n.left+e.outerWidth(),bottom:n.top+e.outerHeight(),startselected:!1,selected:e.hasClass("ui-selected"),selecting:e.hasClass("ui-selecting"),unselecting:e.hasClass("ui-unselecting")})})},this.refresh(),this.selectees=e.addClass("ui-selectee"),this._mouseInit(),this.helper=t("<div class='ui-selectable-helper'></div>")},_destroy:function(){this.selectees.removeClass("ui-selectee").removeData("selectable-item"),this.element.removeClass("ui-selectable ui-selectable-disabled"),this._mouseDestroy()},_mouseStart:function(e){var n=this,i=this.options;this.opos=[e.pageX,e.pageY],this.options.disabled||(this.selectees=t(i.filter,this.element[0]),this._trigger("start",e),t(i.appendTo).append(this.helper),this.helper.css({left:e.pageX,top:e.pageY,width:0,height:0}),i.autoRefresh&&this.refresh(),this.selectees.filter(".ui-selected").each(function(){var i=t.data(this,"selectable-item");i.startselected=!0,e.metaKey||e.ctrlKey||(i.$element.removeClass("ui-selected"),i.selected=!1,i.$element.addClass("ui-unselecting"),i.unselecting=!0,n._trigger("unselecting",e,{unselecting:i.element}))}),t(e.target).parents().addBack().each(function(){var i,r=t.data(this,"selectable-item");return r?(i=!e.metaKey&&!e.ctrlKey||!r.$element.hasClass("ui-selected"),r.$element.removeClass(i?"ui-unselecting":"ui-selected").addClass(i?"ui-selecting":"ui-unselecting"),r.unselecting=!i,r.selecting=i,r.selected=i,i?n._trigger("selecting",e,{selecting:r.element}):n._trigger("unselecting",e,{unselecting:r.element}),!1):void 0}))},_mouseDrag:function(e){if(this.dragged=!0,!this.options.disabled){var n,i=this,r=this.options,o=this.opos[0],a=this.opos[1],s=e.pageX,u=e.pageY;return o>s&&(n=s,s=o,o=n),a>u&&(n=u,u=a,a=n),this.helper.css({left:o,top:a,width:s-o,height:u-a}),this.selectees.each(function(){var n=t.data(this,"selectable-item"),l=!1;n&&n.element!==i.element[0]&&("touch"===r.tolerance?l=!(n.left>s||n.right<o||n.top>u||n.bottom<a):"fit"===r.tolerance&&(l=n.left>o&&n.right<s&&n.top>a&&n.bottom<u),l?(n.selected&&(n.$element.removeClass("ui-selected"),n.selected=!1),n.unselecting&&(n.$element.removeClass("ui-unselecting"),n.unselecting=!1),n.selecting||(n.$element.addClass("ui-selecting"),n.selecting=!0,i._trigger("selecting",e,{selecting:n.element}))):(n.selecting&&((e.metaKey||e.ctrlKey)&&n.startselected?(n.$element.removeClass("ui-selecting"),n.selecting=!1,n.$element.addClass("ui-selected"),n.selected=!0):(n.$element.removeClass("ui-selecting"),n.selecting=!1,n.startselected&&(n.$element.addClass("ui-unselecting"),n.unselecting=!0),i._trigger("unselecting",e,{unselecting:n.element}))),n.selected&&(e.metaKey||e.ctrlKey||n.startselected||(n.$element.removeClass("ui-selected"),n.selected=!1,n.$element.addClass("ui-unselecting"),n.unselecting=!0,i._trigger("unselecting",e,{unselecting:n.element})))))}),!1}},_mouseStop:function(e){var n=this;return this.dragged=!1,t(".ui-unselecting",this.element[0]).each(function(){var i=t.data(this,"selectable-item");i.$element.removeClass("ui-unselecting"),i.unselecting=!1,i.startselected=!1,n._trigger("unselected",e,{unselected:i.element})}),t(".ui-selecting",this.element[0]).each(function(){var i=t.data(this,"selectable-item");i.$element.removeClass("ui-selecting").addClass("ui-selected"),i.selecting=!1,i.selected=!0,i.startselected=!0,n._trigger("selected",e,{selected:i.element})}),this._trigger("stop",e),this.helper.remove(),!1}}),t.widget("ui.selectmenu",{version:"1.11.4",defaultElement:"<select>",options:{appendTo:null,disabled:null,icons:{button:"ui-icon-triangle-1-s"},position:{my:"left top",at:"left bottom",collision:"none"},width:null,change:null,close:null,focus:null,open:null,select:null},_create:function(){var t=this.element.uniqueId().attr("id");this.ids={element:t,button:t+"-button",menu:t+"-menu"},this._drawButton(),this._drawMenu(),this.options.disabled&&this.disable()},_drawButton:function(){var e=this;this.label=t("label[for='"+this.ids.element+"']").attr("for",this.ids.button),this._on(this.label,{click:function(t){this.button.focus(),t.preventDefault()}}),this.element.hide(),this.button=t("<span>",{"class":"ui-selectmenu-button ui-widget ui-state-default ui-corner-all",tabindex:this.options.disabled?-1:0,id:this.ids.button,role:"combobox","aria-expanded":"false","aria-autocomplete":"list","aria-owns":this.ids.menu,"aria-haspopup":"true"}).insertAfter(this.element),t("<span>",{"class":"ui-icon "+this.options.icons.button}).prependTo(this.button),this.buttonText=t("<span>",{"class":"ui-selectmenu-text"}).appendTo(this.button),this._setText(this.buttonText,this.element.find("option:selected").text()),this._resizeButton(),this._on(this.button,this._buttonEvents),this.button.one("focusin",function(){e.menuItems||e._refreshMenu()}),this._hoverable(this.button),this._focusable(this.button)},_drawMenu:function(){var e=this;this.menu=t("<ul>",{"aria-hidden":"true","aria-labelledby":this.ids.button,id:this.ids.menu}),this.menuWrap=t("<div>",{"class":"ui-selectmenu-menu ui-front"}).append(this.menu).appendTo(this._appendTo()),
this.menuInstance=this.menu.menu({role:"listbox",select:function(t,n){t.preventDefault(),e._setSelection(),e._select(n.item.data("ui-selectmenu-item"),t)},focus:function(t,n){var i=n.item.data("ui-selectmenu-item");null!=e.focusIndex&&i.index!==e.focusIndex&&(e._trigger("focus",t,{item:i}),e.isOpen||e._select(i,t)),e.focusIndex=i.index,e.button.attr("aria-activedescendant",e.menuItems.eq(i.index).attr("id"))}}).menu("instance"),this.menu.addClass("ui-corner-bottom").removeClass("ui-corner-all"),this.menuInstance._off(this.menu,"mouseleave"),this.menuInstance._closeOnDocumentClick=function(){return!1},this.menuInstance._isDivider=function(){return!1}},refresh:function(){this._refreshMenu(),this._setText(this.buttonText,this._getSelectedItem().text()),this.options.width||this._resizeButton()},_refreshMenu:function(){this.menu.empty();var t,e=this.element.find("option");e.length&&(this._parseOptions(e),this._renderMenu(this.menu,this.items),this.menuInstance.refresh(),this.menuItems=this.menu.find("li").not(".ui-selectmenu-optgroup"),t=this._getSelectedItem(),this.menuInstance.focus(null,t),this._setAria(t.data("ui-selectmenu-item")),this._setOption("disabled",this.element.prop("disabled")))},open:function(t){this.options.disabled||(this.menuItems?(this.menu.find(".ui-state-focus").removeClass("ui-state-focus"),this.menuInstance.focus(null,this._getSelectedItem())):this._refreshMenu(),this.isOpen=!0,this._toggleAttr(),this._resizeMenu(),this._position(),this._on(this.document,this._documentClick),this._trigger("open",t))},_position:function(){this.menuWrap.position(t.extend({of:this.button},this.options.position))},close:function(t){this.isOpen&&(this.isOpen=!1,this._toggleAttr(),this.range=null,this._off(this.document),this._trigger("close",t))},widget:function(){return this.button},menuWidget:function(){return this.menu},_renderMenu:function(e,n){var i=this,r="";t.each(n,function(n,o){o.optgroup!==r&&(t("<li>",{"class":"ui-selectmenu-optgroup ui-menu-divider"+(o.element.parent("optgroup").prop("disabled")?" ui-state-disabled":""),text:o.optgroup}).appendTo(e),r=o.optgroup),i._renderItemData(e,o)})},_renderItemData:function(t,e){return this._renderItem(t,e).data("ui-selectmenu-item",e)},_renderItem:function(e,n){var i=t("<li>");return n.disabled&&i.addClass("ui-state-disabled"),this._setText(i,n.label),i.appendTo(e)},_setText:function(t,e){e?t.text(e):t.html("&#160;")},_move:function(t,e){var n,i,r=".ui-menu-item";this.isOpen?n=this.menuItems.eq(this.focusIndex):(n=this.menuItems.eq(this.element[0].selectedIndex),r+=":not(.ui-state-disabled)"),i="first"===t||"last"===t?n["first"===t?"prevAll":"nextAll"](r).eq(-1):n[t+"All"](r).eq(0),i.length&&this.menuInstance.focus(e,i)},_getSelectedItem:function(){return this.menuItems.eq(this.element[0].selectedIndex)},_toggle:function(t){this[this.isOpen?"close":"open"](t)},_setSelection:function(){var t;this.range&&(window.getSelection?(t=window.getSelection(),t.removeAllRanges(),t.addRange(this.range)):this.range.select(),this.button.focus())},_documentClick:{mousedown:function(e){this.isOpen&&(t(e.target).closest(".ui-selectmenu-menu, #"+this.ids.button).length||this.close(e))}},_buttonEvents:{mousedown:function(){var t;window.getSelection?(t=window.getSelection(),t.rangeCount&&(this.range=t.getRangeAt(0))):this.range=document.selection.createRange()},click:function(t){this._setSelection(),this._toggle(t)},keydown:function(e){var n=!0;switch(e.keyCode){case t.ui.keyCode.TAB:case t.ui.keyCode.ESCAPE:this.close(e),n=!1;break;case t.ui.keyCode.ENTER:this.isOpen&&this._selectFocusedItem(e);break;case t.ui.keyCode.UP:e.altKey?this._toggle(e):this._move("prev",e);break;case t.ui.keyCode.DOWN:e.altKey?this._toggle(e):this._move("next",e);break;case t.ui.keyCode.SPACE:this.isOpen?this._selectFocusedItem(e):this._toggle(e);break;case t.ui.keyCode.LEFT:this._move("prev",e);break;case t.ui.keyCode.RIGHT:this._move("next",e);break;case t.ui.keyCode.HOME:case t.ui.keyCode.PAGE_UP:this._move("first",e);break;case t.ui.keyCode.END:case t.ui.keyCode.PAGE_DOWN:this._move("last",e);break;default:this.menu.trigger(e),n=!1}n&&e.preventDefault()}},_selectFocusedItem:function(t){var e=this.menuItems.eq(this.focusIndex);e.hasClass("ui-state-disabled")||this._select(e.data("ui-selectmenu-item"),t)},_select:function(t,e){var n=this.element[0].selectedIndex;this.element[0].selectedIndex=t.index,this._setText(this.buttonText,t.label),this._setAria(t),this._trigger("select",e,{item:t}),t.index!==n&&this._trigger("change",e,{item:t}),this.close(e)},_setAria:function(t){var e=this.menuItems.eq(t.index).attr("id");this.button.attr({"aria-labelledby":e,"aria-activedescendant":e}),this.menu.attr("aria-activedescendant",e)},_setOption:function(t,e){"icons"===t&&this.button.find("span.ui-icon").removeClass(this.options.icons.button).addClass(e.button),this._super(t,e),"appendTo"===t&&this.menuWrap.appendTo(this._appendTo()),"disabled"===t&&(this.menuInstance.option("disabled",e),this.button.toggleClass("ui-state-disabled",e).attr("aria-disabled",e),this.element.prop("disabled",e),e?(this.button.attr("tabindex",-1),this.close()):this.button.attr("tabindex",0)),"width"===t&&this._resizeButton()},_appendTo:function(){var e=this.options.appendTo;return e&&(e=e.jquery||e.nodeType?t(e):this.document.find(e).eq(0)),e&&e[0]||(e=this.element.closest(".ui-front")),e.length||(e=this.document[0].body),e},_toggleAttr:function(){this.button.toggleClass("ui-corner-top",this.isOpen).toggleClass("ui-corner-all",!this.isOpen).attr("aria-expanded",this.isOpen),this.menuWrap.toggleClass("ui-selectmenu-open",this.isOpen),this.menu.attr("aria-hidden",!this.isOpen)},_resizeButton:function(){var t=this.options.width;t||(t=this.element.show().outerWidth(),this.element.hide()),this.button.outerWidth(t)},_resizeMenu:function(){this.menu.outerWidth(Math.max(this.button.outerWidth(),this.menu.width("").outerWidth()+1))},_getCreateOptions:function(){return{disabled:this.element.prop("disabled")}},_parseOptions:function(e){var n=[];e.each(function(e,i){var r=t(i),o=r.parent("optgroup");n.push({element:r,index:e,value:r.val(),label:r.text(),optgroup:o.attr("label")||"",disabled:o.prop("disabled")||r.prop("disabled")})}),this.items=n},_destroy:function(){this.menuWrap.remove(),this.button.remove(),this.element.show(),this.element.removeUniqueId(),this.label.attr("for",this.ids.element)}}),t.widget("ui.slider",t.ui.mouse,{version:"1.11.4",widgetEventPrefix:"slide",options:{animate:!1,distance:0,max:100,min:0,orientation:"horizontal",range:!1,step:1,value:0,values:null,change:null,slide:null,start:null,stop:null},numPages:5,_create:function(){this._keySliding=!1,this._mouseSliding=!1,this._animateOff=!0,this._handleIndex=null,this._detectOrientation(),this._mouseInit(),this._calculateNewMax(),this.element.addClass("ui-slider ui-slider-"+this.orientation+" ui-widget ui-widget-content ui-corner-all"),this._refresh(),this._setOption("disabled",this.options.disabled),this._animateOff=!1},_refresh:function(){this._createRange(),this._createHandles(),this._setupEvents(),this._refreshValue()},_createHandles:function(){var e,n,i=this.options,r=this.element.find(".ui-slider-handle").addClass("ui-state-default ui-corner-all"),o="<span class='ui-slider-handle ui-state-default ui-corner-all' tabindex='0'></span>",a=[];for(n=i.values&&i.values.length||1,r.length>n&&(r.slice(n).remove(),r=r.slice(0,n)),e=r.length;n>e;e++)a.push(o);this.handles=r.add(t(a.join("")).appendTo(this.element)),this.handle=this.handles.eq(0),this.handles.each(function(e){t(this).data("ui-slider-handle-index",e)})},_createRange:function(){var e=this.options,n="";e.range?(e.range===!0&&(e.values?e.values.length&&2!==e.values.length?e.values=[e.values[0],e.values[0]]:t.isArray(e.values)&&(e.values=e.values.slice(0)):e.values=[this._valueMin(),this._valueMin()]),this.range&&this.range.length?this.range.removeClass("ui-slider-range-min ui-slider-range-max").css({left:"",bottom:""}):(this.range=t("<div></div>").appendTo(this.element),n="ui-slider-range ui-widget-header ui-corner-all"),this.range.addClass(n+("min"===e.range||"max"===e.range?" ui-slider-range-"+e.range:""))):(this.range&&this.range.remove(),this.range=null)},_setupEvents:function(){this._off(this.handles),this._on(this.handles,this._handleEvents),this._hoverable(this.handles),this._focusable(this.handles)},_destroy:function(){this.handles.remove(),this.range&&this.range.remove(),this.element.removeClass("ui-slider ui-slider-horizontal ui-slider-vertical ui-widget ui-widget-content ui-corner-all"),this._mouseDestroy()},_mouseCapture:function(e){var n,i,r,o,a,s,u,l,c=this,d=this.options;return d.disabled?!1:(this.elementSize={width:this.element.outerWidth(),height:this.element.outerHeight()},this.elementOffset=this.element.offset(),n={x:e.pageX,y:e.pageY},i=this._normValueFromMouse(n),r=this._valueMax()-this._valueMin()+1,this.handles.each(function(e){var n=Math.abs(i-c.values(e));(r>n||r===n&&(e===c._lastChangedValue||c.values(e)===d.min))&&(r=n,o=t(this),a=e)}),s=this._start(e,a),s===!1?!1:(this._mouseSliding=!0,this._handleIndex=a,o.addClass("ui-state-active").focus(),u=o.offset(),l=!t(e.target).parents().addBack().is(".ui-slider-handle"),this._clickOffset=l?{left:0,top:0}:{left:e.pageX-u.left-o.width()/2,top:e.pageY-u.top-o.height()/2-(parseInt(o.css("borderTopWidth"),10)||0)-(parseInt(o.css("borderBottomWidth"),10)||0)+(parseInt(o.css("marginTop"),10)||0)},this.handles.hasClass("ui-state-hover")||this._slide(e,a,i),this._animateOff=!0,!0))},_mouseStart:function(){return!0},_mouseDrag:function(t){var e={x:t.pageX,y:t.pageY},n=this._normValueFromMouse(e);return this._slide(t,this._handleIndex,n),!1},_mouseStop:function(t){return this.handles.removeClass("ui-state-active"),this._mouseSliding=!1,this._stop(t,this._handleIndex),this._change(t,this._handleIndex),this._handleIndex=null,this._clickOffset=null,this._animateOff=!1,!1},_detectOrientation:function(){this.orientation="vertical"===this.options.orientation?"vertical":"horizontal"},_normValueFromMouse:function(t){var e,n,i,r,o;return"horizontal"===this.orientation?(e=this.elementSize.width,n=t.x-this.elementOffset.left-(this._clickOffset?this._clickOffset.left:0)):(e=this.elementSize.height,n=t.y-this.elementOffset.top-(this._clickOffset?this._clickOffset.top:0)),i=n/e,i>1&&(i=1),0>i&&(i=0),"vertical"===this.orientation&&(i=1-i),r=this._valueMax()-this._valueMin(),o=this._valueMin()+i*r,this._trimAlignValue(o)},_start:function(t,e){var n={handle:this.handles[e],value:this.value()};return this.options.values&&this.options.values.length&&(n.value=this.values(e),n.values=this.values()),this._trigger("start",t,n)},_slide:function(t,e,n){var i,r,o;this.options.values&&this.options.values.length?(i=this.values(e?0:1),2===this.options.values.length&&this.options.range===!0&&(0===e&&n>i||1===e&&i>n)&&(n=i),n!==this.values(e)&&(r=this.values(),r[e]=n,o=this._trigger("slide",t,{handle:this.handles[e],value:n,values:r}),i=this.values(e?0:1),o!==!1&&this.values(e,n))):n!==this.value()&&(o=this._trigger("slide",t,{handle:this.handles[e],value:n}),o!==!1&&this.value(n))},_stop:function(t,e){var n={handle:this.handles[e],value:this.value()};this.options.values&&this.options.values.length&&(n.value=this.values(e),n.values=this.values()),this._trigger("stop",t,n)},_change:function(t,e){if(!this._keySliding&&!this._mouseSliding){var n={handle:this.handles[e],value:this.value()};this.options.values&&this.options.values.length&&(n.value=this.values(e),n.values=this.values()),this._lastChangedValue=e,this._trigger("change",t,n)}},value:function(t){return arguments.length?(this.options.value=this._trimAlignValue(t),this._refreshValue(),void this._change(null,0)):this._value()},values:function(e,n){var i,r,o;if(arguments.length>1)return this.options.values[e]=this._trimAlignValue(n),this._refreshValue(),void this._change(null,e);if(!arguments.length)return this._values();if(!t.isArray(arguments[0]))return this.options.values&&this.options.values.length?this._values(e):this.value();for(i=this.options.values,r=arguments[0],o=0;o<i.length;o+=1)i[o]=this._trimAlignValue(r[o]),this._change(null,o);this._refreshValue()},_setOption:function(e,n){var i,r=0;switch("range"===e&&this.options.range===!0&&("min"===n?(this.options.value=this._values(0),this.options.values=null):"max"===n&&(this.options.value=this._values(this.options.values.length-1),this.options.values=null)),t.isArray(this.options.values)&&(r=this.options.values.length),"disabled"===e&&this.element.toggleClass("ui-state-disabled",!!n),this._super(e,n),e){case"orientation":this._detectOrientation(),this.element.removeClass("ui-slider-horizontal ui-slider-vertical").addClass("ui-slider-"+this.orientation),this._refreshValue(),this.handles.css("horizontal"===n?"bottom":"left","");break;case"value":this._animateOff=!0,this._refreshValue(),this._change(null,0),this._animateOff=!1;break;case"values":for(this._animateOff=!0,this._refreshValue(),i=0;r>i;i+=1)this._change(null,i);this._animateOff=!1;break;case"step":case"min":case"max":this._animateOff=!0,this._calculateNewMax(),this._refreshValue(),this._animateOff=!1;break;case"range":this._animateOff=!0,this._refresh(),this._animateOff=!1}},_value:function(){var t=this.options.value;return t=this._trimAlignValue(t)},_values:function(t){var e,n,i;if(arguments.length)return e=this.options.values[t],e=this._trimAlignValue(e);if(this.options.values&&this.options.values.length){for(n=this.options.values.slice(),i=0;i<n.length;i+=1)n[i]=this._trimAlignValue(n[i]);return n}return[]},_trimAlignValue:function(t){if(t<=this._valueMin())return this._valueMin();if(t>=this._valueMax())return this._valueMax();var e=this.options.step>0?this.options.step:1,n=(t-this._valueMin())%e,i=t-n;return 2*Math.abs(n)>=e&&(i+=n>0?e:-e),parseFloat(i.toFixed(5))},_calculateNewMax:function(){var t=this.options.max,e=this._valueMin(),n=this.options.step,i=Math.floor(+(t-e).toFixed(this._precision())/n)*n;t=i+e,this.max=parseFloat(t.toFixed(this._precision()))},_precision:function(){var t=this._precisionOf(this.options.step);return null!==this.options.min&&(t=Math.max(t,this._precisionOf(this.options.min))),t},_precisionOf:function(t){var e=t.toString(),n=e.indexOf(".");return-1===n?0:e.length-n-1},_valueMin:function(){return this.options.min},_valueMax:function(){return this.max},_refreshValue:function(){var e,n,i,r,o,a=this.options.range,s=this.options,u=this,l=this._animateOff?!1:s.animate,c={};this.options.values&&this.options.values.length?this.handles.each(function(i){n=(u.values(i)-u._valueMin())/(u._valueMax()-u._valueMin())*100,c["horizontal"===u.orientation?"left":"bottom"]=n+"%",t(this).stop(1,1)[l?"animate":"css"](c,s.animate),u.options.range===!0&&("horizontal"===u.orientation?(0===i&&u.range.stop(1,1)[l?"animate":"css"]({left:n+"%"},s.animate),1===i&&u.range[l?"animate":"css"]({width:n-e+"%"},{queue:!1,duration:s.animate})):(0===i&&u.range.stop(1,1)[l?"animate":"css"]({bottom:n+"%"},s.animate),1===i&&u.range[l?"animate":"css"]({height:n-e+"%"},{queue:!1,duration:s.animate}))),e=n}):(i=this.value(),r=this._valueMin(),o=this._valueMax(),n=o!==r?(i-r)/(o-r)*100:0,c["horizontal"===this.orientation?"left":"bottom"]=n+"%",this.handle.stop(1,1)[l?"animate":"css"](c,s.animate),"min"===a&&"horizontal"===this.orientation&&this.range.stop(1,1)[l?"animate":"css"]({width:n+"%"},s.animate),"max"===a&&"horizontal"===this.orientation&&this.range[l?"animate":"css"]({width:100-n+"%"},{queue:!1,duration:s.animate}),"min"===a&&"vertical"===this.orientation&&this.range.stop(1,1)[l?"animate":"css"]({height:n+"%"},s.animate),"max"===a&&"vertical"===this.orientation&&this.range[l?"animate":"css"]({height:100-n+"%"},{queue:!1,duration:s.animate}))},_handleEvents:{keydown:function(e){var n,i,r,o,a=t(e.target).data("ui-slider-handle-index");switch(e.keyCode){case t.ui.keyCode.HOME:case t.ui.keyCode.END:case t.ui.keyCode.PAGE_UP:case t.ui.keyCode.PAGE_DOWN:case t.ui.keyCode.UP:case t.ui.keyCode.RIGHT:case t.ui.keyCode.DOWN:case t.ui.keyCode.LEFT:if(e.preventDefault(),!this._keySliding&&(this._keySliding=!0,t(e.target).addClass("ui-state-active"),n=this._start(e,a),n===!1))return}switch(o=this.options.step,i=r=this.options.values&&this.options.values.length?this.values(a):this.value(),e.keyCode){case t.ui.keyCode.HOME:r=this._valueMin();break;case t.ui.keyCode.END:r=this._valueMax();break;case t.ui.keyCode.PAGE_UP:r=this._trimAlignValue(i+(this._valueMax()-this._valueMin())/this.numPages);break;case t.ui.keyCode.PAGE_DOWN:r=this._trimAlignValue(i-(this._valueMax()-this._valueMin())/this.numPages);break;case t.ui.keyCode.UP:case t.ui.keyCode.RIGHT:if(i===this._valueMax())return;r=this._trimAlignValue(i+o);break;case t.ui.keyCode.DOWN:case t.ui.keyCode.LEFT:if(i===this._valueMin())return;r=this._trimAlignValue(i-o)}this._slide(e,a,r)},keyup:function(e){var n=t(e.target).data("ui-slider-handle-index");this._keySliding&&(this._keySliding=!1,this._stop(e,n),this._change(e,n),t(e.target).removeClass("ui-state-active"))}}}),t.widget("ui.sortable",t.ui.mouse,{version:"1.11.4",widgetEventPrefix:"sort",ready:!1,options:{appendTo:"parent",axis:!1,connectWith:!1,containment:!1,cursor:"auto",cursorAt:!1,dropOnEmpty:!0,forcePlaceholderSize:!1,forceHelperSize:!1,grid:!1,handle:!1,helper:"original",items:"> *",opacity:!1,placeholder:!1,revert:!1,scroll:!0,scrollSensitivity:20,scrollSpeed:20,scope:"default",tolerance:"intersect",zIndex:1e3,activate:null,beforeStop:null,change:null,deactivate:null,out:null,over:null,receive:null,remove:null,sort:null,start:null,stop:null,update:null},_isOverAxis:function(t,e,n){return t>=e&&e+n>t},_isFloating:function(t){return/left|right/.test(t.css("float"))||/inline|table-cell/.test(t.css("display"))},_create:function(){this.containerCache={},this.element.addClass("ui-sortable"),this.refresh(),this.offset=this.element.offset(),this._mouseInit(),this._setHandleClassName(),this.ready=!0},_setOption:function(t,e){this._super(t,e),"handle"===t&&this._setHandleClassName()},_setHandleClassName:function(){this.element.find(".ui-sortable-handle").removeClass("ui-sortable-handle"),t.each(this.items,function(){(this.instance.options.handle?this.item.find(this.instance.options.handle):this.item).addClass("ui-sortable-handle")})},_destroy:function(){this.element.removeClass("ui-sortable ui-sortable-disabled").find(".ui-sortable-handle").removeClass("ui-sortable-handle"),this._mouseDestroy();for(var t=this.items.length-1;t>=0;t--)this.items[t].item.removeData(this.widgetName+"-item");return this},_mouseCapture:function(e,n){var i=null,r=!1,o=this;return this.reverting?!1:this.options.disabled||"static"===this.options.type?!1:(this._refreshItems(e),t(e.target).parents().each(function(){return t.data(this,o.widgetName+"-item")===o?(i=t(this),!1):void 0}),t.data(e.target,o.widgetName+"-item")===o&&(i=t(e.target)),i&&(!this.options.handle||n||(t(this.options.handle,i).find("*").addBack().each(function(){this===e.target&&(r=!0)}),r))?(this.currentItem=i,this._removeCurrentsFromItems(),!0):!1)},_mouseStart:function(e,n,i){var r,o,a=this.options;if(this.currentContainer=this,this.refreshPositions(),this.helper=this._createHelper(e),this._cacheHelperProportions(),this._cacheMargins(),this.scrollParent=this.helper.scrollParent(),this.offset=this.currentItem.offset(),this.offset={top:this.offset.top-this.margins.top,left:this.offset.left-this.margins.left},t.extend(this.offset,{click:{left:e.pageX-this.offset.left,top:e.pageY-this.offset.top},parent:this._getParentOffset(),relative:this._getRelativeOffset()}),this.helper.css("position","absolute"),this.cssPosition=this.helper.css("position"),this.originalPosition=this._generatePosition(e),this.originalPageX=e.pageX,this.originalPageY=e.pageY,a.cursorAt&&this._adjustOffsetFromHelper(a.cursorAt),this.domPosition={prev:this.currentItem.prev()[0],parent:this.currentItem.parent()[0]},this.helper[0]!==this.currentItem[0]&&this.currentItem.hide(),this._createPlaceholder(),a.containment&&this._setContainment(),a.cursor&&"auto"!==a.cursor&&(o=this.document.find("body"),this.storedCursor=o.css("cursor"),o.css("cursor",a.cursor),this.storedStylesheet=t("<style>*{ cursor: "+a.cursor+" !important; }</style>").appendTo(o)),a.opacity&&(this.helper.css("opacity")&&(this._storedOpacity=this.helper.css("opacity")),this.helper.css("opacity",a.opacity)),a.zIndex&&(this.helper.css("zIndex")&&(this._storedZIndex=this.helper.css("zIndex")),this.helper.css("zIndex",a.zIndex)),this.scrollParent[0]!==this.document[0]&&"HTML"!==this.scrollParent[0].tagName&&(this.overflowOffset=this.scrollParent.offset()),this._trigger("start",e,this._uiHash()),this._preserveHelperProportions||this._cacheHelperProportions(),!i)for(r=this.containers.length-1;r>=0;r--)this.containers[r]._trigger("activate",e,this._uiHash(this));return t.ui.ddmanager&&(t.ui.ddmanager.current=this),t.ui.ddmanager&&!a.dropBehaviour&&t.ui.ddmanager.prepareOffsets(this,e),this.dragging=!0,this.helper.addClass("ui-sortable-helper"),this._mouseDrag(e),!0},_mouseDrag:function(e){var n,i,r,o,a=this.options,s=!1;for(this.position=this._generatePosition(e),this.positionAbs=this._convertPositionTo("absolute"),this.lastPositionAbs||(this.lastPositionAbs=this.positionAbs),this.options.scroll&&(this.scrollParent[0]!==this.document[0]&&"HTML"!==this.scrollParent[0].tagName?(this.overflowOffset.top+this.scrollParent[0].offsetHeight-e.pageY<a.scrollSensitivity?this.scrollParent[0].scrollTop=s=this.scrollParent[0].scrollTop+a.scrollSpeed:e.pageY-this.overflowOffset.top<a.scrollSensitivity&&(this.scrollParent[0].scrollTop=s=this.scrollParent[0].scrollTop-a.scrollSpeed),this.overflowOffset.left+this.scrollParent[0].offsetWidth-e.pageX<a.scrollSensitivity?this.scrollParent[0].scrollLeft=s=this.scrollParent[0].scrollLeft+a.scrollSpeed:e.pageX-this.overflowOffset.left<a.scrollSensitivity&&(this.scrollParent[0].scrollLeft=s=this.scrollParent[0].scrollLeft-a.scrollSpeed)):(e.pageY-this.document.scrollTop()<a.scrollSensitivity?s=this.document.scrollTop(this.document.scrollTop()-a.scrollSpeed):this.window.height()-(e.pageY-this.document.scrollTop())<a.scrollSensitivity&&(s=this.document.scrollTop(this.document.scrollTop()+a.scrollSpeed)),e.pageX-this.document.scrollLeft()<a.scrollSensitivity?s=this.document.scrollLeft(this.document.scrollLeft()-a.scrollSpeed):this.window.width()-(e.pageX-this.document.scrollLeft())<a.scrollSensitivity&&(s=this.document.scrollLeft(this.document.scrollLeft()+a.scrollSpeed))),s!==!1&&t.ui.ddmanager&&!a.dropBehaviour&&t.ui.ddmanager.prepareOffsets(this,e)),this.positionAbs=this._convertPositionTo("absolute"),this.options.axis&&"y"===this.options.axis||(this.helper[0].style.left=this.position.left+"px"),this.options.axis&&"x"===this.options.axis||(this.helper[0].style.top=this.position.top+"px"),n=this.items.length-1;n>=0;n--)if(i=this.items[n],r=i.item[0],o=this._intersectsWithPointer(i),o&&i.instance===this.currentContainer&&r!==this.currentItem[0]&&this.placeholder[1===o?"next":"prev"]()[0]!==r&&!t.contains(this.placeholder[0],r)&&("semi-dynamic"===this.options.type?!t.contains(this.element[0],r):!0)){if(this.direction=1===o?"down":"up","pointer"!==this.options.tolerance&&!this._intersectsWithSides(i))break;this._rearrange(e,i),this._trigger("change",e,this._uiHash());break}return this._contactContainers(e),t.ui.ddmanager&&t.ui.ddmanager.drag(this,e),this._trigger("sort",e,this._uiHash()),this.lastPositionAbs=this.positionAbs,!1},_mouseStop:function(e,n){if(e){if(t.ui.ddmanager&&!this.options.dropBehaviour&&t.ui.ddmanager.drop(this,e),this.options.revert){var i=this,r=this.placeholder.offset(),o=this.options.axis,a={};o&&"x"!==o||(a.left=r.left-this.offset.parent.left-this.margins.left+(this.offsetParent[0]===this.document[0].body?0:this.offsetParent[0].scrollLeft)),o&&"y"!==o||(a.top=r.top-this.offset.parent.top-this.margins.top+(this.offsetParent[0]===this.document[0].body?0:this.offsetParent[0].scrollTop)),this.reverting=!0,t(this.helper).animate(a,parseInt(this.options.revert,10)||500,function(){i._clear(e)})}else this._clear(e,n);return!1}},cancel:function(){if(this.dragging){this._mouseUp({target:null}),"original"===this.options.helper?this.currentItem.css(this._storedCSS).removeClass("ui-sortable-helper"):this.currentItem.show();for(var e=this.containers.length-1;e>=0;e--)this.containers[e]._trigger("deactivate",null,this._uiHash(this)),this.containers[e].containerCache.over&&(this.containers[e]._trigger("out",null,this._uiHash(this)),this.containers[e].containerCache.over=0)}return this.placeholder&&(this.placeholder[0].parentNode&&this.placeholder[0].parentNode.removeChild(this.placeholder[0]),"original"!==this.options.helper&&this.helper&&this.helper[0].parentNode&&this.helper.remove(),t.extend(this,{helper:null,dragging:!1,reverting:!1,_noFinalSort:null}),this.domPosition.prev?t(this.domPosition.prev).after(this.currentItem):t(this.domPosition.parent).prepend(this.currentItem)),this},serialize:function(e){var n=this._getItemsAsjQuery(e&&e.connected),i=[];return e=e||{},t(n).each(function(){var n=(t(e.item||this).attr(e.attribute||"id")||"").match(e.expression||/(.+)[\-=_](.+)/);n&&i.push((e.key||n[1]+"[]")+"="+(e.key&&e.expression?n[1]:n[2]))}),!i.length&&e.key&&i.push(e.key+"="),i.join("&")},toArray:function(e){var n=this._getItemsAsjQuery(e&&e.connected),i=[];return e=e||{},n.each(function(){i.push(t(e.item||this).attr(e.attribute||"id")||"")}),i},_intersectsWith:function(t){var e=this.positionAbs.left,n=e+this.helperProportions.width,i=this.positionAbs.top,r=i+this.helperProportions.height,o=t.left,a=o+t.width,s=t.top,u=s+t.height,l=this.offset.click.top,c=this.offset.click.left,d="x"===this.options.axis||i+l>s&&u>i+l,h="y"===this.options.axis||e+c>o&&a>e+c,f=d&&h;return"pointer"===this.options.tolerance||this.options.forcePointerForContainers||"pointer"!==this.options.tolerance&&this.helperProportions[this.floating?"width":"height"]>t[this.floating?"width":"height"]?f:o<e+this.helperProportions.width/2&&n-this.helperProportions.width/2<a&&s<i+this.helperProportions.height/2&&r-this.helperProportions.height/2<u},_intersectsWithPointer:function(t){var e="x"===this.options.axis||this._isOverAxis(this.positionAbs.top+this.offset.click.top,t.top,t.height),n="y"===this.options.axis||this._isOverAxis(this.positionAbs.left+this.offset.click.left,t.left,t.width),i=e&&n,r=this._getDragVerticalDirection(),o=this._getDragHorizontalDirection();return i?this.floating?o&&"right"===o||"down"===r?2:1:r&&("down"===r?2:1):!1},_intersectsWithSides:function(t){var e=this._isOverAxis(this.positionAbs.top+this.offset.click.top,t.top+t.height/2,t.height),n=this._isOverAxis(this.positionAbs.left+this.offset.click.left,t.left+t.width/2,t.width),i=this._getDragVerticalDirection(),r=this._getDragHorizontalDirection();return this.floating&&r?"right"===r&&n||"left"===r&&!n:i&&("down"===i&&e||"up"===i&&!e)},_getDragVerticalDirection:function(){var t=this.positionAbs.top-this.lastPositionAbs.top;return 0!==t&&(t>0?"down":"up")},_getDragHorizontalDirection:function(){var t=this.positionAbs.left-this.lastPositionAbs.left;return 0!==t&&(t>0?"right":"left")},refresh:function(t){return this._refreshItems(t),this._setHandleClassName(),this.refreshPositions(),this},_connectWith:function(){var t=this.options;return t.connectWith.constructor===String?[t.connectWith]:t.connectWith},_getItemsAsjQuery:function(e){function n(){s.push(this)}var i,r,o,a,s=[],u=[],l=this._connectWith();if(l&&e)for(i=l.length-1;i>=0;i--)for(o=t(l[i],this.document[0]),r=o.length-1;r>=0;r--)a=t.data(o[r],this.widgetFullName),a&&a!==this&&!a.options.disabled&&u.push([t.isFunction(a.options.items)?a.options.items.call(a.element):t(a.options.items,a.element).not(".ui-sortable-helper").not(".ui-sortable-placeholder"),a]);for(u.push([t.isFunction(this.options.items)?this.options.items.call(this.element,null,{options:this.options,item:this.currentItem}):t(this.options.items,this.element).not(".ui-sortable-helper").not(".ui-sortable-placeholder"),this]),i=u.length-1;i>=0;i--)u[i][0].each(n);return t(s)},_removeCurrentsFromItems:function(){var e=this.currentItem.find(":data("+this.widgetName+"-item)");this.items=t.grep(this.items,function(t){for(var n=0;n<e.length;n++)if(e[n]===t.item[0])return!1;return!0})},_refreshItems:function(e){this.items=[],this.containers=[this];var n,i,r,o,a,s,u,l,c=this.items,d=[[t.isFunction(this.options.items)?this.options.items.call(this.element[0],e,{item:this.currentItem}):t(this.options.items,this.element),this]],h=this._connectWith();if(h&&this.ready)for(n=h.length-1;n>=0;n--)for(r=t(h[n],this.document[0]),i=r.length-1;i>=0;i--)o=t.data(r[i],this.widgetFullName),o&&o!==this&&!o.options.disabled&&(d.push([t.isFunction(o.options.items)?o.options.items.call(o.element[0],e,{item:this.currentItem}):t(o.options.items,o.element),o]),this.containers.push(o));for(n=d.length-1;n>=0;n--)for(a=d[n][1],s=d[n][0],i=0,l=s.length;l>i;i++)u=t(s[i]),u.data(this.widgetName+"-item",a),c.push({item:u,instance:a,width:0,height:0,left:0,top:0})},refreshPositions:function(e){this.floating=this.items.length?"x"===this.options.axis||this._isFloating(this.items[0].item):!1,this.offsetParent&&this.helper&&(this.offset.parent=this._getParentOffset());var n,i,r,o;for(n=this.items.length-1;n>=0;n--)i=this.items[n],i.instance!==this.currentContainer&&this.currentContainer&&i.item[0]!==this.currentItem[0]||(r=this.options.toleranceElement?t(this.options.toleranceElement,i.item):i.item,e||(i.width=r.outerWidth(),i.height=r.outerHeight()),o=r.offset(),i.left=o.left,i.top=o.top);if(this.options.custom&&this.options.custom.refreshContainers)this.options.custom.refreshContainers.call(this);else for(n=this.containers.length-1;n>=0;n--)o=this.containers[n].element.offset(),this.containers[n].containerCache.left=o.left,this.containers[n].containerCache.top=o.top,this.containers[n].containerCache.width=this.containers[n].element.outerWidth(),this.containers[n].containerCache.height=this.containers[n].element.outerHeight();return this},_createPlaceholder:function(e){e=e||this;var n,i=e.options;i.placeholder&&i.placeholder.constructor!==String||(n=i.placeholder,i.placeholder={element:function(){var i=e.currentItem[0].nodeName.toLowerCase(),r=t("<"+i+">",e.document[0]).addClass(n||e.currentItem[0].className+" ui-sortable-placeholder").removeClass("ui-sortable-helper");return"tbody"===i?e._createTrPlaceholder(e.currentItem.find("tr").eq(0),t("<tr>",e.document[0]).appendTo(r)):"tr"===i?e._createTrPlaceholder(e.currentItem,r):"img"===i&&r.attr("src",e.currentItem.attr("src")),n||r.css("visibility","hidden"),r},update:function(t,r){(!n||i.forcePlaceholderSize)&&(r.height()||r.height(e.currentItem.innerHeight()-parseInt(e.currentItem.css("paddingTop")||0,10)-parseInt(e.currentItem.css("paddingBottom")||0,10)),r.width()||r.width(e.currentItem.innerWidth()-parseInt(e.currentItem.css("paddingLeft")||0,10)-parseInt(e.currentItem.css("paddingRight")||0,10)))}}),e.placeholder=t(i.placeholder.element.call(e.element,e.currentItem)),e.currentItem.after(e.placeholder),i.placeholder.update(e,e.placeholder)},_createTrPlaceholder:function(e,n){var i=this;e.children().each(function(){t("<td>&#160;</td>",i.document[0]).attr("colspan",t(this).attr("colspan")||1).appendTo(n)})},_contactContainers:function(e){var n,i,r,o,a,s,u,l,c,d,h=null,f=null;for(n=this.containers.length-1;n>=0;n--)if(!t.contains(this.currentItem[0],this.containers[n].element[0]))if(this._intersectsWith(this.containers[n].containerCache)){if(h&&t.contains(this.containers[n].element[0],h.element[0]))continue;h=this.containers[n],f=n}else this.containers[n].containerCache.over&&(this.containers[n]._trigger("out",e,this._uiHash(this)),this.containers[n].containerCache.over=0);if(h)if(1===this.containers.length)this.containers[f].containerCache.over||(this.containers[f]._trigger("over",e,this._uiHash(this)),this.containers[f].containerCache.over=1);else{for(r=1e4,o=null,c=h.floating||this._isFloating(this.currentItem),a=c?"left":"top",s=c?"width":"height",
d=c?"clientX":"clientY",i=this.items.length-1;i>=0;i--)t.contains(this.containers[f].element[0],this.items[i].item[0])&&this.items[i].item[0]!==this.currentItem[0]&&(u=this.items[i].item.offset()[a],l=!1,e[d]-u>this.items[i][s]/2&&(l=!0),Math.abs(e[d]-u)<r&&(r=Math.abs(e[d]-u),o=this.items[i],this.direction=l?"up":"down"));if(!o&&!this.options.dropOnEmpty)return;if(this.currentContainer===this.containers[f])return void(this.currentContainer.containerCache.over||(this.containers[f]._trigger("over",e,this._uiHash()),this.currentContainer.containerCache.over=1));o?this._rearrange(e,o,null,!0):this._rearrange(e,null,this.containers[f].element,!0),this._trigger("change",e,this._uiHash()),this.containers[f]._trigger("change",e,this._uiHash(this)),this.currentContainer=this.containers[f],this.options.placeholder.update(this.currentContainer,this.placeholder),this.containers[f]._trigger("over",e,this._uiHash(this)),this.containers[f].containerCache.over=1}},_createHelper:function(e){var n=this.options,i=t.isFunction(n.helper)?t(n.helper.apply(this.element[0],[e,this.currentItem])):"clone"===n.helper?this.currentItem.clone():this.currentItem;return i.parents("body").length||t("parent"!==n.appendTo?n.appendTo:this.currentItem[0].parentNode)[0].appendChild(i[0]),i[0]===this.currentItem[0]&&(this._storedCSS={width:this.currentItem[0].style.width,height:this.currentItem[0].style.height,position:this.currentItem.css("position"),top:this.currentItem.css("top"),left:this.currentItem.css("left")}),(!i[0].style.width||n.forceHelperSize)&&i.width(this.currentItem.width()),(!i[0].style.height||n.forceHelperSize)&&i.height(this.currentItem.height()),i},_adjustOffsetFromHelper:function(e){"string"==typeof e&&(e=e.split(" ")),t.isArray(e)&&(e={left:+e[0],top:+e[1]||0}),"left"in e&&(this.offset.click.left=e.left+this.margins.left),"right"in e&&(this.offset.click.left=this.helperProportions.width-e.right+this.margins.left),"top"in e&&(this.offset.click.top=e.top+this.margins.top),"bottom"in e&&(this.offset.click.top=this.helperProportions.height-e.bottom+this.margins.top)},_getParentOffset:function(){this.offsetParent=this.helper.offsetParent();var e=this.offsetParent.offset();return"absolute"===this.cssPosition&&this.scrollParent[0]!==this.document[0]&&t.contains(this.scrollParent[0],this.offsetParent[0])&&(e.left+=this.scrollParent.scrollLeft(),e.top+=this.scrollParent.scrollTop()),(this.offsetParent[0]===this.document[0].body||this.offsetParent[0].tagName&&"html"===this.offsetParent[0].tagName.toLowerCase()&&t.ui.ie)&&(e={top:0,left:0}),{top:e.top+(parseInt(this.offsetParent.css("borderTopWidth"),10)||0),left:e.left+(parseInt(this.offsetParent.css("borderLeftWidth"),10)||0)}},_getRelativeOffset:function(){if("relative"===this.cssPosition){var t=this.currentItem.position();return{top:t.top-(parseInt(this.helper.css("top"),10)||0)+this.scrollParent.scrollTop(),left:t.left-(parseInt(this.helper.css("left"),10)||0)+this.scrollParent.scrollLeft()}}return{top:0,left:0}},_cacheMargins:function(){this.margins={left:parseInt(this.currentItem.css("marginLeft"),10)||0,top:parseInt(this.currentItem.css("marginTop"),10)||0}},_cacheHelperProportions:function(){this.helperProportions={width:this.helper.outerWidth(),height:this.helper.outerHeight()}},_setContainment:function(){var e,n,i,r=this.options;"parent"===r.containment&&(r.containment=this.helper[0].parentNode),("document"===r.containment||"window"===r.containment)&&(this.containment=[0-this.offset.relative.left-this.offset.parent.left,0-this.offset.relative.top-this.offset.parent.top,"document"===r.containment?this.document.width():this.window.width()-this.helperProportions.width-this.margins.left,("document"===r.containment?this.document.width():this.window.height()||this.document[0].body.parentNode.scrollHeight)-this.helperProportions.height-this.margins.top]),/^(document|window|parent)$/.test(r.containment)||(e=t(r.containment)[0],n=t(r.containment).offset(),i="hidden"!==t(e).css("overflow"),this.containment=[n.left+(parseInt(t(e).css("borderLeftWidth"),10)||0)+(parseInt(t(e).css("paddingLeft"),10)||0)-this.margins.left,n.top+(parseInt(t(e).css("borderTopWidth"),10)||0)+(parseInt(t(e).css("paddingTop"),10)||0)-this.margins.top,n.left+(i?Math.max(e.scrollWidth,e.offsetWidth):e.offsetWidth)-(parseInt(t(e).css("borderLeftWidth"),10)||0)-(parseInt(t(e).css("paddingRight"),10)||0)-this.helperProportions.width-this.margins.left,n.top+(i?Math.max(e.scrollHeight,e.offsetHeight):e.offsetHeight)-(parseInt(t(e).css("borderTopWidth"),10)||0)-(parseInt(t(e).css("paddingBottom"),10)||0)-this.helperProportions.height-this.margins.top])},_convertPositionTo:function(e,n){n||(n=this.position);var i="absolute"===e?1:-1,r="absolute"!==this.cssPosition||this.scrollParent[0]!==this.document[0]&&t.contains(this.scrollParent[0],this.offsetParent[0])?this.scrollParent:this.offsetParent,o=/(html|body)/i.test(r[0].tagName);return{top:n.top+this.offset.relative.top*i+this.offset.parent.top*i-("fixed"===this.cssPosition?-this.scrollParent.scrollTop():o?0:r.scrollTop())*i,left:n.left+this.offset.relative.left*i+this.offset.parent.left*i-("fixed"===this.cssPosition?-this.scrollParent.scrollLeft():o?0:r.scrollLeft())*i}},_generatePosition:function(e){var n,i,r=this.options,o=e.pageX,a=e.pageY,s="absolute"!==this.cssPosition||this.scrollParent[0]!==this.document[0]&&t.contains(this.scrollParent[0],this.offsetParent[0])?this.scrollParent:this.offsetParent,u=/(html|body)/i.test(s[0].tagName);return"relative"!==this.cssPosition||this.scrollParent[0]!==this.document[0]&&this.scrollParent[0]!==this.offsetParent[0]||(this.offset.relative=this._getRelativeOffset()),this.originalPosition&&(this.containment&&(e.pageX-this.offset.click.left<this.containment[0]&&(o=this.containment[0]+this.offset.click.left),e.pageY-this.offset.click.top<this.containment[1]&&(a=this.containment[1]+this.offset.click.top),e.pageX-this.offset.click.left>this.containment[2]&&(o=this.containment[2]+this.offset.click.left),e.pageY-this.offset.click.top>this.containment[3]&&(a=this.containment[3]+this.offset.click.top)),r.grid&&(n=this.originalPageY+Math.round((a-this.originalPageY)/r.grid[1])*r.grid[1],a=this.containment?n-this.offset.click.top>=this.containment[1]&&n-this.offset.click.top<=this.containment[3]?n:n-this.offset.click.top>=this.containment[1]?n-r.grid[1]:n+r.grid[1]:n,i=this.originalPageX+Math.round((o-this.originalPageX)/r.grid[0])*r.grid[0],o=this.containment?i-this.offset.click.left>=this.containment[0]&&i-this.offset.click.left<=this.containment[2]?i:i-this.offset.click.left>=this.containment[0]?i-r.grid[0]:i+r.grid[0]:i)),{top:a-this.offset.click.top-this.offset.relative.top-this.offset.parent.top+("fixed"===this.cssPosition?-this.scrollParent.scrollTop():u?0:s.scrollTop()),left:o-this.offset.click.left-this.offset.relative.left-this.offset.parent.left+("fixed"===this.cssPosition?-this.scrollParent.scrollLeft():u?0:s.scrollLeft())}},_rearrange:function(t,e,n,i){n?n[0].appendChild(this.placeholder[0]):e.item[0].parentNode.insertBefore(this.placeholder[0],"down"===this.direction?e.item[0]:e.item[0].nextSibling),this.counter=this.counter?++this.counter:1;var r=this.counter;this._delay(function(){r===this.counter&&this.refreshPositions(!i)})},_clear:function(t,e){function n(t,e,n){return function(i){n._trigger(t,i,e._uiHash(e))}}this.reverting=!1;var i,r=[];if(!this._noFinalSort&&this.currentItem.parent().length&&this.placeholder.before(this.currentItem),this._noFinalSort=null,this.helper[0]===this.currentItem[0]){for(i in this._storedCSS)("auto"===this._storedCSS[i]||"static"===this._storedCSS[i])&&(this._storedCSS[i]="");this.currentItem.css(this._storedCSS).removeClass("ui-sortable-helper")}else this.currentItem.show();for(this.fromOutside&&!e&&r.push(function(t){this._trigger("receive",t,this._uiHash(this.fromOutside))}),!this.fromOutside&&this.domPosition.prev===this.currentItem.prev().not(".ui-sortable-helper")[0]&&this.domPosition.parent===this.currentItem.parent()[0]||e||r.push(function(t){this._trigger("update",t,this._uiHash())}),this!==this.currentContainer&&(e||(r.push(function(t){this._trigger("remove",t,this._uiHash())}),r.push(function(t){return function(e){t._trigger("receive",e,this._uiHash(this))}}.call(this,this.currentContainer)),r.push(function(t){return function(e){t._trigger("update",e,this._uiHash(this))}}.call(this,this.currentContainer)))),i=this.containers.length-1;i>=0;i--)e||r.push(n("deactivate",this,this.containers[i])),this.containers[i].containerCache.over&&(r.push(n("out",this,this.containers[i])),this.containers[i].containerCache.over=0);if(this.storedCursor&&(this.document.find("body").css("cursor",this.storedCursor),this.storedStylesheet.remove()),this._storedOpacity&&this.helper.css("opacity",this._storedOpacity),this._storedZIndex&&this.helper.css("zIndex","auto"===this._storedZIndex?"":this._storedZIndex),this.dragging=!1,e||this._trigger("beforeStop",t,this._uiHash()),this.placeholder[0].parentNode.removeChild(this.placeholder[0]),this.cancelHelperRemoval||(this.helper[0]!==this.currentItem[0]&&this.helper.remove(),this.helper=null),!e){for(i=0;i<r.length;i++)r[i].call(this,t);this._trigger("stop",t,this._uiHash())}return this.fromOutside=!1,!this.cancelHelperRemoval},_trigger:function(){t.Widget.prototype._trigger.apply(this,arguments)===!1&&this.cancel()},_uiHash:function(e){var n=e||this;return{helper:n.helper,placeholder:n.placeholder||t([]),position:n.position,originalPosition:n.originalPosition,offset:n.positionAbs,item:n.currentItem,sender:e?e.element:null}}}),t.widget("ui.spinner",{version:"1.11.4",defaultElement:"<input>",widgetEventPrefix:"spin",options:{culture:null,icons:{down:"ui-icon-triangle-1-s",up:"ui-icon-triangle-1-n"},incremental:!0,max:null,min:null,numberFormat:null,page:10,step:1,change:null,spin:null,start:null,stop:null},_create:function(){this._setOption("max",this.options.max),this._setOption("min",this.options.min),this._setOption("step",this.options.step),""!==this.value()&&this._value(this.element.val(),!0),this._draw(),this._on(this._events),this._refresh(),this._on(this.window,{beforeunload:function(){this.element.removeAttr("autocomplete")}})},_getCreateOptions:function(){var e={},n=this.element;return t.each(["min","max","step"],function(t,i){var r=n.attr(i);void 0!==r&&r.length&&(e[i]=r)}),e},_events:{keydown:function(t){this._start(t)&&this._keydown(t)&&t.preventDefault()},keyup:"_stop",focus:function(){this.previous=this.element.val()},blur:function(t){return this.cancelBlur?void delete this.cancelBlur:(this._stop(),this._refresh(),void(this.previous!==this.element.val()&&this._trigger("change",t)))},mousewheel:function(t,e){if(e){if(!this.spinning&&!this._start(t))return!1;this._spin((e>0?1:-1)*this.options.step,t),clearTimeout(this.mousewheelTimer),this.mousewheelTimer=this._delay(function(){this.spinning&&this._stop(t)},100),t.preventDefault()}},"mousedown .ui-spinner-button":function(e){function n(){var t=this.element[0]===this.document[0].activeElement;t||(this.element.focus(),this.previous=i,this._delay(function(){this.previous=i}))}var i;i=this.element[0]===this.document[0].activeElement?this.previous:this.element.val(),e.preventDefault(),n.call(this),this.cancelBlur=!0,this._delay(function(){delete this.cancelBlur,n.call(this)}),this._start(e)!==!1&&this._repeat(null,t(e.currentTarget).hasClass("ui-spinner-up")?1:-1,e)},"mouseup .ui-spinner-button":"_stop","mouseenter .ui-spinner-button":function(e){return t(e.currentTarget).hasClass("ui-state-active")?this._start(e)===!1?!1:void this._repeat(null,t(e.currentTarget).hasClass("ui-spinner-up")?1:-1,e):void 0},"mouseleave .ui-spinner-button":"_stop"},_draw:function(){var t=this.uiSpinner=this.element.addClass("ui-spinner-input").attr("autocomplete","off").wrap(this._uiSpinnerHtml()).parent().append(this._buttonHtml());this.element.attr("role","spinbutton"),this.buttons=t.find(".ui-spinner-button").attr("tabIndex",-1).button().removeClass("ui-corner-all"),this.buttons.height()>Math.ceil(.5*t.height())&&t.height()>0&&t.height(t.height()),this.options.disabled&&this.disable()},_keydown:function(e){var n=this.options,i=t.ui.keyCode;switch(e.keyCode){case i.UP:return this._repeat(null,1,e),!0;case i.DOWN:return this._repeat(null,-1,e),!0;case i.PAGE_UP:return this._repeat(null,n.page,e),!0;case i.PAGE_DOWN:return this._repeat(null,-n.page,e),!0}return!1},_uiSpinnerHtml:function(){return"<span class='ui-spinner ui-widget ui-widget-content ui-corner-all'></span>"},_buttonHtml:function(){return"<a class='ui-spinner-button ui-spinner-up ui-corner-tr'><span class='ui-icon "+this.options.icons.up+"'>&#9650;</span></a><a class='ui-spinner-button ui-spinner-down ui-corner-br'><span class='ui-icon "+this.options.icons.down+"'>&#9660;</span></a>"},_start:function(t){return this.spinning||this._trigger("start",t)!==!1?(this.counter||(this.counter=1),this.spinning=!0,!0):!1},_repeat:function(t,e,n){t=t||500,clearTimeout(this.timer),this.timer=this._delay(function(){this._repeat(40,e,n)},t),this._spin(e*this.options.step,n)},_spin:function(t,e){var n=this.value()||0;this.counter||(this.counter=1),n=this._adjustValue(n+t*this._increment(this.counter)),this.spinning&&this._trigger("spin",e,{value:n})===!1||(this._value(n),this.counter++)},_increment:function(e){var n=this.options.incremental;return n?t.isFunction(n)?n(e):Math.floor(e*e*e/5e4-e*e/500+17*e/200+1):1},_precision:function(){var t=this._precisionOf(this.options.step);return null!==this.options.min&&(t=Math.max(t,this._precisionOf(this.options.min))),t},_precisionOf:function(t){var e=t.toString(),n=e.indexOf(".");return-1===n?0:e.length-n-1},_adjustValue:function(t){var e,n,i=this.options;return e=null!==i.min?i.min:0,n=t-e,n=Math.round(n/i.step)*i.step,t=e+n,t=parseFloat(t.toFixed(this._precision())),null!==i.max&&t>i.max?i.max:null!==i.min&&t<i.min?i.min:t},_stop:function(t){this.spinning&&(clearTimeout(this.timer),clearTimeout(this.mousewheelTimer),this.counter=0,this.spinning=!1,this._trigger("stop",t))},_setOption:function(t,e){if("culture"===t||"numberFormat"===t){var n=this._parse(this.element.val());return this.options[t]=e,void this.element.val(this._format(n))}("max"===t||"min"===t||"step"===t)&&"string"==typeof e&&(e=this._parse(e)),"icons"===t&&(this.buttons.first().find(".ui-icon").removeClass(this.options.icons.up).addClass(e.up),this.buttons.last().find(".ui-icon").removeClass(this.options.icons.down).addClass(e.down)),this._super(t,e),"disabled"===t&&(this.widget().toggleClass("ui-state-disabled",!!e),this.element.prop("disabled",!!e),this.buttons.button(e?"disable":"enable"))},_setOptions:u(function(t){this._super(t)}),_parse:function(t){return"string"==typeof t&&""!==t&&(t=window.Globalize&&this.options.numberFormat?Globalize.parseFloat(t,10,this.options.culture):+t),""===t||isNaN(t)?null:t},_format:function(t){return""===t?"":window.Globalize&&this.options.numberFormat?Globalize.format(t,this.options.numberFormat,this.options.culture):t},_refresh:function(){this.element.attr({"aria-valuemin":this.options.min,"aria-valuemax":this.options.max,"aria-valuenow":this._parse(this.element.val())})},isValid:function(){var t=this.value();return null===t?!1:t===this._adjustValue(t)},_value:function(t,e){var n;""!==t&&(n=this._parse(t),null!==n&&(e||(n=this._adjustValue(n)),t=this._format(n))),this.element.val(t),this._refresh()},_destroy:function(){this.element.removeClass("ui-spinner-input").prop("disabled",!1).removeAttr("autocomplete").removeAttr("role").removeAttr("aria-valuemin").removeAttr("aria-valuemax").removeAttr("aria-valuenow"),this.uiSpinner.replaceWith(this.element)},stepUp:u(function(t){this._stepUp(t)}),_stepUp:function(t){this._start()&&(this._spin((t||1)*this.options.step),this._stop())},stepDown:u(function(t){this._stepDown(t)}),_stepDown:function(t){this._start()&&(this._spin((t||1)*-this.options.step),this._stop())},pageUp:u(function(t){this._stepUp((t||1)*this.options.page)}),pageDown:u(function(t){this._stepDown((t||1)*this.options.page)}),value:function(t){return arguments.length?void u(this._value).call(this,t):this._parse(this.element.val())},widget:function(){return this.uiSpinner}}),t.widget("ui.tabs",{version:"1.11.4",delay:300,options:{active:null,collapsible:!1,event:"click",heightStyle:"content",hide:null,show:null,activate:null,beforeActivate:null,beforeLoad:null,load:null},_isLocal:function(){var t=/#.*$/;return function(e){var n,i;e=e.cloneNode(!1),n=e.href.replace(t,""),i=location.href.replace(t,"");try{n=decodeURIComponent(n)}catch(r){}try{i=decodeURIComponent(i)}catch(r){}return e.hash.length>1&&n===i}}(),_create:function(){var e=this,n=this.options;this.running=!1,this.element.addClass("ui-tabs ui-widget ui-widget-content ui-corner-all").toggleClass("ui-tabs-collapsible",n.collapsible),this._processTabs(),n.active=this._initialActive(),t.isArray(n.disabled)&&(n.disabled=t.unique(n.disabled.concat(t.map(this.tabs.filter(".ui-state-disabled"),function(t){return e.tabs.index(t)}))).sort()),this.options.active!==!1&&this.anchors.length?this.active=this._findActive(n.active):this.active=t(),this._refresh(),this.active.length&&this.load(n.active)},_initialActive:function(){var e=this.options.active,n=this.options.collapsible,i=location.hash.substring(1);return null===e&&(i&&this.tabs.each(function(n,r){return t(r).attr("aria-controls")===i?(e=n,!1):void 0}),null===e&&(e=this.tabs.index(this.tabs.filter(".ui-tabs-active"))),(null===e||-1===e)&&(e=this.tabs.length?0:!1)),e!==!1&&(e=this.tabs.index(this.tabs.eq(e)),-1===e&&(e=n?!1:0)),!n&&e===!1&&this.anchors.length&&(e=0),e},_getCreateEventData:function(){return{tab:this.active,panel:this.active.length?this._getPanelForTab(this.active):t()}},_tabKeydown:function(e){var n=t(this.document[0].activeElement).closest("li"),i=this.tabs.index(n),r=!0;if(!this._handlePageNav(e)){switch(e.keyCode){case t.ui.keyCode.RIGHT:case t.ui.keyCode.DOWN:i++;break;case t.ui.keyCode.UP:case t.ui.keyCode.LEFT:r=!1,i--;break;case t.ui.keyCode.END:i=this.anchors.length-1;break;case t.ui.keyCode.HOME:i=0;break;case t.ui.keyCode.SPACE:return e.preventDefault(),clearTimeout(this.activating),void this._activate(i);case t.ui.keyCode.ENTER:return e.preventDefault(),clearTimeout(this.activating),void this._activate(i===this.options.active?!1:i);default:return}e.preventDefault(),clearTimeout(this.activating),i=this._focusNextTab(i,r),e.ctrlKey||e.metaKey||(n.attr("aria-selected","false"),this.tabs.eq(i).attr("aria-selected","true"),this.activating=this._delay(function(){this.option("active",i)},this.delay))}},_panelKeydown:function(e){this._handlePageNav(e)||e.ctrlKey&&e.keyCode===t.ui.keyCode.UP&&(e.preventDefault(),this.active.focus())},_handlePageNav:function(e){return e.altKey&&e.keyCode===t.ui.keyCode.PAGE_UP?(this._activate(this._focusNextTab(this.options.active-1,!1)),!0):e.altKey&&e.keyCode===t.ui.keyCode.PAGE_DOWN?(this._activate(this._focusNextTab(this.options.active+1,!0)),!0):void 0},_findNextTab:function(e,n){function i(){return e>r&&(e=0),0>e&&(e=r),e}for(var r=this.tabs.length-1;-1!==t.inArray(i(),this.options.disabled);)e=n?e+1:e-1;return e},_focusNextTab:function(t,e){return t=this._findNextTab(t,e),this.tabs.eq(t).focus(),t},_setOption:function(t,e){return"active"===t?void this._activate(e):"disabled"===t?void this._setupDisabled(e):(this._super(t,e),"collapsible"===t&&(this.element.toggleClass("ui-tabs-collapsible",e),e||this.options.active!==!1||this._activate(0)),"event"===t&&this._setupEvents(e),void("heightStyle"===t&&this._setupHeightStyle(e)))},_sanitizeSelector:function(t){return t?t.replace(/[!"$%&'()*+,.\/:;<=>?@\[\]\^`{|}~]/g,"\\$&"):""},refresh:function(){var e=this.options,n=this.tablist.children(":has(a[href])");e.disabled=t.map(n.filter(".ui-state-disabled"),function(t){return n.index(t)}),this._processTabs(),e.active!==!1&&this.anchors.length?this.active.length&&!t.contains(this.tablist[0],this.active[0])?this.tabs.length===e.disabled.length?(e.active=!1,this.active=t()):this._activate(this._findNextTab(Math.max(0,e.active-1),!1)):e.active=this.tabs.index(this.active):(e.active=!1,this.active=t()),this._refresh()},_refresh:function(){this._setupDisabled(this.options.disabled),this._setupEvents(this.options.event),this._setupHeightStyle(this.options.heightStyle),this.tabs.not(this.active).attr({"aria-selected":"false","aria-expanded":"false",tabIndex:-1}),this.panels.not(this._getPanelForTab(this.active)).hide().attr({"aria-hidden":"true"}),this.active.length?(this.active.addClass("ui-tabs-active ui-state-active").attr({"aria-selected":"true","aria-expanded":"true",tabIndex:0}),this._getPanelForTab(this.active).show().attr({"aria-hidden":"false"})):this.tabs.eq(0).attr("tabIndex",0)},_processTabs:function(){var e=this,n=this.tabs,i=this.anchors,r=this.panels;this.tablist=this._getList().addClass("ui-tabs-nav ui-helper-reset ui-helper-clearfix ui-widget-header ui-corner-all").attr("role","tablist").delegate("> li","mousedown"+this.eventNamespace,function(e){t(this).is(".ui-state-disabled")&&e.preventDefault()}).delegate(".ui-tabs-anchor","focus"+this.eventNamespace,function(){t(this).closest("li").is(".ui-state-disabled")&&this.blur()}),this.tabs=this.tablist.find("> li:has(a[href])").addClass("ui-state-default ui-corner-top").attr({role:"tab",tabIndex:-1}),this.anchors=this.tabs.map(function(){return t("a",this)[0]}).addClass("ui-tabs-anchor").attr({role:"presentation",tabIndex:-1}),this.panels=t(),this.anchors.each(function(n,i){var r,o,a,s=t(i).uniqueId().attr("id"),u=t(i).closest("li"),l=u.attr("aria-controls");e._isLocal(i)?(r=i.hash,a=r.substring(1),o=e.element.find(e._sanitizeSelector(r))):(a=u.attr("aria-controls")||t({}).uniqueId()[0].id,r="#"+a,o=e.element.find(r),o.length||(o=e._createPanel(a),o.insertAfter(e.panels[n-1]||e.tablist)),o.attr("aria-live","polite")),o.length&&(e.panels=e.panels.add(o)),l&&u.data("ui-tabs-aria-controls",l),u.attr({"aria-controls":a,"aria-labelledby":s}),o.attr("aria-labelledby",s)}),this.panels.addClass("ui-tabs-panel ui-widget-content ui-corner-bottom").attr("role","tabpanel"),n&&(this._off(n.not(this.tabs)),this._off(i.not(this.anchors)),this._off(r.not(this.panels)))},_getList:function(){return this.tablist||this.element.find("ol,ul").eq(0)},_createPanel:function(e){return t("<div>").attr("id",e).addClass("ui-tabs-panel ui-widget-content ui-corner-bottom").data("ui-tabs-destroy",!0)},_setupDisabled:function(e){t.isArray(e)&&(e.length?e.length===this.anchors.length&&(e=!0):e=!1);for(var n,i=0;n=this.tabs[i];i++)e===!0||-1!==t.inArray(i,e)?t(n).addClass("ui-state-disabled").attr("aria-disabled","true"):t(n).removeClass("ui-state-disabled").removeAttr("aria-disabled");this.options.disabled=e},_setupEvents:function(e){var n={};e&&t.each(e.split(" "),function(t,e){n[e]="_eventHandler"}),this._off(this.anchors.add(this.tabs).add(this.panels)),this._on(!0,this.anchors,{click:function(t){t.preventDefault()}}),this._on(this.anchors,n),this._on(this.tabs,{keydown:"_tabKeydown"}),this._on(this.panels,{keydown:"_panelKeydown"}),this._focusable(this.tabs),this._hoverable(this.tabs)},_setupHeightStyle:function(e){var n,i=this.element.parent();"fill"===e?(n=i.height(),n-=this.element.outerHeight()-this.element.height(),this.element.siblings(":visible").each(function(){var e=t(this),i=e.css("position");"absolute"!==i&&"fixed"!==i&&(n-=e.outerHeight(!0))}),this.element.children().not(this.panels).each(function(){n-=t(this).outerHeight(!0)}),this.panels.each(function(){t(this).height(Math.max(0,n-t(this).innerHeight()+t(this).height()))}).css("overflow","auto")):"auto"===e&&(n=0,this.panels.each(function(){n=Math.max(n,t(this).height("").height())}).height(n))},_eventHandler:function(e){var n=this.options,i=this.active,r=t(e.currentTarget),o=r.closest("li"),a=o[0]===i[0],s=a&&n.collapsible,u=s?t():this._getPanelForTab(o),l=i.length?this._getPanelForTab(i):t(),c={oldTab:i,oldPanel:l,newTab:s?t():o,newPanel:u};e.preventDefault(),o.hasClass("ui-state-disabled")||o.hasClass("ui-tabs-loading")||this.running||a&&!n.collapsible||this._trigger("beforeActivate",e,c)===!1||(n.active=s?!1:this.tabs.index(o),this.active=a?t():o,this.xhr&&this.xhr.abort(),l.length||u.length||t.error("jQuery UI Tabs: Mismatching fragment identifier."),u.length&&this.load(this.tabs.index(o),e),this._toggle(e,c))},_toggle:function(e,n){function i(){o.running=!1,o._trigger("activate",e,n)}function r(){n.newTab.closest("li").addClass("ui-tabs-active ui-state-active"),a.length&&o.options.show?o._show(a,o.options.show,i):(a.show(),i())}var o=this,a=n.newPanel,s=n.oldPanel;this.running=!0,s.length&&this.options.hide?this._hide(s,this.options.hide,function(){n.oldTab.closest("li").removeClass("ui-tabs-active ui-state-active"),r()}):(n.oldTab.closest("li").removeClass("ui-tabs-active ui-state-active"),s.hide(),r()),s.attr("aria-hidden","true"),n.oldTab.attr({"aria-selected":"false","aria-expanded":"false"}),a.length&&s.length?n.oldTab.attr("tabIndex",-1):a.length&&this.tabs.filter(function(){return 0===t(this).attr("tabIndex")}).attr("tabIndex",-1),a.attr("aria-hidden","false"),n.newTab.attr({"aria-selected":"true","aria-expanded":"true",tabIndex:0})},_activate:function(e){var n,i=this._findActive(e);i[0]!==this.active[0]&&(i.length||(i=this.active),n=i.find(".ui-tabs-anchor")[0],this._eventHandler({target:n,currentTarget:n,preventDefault:t.noop}))},_findActive:function(e){return e===!1?t():this.tabs.eq(e)},_getIndex:function(t){return"string"==typeof t&&(t=this.anchors.index(this.anchors.filter("[href$='"+t+"']"))),t},_destroy:function(){this.xhr&&this.xhr.abort(),this.element.removeClass("ui-tabs ui-widget ui-widget-content ui-corner-all ui-tabs-collapsible"),this.tablist.removeClass("ui-tabs-nav ui-helper-reset ui-helper-clearfix ui-widget-header ui-corner-all").removeAttr("role"),this.anchors.removeClass("ui-tabs-anchor").removeAttr("role").removeAttr("tabIndex").removeUniqueId(),this.tablist.unbind(this.eventNamespace),this.tabs.add(this.panels).each(function(){t.data(this,"ui-tabs-destroy")?t(this).remove():t(this).removeClass("ui-state-default ui-state-active ui-state-disabled ui-corner-top ui-corner-bottom ui-widget-content ui-tabs-active ui-tabs-panel").removeAttr("tabIndex").removeAttr("aria-live").removeAttr("aria-busy").removeAttr("aria-selected").removeAttr("aria-labelledby").removeAttr("aria-hidden").removeAttr("aria-expanded").removeAttr("role")}),this.tabs.each(function(){var e=t(this),n=e.data("ui-tabs-aria-controls");n?e.attr("aria-controls",n).removeData("ui-tabs-aria-controls"):e.removeAttr("aria-controls")}),this.panels.show(),"content"!==this.options.heightStyle&&this.panels.css("height","")},enable:function(e){var n=this.options.disabled;n!==!1&&(void 0===e?n=!1:(e=this._getIndex(e),n=t.isArray(n)?t.map(n,function(t){return t!==e?t:null}):t.map(this.tabs,function(t,n){return n!==e?n:null})),this._setupDisabled(n))},disable:function(e){var n=this.options.disabled;if(n!==!0){if(void 0===e)n=!0;else{if(e=this._getIndex(e),-1!==t.inArray(e,n))return;n=t.isArray(n)?t.merge([e],n).sort():[e]}this._setupDisabled(n)}},load:function(e,n){e=this._getIndex(e);var i=this,r=this.tabs.eq(e),o=r.find(".ui-tabs-anchor"),a=this._getPanelForTab(r),s={tab:r,panel:a},u=function(t,e){"abort"===e&&i.panels.stop(!1,!0),r.removeClass("ui-tabs-loading"),a.removeAttr("aria-busy"),t===i.xhr&&delete i.xhr};this._isLocal(o[0])||(this.xhr=t.ajax(this._ajaxSettings(o,n,s)),this.xhr&&"canceled"!==this.xhr.statusText&&(r.addClass("ui-tabs-loading"),a.attr("aria-busy","true"),this.xhr.done(function(t,e,r){setTimeout(function(){a.html(t),i._trigger("load",n,s),u(r,e)},1)}).fail(function(t,e){setTimeout(function(){u(t,e)},1)})))},_ajaxSettings:function(e,n,i){var r=this;return{url:e.attr("href"),beforeSend:function(e,o){return r._trigger("beforeLoad",n,t.extend({jqXHR:e,ajaxSettings:o},i))}}},_getPanelForTab:function(e){var n=t(e).attr("aria-controls");return this.element.find(this._sanitizeSelector("#"+n))}}),t.widget("ui.tooltip",{version:"1.11.4",options:{content:function(){var e=t(this).attr("title")||"";return t("<a>").text(e).html()},hide:!0,items:"[title]:not([disabled])",position:{my:"left top+15",at:"left bottom",collision:"flipfit flip"},show:!0,tooltipClass:null,track:!1,close:null,open:null},_addDescribedBy:function(e,n){var i=(e.attr("aria-describedby")||"").split(/\s+/);i.push(n),e.data("ui-tooltip-id",n).attr("aria-describedby",t.trim(i.join(" ")))},_removeDescribedBy:function(e){var n=e.data("ui-tooltip-id"),i=(e.attr("aria-describedby")||"").split(/\s+/),r=t.inArray(n,i);-1!==r&&i.splice(r,1),e.removeData("ui-tooltip-id"),i=t.trim(i.join(" ")),i?e.attr("aria-describedby",i):e.removeAttr("aria-describedby")},_create:function(){this._on({mouseover:"open",focusin:"open"}),this.tooltips={},this.parents={},this.options.disabled&&this._disable(),this.liveRegion=t("<div>").attr({role:"log","aria-live":"assertive","aria-relevant":"additions"}).addClass("ui-helper-hidden-accessible").appendTo(this.document[0].body)},_setOption:function(e,n){var i=this;return"disabled"===e?(this[n?"_disable":"_enable"](),void(this.options[e]=n)):(this._super(e,n),void("content"===e&&t.each(this.tooltips,function(t,e){i._updateContent(e.element)})))},_disable:function(){var e=this;t.each(this.tooltips,function(n,i){var r=t.Event("blur");r.target=r.currentTarget=i.element[0],e.close(r,!0)}),this.element.find(this.options.items).addBack().each(function(){var e=t(this);e.is("[title]")&&e.data("ui-tooltip-title",e.attr("title")).removeAttr("title")})},_enable:function(){this.element.find(this.options.items).addBack().each(function(){var e=t(this);e.data("ui-tooltip-title")&&e.attr("title",e.data("ui-tooltip-title"))})},open:function(e){var n=this,i=t(e?e.target:this.element).closest(this.options.items);i.length&&!i.data("ui-tooltip-id")&&(i.attr("title")&&i.data("ui-tooltip-title",i.attr("title")),i.data("ui-tooltip-open",!0),e&&"mouseover"===e.type&&i.parents().each(function(){var e,i=t(this);i.data("ui-tooltip-open")&&(e=t.Event("blur"),e.target=e.currentTarget=this,n.close(e,!0)),i.attr("title")&&(i.uniqueId(),n.parents[this.id]={element:this,title:i.attr("title")},i.attr("title",""))}),this._registerCloseHandlers(e,i),this._updateContent(i,e))},_updateContent:function(t,e){var n,i=this.options.content,r=this,o=e?e.type:null;return"string"==typeof i?this._open(e,t,i):(n=i.call(t[0],function(n){r._delay(function(){t.data("ui-tooltip-open")&&(e&&(e.type=o),this._open(e,t,n))})}),void(n&&this._open(e,t,n)))},_open:function(e,n,i){function r(t){l.of=t,a.is(":hidden")||a.position(l)}var o,a,s,u,l=t.extend({},this.options.position);if(i){if(o=this._find(n))return void o.tooltip.find(".ui-tooltip-content").html(i);n.is("[title]")&&(e&&"mouseover"===e.type?n.attr("title",""):n.removeAttr("title")),o=this._tooltip(n),a=o.tooltip,this._addDescribedBy(n,a.attr("id")),a.find(".ui-tooltip-content").html(i),this.liveRegion.children().hide(),i.clone?(u=i.clone(),u.removeAttr("id").find("[id]").removeAttr("id")):u=i,t("<div>").html(u).appendTo(this.liveRegion),this.options.track&&e&&/^mouse/.test(e.type)?(this._on(this.document,{mousemove:r}),r(e)):a.position(t.extend({of:n},this.options.position)),a.hide(),this._show(a,this.options.show),this.options.show&&this.options.show.delay&&(s=this.delayedShow=setInterval(function(){a.is(":visible")&&(r(l.of),clearInterval(s))},t.fx.interval)),this._trigger("open",e,{tooltip:a})}},_registerCloseHandlers:function(e,n){var i={keyup:function(e){if(e.keyCode===t.ui.keyCode.ESCAPE){var i=t.Event(e);i.currentTarget=n[0],this.close(i,!0)}}};n[0]!==this.element[0]&&(i.remove=function(){this._removeTooltip(this._find(n).tooltip)}),e&&"mouseover"!==e.type||(i.mouseleave="close"),e&&"focusin"!==e.type||(i.focusout="close"),this._on(!0,n,i)},close:function(e){var n,i=this,r=t(e?e.currentTarget:this.element),o=this._find(r);return o?(n=o.tooltip,void(o.closing||(clearInterval(this.delayedShow),r.data("ui-tooltip-title")&&!r.attr("title")&&r.attr("title",r.data("ui-tooltip-title")),
this._removeDescribedBy(r),o.hiding=!0,n.stop(!0),this._hide(n,this.options.hide,function(){i._removeTooltip(t(this))}),r.removeData("ui-tooltip-open"),this._off(r,"mouseleave focusout keyup"),r[0]!==this.element[0]&&this._off(r,"remove"),this._off(this.document,"mousemove"),e&&"mouseleave"===e.type&&t.each(this.parents,function(e,n){t(n.element).attr("title",n.title),delete i.parents[e]}),o.closing=!0,this._trigger("close",e,{tooltip:n}),o.hiding||(o.closing=!1)))):void r.removeData("ui-tooltip-open")},_tooltip:function(e){var n=t("<div>").attr("role","tooltip").addClass("ui-tooltip ui-widget ui-corner-all ui-widget-content "+(this.options.tooltipClass||"")),i=n.uniqueId().attr("id");return t("<div>").addClass("ui-tooltip-content").appendTo(n),n.appendTo(this.document[0].body),this.tooltips[i]={element:e,tooltip:n}},_find:function(t){var e=t.data("ui-tooltip-id");return e?this.tooltips[e]:null},_removeTooltip:function(t){t.remove(),delete this.tooltips[t.attr("id")]},_destroy:function(){var e=this;t.each(this.tooltips,function(n,i){var r=t.Event("blur"),o=i.element;r.target=r.currentTarget=o[0],e.close(r,!0),t("#"+n).remove(),o.data("ui-tooltip-title")&&(o.attr("title")||o.attr("title",o.data("ui-tooltip-title")),o.removeData("ui-tooltip-title"))}),this.liveRegion.remove()}})}),/**
 * angular-ui-sortable - This directive allows you to jQueryUI Sortable.
 * @version v0.13.4 - 2015-06-07
 * @link http://angular-ui.github.com
 * @license MIT
 */
function(t,e,n){"use strict";e.module("ui.sortable",[]).value("uiSortableConfig",{}).directive("uiSortable",["uiSortableConfig","$timeout","$log",function(t,i,r){return{require:"?ngModel",scope:{ngModel:"=",uiSortable:"="},link:function(o,a,s,u){function l(t,e){return e&&"function"==typeof e?function(){t.apply(this,arguments),e.apply(this,arguments)}:t}function c(t){var e=t.data("ui-sortable");return e&&"object"==typeof e&&"ui-sortable"===e.widgetFullName?e:null}function d(t,e){var n=t.sortable("option","helper");return"clone"===n||"function"==typeof n&&e.item.sortable.isCustomHelperUsed()}function h(t){return/left|right/.test(t.css("float"))||/inline|table-cell/.test(t.css("display"))}function f(t,e){for(var n=null,i=0;i<t.length;i++){var r=t[i];if(r.element[0]===e[0]){n=r.scope;break}}return n}function p(t,e){e.item.sortable._destroy()}var g,m={},v={"ui-floating":n},y={receive:null,remove:null,start:null,stop:null,update:null},b={helper:null};return e.extend(m,v,t,o.uiSortable),e.element.fn&&e.element.fn.jquery?(u?(o.$watch("ngModel.length",function(){i(function(){c(a)&&a.sortable("refresh")},0,!1)}),y.start=function(t,i){if("auto"===m["ui-floating"]){var r=i.item.siblings(),o=c(e.element(t.target));o.floating=h(r)}i.item.sortable={model:u.$modelValue[i.item.index()],index:i.item.index(),source:i.item.parent(),sourceModel:u.$modelValue,cancel:function(){i.item.sortable._isCanceled=!0},isCanceled:function(){return i.item.sortable._isCanceled},isCustomHelperUsed:function(){return!!i.item.sortable._isCustomHelperUsed},_isCanceled:!1,_isCustomHelperUsed:i.item.sortable._isCustomHelperUsed,_destroy:function(){e.forEach(i.item.sortable,function(t,e){i.item.sortable[e]=n})}}},y.activate=function(t,n){g=a.contents();var i=a.sortable("option","placeholder");if(i&&i.element&&"function"==typeof i.element){var r=i.element();r=e.element(r);var s=a.find('[class="'+r.attr("class")+'"]:not([ng-repeat], [data-ng-repeat])');g=g.not(s)}var u=n.item.sortable._connectedSortables||[];u.push({element:a,scope:o}),n.item.sortable._connectedSortables=u},y.update=function(t,e){if(!e.item.sortable.received){e.item.sortable.dropindex=e.item.index();var n=e.item.parent();e.item.sortable.droptarget=n;var i=f(e.item.sortable._connectedSortables,n);e.item.sortable.droptargetModel=i.ngModel,a.sortable("cancel")}d(a,e)&&!e.item.sortable.received&&"parent"===a.sortable("option","appendTo")&&(g=g.not(g.last())),g.appendTo(a),e.item.sortable.received&&(g=null),e.item.sortable.received&&!e.item.sortable.isCanceled()&&o.$apply(function(){u.$modelValue.splice(e.item.sortable.dropindex,0,e.item.sortable.moved)})},y.stop=function(t,e){!e.item.sortable.received&&"dropindex"in e.item.sortable&&!e.item.sortable.isCanceled()?o.$apply(function(){u.$modelValue.splice(e.item.sortable.dropindex,0,u.$modelValue.splice(e.item.sortable.index,1)[0])}):"dropindex"in e.item.sortable&&!e.item.sortable.isCanceled()||d(a,e)||g.appendTo(a),g=null},y.receive=function(t,e){e.item.sortable.received=!0},y.remove=function(t,e){"dropindex"in e.item.sortable||(a.sortable("cancel"),e.item.sortable.cancel()),e.item.sortable.isCanceled()||o.$apply(function(){e.item.sortable.moved=u.$modelValue.splice(e.item.sortable.index,1)[0]})},b.helper=function(t){return t&&"function"==typeof t?function(e,n){var i=t.apply(this,arguments);return n.sortable._isCustomHelperUsed=n!==i,i}:t},o.$watch("uiSortable",function(t){var n=c(a);n&&e.forEach(t,function(t,e){return e in v?("ui-floating"!==e||t!==!1&&t!==!0||(n.floating=t),void(m[e]=t)):(y[e]?("stop"===e&&(t=l(t,function(){o.$apply()}),t=l(t,p)),t=l(y[e],t)):b[e]&&(t=b[e](t)),m[e]=t,void a.sortable("option",e,t))})},!0),e.forEach(y,function(t,e){m[e]=l(t,m[e]),"stop"===e&&(m[e]=l(m[e],p))})):r.info("ui.sortable: ngModel not provided!",a),void a.sortable(m)):void r.error("ui.sortable: jQuery should be included before AngularJS!")}}}])}(window,window.angular),angular.module("ui.dashboard",["ui.bootstrap","ui.sortable"]),angular.module("ui.dashboard").directive("dashboard",["WidgetModel","WidgetDefCollection","$uibModal","DashboardState","$log",function(t,e,n,i,r){return{restrict:"A",templateUrl:function(t,e){return e.templateUrl?e.templateUrl:"components/directives/dashboard/dashboard.html"},scope:!0,controller:["$scope","$attrs",function(t,e){var n={stringifyStorage:!0,hideWidgetSettings:!1,hideWidgetClose:!1,settingsModalOptions:{templateUrl:"components/directives/dashboard/widget-settings-template.html",controller:"WidgetSettingsCtrl"},onSettingsClose:function(t,e){jQuery.extend(!0,e,t)},onSettingsDismiss:function(t){r.info("widget settings were dismissed. Reason: ",t)}};t.options=t.$eval(e.dashboard),t.options.settingsModalOptions=t.options.settingsModalOptions||{},_.each(["settingsModalOptions"],function(e){t.options[e]=t.options[e]||{},_.defaults(t.options[e],n[e])}),_.defaults(t.options,n);var i={stop:function(){t.saveDashboard()},handle:".widget-header",distance:5};t.sortableOptions=angular.extend({},i,t.options.sortableOptions||{})}],link:function(r){function o(t){r.options.unsavedChangeCount=0,t&&t.length?r.loadWidgets(t):r.defaultWidgets?r.loadWidgets(r.defaultWidgets):r.clear(!0)}r.defaultWidgets=r.options.defaultWidgets,r.widgetDefs=new e(r.options.widgetDefinitions);var a=1;r.dashboardState=new i(r.options.storage,r.options.storageId,r.options.storageHash,r.widgetDefs,r.options.stringifyStorage),r.addWidget=function(e,n){"string"==typeof e&&(e={name:e});var i=r.widgetDefs.getByName(e.name);if(!i)throw"Widget "+e.name+" is not found.";e.title||i.title||(e.title="Widget "+a++);var o=new t(i,e);return r.widgets.push(o),n||r.saveDashboard(),o},r.removeWidget=function(t){r.widgets.splice(_.indexOf(r.widgets,t),1),r.saveDashboard()},r.openWidgetSettings=function(t){var e=_.defaults({scope:r},t.settingsModalOptions,r.options.settingsModalOptions);e.resolve={widget:function(){return t}};var i=n.open(e),o=t.onSettingsClose||r.options.onSettingsClose,a=t.onSettingsDismiss||r.options.onSettingsDismiss;i.result.then(function(e){o(e,t,r),r.$emit("widgetChanged",t)},function(t){a(t,r)})},r.clear=function(t){r.widgets=[],t!==!0&&r.saveDashboard()},r.addWidgetInternal=function(t,e){t.preventDefault(),r.addWidget(e)},r.saveDashboard=function(t){r.options.explicitSave?(angular.isNumber(r.options.unsavedChangeCount)||(r.options.unsavedChangeCount=0),t?(r.options.unsavedChangeCount=0,r.dashboardState.save(r.widgets)):++r.options.unsavedChangeCount):r.dashboardState.save(r.widgets)},r.externalSaveDashboard=function(t){angular.isDefined(t)?r.saveDashboard(t):r.saveDashboard(!0)},r.loadWidgets=function(t){r.savedWidgetDefs=t,r.clear(!0),_.each(t,function(t){r.addWidget(t,!0)})},r.resetWidgetsToDefault=function(){r.loadWidgets(r.defaultWidgets),r.saveDashboard()};var s=r.dashboardState.load();angular.isArray(s)?o(s):s&&angular.isObject(s)&&angular.isFunction(s.then)?s.then(o,o):o(),r.options.addWidget=r.addWidget,r.options.loadWidgets=r.loadWidgets,r.options.saveDashboard=r.externalSaveDashboard,r.options.removeWidget=r.removeWidget,r.options.openWidgetSettings=r.openWidgetSettings,r.$on("widgetChanged",function(t){t.stopPropagation(),r.saveDashboard()})}}}]),angular.module("ui.dashboard").run(["$templateCache",function(t){t.put("components/directives/dashboard/altDashboard.html",'<div>\n    <div class="btn-toolbar" ng-if="!options.hideToolbar">\n        <div class="btn-group" ng-if="!options.widgetButtons">\n            <span class="dropdown" on-toggle="toggled(open)">\n              <button type="button" class="btn btn-primary dropdown-toggle" ng-disabled="disabled">\n                Button dropdown <span class="caret"></span>\n              </button>\n              <ul class="dropdown-menu" role="menu">\n                <li ng-repeat="widget in widgetDefs">\n                  <a href="#" ng-click="addWidgetInternal($event, widget);" class="dropdown-toggle">{{widget.name}}</a>\n                </li>\n              </ul>\n            </span>\n        </div>\n\n        <div class="btn-group" ng-if="options.widgetButtons">\n            <button ng-repeat="widget in widgetDefs"\n                    ng-click="addWidgetInternal($event, widget);" type="button" class="btn btn-primary">\n                {{widget.name}}\n            </button>\n        </div>\n\n        <button class="btn btn-warning" ng-click="resetWidgetsToDefault()">Default Widgets</button>\n\n        <button ng-if="options.storage && options.explicitSave" ng-click="options.saveDashboard()" class="btn btn-success" ng-hide="!options.unsavedChangeCount">{{ !options.unsavedChangeCount ? "Alternative - No Changes" : "Save" }}</button>\n\n        <button ng-click="clear();" ng-hide="!widgets.length" type="button" class="btn btn-info">Clear</button>\n    </div>\n\n    <div ui-sortable="sortableOptions" ng-model="widgets" class="dashboard-widget-area">\n        <div ng-repeat="widget in widgets" ng-style="widget.style" class="widget-container" widget>\n            <div class="widget panel panel-default">\n                <div class="widget-header panel-heading">\n                    <h3 class="panel-title">\n                        <span class="widget-title" ng-dblclick="editTitle(widget)" ng-hide="widget.editingTitle">{{widget.title}}</span>\n                        <form action="" class="widget-title" ng-show="widget.editingTitle" ng-submit="saveTitleEdit(widget)">\n                            <input type="text" ng-model="widget.title" class="form-control">\n                        </form>\n                        <span class="label label-primary" ng-if="!options.hideWidgetName">{{widget.name}}</span>\n                        <span ng-click="removeWidget(widget);" class="glyphicon glyphicon-remove" ng-if="!options.hideWidgetClose"></span>\n                        <span ng-click="openWidgetSettings(widget);" class="glyphicon glyphicon-cog" ng-if="!options.hideWidgetSettings"></span>\n                    </h3>\n                </div>\n                <div class="panel-body widget-content"></div>\n                <div class="widget-ew-resizer" ng-mousedown="grabResizer($event)"></div>\n            </div>\n        </div>\n    </div>\n</div>\n'),t.put("components/directives/dashboard/dashboard.html",'<div>\n    <div class="btn-toolbar" ng-if="!options.hideToolbar">\n        <div class="btn-group" ng-if="!options.widgetButtons">\n            <span class="dropdown" on-toggle="toggled(open)">\n              <button type="button" class="btn btn-primary dropdown-toggle" data-toggle="dropdown">\n                Button dropdown <span class="caret"></span>\n              </button>\n              <ul class="dropdown-menu" role="menu">\n                <li ng-repeat="widget in widgetDefs">\n                  <a href="#" ng-click="addWidgetInternal($event, widget);" class="dropdown-toggle"><span class="label label-primary">{{widget.name}}</span></a>\n                </li>\n              </ul>\n            </span>\n    </div>\n        <div class="btn-group" ng-if="options.widgetButtons">\n            <button ng-repeat="widget in widgetDefs"\n                    ng-click="addWidgetInternal($event, widget);" type="button" class="btn btn-primary">\n                {{widget.name}}\n            </button>\n        </div>\n\n        <button class="btn btn-warning" ng-click="resetWidgetsToDefault()">Default Widgets</button>\n\n        <button ng-if="options.storage && options.explicitSave" ng-click="options.saveDashboard()" class="btn btn-success" ng-disabled="!options.unsavedChangeCount">{{ !options.unsavedChangeCount ? "all saved" : "save changes (" + options.unsavedChangeCount + ")" }}</button>\n\n        <button ng-click="clear();" type="button" class="btn btn-info">Clear</button>\n    </div>\n\n    <div ui-sortable="sortableOptions" ng-model="widgets" class="dashboard-widget-area">\n        <div ng-repeat="widget in widgets" ng-style="widget.containerStyle" class="widget-container" widget>\n            <div class="widget panel panel-default">\n                <div class="widget-header panel-heading">\n                    <h3 class="panel-title">\n                        <span class="widget-title" ng-dblclick="editTitle(widget)" ng-hide="widget.editingTitle">{{widget.title}}</span>\n                        <form action="" class="widget-title" ng-show="widget.editingTitle" ng-submit="saveTitleEdit(widget)">\n                            <input type="text" ng-model="widget.title" class="form-control">\n                        </form>\n                        <span class="label label-primary" ng-if="!options.hideWidgetName">{{widget.name}}</span>\n                        <span ng-click="removeWidget(widget);" class="glyphicon glyphicon-remove" ng-if="!options.hideWidgetClose"></span>\n                        <span ng-click="openWidgetSettings(widget);" class="glyphicon glyphicon-cog" ng-if="!options.hideWidgetSettings"></span>\n                        <span ng-click="widget.contentStyle.display = widget.contentStyle.display === \'none\' ? \'block\' : \'none\'" class="glyphicon" ng-class="{\'glyphicon-plus\': widget.contentStyle.display === \'none\', \'glyphicon-minus\': widget.contentStyle.display !== \'none\' }"></span>\n                    </h3>\n                </div>\n                <div class="panel-body widget-content" ng-style="widget.contentStyle"></div>\n                <div class="widget-ew-resizer" ng-mousedown="grabResizer($event)"></div>\n                <div ng-if="widget.enableVerticalResize" class="widget-s-resizer" ng-mousedown="grabSouthResizer($event)"></div>\n            </div>\n        </div>\n    </div>\n</div>'),t.put("components/directives/dashboard/widget-settings-template.html",'<div class="modal-header">\n    <button type="button" class="close" data-dismiss="modal" aria-hidden="true" ng-click="cancel()">&times;</button>\n  <h3>Widget Options <small>{{widget.title}}</small></h3>\n</div>\n\n<div class="modal-body">\n    <form name="form" novalidate class="form-horizontal">\n        <div class="form-group">\n            <label for="widgetTitle" class="col-sm-2 control-label">Title</label>\n            <div class="col-sm-10">\n                <input type="text" class="form-control" name="widgetTitle" ng-model="result.title">\n            </div>\n        </div>\n        <div ng-if="widget.settingsModalOptions.partialTemplateUrl"\n             ng-include="widget.settingsModalOptions.partialTemplateUrl"></div>\n    </form>\n</div>\n\n<div class="modal-footer">\n    <button type="button" class="btn btn-default" ng-click="cancel()">Cancel</button>\n    <button type="button" class="btn btn-primary" ng-click="ok()">OK</button>\n</div>'),t.put("components/directives/dashboardLayouts/SaveChangesModal.html",'<div class="modal-header">\n    <button type="button" class="close" data-dismiss="modal" aria-hidden="true" ng-click="cancel()">&times;</button>\n  <h3>Unsaved Changes to "{{layout.title}}"</h3>\n</div>\n\n<div class="modal-body">\n    <p>You have {{layout.dashboard.unsavedChangeCount}} unsaved changes on this dashboard. Would you like to save them?</p>\n</div>\n\n<div class="modal-footer">\n    <button type="button" class="btn btn-default" ng-click="cancel()">Don\'t Save</button>\n    <button type="button" class="btn btn-primary" ng-click="ok()">Save</button>\n</div>'),t.put("components/directives/dashboardLayouts/dashboardLayouts.html",'<ul ui-sortable="sortableOptions" ng-model="layouts" class="nav nav-tabs layout-tabs">\n    <li ng-repeat="layout in layouts" ng-class="{ active: layout.active }">\n        <a ng-click="makeLayoutActive(layout)">\n            <span ng-dblclick="editTitle(layout)" ng-show="!layout.editingTitle">{{layout.title}}</span>\n            <form action="" class="layout-title" ng-show="layout.editingTitle" ng-submit="saveTitleEdit(layout)">\n                <input type="text" ng-model="layout.title" class="form-control" data-layout="{{layout.id}}">\n            </form>\n            <span ng-if="!layout.locked" ng-click="removeLayout(layout)" class="glyphicon glyphicon-remove remove-layout-icon"></span>\n            <!-- <span class="glyphicon glyphicon-pencil"></span> -->\n            <!-- <span class="glyphicon glyphicon-remove"></span> -->\n        </a>\n    </li>\n    <li>\n        <a ng-click="createNewLayout()">\n            <span class="glyphicon glyphicon-plus"></span>\n        </a>\n    </li>\n</ul>\n<div ng-repeat="layout in layouts | filter:isActive" dashboard="layout.dashboard" template-url="components/directives/dashboard/dashboard.html"></div>')}]),angular.module("ui.dashboard").directive("dashboardLayouts",["LayoutStorage","$timeout","$uibModal",function(t,e,n){return{scope:!0,templateUrl:function(t,e){return e.templateUrl?e.templateUrl:"components/directives/dashboardLayouts/dashboardLayouts.html"},link:function(i,r,o){i.options=i.$eval(o.dashboardLayouts);var a=new t(i.options);i.layouts=a.layouts,i.createNewLayout=function(){var t={title:"Custom",defaultWidgets:i.options.defaultWidgets||[]};return a.add(t),i.makeLayoutActive(t),a.save(),t},i.removeLayout=function(t){a.remove(t),a.save()},i.makeLayoutActive=function(t){var e=a.getActiveLayout();if(e&&e.dashboard.unsavedChangeCount){var r=n.open({templateUrl:"template/SaveChangesModal.html",resolve:{layout:function(){return t}},controller:"SaveChangesModalCtrl"});r.result.then(function(){e.dashboard.saveDashboard(),i._makeLayoutActive(t)},function(){i._makeLayoutActive(t)})}else i._makeLayoutActive(t)},i._makeLayoutActive=function(t){angular.forEach(i.layouts,function(e){e!==t?e.active=!1:e.active=!0}),a.save()},i.isActive=function(t){return!!t.active},i.editTitle=function(t){if(!t.locked){var n=r.find('input[data-layout="'+t.id+'"]');t.editingTitle=!0,e(function(){n.focus()[0].setSelectionRange(0,9999)})}},i.saveTitleEdit=function(t){t.editingTitle=!1,a.save()},i.options.saveLayouts=function(){a.save(!0)},i.options.addWidget=function(){var t=a.getActiveLayout();t&&t.dashboard.addWidget.apply(t.dashboard,arguments)},i.options.loadWidgets=function(){var t=a.getActiveLayout();t&&t.dashboard.loadWidgets.apply(t.dashboard,arguments)},i.options.saveDashboard=function(){var t=a.getActiveLayout();t&&t.dashboard.saveDashboard.apply(t.dashboard,arguments)};var s={stop:function(){i.options.saveLayouts()},distance:5};i.sortableOptions=angular.extend({},s,i.options.sortableOptions||{})}}}]),angular.module("ui.dashboard").controller("SaveChangesModalCtrl",["$scope","$uibModalInstance","layout",function(t,e,n){t.layout=n,t.ok=function(){e.close()},t.cancel=function(){e.dismiss()}}]),angular.module("ui.dashboard").directive("widget",["$injector",function(t){return{controller:"DashboardWidgetCtrl",link:function(e){var n=e.widget,i=n.dataModelType;if(i){var r;if(angular.isFunction(i))r=i;else{if(!angular.isString(i))throw new Error("widget dataModelType should be function or string");t.invoke([i,function(t){r=t}])}var o;o=n.dataModelArgs?new r(n.dataModelArgs):new r,n.dataModel=o,o.setup(n,e),o.init(),e.$on("$destroy",_.bind(o.destroy,o))}e.compileTemplate(),e.$emit("widgetAdded",n)}}}]),angular.module("ui.dashboard").controller("DashboardWidgetCtrl",["$scope","$element","$compile","$window","$timeout",function(t,e,n,i,r){t.status={isopen:!1},t.makeTemplateString=function(){var e=t.widget,n="";return e.templateUrl?n="<div ng-include=\"'"+e.templateUrl+"'\"></div>":e.template?n=e.template:(n="<div "+e.directive,e.dataAttrName&&(e.attrs=e.attrs||{},e.attrs[e.dataAttrName]="widgetData"),e.attrs&&(e.attrs[e.directive]&&(n+='="'+e.attrs[e.directive]+'"'),_.each(e.attrs,function(t,i){i!==e.directive&&(n+=" "+i+'="'+t+'"')})),n+="></div>"),n},t.grabResizer=function(n){var r=t.widget,o=e.find(".widget");if(1===n.which){n.stopPropagation(),n.originalEvent.preventDefault();var a=n.clientX,s=o.width(),u=o.height(),l=r.containerStyle.width,c=r.widthUnits,d=parseFloat(l),h=angular.element('<div class="widget-resizer-marquee" style="height: '+u+"px; width: "+s+'px;"></div>');o.append(h);var f=d/s,p=function(t){var e=t.clientX,n=e-a,i=s+n;h.css("width",i+"px")},g=function(e){jQuery(i).off("mousemove",p),h.remove();var n=e.clientX,o=n-a,s=Math.round(o*f*100)/100,u=1*d+s;r.setWidth(u,c),t.$emit("widgetChanged",r),t.$apply(),t.$broadcast("widgetResized",{width:u})};jQuery(i).on("mousemove",p).one("mouseup",g)}},t.grabSouthResizer=function(n){var r=e.find(".widget");if(1===n.which){n.stopPropagation(),n.originalEvent.preventDefault();var o=n.clientY,a=r.width(),s=r.height(),u=angular.element('<div class="widget-resizer-marquee" style="height: '+s+"px; width: "+a+'px;"></div>');r.append(u);var l=function(t){var e=t.clientY,n=e-o,i=s+n;u.css("height",i+"px")},c=function(e){jQuery(i).off("mousemove",l),u.remove();var n=e.clientY,a=n-o,s=r.find(".widget-content"),c=a,d=parseInt(s.css("height"),10),h=d+c;t.widget.setHeight(h+"px"),t.$emit("widgetChanged",t.widget),t.$apply(),t.$broadcast("widgetResized",{height:h})};jQuery(i).on("mousemove",l).one("mouseup",c)}},t.editTitle=function(t){var n=e.find(".widget");t.editingTitle=!0,r(function(){n.find("form.widget-title input:eq(0)").focus()[0].setSelectionRange(0,9999)})},t.saveTitleEdit=function(e){e.editingTitle=!1,t.$emit("widgetChanged",e)},t.compileTemplate=function(){var i=t.findWidgetContainer(e),r=t.makeTemplateString(),o=angular.element(r);i.empty(),i.append(o),n(o)(t)},t.findWidgetContainer=function(t){return t.find(".widget-content")}}]),angular.module("ui.dashboard").controller("WidgetSettingsCtrl",["$scope","$uibModalInstance","widget",function(t,e,n){t.widget=n,t.result=jQuery.extend(!0,{},n),t.ok=function(){e.close(t.result)},t.cancel=function(){e.dismiss("cancel")}}]),angular.module("ui.dashboard").factory("WidgetModel",["$log",function(t){function e(){return{title:"Widget",style:{},size:{},enableVerticalResize:!0,containerStyle:{width:"33%"},contentStyle:{}}}function n(t,n){angular.extend(this,e(),_.merge(angular.copy(t),n)),this.updateContainerStyle(this.style),this.templateUrl||this.template||this.directive||(this.directive=t.name),this.size&&_.has(this.size,"height")&&this.setHeight(this.size.height),this.style&&_.has(this.style,"width")&&this.setWidth(this.style.width),this.size&&_.has(this.size,"width")&&this.setWidth(this.size.width)}return n.prototype={setWidth:function(e,n){return e=e.toString(),n=n||e.replace(/^[-\.\d]+/,"")||"%",this.widthUnits=n,e=parseFloat(e),0>e||isNaN(e)?(t.warn("malhar-angular-dashboard: setWidth was called when width was "+e),!1):("%"===n&&(e=Math.min(100,e),e=Math.max(0,e)),this.containerStyle.width=e+""+n,this.updateSize(this.containerStyle),!0)},setHeight:function(t){this.contentStyle.height=t,this.updateSize(this.contentStyle)},setStyle:function(t){this.style=t,this.updateContainerStyle(t)},updateSize:function(t){angular.extend(this.size,t)},updateContainerStyle:function(t){angular.extend(this.containerStyle,t)},serialize:function(){return _.pick(this,["title","name","style","size","dataModelOptions","attrs","storageHash"])}},n}]),angular.module("ui.dashboard").factory("WidgetDefCollection",function(){function t(t){return"function"==typeof t?new t:t}function e(e){e=e.map(t),this.push.apply(this,e);var n={};_.each(e,function(t){n[t.name]=t}),this.map=n}return e.prototype=Object.create(Array.prototype),e.prototype.getByName=function(t){return this.map[t]},e.prototype.add=function(e){e=t(e),this.push(e),this.map[e.name]=e},e}),angular.module("ui.dashboard").factory("WidgetDataModel",function(){function t(){}return t.prototype={setup:function(t,e){this.dataAttrName=t.dataAttrName,this.dataModelOptions=t.dataModelOptions,this.widgetScope=e},updateScope:function(t){this.widgetScope.widgetData=t},init:function(){},destroy:function(){}},t}),angular.module("ui.dashboard").factory("LayoutStorage",function(){function t(t){var n={storage:e,storageHash:"",stringifyStorage:!0};angular.extend(n,t),angular.extend(t,n),this.id=t.storageId,this.storage=t.storage,this.storageHash=t.storageHash,this.stringifyStorage=t.stringifyStorage,this.widgetDefinitions=t.widgetDefinitions,this.defaultLayouts=t.defaultLayouts,this.lockDefaultLayouts=t.lockDefaultLayouts,this.widgetButtons=t.widgetButtons,this.explicitSave=t.explicitSave,this.defaultWidgets=t.defaultWidgets,this.settingsModalOptions=t.settingsModalOptions,this.onSettingsClose=t.onSettingsClose,this.onSettingsDismiss=t.onSettingsDismiss,this.options=t,this.options.unsavedChangeCount=0,this.layouts=[],this.states={},this.load(),this._ensureActiveLayout()}var e={setItem:function(){},getItem:function(){},removeItem:function(){}};return t.prototype={add:function(t){angular.isArray(t)||(t=[t]);var e=this;angular.forEach(t,function(t){t.dashboard=t.dashboard||{},t.dashboard.storage=e,t.dashboard.storageId=t.id=e._getLayoutId.call(e,t),t.dashboard.widgetDefinitions=t.widgetDefinitions||e.widgetDefinitions,t.dashboard.stringifyStorage=!1,t.dashboard.defaultWidgets=t.defaultWidgets||e.defaultWidgets,t.dashboard.widgetButtons=e.widgetButtons,t.dashboard.explicitSave=e.explicitSave,t.dashboard.settingsModalOptions=e.settingsModalOptions,t.dashboard.onSettingsClose=e.onSettingsClose,t.dashboard.onSettingsDismiss=e.onSettingsDismiss,e.layouts.push(t)})},remove:function(t){var e=this.layouts.indexOf(t);if(e>=0&&(this.layouts.splice(e,1),delete this.states[t.id],t.active&&this.layouts.length)){var n=e>0?e-1:0;this.layouts[n].active=!0}},save:function(){var t={layouts:this._serializeLayouts(),states:this.states,storageHash:this.storageHash};this.stringifyStorage&&(t=JSON.stringify(t)),this.storage.setItem(this.id,t),this.options.unsavedChangeCount=0},load:function(){var t=this.storage.getItem(this.id);this.clear(),t?angular.isObject(t)&&angular.isFunction(t.then)?this._handleAsyncLoad(t):this._handleSyncLoad(t):this._addDefaultLayouts()},clear:function(){this.layouts=[],this.states={}},setItem:function(t,e){this.states[t]=e,this.save()},getItem:function(t){return this.states[t]},removeItem:function(t){delete this.states[t],this.save()},getActiveLayout:function(){for(var t=this.layouts.length,e=0;t>e;e++){var n=this.layouts[e];if(n.active)return n}return!1},_addDefaultLayouts:function(){var t=this,e=this.lockDefaultLayouts?{locked:!0}:{};angular.forEach(this.defaultLayouts,function(n){t.add(angular.extend(_.clone(e),n))})},_serializeLayouts:function(){var t=[];return angular.forEach(this.layouts,function(e){t.push({title:e.title,id:e.id,active:e.active,locked:e.locked,defaultWidgets:e.dashboard.defaultWidgets})}),t},_handleSyncLoad:function(t){var e;if(this.stringifyStorage)try{e=JSON.parse(t)}catch(n){return void this._addDefaultLayouts()}else e=t;return this.storageHash!==e.storageHash?void this._addDefaultLayouts():(this.states=e.states,void this.add(e.layouts))},_handleAsyncLoad:function(t){var e=this;t.then(angular.bind(e,this._handleSyncLoad),angular.bind(e,this._addDefaultLayouts))},_ensureActiveLayout:function(){for(var t=0;t<this.layouts.length;t++){var e=this.layouts[t];if(e.active)return}this.layouts[0]&&(this.layouts[0].active=!0)},_getLayoutId:function(t){if(t.id)return t.id;for(var e=0,n=0;n<this.layouts.length;n++){var i=this.layouts[n].id;e=Math.max(e,1*i)}return e+1}},t}),angular.module("ui.dashboard").factory("DashboardState",["$log","$q",function(t,e){function n(t,e,n,i,r){this.storage=t,this.id=e,this.hash=n,this.widgetDefinitions=i,this.stringify=r}return n.prototype={save:function(t){if(!this.storage)return!0;var e=_.map(t,function(t){return t.serialize()}),n={widgets:e,hash:this.hash};return this.stringify&&(n=JSON.stringify(n)),this.storage.setItem(this.id,n),!0},load:function(){if(!this.storage)return null;var t;return t=this.storage.getItem(this.id),t?angular.isObject(t)&&angular.isFunction(t.then)?this._handleAsyncLoad(t):this._handleSyncLoad(t):null},_handleSyncLoad:function(e){var n,i=[];if(!e)return null;if(this.stringify)try{n=JSON.parse(e)}catch(r){return t.warn("Serialized dashboard state was malformed and could not be parsed: ",e),null}else n=e;if(n.hash!==this.hash)return t.info("Serialized dashboard from storage was stale (old hash: "+n.hash+", new hash: "+this.hash+")"),this.storage.removeItem(this.id),null;for(var o=n.widgets,a=0;a<o.length;a++){var s=o[a],u=this.widgetDefinitions.getByName(s.name);u?u.hasOwnProperty("storageHash")&&u.storageHash!==s.storageHash?t.info('Widget Definition Object with name "'+s.name+'" was found but the storageHash property on the widget definition is different from that on the serialized widget loaded from storage. hash from storage: "'+s.storageHash+'", hash from WDO: "'+u.storageHash+'"'):i.push(s):t.warn('Widget with name "'+s.name+'" was not found in given widget definition objects')}return i},_handleAsyncLoad:function(t){var n=this,i=e.defer();return t.then(function(t){var e=n._handleSyncLoad(t);e?i.resolve(e):i.reject(e)},function(t){i.reject(t)}),i.promise}},n}]),!function(){function t(t){return t&&(t.ownerDocument||t.document||t).documentElement}function e(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}function n(t,e){return e>t?-1:t>e?1:t>=e?0:NaN}function i(t){return null===t?NaN:+t}function r(t){return!isNaN(t)}function o(t){return{left:function(e,n,i,r){for(arguments.length<3&&(i=0),arguments.length<4&&(r=e.length);r>i;){var o=i+r>>>1;t(e[o],n)<0?i=o+1:r=o}return i},right:function(e,n,i,r){for(arguments.length<3&&(i=0),arguments.length<4&&(r=e.length);r>i;){var o=i+r>>>1;t(e[o],n)>0?r=o:i=o+1}return i}}}function a(t){return t.length}function s(t){for(var e=1;t*e%1;)e*=10;return e}function u(t,e){for(var n in e)Object.defineProperty(t.prototype,n,{value:e[n],enumerable:!1})}function l(){this._=Object.create(null)}function c(t){return(t+="")===wa||t[0]===_a?_a+t:t}function d(t){return(t+="")[0]===_a?t.slice(1):t}function h(t){return c(t)in this._}function f(t){return(t=c(t))in this._&&delete this._[t]}function p(){var t=[];for(var e in this._)t.push(d(e));return t}function g(){var t=0;for(var e in this._)++t;return t}function m(){for(var t in this._)return!1;return!0}function v(){this._=Object.create(null)}function y(t){return t}function b(t,e,n){return function(){var i=n.apply(e,arguments);return i===e?t:i}}function x(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var n=0,i=$a.length;i>n;++n){var r=$a[n]+e;if(r in t)return r}}function w(){}function _(){}function $(t){function e(){for(var e,i=n,r=-1,o=i.length;++r<o;)(e=i[r].on)&&e.apply(this,arguments);return t}var n=[],i=new l;return e.on=function(e,r){var o,a=i.get(e);return arguments.length<2?a&&a.on:(a&&(a.on=null,n=n.slice(0,o=n.indexOf(a)).concat(n.slice(o+1)),i.remove(e)),r&&n.push(i.set(e,{on:r})),t)},e}function k(){ua.event.preventDefault()}function C(){for(var t,e=ua.event;t=e.sourceEvent;)e=t;return e}function M(t){for(var e=new _,n=0,i=arguments.length;++n<i;)e[arguments[n]]=$(e);return e.of=function(n,i){return function(r){try{var o=r.sourceEvent=ua.event;r.target=t,ua.event=r,e[r.type].apply(n,i)}finally{ua.event=o}}},e}function D(t){return Ca(t,Ta),t}function S(t){return"function"==typeof t?t:function(){return Ma(t,this)}}function T(t){return"function"==typeof t?t:function(){return Da(t,this)}}function A(t,e){function n(){this.removeAttribute(t)}function i(){this.removeAttributeNS(t.space,t.local)}function r(){this.setAttribute(t,e)}function o(){this.setAttributeNS(t.space,t.local,e)}function a(){var n=e.apply(this,arguments);null==n?this.removeAttribute(t):this.setAttribute(t,n)}function s(){var n=e.apply(this,arguments);null==n?this.removeAttributeNS(t.space,t.local):this.setAttributeNS(t.space,t.local,n)}return t=ua.ns.qualify(t),null==e?t.local?i:n:"function"==typeof e?t.local?s:a:t.local?o:r}function E(t){return t.trim().replace(/\s+/g," ")}function O(t){return new RegExp("(?:^|\\s+)"+ua.requote(t)+"(?:\\s+|$)","g")}function N(t){return(t+"").trim().split(/^|\s+/)}function I(t,e){function n(){for(var n=-1;++n<r;)t[n](this,e)}function i(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}t=N(t).map(P);var r=t.length;return"function"==typeof e?i:n}function P(t){var e=O(t);return function(n,i){
if(r=n.classList)return i?r.add(t):r.remove(t);var r=n.getAttribute("class")||"";i?(e.lastIndex=0,e.test(r)||n.setAttribute("class",E(r+" "+t))):n.setAttribute("class",E(r.replace(e," ")))}}function F(t,e,n){function i(){this.style.removeProperty(t)}function r(){this.style.setProperty(t,e,n)}function o(){var i=e.apply(this,arguments);null==i?this.style.removeProperty(t):this.style.setProperty(t,i,n)}return null==e?i:"function"==typeof e?o:r}function W(t,e){function n(){delete this[t]}function i(){this[t]=e}function r(){var n=e.apply(this,arguments);null==n?delete this[t]:this[t]=n}return null==e?n:"function"==typeof e?r:i}function H(t){function e(){var e=this.ownerDocument,n=this.namespaceURI;return n===Aa&&e.documentElement.namespaceURI===Aa?e.createElement(t):e.createElementNS(n,t)}function n(){return this.ownerDocument.createElementNS(t.space,t.local)}return"function"==typeof t?t:(t=ua.ns.qualify(t)).local?n:e}function L(){var t=this.parentNode;t&&t.removeChild(this)}function z(t){return{__data__:t}}function j(t){return function(){return Sa(this,t)}}function R(t){return arguments.length||(t=n),function(e,n){return e&&n?t(e.__data__,n.__data__):!e-!n}}function U(t,e){for(var n=0,i=t.length;i>n;n++)for(var r,o=t[n],a=0,s=o.length;s>a;a++)(r=o[a])&&e(r,a,n);return t}function q(t){return Ca(t,Oa),t}function B(t){var e,n;return function(i,r,o){var a,s=t[o].update,u=s.length;for(o!=n&&(n=o,e=0),r>=e&&(e=r+1);!(a=s[e])&&++e<u;);return a}}function V(t,e,n){function i(){var e=this[a];e&&(this.removeEventListener(t,e,e.$),delete this[a])}function r(){var r=u(e,ca(arguments));i.call(this),this.addEventListener(t,this[a]=r,r.$=n),r._=e}function o(){var e,n=new RegExp("^__on([^.]+)"+ua.requote(t)+"$");for(var i in this)if(e=i.match(n)){var r=this[i];this.removeEventListener(e[1],r,r.$),delete this[i]}}var a="__on"+t,s=t.indexOf("."),u=Y;s>0&&(t=t.slice(0,s));var l=Na.get(t);return l&&(t=l,u=G),s?e?r:i:e?w:o}function Y(t,e){return function(n){var i=ua.event;ua.event=n,e[0]=this.__data__;try{t.apply(this,e)}finally{ua.event=i}}}function G(t,e){var n=Y(t,e);return function(t){var e=this,i=t.relatedTarget;i&&(i===e||8&i.compareDocumentPosition(e))||n.call(e,t)}}function X(n){var i=".dragsuppress-"+ ++Pa,r="click"+i,o=ua.select(e(n)).on("touchmove"+i,k).on("dragstart"+i,k).on("selectstart"+i,k);if(null==Ia&&(Ia="onselectstart"in n?!1:x(n.style,"userSelect")),Ia){var a=t(n).style,s=a[Ia];a[Ia]="none"}return function(t){if(o.on(i,null),Ia&&(a[Ia]=s),t){var e=function(){o.on(r,null)};o.on(r,function(){k(),e()},!0),setTimeout(e,0)}}}function K(t,n){n.changedTouches&&(n=n.changedTouches[0]);var i=t.ownerSVGElement||t;if(i.createSVGPoint){var r=i.createSVGPoint();if(0>Fa){var o=e(t);if(o.scrollX||o.scrollY){i=ua.select("body").append("svg").style({position:"absolute",top:0,left:0,margin:0,padding:0,border:"none"},"important");var a=i[0][0].getScreenCTM();Fa=!(a.f||a.e),i.remove()}}return Fa?(r.x=n.pageX,r.y=n.pageY):(r.x=n.clientX,r.y=n.clientY),r=r.matrixTransform(t.getScreenCTM().inverse()),[r.x,r.y]}var s=t.getBoundingClientRect();return[n.clientX-s.left-t.clientLeft,n.clientY-s.top-t.clientTop]}function Z(){return ua.event.changedTouches[0].identifier}function Q(t){return t>0?1:0>t?-1:0}function J(t,e,n){return(e[0]-t[0])*(n[1]-t[1])-(e[1]-t[1])*(n[0]-t[0])}function tt(t){return t>1?0:-1>t?La:Math.acos(t)}function et(t){return t>1?Ra:-1>t?-Ra:Math.asin(t)}function nt(t){return((t=Math.exp(t))-1/t)/2}function it(t){return((t=Math.exp(t))+1/t)/2}function rt(t){return((t=Math.exp(2*t))-1)/(t+1)}function ot(t){return(t=Math.sin(t/2))*t}function at(){}function st(t,e,n){return this instanceof st?(this.h=+t,this.s=+e,void(this.l=+n)):arguments.length<2?t instanceof st?new st(t.h,t.s,t.l):wt(""+t,_t,st):new st(t,e,n)}function ut(t,e,n){function i(t){return t>360?t-=360:0>t&&(t+=360),60>t?o+(a-o)*t/60:180>t?a:240>t?o+(a-o)*(240-t)/60:o}function r(t){return Math.round(255*i(t))}var o,a;return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:0>e?0:e>1?1:e,n=0>n?0:n>1?1:n,a=.5>=n?n*(1+e):n+e-n*e,o=2*n-a,new vt(r(t+120),r(t),r(t-120))}function lt(t,e,n){return this instanceof lt?(this.h=+t,this.c=+e,void(this.l=+n)):arguments.length<2?t instanceof lt?new lt(t.h,t.c,t.l):t instanceof dt?ft(t.l,t.a,t.b):ft((t=$t((t=ua.rgb(t)).r,t.g,t.b)).l,t.a,t.b):new lt(t,e,n)}function ct(t,e,n){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new dt(n,Math.cos(t*=Ua)*e,Math.sin(t)*e)}function dt(t,e,n){return this instanceof dt?(this.l=+t,this.a=+e,void(this.b=+n)):arguments.length<2?t instanceof dt?new dt(t.l,t.a,t.b):t instanceof lt?ct(t.h,t.c,t.l):$t((t=vt(t)).r,t.g,t.b):new dt(t,e,n)}function ht(t,e,n){var i=(t+16)/116,r=i+e/500,o=i-n/200;return r=pt(r)*ts,i=pt(i)*es,o=pt(o)*ns,new vt(mt(3.2404542*r-1.5371385*i-.4985314*o),mt(-.969266*r+1.8760108*i+.041556*o),mt(.0556434*r-.2040259*i+1.0572252*o))}function ft(t,e,n){return t>0?new lt(Math.atan2(n,e)*qa,Math.sqrt(e*e+n*n),t):new lt(NaN,NaN,t)}function pt(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function gt(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function mt(t){return Math.round(255*(.00304>=t?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function vt(t,e,n){return this instanceof vt?(this.r=~~t,this.g=~~e,void(this.b=~~n)):arguments.length<2?t instanceof vt?new vt(t.r,t.g,t.b):wt(""+t,vt,ut):new vt(t,e,n)}function yt(t){return new vt(t>>16,t>>8&255,255&t)}function bt(t){return yt(t)+""}function xt(t){return 16>t?"0"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function wt(t,e,n){var i,r,o,a=0,s=0,u=0;if(i=/([a-z]+)\((.*)\)/.exec(t=t.toLowerCase()))switch(r=i[2].split(","),i[1]){case"hsl":return n(parseFloat(r[0]),parseFloat(r[1])/100,parseFloat(r[2])/100);case"rgb":return e(Ct(r[0]),Ct(r[1]),Ct(r[2]))}return(o=os.get(t))?e(o.r,o.g,o.b):(null==t||"#"!==t.charAt(0)||isNaN(o=parseInt(t.slice(1),16))||(4===t.length?(a=(3840&o)>>4,a=a>>4|a,s=240&o,s=s>>4|s,u=15&o,u=u<<4|u):7===t.length&&(a=(16711680&o)>>16,s=(65280&o)>>8,u=255&o)),e(a,s,u))}function _t(t,e,n){var i,r,o=Math.min(t/=255,e/=255,n/=255),a=Math.max(t,e,n),s=a-o,u=(a+o)/2;return s?(r=.5>u?s/(a+o):s/(2-a-o),i=t==a?(e-n)/s+(n>e?6:0):e==a?(n-t)/s+2:(t-e)/s+4,i*=60):(i=NaN,r=u>0&&1>u?0:i),new st(i,r,u)}function $t(t,e,n){t=kt(t),e=kt(e),n=kt(n);var i=gt((.4124564*t+.3575761*e+.1804375*n)/ts),r=gt((.2126729*t+.7151522*e+.072175*n)/es),o=gt((.0193339*t+.119192*e+.9503041*n)/ns);return dt(116*r-16,500*(i-r),200*(r-o))}function kt(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function Ct(t){var e=parseFloat(t);return"%"===t.charAt(t.length-1)?Math.round(2.55*e):e}function Mt(t){return"function"==typeof t?t:function(){return t}}function Dt(t){return function(e,n,i){return 2===arguments.length&&"function"==typeof n&&(i=n,n=null),St(e,n,t,i)}}function St(t,e,n,i){function r(){var t,e=u.status;if(!e&&At(u)||e>=200&&300>e||304===e){try{t=n.call(o,u)}catch(i){return void a.error.call(o,i)}a.load.call(o,t)}else a.error.call(o,u)}var o={},a=ua.dispatch("beforesend","progress","load","error"),s={},u=new XMLHttpRequest,l=null;return!this.XDomainRequest||"withCredentials"in u||!/^(http(s)?:)?\/\//.test(t)||(u=new XDomainRequest),"onload"in u?u.onload=u.onerror=r:u.onreadystatechange=function(){u.readyState>3&&r()},u.onprogress=function(t){var e=ua.event;ua.event=t;try{a.progress.call(o,u)}finally{ua.event=e}},o.header=function(t,e){return t=(t+"").toLowerCase(),arguments.length<2?s[t]:(null==e?delete s[t]:s[t]=e+"",o)},o.mimeType=function(t){return arguments.length?(e=null==t?null:t+"",o):e},o.responseType=function(t){return arguments.length?(l=t,o):l},o.response=function(t){return n=t,o},["get","post"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(ca(arguments)))}}),o.send=function(n,i,r){if(2===arguments.length&&"function"==typeof i&&(r=i,i=null),u.open(n,t,!0),null==e||"accept"in s||(s.accept=e+",*/*"),u.setRequestHeader)for(var c in s)u.setRequestHeader(c,s[c]);return null!=e&&u.overrideMimeType&&u.overrideMimeType(e),null!=l&&(u.responseType=l),null!=r&&o.on("error",r).on("load",function(t){r(null,t)}),a.beforesend.call(o,u),u.send(null==i?null:i),o},o.abort=function(){return u.abort(),o},ua.rebind(o,a,"on"),null==i?o:o.get(Tt(i))}function Tt(t){return 1===t.length?function(e,n){t(null==e?n:null)}:t}function At(t){var e=t.responseType;return e&&"text"!==e?t.response:t.responseText}function Et(t,e,n){var i=arguments.length;2>i&&(e=0),3>i&&(n=Date.now());var r=n+e,o={c:t,t:r,n:null};return ss?ss.n=o:as=o,ss=o,us||(ls=clearTimeout(ls),us=1,cs(Ot)),o}function Ot(){var t=Nt(),e=It()-t;e>24?(isFinite(e)&&(clearTimeout(ls),ls=setTimeout(Ot,e)),us=0):(us=1,cs(Ot))}function Nt(){for(var t=Date.now(),e=as;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function It(){for(var t,e=as,n=1/0;e;)e.c?(e.t<n&&(n=e.t),e=(t=e).n):e=t?t.n=e.n:as=e.n;return ss=t,n}function Pt(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}function Ft(t,e){var n=Math.pow(10,3*xa(8-e));return{scale:e>8?function(t){return t/n}:function(t){return t*n},symbol:t}}function Wt(t){var e=t.decimal,n=t.thousands,i=t.grouping,r=t.currency,o=i&&n?function(t,e){for(var r=t.length,o=[],a=0,s=i[0],u=0;r>0&&s>0&&(u+s+1>e&&(s=Math.max(1,e-u)),o.push(t.substring(r-=s,r+s)),!((u+=s+1)>e));)s=i[a=(a+1)%i.length];return o.reverse().join(n)}:y;return function(t){var n=hs.exec(t),i=n[1]||" ",a=n[2]||">",s=n[3]||"-",u=n[4]||"",l=n[5],c=+n[6],d=n[7],h=n[8],f=n[9],p=1,g="",m="",v=!1,y=!0;switch(h&&(h=+h.substring(1)),(l||"0"===i&&"="===a)&&(l=i="0",a="="),f){case"n":d=!0,f="g";break;case"%":p=100,m="%",f="f";break;case"p":p=100,m="%",f="r";break;case"b":case"o":case"x":case"X":"#"===u&&(g="0"+f.toLowerCase());case"c":y=!1;case"d":v=!0,h=0;break;case"s":p=-1,f="r"}"$"===u&&(g=r[0],m=r[1]),"r"!=f||h||(f="g"),null!=h&&("g"==f?h=Math.max(1,Math.min(21,h)):("e"==f||"f"==f)&&(h=Math.max(0,Math.min(20,h)))),f=fs.get(f)||Ht;var b=l&&d;return function(t){var n=m;if(v&&t%1)return"";var r=0>t||0===t&&0>1/t?(t=-t,"-"):"-"===s?"":s;if(0>p){var u=ua.formatPrefix(t,h);t=u.scale(t),n=u.symbol+m}else t*=p;t=f(t,h);var x,w,_=t.lastIndexOf(".");if(0>_){var $=y?t.lastIndexOf("e"):-1;0>$?(x=t,w=""):(x=t.substring(0,$),w=t.substring($))}else x=t.substring(0,_),w=e+t.substring(_+1);!l&&d&&(x=o(x,1/0));var k=g.length+x.length+w.length+(b?0:r.length),C=c>k?new Array(k=c-k+1).join(i):"";return b&&(x=o(C+x,C.length?c-w.length:1/0)),r+=g,t=x+w,("<"===a?r+t+C:">"===a?C+r+t:"^"===a?C.substring(0,k>>=1)+r+t+C.substring(k):r+(b?t:C+t))+n}}}function Ht(t){return t+""}function Lt(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}function zt(t,e,n){function i(e){var n=t(e),i=o(n,1);return i-e>e-n?n:i}function r(n){return e(n=t(new gs(n-1)),1),n}function o(t,n){return e(t=new gs(+t),n),t}function a(t,i,o){var a=r(t),s=[];if(o>1)for(;i>a;)n(a)%o||s.push(new Date(+a)),e(a,1);else for(;i>a;)s.push(new Date(+a)),e(a,1);return s}function s(t,e,n){try{gs=Lt;var i=new Lt;return i._=t,a(i,e,n)}finally{gs=Date}}t.floor=t,t.round=i,t.ceil=r,t.offset=o,t.range=a;var u=t.utc=jt(t);return u.floor=u,u.round=jt(i),u.ceil=jt(r),u.offset=jt(o),u.range=s,t}function jt(t){return function(e,n){try{gs=Lt;var i=new Lt;return i._=e,t(i,n)._}finally{gs=Date}}}function Rt(t){function e(t){function e(e){for(var n,r,o,a=[],s=-1,u=0;++s<i;)37===t.charCodeAt(s)&&(a.push(t.slice(u,s)),null!=(r=vs[n=t.charAt(++s)])&&(n=t.charAt(++s)),(o=S[n])&&(n=o(e,null==r?"e"===n?" ":"0":r)),a.push(n),u=s+1);return a.push(t.slice(u,s)),a.join("")}var i=t.length;return e.parse=function(e){var i={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null},r=n(i,t,e,0);if(r!=e.length)return null;"p"in i&&(i.H=i.H%12+12*i.p);var o=null!=i.Z&&gs!==Lt,a=new(o?Lt:gs);return"j"in i?a.setFullYear(i.y,0,i.j):"W"in i||"U"in i?("w"in i||(i.w="W"in i?1:0),a.setFullYear(i.y,0,1),a.setFullYear(i.y,0,"W"in i?(i.w+6)%7+7*i.W-(a.getDay()+5)%7:i.w+7*i.U-(a.getDay()+6)%7)):a.setFullYear(i.y,i.m,i.d),a.setHours(i.H+(i.Z/100|0),i.M+i.Z%100,i.S,i.L),o?a._:a},e.toString=function(){return t},e}function n(t,e,n,i){for(var r,o,a,s=0,u=e.length,l=n.length;u>s;){if(i>=l)return-1;if(r=e.charCodeAt(s++),37===r){if(a=e.charAt(s++),o=T[a in vs?e.charAt(s++):a],!o||(i=o(t,n,i))<0)return-1}else if(r!=n.charCodeAt(i++))return-1}return i}function i(t,e,n){_.lastIndex=0;var i=_.exec(e.slice(n));return i?(t.w=$.get(i[0].toLowerCase()),n+i[0].length):-1}function r(t,e,n){x.lastIndex=0;var i=x.exec(e.slice(n));return i?(t.w=w.get(i[0].toLowerCase()),n+i[0].length):-1}function o(t,e,n){M.lastIndex=0;var i=M.exec(e.slice(n));return i?(t.m=D.get(i[0].toLowerCase()),n+i[0].length):-1}function a(t,e,n){k.lastIndex=0;var i=k.exec(e.slice(n));return i?(t.m=C.get(i[0].toLowerCase()),n+i[0].length):-1}function s(t,e,i){return n(t,S.c.toString(),e,i)}function u(t,e,i){return n(t,S.x.toString(),e,i)}function l(t,e,i){return n(t,S.X.toString(),e,i)}function c(t,e,n){var i=b.get(e.slice(n,n+=2).toLowerCase());return null==i?-1:(t.p=i,n)}var d=t.dateTime,h=t.date,f=t.time,p=t.periods,g=t.days,m=t.shortDays,v=t.months,y=t.shortMonths;e.utc=function(t){function n(t){try{gs=Lt;var e=new gs;return e._=t,i(e)}finally{gs=Date}}var i=e(t);return n.parse=function(t){try{gs=Lt;var e=i.parse(t);return e&&e._}finally{gs=Date}},n.toString=i.toString,n},e.multi=e.utc.multi=ue;var b=ua.map(),x=qt(g),w=Bt(g),_=qt(m),$=Bt(m),k=qt(v),C=Bt(v),M=qt(y),D=Bt(y);p.forEach(function(t,e){b.set(t.toLowerCase(),e)});var S={a:function(t){return m[t.getDay()]},A:function(t){return g[t.getDay()]},b:function(t){return y[t.getMonth()]},B:function(t){return v[t.getMonth()]},c:e(d),d:function(t,e){return Ut(t.getDate(),e,2)},e:function(t,e){return Ut(t.getDate(),e,2)},H:function(t,e){return Ut(t.getHours(),e,2)},I:function(t,e){return Ut(t.getHours()%12||12,e,2)},j:function(t,e){return Ut(1+ps.dayOfYear(t),e,3)},L:function(t,e){return Ut(t.getMilliseconds(),e,3)},m:function(t,e){return Ut(t.getMonth()+1,e,2)},M:function(t,e){return Ut(t.getMinutes(),e,2)},p:function(t){return p[+(t.getHours()>=12)]},S:function(t,e){return Ut(t.getSeconds(),e,2)},U:function(t,e){return Ut(ps.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ut(ps.mondayOfYear(t),e,2)},x:e(h),X:e(f),y:function(t,e){return Ut(t.getFullYear()%100,e,2)},Y:function(t,e){return Ut(t.getFullYear()%1e4,e,4)},Z:ae,"%":function(){return"%"}},T={a:i,A:r,b:o,B:a,c:s,d:te,e:te,H:ne,I:ne,j:ee,L:oe,m:Jt,M:ie,p:c,S:re,U:Yt,w:Vt,W:Gt,x:u,X:l,y:Kt,Y:Xt,Z:Zt,"%":se};return e}function Ut(t,e,n){var i=0>t?"-":"",r=(i?-t:t)+"",o=r.length;return i+(n>o?new Array(n-o+1).join(e)+r:r)}function qt(t){return new RegExp("^(?:"+t.map(ua.requote).join("|")+")","i")}function Bt(t){for(var e=new l,n=-1,i=t.length;++n<i;)e.set(t[n].toLowerCase(),n);return e}function Vt(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n,n+1));return i?(t.w=+i[0],n+i[0].length):-1}function Yt(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n));return i?(t.U=+i[0],n+i[0].length):-1}function Gt(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n));return i?(t.W=+i[0],n+i[0].length):-1}function Xt(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n,n+4));return i?(t.y=+i[0],n+i[0].length):-1}function Kt(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n,n+2));return i?(t.y=Qt(+i[0]),n+i[0].length):-1}function Zt(t,e,n){return/^[+-]\d{4}$/.test(e=e.slice(n,n+5))?(t.Z=-e,n+5):-1}function Qt(t){return t+(t>68?1900:2e3)}function Jt(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n,n+2));return i?(t.m=i[0]-1,n+i[0].length):-1}function te(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n,n+2));return i?(t.d=+i[0],n+i[0].length):-1}function ee(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n,n+3));return i?(t.j=+i[0],n+i[0].length):-1}function ne(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n,n+2));return i?(t.H=+i[0],n+i[0].length):-1}function ie(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n,n+2));return i?(t.M=+i[0],n+i[0].length):-1}function re(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n,n+2));return i?(t.S=+i[0],n+i[0].length):-1}function oe(t,e,n){ys.lastIndex=0;var i=ys.exec(e.slice(n,n+3));return i?(t.L=+i[0],n+i[0].length):-1}function ae(t){var e=t.getTimezoneOffset(),n=e>0?"-":"+",i=xa(e)/60|0,r=xa(e)%60;return n+Ut(i,"0",2)+Ut(r,"0",2)}function se(t,e,n){bs.lastIndex=0;var i=bs.exec(e.slice(n,n+1));return i?n+i[0].length:-1}function ue(t){for(var e=t.length,n=-1;++n<e;)t[n][0]=this(t[n][0]);return function(e){for(var n=0,i=t[n];!i[1](e);)i=t[++n];return i[0](e)}}function le(){}function ce(t,e,n){var i=n.s=t+e,r=i-t,o=i-r;n.t=t-o+(e-r)}function de(t,e){t&&$s.hasOwnProperty(t.type)&&$s[t.type](t,e)}function he(t,e,n){var i,r=-1,o=t.length-n;for(e.lineStart();++r<o;)i=t[r],e.point(i[0],i[1],i[2]);e.lineEnd()}function fe(t,e){var n=-1,i=t.length;for(e.polygonStart();++n<i;)he(t[n],e,1);e.polygonEnd()}function pe(){function t(t,e){t*=Ua,e=e*Ua/2+La/4;var n=t-i,a=n>=0?1:-1,s=a*n,u=Math.cos(e),l=Math.sin(e),c=o*l,d=r*u+c*Math.cos(s),h=c*a*Math.sin(s);Cs.add(Math.atan2(h,d)),i=t,r=u,o=l}var e,n,i,r,o;Ms.point=function(a,s){Ms.point=t,i=(e=a)*Ua,r=Math.cos(s=(n=s)*Ua/2+La/4),o=Math.sin(s)},Ms.lineEnd=function(){t(e,n)}}function ge(t){var e=t[0],n=t[1],i=Math.cos(n);return[i*Math.cos(e),i*Math.sin(e),Math.sin(n)]}function me(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function ve(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function ye(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function be(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function xe(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function we(t){return[Math.atan2(t[1],t[0]),et(t[2])]}function _e(t,e){return xa(t[0]-e[0])<Wa&&xa(t[1]-e[1])<Wa}function $e(t,e){t*=Ua;var n=Math.cos(e*=Ua);ke(n*Math.cos(t),n*Math.sin(t),Math.sin(e))}function ke(t,e,n){++Ds,Ts+=(t-Ts)/Ds,As+=(e-As)/Ds,Es+=(n-Es)/Ds}function Ce(){function t(t,r){t*=Ua;var o=Math.cos(r*=Ua),a=o*Math.cos(t),s=o*Math.sin(t),u=Math.sin(r),l=Math.atan2(Math.sqrt((l=n*u-i*s)*l+(l=i*a-e*u)*l+(l=e*s-n*a)*l),e*a+n*s+i*u);Ss+=l,Os+=l*(e+(e=a)),Ns+=l*(n+(n=s)),Is+=l*(i+(i=u)),ke(e,n,i)}var e,n,i;Hs.point=function(r,o){r*=Ua;var a=Math.cos(o*=Ua);e=a*Math.cos(r),n=a*Math.sin(r),i=Math.sin(o),Hs.point=t,ke(e,n,i)}}function Me(){Hs.point=$e}function De(){function t(t,e){t*=Ua;var n=Math.cos(e*=Ua),a=n*Math.cos(t),s=n*Math.sin(t),u=Math.sin(e),l=r*u-o*s,c=o*a-i*u,d=i*s-r*a,h=Math.sqrt(l*l+c*c+d*d),f=i*a+r*s+o*u,p=h&&-tt(f)/h,g=Math.atan2(h,f);Ps+=p*l,Fs+=p*c,Ws+=p*d,Ss+=g,Os+=g*(i+(i=a)),Ns+=g*(r+(r=s)),Is+=g*(o+(o=u)),ke(i,r,o)}var e,n,i,r,o;Hs.point=function(a,s){e=a,n=s,Hs.point=t,a*=Ua;var u=Math.cos(s*=Ua);i=u*Math.cos(a),r=u*Math.sin(a),o=Math.sin(s),ke(i,r,o)},Hs.lineEnd=function(){t(e,n),Hs.lineEnd=Me,Hs.point=$e}}function Se(t,e){function n(n,i){return n=t(n,i),e(n[0],n[1])}return t.invert&&e.invert&&(n.invert=function(n,i){return n=e.invert(n,i),n&&t.invert(n[0],n[1])}),n}function Te(){return!0}function Ae(t,e,n,i,r){var o=[],a=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,n=t[0],i=t[e];if(_e(n,i)){r.lineStart();for(var s=0;e>s;++s)r.point((n=t[s])[0],n[1]);return void r.lineEnd()}var u=new Oe(n,t,null,!0),l=new Oe(n,null,u,!1);u.o=l,o.push(u),a.push(l),u=new Oe(i,t,null,!1),l=new Oe(i,null,u,!0),u.o=l,o.push(u),a.push(l)}}),a.sort(e),Ee(o),Ee(a),o.length){for(var s=0,u=n,l=a.length;l>s;++s)a[s].e=u=!u;for(var c,d,h=o[0];;){for(var f=h,p=!0;f.v;)if((f=f.n)===h)return;c=f.z,r.lineStart();do{if(f.v=f.o.v=!0,f.e){if(p)for(var s=0,l=c.length;l>s;++s)r.point((d=c[s])[0],d[1]);else i(f.x,f.n.x,1,r);f=f.n}else{if(p){c=f.p.z;for(var s=c.length-1;s>=0;--s)r.point((d=c[s])[0],d[1])}else i(f.x,f.p.x,-1,r);f=f.p}f=f.o,c=f.z,p=!p}while(!f.v);r.lineEnd()}}}function Ee(t){if(e=t.length){for(var e,n,i=0,r=t[0];++i<e;)r.n=n=t[i],n.p=r,r=n;r.n=n=t[0],n.p=r}}function Oe(t,e,n,i){this.x=t,this.z=e,this.o=n,this.e=i,this.v=!1,this.n=this.p=null}function Ne(t,e,n,i){return function(r,o){function a(e,n){var i=r(e,n);t(e=i[0],n=i[1])&&o.point(e,n)}function s(t,e){var n=r(t,e);m.point(n[0],n[1])}function u(){y.point=s,m.lineStart()}function l(){y.point=a,m.lineEnd()}function c(t,e){g.push([t,e]);var n=r(t,e);x.point(n[0],n[1])}function d(){x.lineStart(),g=[]}function h(){c(g[0][0],g[0][1]),x.lineEnd();var t,e=x.clean(),n=b.buffer(),i=n.length;if(g.pop(),p.push(g),g=null,i)if(1&e){t=n[0];var r,i=t.length-1,a=-1;if(i>0){for(w||(o.polygonStart(),w=!0),o.lineStart();++a<i;)o.point((r=t[a])[0],r[1]);o.lineEnd()}}else i>1&&2&e&&n.push(n.pop().concat(n.shift())),f.push(n.filter(Ie))}var f,p,g,m=e(o),v=r.invert(i[0],i[1]),y={point:a,lineStart:u,lineEnd:l,polygonStart:function(){y.point=c,y.lineStart=d,y.lineEnd=h,f=[],p=[]},polygonEnd:function(){y.point=a,y.lineStart=u,y.lineEnd=l,f=ua.merge(f);var t=ze(v,p);f.length?(w||(o.polygonStart(),w=!0),Ae(f,Fe,t,n,o)):t&&(w||(o.polygonStart(),w=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),w&&(o.polygonEnd(),w=!1),f=p=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}},b=Pe(),x=e(b),w=!1;return y}}function Ie(t){return t.length>1}function Pe(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,n){t.push([e,n])},lineEnd:w,buffer:function(){var n=e;return e=[],t=null,n},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Fe(t,e){return((t=t.x)[0]<0?t[1]-Ra-Wa:Ra-t[1])-((e=e.x)[0]<0?e[1]-Ra-Wa:Ra-e[1])}function We(t){var e,n=NaN,i=NaN,r=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(o,a){var s=o>0?La:-La,u=xa(o-n);xa(u-La)<Wa?(t.point(n,i=(i+a)/2>0?Ra:-Ra),t.point(r,i),t.lineEnd(),t.lineStart(),t.point(s,i),t.point(o,i),e=0):r!==s&&u>=La&&(xa(n-r)<Wa&&(n-=r*Wa),xa(o-s)<Wa&&(o-=s*Wa),i=He(n,i,o,a),t.point(r,i),t.lineEnd(),t.lineStart(),t.point(s,i),e=0),t.point(n=o,i=a),r=s},lineEnd:function(){t.lineEnd(),n=i=NaN},clean:function(){return 2-e}}}function He(t,e,n,i){var r,o,a=Math.sin(t-n);return xa(a)>Wa?Math.atan((Math.sin(e)*(o=Math.cos(i))*Math.sin(n)-Math.sin(i)*(r=Math.cos(e))*Math.sin(t))/(r*o*a)):(e+i)/2}function Le(t,e,n,i){var r;if(null==t)r=n*Ra,i.point(-La,r),i.point(0,r),i.point(La,r),i.point(La,0),i.point(La,-r),i.point(0,-r),i.point(-La,-r),i.point(-La,0),i.point(-La,r);else if(xa(t[0]-e[0])>Wa){var o=t[0]<e[0]?La:-La;r=n*o/2,i.point(-o,r),i.point(0,r),i.point(o,r)}else i.point(e[0],e[1])}function ze(t,e){var n=t[0],i=t[1],r=[Math.sin(n),-Math.cos(n),0],o=0,a=0;Cs.reset();for(var s=0,u=e.length;u>s;++s){var l=e[s],c=l.length;if(c)for(var d=l[0],h=d[0],f=d[1]/2+La/4,p=Math.sin(f),g=Math.cos(f),m=1;;){m===c&&(m=0),t=l[m];var v=t[0],y=t[1]/2+La/4,b=Math.sin(y),x=Math.cos(y),w=v-h,_=w>=0?1:-1,$=_*w,k=$>La,C=p*b;if(Cs.add(Math.atan2(C*_*Math.sin($),g*x+C*Math.cos($))),o+=k?w+_*za:w,k^h>=n^v>=n){var M=ve(ge(d),ge(t));xe(M);var D=ve(r,M);xe(D);var S=(k^w>=0?-1:1)*et(D[2]);(i>S||i===S&&(M[0]||M[1]))&&(a+=k^w>=0?1:-1)}if(!m++)break;h=v,p=b,g=x,d=t}}return(-Wa>o||Wa>o&&0>Cs)^1&a}function je(t){function e(t,e){return Math.cos(t)*Math.cos(e)>o}function n(t){var n,o,u,l,c;return{lineStart:function(){l=u=!1,c=1},point:function(d,h){var f,p=[d,h],g=e(d,h),m=a?g?0:r(d,h):g?r(d+(0>d?La:-La),h):0;if(!n&&(l=u=g)&&t.lineStart(),g!==u&&(f=i(n,p),(_e(n,f)||_e(p,f))&&(p[0]+=Wa,p[1]+=Wa,g=e(p[0],p[1]))),g!==u)c=0,g?(t.lineStart(),f=i(p,n),t.point(f[0],f[1])):(f=i(n,p),t.point(f[0],f[1]),t.lineEnd()),n=f;else if(s&&n&&a^g){var v;m&o||!(v=i(p,n,!0))||(c=0,a?(t.lineStart(),t.point(v[0][0],v[0][1]),t.point(v[1][0],v[1][1]),t.lineEnd()):(t.point(v[1][0],v[1][1]),t.lineEnd(),t.lineStart(),t.point(v[0][0],v[0][1])))}!g||n&&_e(n,p)||t.point(p[0],p[1]),n=p,u=g,o=m},lineEnd:function(){u&&t.lineEnd(),n=null},clean:function(){return c|(l&&u)<<1}}}function i(t,e,n){var i=ge(t),r=ge(e),a=[1,0,0],s=ve(i,r),u=me(s,s),l=s[0],c=u-l*l;if(!c)return!n&&t;var d=o*u/c,h=-o*l/c,f=ve(a,s),p=be(a,d),g=be(s,h);ye(p,g);var m=f,v=me(p,m),y=me(m,m),b=v*v-y*(me(p,p)-1);if(!(0>b)){var x=Math.sqrt(b),w=be(m,(-v-x)/y);if(ye(w,p),w=we(w),!n)return w;var _,$=t[0],k=e[0],C=t[1],M=e[1];$>k&&(_=$,$=k,k=_);var D=k-$,S=xa(D-La)<Wa,T=S||Wa>D;if(!S&&C>M&&(_=C,C=M,M=_),T?S?C+M>0^w[1]<(xa(w[0]-$)<Wa?C:M):C<=w[1]&&w[1]<=M:D>La^($<=w[0]&&w[0]<=k)){var A=be(m,(-v+x)/y);return ye(A,p),[w,we(A)]}}}function r(e,n){var i=a?t:La-t,r=0;return-i>e?r|=1:e>i&&(r|=2),-i>n?r|=4:n>i&&(r|=8),r}var o=Math.cos(t),a=o>0,s=xa(o)>Wa,u=gn(t,6*Ua);return Ne(e,n,u,a?[0,-t]:[-La,t-La])}function Re(t,e,n,i){return function(r){var o,a=r.a,s=r.b,u=a.x,l=a.y,c=s.x,d=s.y,h=0,f=1,p=c-u,g=d-l;if(o=t-u,p||!(o>0)){if(o/=p,0>p){if(h>o)return;f>o&&(f=o)}else if(p>0){if(o>f)return;o>h&&(h=o)}if(o=n-u,p||!(0>o)){if(o/=p,0>p){if(o>f)return;o>h&&(h=o)}else if(p>0){if(h>o)return;f>o&&(f=o)}if(o=e-l,g||!(o>0)){if(o/=g,0>g){if(h>o)return;f>o&&(f=o)}else if(g>0){if(o>f)return;o>h&&(h=o)}if(o=i-l,g||!(0>o)){if(o/=g,0>g){if(o>f)return;o>h&&(h=o)}else if(g>0){if(h>o)return;f>o&&(f=o)}return h>0&&(r.a={x:u+h*p,y:l+h*g}),1>f&&(r.b={x:u+f*p,y:l+f*g}),r}}}}}}function Ue(t,e,n,i){function r(i,r){return xa(i[0]-t)<Wa?r>0?0:3:xa(i[0]-n)<Wa?r>0?2:1:xa(i[1]-e)<Wa?r>0?1:0:r>0?3:2}function o(t,e){return a(t.x,e.x)}function a(t,e){var n=r(t,1),i=r(e,1);return n!==i?n-i:0===n?e[1]-t[1]:1===n?t[0]-e[0]:2===n?t[1]-e[1]:e[0]-t[0]}return function(s){function u(t){for(var e=0,n=m.length,i=t[1],r=0;n>r;++r)for(var o,a=1,s=m[r],u=s.length,l=s[0];u>a;++a)o=s[a],l[1]<=i?o[1]>i&&J(l,o,t)>0&&++e:o[1]<=i&&J(l,o,t)<0&&--e,l=o;return 0!==e}function l(o,s,u,l){var c=0,d=0;if(null==o||(c=r(o,u))!==(d=r(s,u))||a(o,s)<0^u>0){do l.point(0===c||3===c?t:n,c>1?i:e);while((c=(c+u+4)%4)!==d)}else l.point(s[0],s[1])}function c(r,o){return r>=t&&n>=r&&o>=e&&i>=o}function d(t,e){c(t,e)&&s.point(t,e)}function h(){T.point=p,m&&m.push(v=[]),k=!0,$=!1,w=_=NaN}function f(){g&&(p(y,b),x&&$&&D.rejoin(),g.push(D.buffer())),T.point=d,$&&s.lineEnd()}function p(t,e){t=Math.max(-zs,Math.min(zs,t)),e=Math.max(-zs,Math.min(zs,e));var n=c(t,e);if(m&&v.push([t,e]),k)y=t,b=e,x=n,k=!1,n&&(s.lineStart(),s.point(t,e));else if(n&&$)s.point(t,e);else{var i={a:{x:w,y:_},b:{x:t,y:e}};S(i)?($||(s.lineStart(),s.point(i.a.x,i.a.y)),s.point(i.b.x,i.b.y),n||s.lineEnd(),C=!1):n&&(s.lineStart(),s.point(t,e),C=!1)}w=t,_=e,$=n}var g,m,v,y,b,x,w,_,$,k,C,M=s,D=Pe(),S=Re(t,e,n,i),T={point:d,lineStart:h,lineEnd:f,polygonStart:function(){s=D,g=[],m=[],C=!0},polygonEnd:function(){s=M,g=ua.merge(g);var e=u([t,i]),n=C&&e,r=g.length;(n||r)&&(s.polygonStart(),n&&(s.lineStart(),l(null,null,1,s),s.lineEnd()),r&&Ae(g,o,e,l,s),s.polygonEnd()),g=m=v=null}};return T}}function qe(t){var e=0,n=La/3,i=sn(t),r=i(e,n);return r.parallels=function(t){return arguments.length?i(e=t[0]*La/180,n=t[1]*La/180):[e/La*180,n/La*180]},r}function Be(t,e){function n(t,e){var n=Math.sqrt(o-2*r*Math.sin(e))/r;return[n*Math.sin(t*=r),a-n*Math.cos(t)]}var i=Math.sin(t),r=(i+Math.sin(e))/2,o=1+i*(2*r-i),a=Math.sqrt(o)/r;return n.invert=function(t,e){var n=a-e;return[Math.atan2(t,n)/r,et((o-(t*t+n*n)*r*r)/(2*r))]},n}function Ve(){function t(t,e){Rs+=r*t-i*e,i=t,r=e}var e,n,i,r;Ys.point=function(o,a){Ys.point=t,e=i=o,n=r=a},Ys.lineEnd=function(){t(e,n)}}function Ye(t,e){Us>t&&(Us=t),t>Bs&&(Bs=t),qs>e&&(qs=e),e>Vs&&(Vs=e)}function Ge(){function t(t,e){a.push("M",t,",",e,o)}function e(t,e){a.push("M",t,",",e),s.point=n}function n(t,e){a.push("L",t,",",e)}function i(){s.point=t}function r(){a.push("Z")}var o=Xe(4.5),a=[],s={point:t,lineStart:function(){s.point=e},lineEnd:i,polygonStart:function(){s.lineEnd=r},polygonEnd:function(){s.lineEnd=i,s.point=t},pointRadius:function(t){return o=Xe(t),s},result:function(){if(a.length){var t=a.join("");return a=[],t}}};return s}function Xe(t){return"m0,"+t+"a"+t+","+t+" 0 1,1 0,"+-2*t+"a"+t+","+t+" 0 1,1 0,"+2*t+"z"}function Ke(t,e){Ts+=t,As+=e,++Es}function Ze(){function t(t,i){var r=t-e,o=i-n,a=Math.sqrt(r*r+o*o);Os+=a*(e+t)/2,Ns+=a*(n+i)/2,Is+=a,Ke(e=t,n=i)}var e,n;Xs.point=function(i,r){Xs.point=t,Ke(e=i,n=r)}}function Qe(){Xs.point=Ke}function Je(){function t(t,e){var n=t-i,o=e-r,a=Math.sqrt(n*n+o*o);Os+=a*(i+t)/2,Ns+=a*(r+e)/2,Is+=a,a=r*t-i*e,Ps+=a*(i+t),Fs+=a*(r+e),Ws+=3*a,Ke(i=t,r=e)}var e,n,i,r;Xs.point=function(o,a){Xs.point=t,Ke(e=i=o,n=r=a)},Xs.lineEnd=function(){t(e,n)}}function tn(t){function e(e,n){t.moveTo(e+a,n),t.arc(e,n,a,0,za)}function n(e,n){t.moveTo(e,n),s.point=i}function i(e,n){t.lineTo(e,n)}function r(){s.point=e}function o(){t.closePath()}var a=4.5,s={point:e,lineStart:function(){s.point=n},lineEnd:r,polygonStart:function(){s.lineEnd=o},polygonEnd:function(){s.lineEnd=r,s.point=e},pointRadius:function(t){return a=t,s},result:w};return s}function en(t){function e(t){return(s?i:n)(t)}function n(e){return on(e,function(n,i){n=t(n,i),e.point(n[0],n[1])})}function i(e){function n(n,i){n=t(n,i),e.point(n[0],n[1])}function i(){b=NaN,k.point=o,e.lineStart()}function o(n,i){var o=ge([n,i]),a=t(n,i);r(b,x,y,w,_,$,b=a[0],x=a[1],y=n,w=o[0],_=o[1],$=o[2],s,e),e.point(b,x)}function a(){k.point=n,e.lineEnd()}function u(){i(),k.point=l,k.lineEnd=c}function l(t,e){o(d=t,h=e),f=b,p=x,g=w,m=_,v=$,k.point=o}function c(){r(b,x,y,w,_,$,f,p,d,g,m,v,s,e),k.lineEnd=a,a()}var d,h,f,p,g,m,v,y,b,x,w,_,$,k={point:n,lineStart:i,lineEnd:a,polygonStart:function(){e.polygonStart(),k.lineStart=u},polygonEnd:function(){e.polygonEnd(),k.lineStart=i}};return k}function r(e,n,i,s,u,l,c,d,h,f,p,g,m,v){var y=c-e,b=d-n,x=y*y+b*b;if(x>4*o&&m--){var w=s+f,_=u+p,$=l+g,k=Math.sqrt(w*w+_*_+$*$),C=Math.asin($/=k),M=xa(xa($)-1)<Wa||xa(i-h)<Wa?(i+h)/2:Math.atan2(_,w),D=t(M,C),S=D[0],T=D[1],A=S-e,E=T-n,O=b*A-y*E;(O*O/x>o||xa((y*A+b*E)/x-.5)>.3||a>s*f+u*p+l*g)&&(r(e,n,i,s,u,l,S,T,M,w/=k,_/=k,$,m,v),v.point(S,T),r(S,T,M,w,_,$,c,d,h,f,p,g,m,v))}}var o=.5,a=Math.cos(30*Ua),s=16;return e.precision=function(t){return arguments.length?(s=(o=t*t)>0&&16,e):Math.sqrt(o)},e}function nn(t){var e=en(function(e,n){return t([e*qa,n*qa])});return function(t){return un(e(t))}}function rn(t){this.stream=t}function on(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function an(t){return sn(function(){return t})()}function sn(t){function e(t){return t=s(t[0]*Ua,t[1]*Ua),[t[0]*h+u,l-t[1]*h]}function n(t){return t=s.invert((t[0]-u)/h,(l-t[1])/h),t&&[t[0]*qa,t[1]*qa]}function i(){s=Se(a=dn(v,b,x),o);var t=o(g,m);return u=f-t[0]*h,l=p+t[1]*h,r()}function r(){return c&&(c.valid=!1,c=null),e}var o,a,s,u,l,c,d=en(function(t,e){return t=o(t,e),[t[0]*h+u,l-t[1]*h]}),h=150,f=480,p=250,g=0,m=0,v=0,b=0,x=0,w=Ls,_=y,$=null,k=null;return e.stream=function(t){return c&&(c.valid=!1),c=un(w(a,d(_(t)))),c.valid=!0,c},e.clipAngle=function(t){return arguments.length?(w=null==t?($=t,Ls):je(($=+t)*Ua),r()):$},e.clipExtent=function(t){return arguments.length?(k=t,_=t?Ue(t[0][0],t[0][1],t[1][0],t[1][1]):y,r()):k},e.scale=function(t){return arguments.length?(h=+t,i()):h},e.translate=function(t){return arguments.length?(f=+t[0],p=+t[1],i()):[f,p]},e.center=function(t){return arguments.length?(g=t[0]%360*Ua,m=t[1]%360*Ua,i()):[g*qa,m*qa]},e.rotate=function(t){return arguments.length?(v=t[0]%360*Ua,b=t[1]%360*Ua,x=t.length>2?t[2]%360*Ua:0,i()):[v*qa,b*qa,x*qa]},ua.rebind(e,d,"precision"),function(){return o=t.apply(this,arguments),e.invert=o.invert&&n,i()}}function un(t){return on(t,function(e,n){t.point(e*Ua,n*Ua)})}function ln(t,e){return[t,e]}function cn(t,e){return[t>La?t-za:-La>t?t+za:t,e]}function dn(t,e,n){return t?e||n?Se(fn(t),pn(e,n)):fn(t):e||n?pn(e,n):cn}function hn(t){return function(e,n){return e+=t,[e>La?e-za:-La>e?e+za:e,n]}}function fn(t){var e=hn(t);return e.invert=hn(-t),e}function pn(t,e){function n(t,e){var n=Math.cos(e),s=Math.cos(t)*n,u=Math.sin(t)*n,l=Math.sin(e),c=l*i+s*r;return[Math.atan2(u*o-c*a,s*i-l*r),et(c*o+u*a)]}var i=Math.cos(t),r=Math.sin(t),o=Math.cos(e),a=Math.sin(e);return n.invert=function(t,e){var n=Math.cos(e),s=Math.cos(t)*n,u=Math.sin(t)*n,l=Math.sin(e),c=l*o-u*a;return[Math.atan2(u*o+l*a,s*i+c*r),et(c*i-s*r)]},n}function gn(t,e){var n=Math.cos(t),i=Math.sin(t);return function(r,o,a,s){var u=a*e;null!=r?(r=mn(n,r),o=mn(n,o),(a>0?o>r:r>o)&&(r+=a*za)):(r=t+a*za,o=t-.5*u);for(var l,c=r;a>0?c>o:o>c;c-=u)s.point((l=we([n,-i*Math.cos(c),-i*Math.sin(c)]))[0],l[1]);
}}function mn(t,e){var n=ge(e);n[0]-=t,xe(n);var i=tt(-n[1]);return((-n[2]<0?-i:i)+2*Math.PI-Wa)%(2*Math.PI)}function vn(t,e,n){var i=ua.range(t,e-Wa,n).concat(e);return function(t){return i.map(function(e){return[t,e]})}}function yn(t,e,n){var i=ua.range(t,e-Wa,n).concat(e);return function(t){return i.map(function(e){return[e,t]})}}function bn(t){return t.source}function xn(t){return t.target}function wn(t,e,n,i){var r=Math.cos(e),o=Math.sin(e),a=Math.cos(i),s=Math.sin(i),u=r*Math.cos(t),l=r*Math.sin(t),c=a*Math.cos(n),d=a*Math.sin(n),h=2*Math.asin(Math.sqrt(ot(i-e)+r*a*ot(n-t))),f=1/Math.sin(h),p=h?function(t){var e=Math.sin(t*=h)*f,n=Math.sin(h-t)*f,i=n*u+e*c,r=n*l+e*d,a=n*o+e*s;return[Math.atan2(r,i)*qa,Math.atan2(a,Math.sqrt(i*i+r*r))*qa]}:function(){return[t*qa,e*qa]};return p.distance=h,p}function _n(){function t(t,r){var o=Math.sin(r*=Ua),a=Math.cos(r),s=xa((t*=Ua)-e),u=Math.cos(s);Ks+=Math.atan2(Math.sqrt((s=a*Math.sin(s))*s+(s=i*o-n*a*u)*s),n*o+i*a*u),e=t,n=o,i=a}var e,n,i;Zs.point=function(r,o){e=r*Ua,n=Math.sin(o*=Ua),i=Math.cos(o),Zs.point=t},Zs.lineEnd=function(){Zs.point=Zs.lineEnd=w}}function $n(t,e){function n(e,n){var i=Math.cos(e),r=Math.cos(n),o=t(i*r);return[o*r*Math.sin(e),o*Math.sin(n)]}return n.invert=function(t,n){var i=Math.sqrt(t*t+n*n),r=e(i),o=Math.sin(r),a=Math.cos(r);return[Math.atan2(t*o,i*a),Math.asin(i&&n*o/i)]},n}function kn(t,e){function n(t,e){a>0?-Ra+Wa>e&&(e=-Ra+Wa):e>Ra-Wa&&(e=Ra-Wa);var n=a/Math.pow(r(e),o);return[n*Math.sin(o*t),a-n*Math.cos(o*t)]}var i=Math.cos(t),r=function(t){return Math.tan(La/4+t/2)},o=t===e?Math.sin(t):Math.log(i/Math.cos(e))/Math.log(r(e)/r(t)),a=i*Math.pow(r(t),o)/o;return o?(n.invert=function(t,e){var n=a-e,i=Q(o)*Math.sqrt(t*t+n*n);return[Math.atan2(t,n)/o,2*Math.atan(Math.pow(a/i,1/o))-Ra]},n):Mn}function Cn(t,e){function n(t,e){var n=o-e;return[n*Math.sin(r*t),o-n*Math.cos(r*t)]}var i=Math.cos(t),r=t===e?Math.sin(t):(i-Math.cos(e))/(e-t),o=i/r+t;return xa(r)<Wa?ln:(n.invert=function(t,e){var n=o-e;return[Math.atan2(t,n)/r,o-Q(r)*Math.sqrt(t*t+n*n)]},n)}function Mn(t,e){return[t,Math.log(Math.tan(La/4+e/2))]}function Dn(t){var e,n=an(t),i=n.scale,r=n.translate,o=n.clipExtent;return n.scale=function(){var t=i.apply(n,arguments);return t===n?e?n.clipExtent(null):n:t},n.translate=function(){var t=r.apply(n,arguments);return t===n?e?n.clipExtent(null):n:t},n.clipExtent=function(t){var a=o.apply(n,arguments);if(a===n){if(e=null==t){var s=La*i(),u=r();o([[u[0]-s,u[1]-s],[u[0]+s,u[1]+s]])}}else e&&(a=null);return a},n.clipExtent(null)}function Sn(t,e){return[Math.log(Math.tan(La/4+e/2)),-t]}function Tn(t){return t[0]}function An(t){return t[1]}function En(t){for(var e=t.length,n=[0,1],i=2,r=2;e>r;r++){for(;i>1&&J(t[n[i-2]],t[n[i-1]],t[r])<=0;)--i;n[i++]=r}return n.slice(0,i)}function On(t,e){return t[0]-e[0]||t[1]-e[1]}function Nn(t,e,n){return(n[0]-e[0])*(t[1]-e[1])<(n[1]-e[1])*(t[0]-e[0])}function In(t,e,n,i){var r=t[0],o=n[0],a=e[0]-r,s=i[0]-o,u=t[1],l=n[1],c=e[1]-u,d=i[1]-l,h=(s*(u-l)-d*(r-o))/(d*a-s*c);return[r+h*a,u+h*c]}function Pn(t){var e=t[0],n=t[t.length-1];return!(e[0]-n[0]||e[1]-n[1])}function Fn(){ii(this),this.edge=this.site=this.circle=null}function Wn(t){var e=lu.pop()||new Fn;return e.site=t,e}function Hn(t){Gn(t),au.remove(t),lu.push(t),ii(t)}function Ln(t){var e=t.circle,n=e.x,i=e.cy,r={x:n,y:i},o=t.P,a=t.N,s=[t];Hn(t);for(var u=o;u.circle&&xa(n-u.circle.x)<Wa&&xa(i-u.circle.cy)<Wa;)o=u.P,s.unshift(u),Hn(u),u=o;s.unshift(u),Gn(u);for(var l=a;l.circle&&xa(n-l.circle.x)<Wa&&xa(i-l.circle.cy)<Wa;)a=l.N,s.push(l),Hn(l),l=a;s.push(l),Gn(l);var c,d=s.length;for(c=1;d>c;++c)l=s[c],u=s[c-1],ti(l.edge,u.site,l.site,r);u=s[0],l=s[d-1],l.edge=Qn(u.site,l.site,null,r),Yn(u),Yn(l)}function zn(t){for(var e,n,i,r,o=t.x,a=t.y,s=au._;s;)if(i=jn(s,a)-o,i>Wa)s=s.L;else{if(r=o-Rn(s,a),!(r>Wa)){i>-Wa?(e=s.P,n=s):r>-Wa?(e=s,n=s.N):e=n=s;break}if(!s.R){e=s;break}s=s.R}var u=Wn(t);if(au.insert(e,u),e||n){if(e===n)return Gn(e),n=Wn(e.site),au.insert(u,n),u.edge=n.edge=Qn(e.site,u.site),Yn(e),void Yn(n);if(!n)return void(u.edge=Qn(e.site,u.site));Gn(e),Gn(n);var l=e.site,c=l.x,d=l.y,h=t.x-c,f=t.y-d,p=n.site,g=p.x-c,m=p.y-d,v=2*(h*m-f*g),y=h*h+f*f,b=g*g+m*m,x={x:(m*y-f*b)/v+c,y:(h*b-g*y)/v+d};ti(n.edge,l,p,x),u.edge=Qn(l,t,null,x),n.edge=Qn(t,p,null,x),Yn(e),Yn(n)}}function jn(t,e){var n=t.site,i=n.x,r=n.y,o=r-e;if(!o)return i;var a=t.P;if(!a)return-(1/0);n=a.site;var s=n.x,u=n.y,l=u-e;if(!l)return s;var c=s-i,d=1/o-1/l,h=c/l;return d?(-h+Math.sqrt(h*h-2*d*(c*c/(-2*l)-u+l/2+r-o/2)))/d+i:(i+s)/2}function Rn(t,e){var n=t.N;if(n)return jn(n,e);var i=t.site;return i.y===e?i.x:1/0}function Un(t){this.site=t,this.edges=[]}function qn(t){for(var e,n,i,r,o,a,s,u,l,c,d=t[0][0],h=t[1][0],f=t[0][1],p=t[1][1],g=ou,m=g.length;m--;)if(o=g[m],o&&o.prepare())for(s=o.edges,u=s.length,a=0;u>a;)c=s[a].end(),i=c.x,r=c.y,l=s[++a%u].start(),e=l.x,n=l.y,(xa(i-e)>Wa||xa(r-n)>Wa)&&(s.splice(a,0,new ei(Jn(o.site,c,xa(i-d)<Wa&&p-r>Wa?{x:d,y:xa(e-d)<Wa?n:p}:xa(r-p)<Wa&&h-i>Wa?{x:xa(n-p)<Wa?e:h,y:p}:xa(i-h)<Wa&&r-f>Wa?{x:h,y:xa(e-h)<Wa?n:f}:xa(r-f)<Wa&&i-d>Wa?{x:xa(n-f)<Wa?e:d,y:f}:null),o.site,null)),++u)}function Bn(t,e){return e.angle-t.angle}function Vn(){ii(this),this.x=this.y=this.arc=this.site=this.cy=null}function Yn(t){var e=t.P,n=t.N;if(e&&n){var i=e.site,r=t.site,o=n.site;if(i!==o){var a=r.x,s=r.y,u=i.x-a,l=i.y-s,c=o.x-a,d=o.y-s,h=2*(u*d-l*c);if(!(h>=-Ha)){var f=u*u+l*l,p=c*c+d*d,g=(d*f-l*p)/h,m=(u*p-c*f)/h,d=m+s,v=cu.pop()||new Vn;v.arc=t,v.site=r,v.x=g+a,v.y=d+Math.sqrt(g*g+m*m),v.cy=d,t.circle=v;for(var y=null,b=uu._;b;)if(v.y<b.y||v.y===b.y&&v.x<=b.x){if(!b.L){y=b.P;break}b=b.L}else{if(!b.R){y=b;break}b=b.R}uu.insert(y,v),y||(su=v)}}}}function Gn(t){var e=t.circle;e&&(e.P||(su=e.N),uu.remove(e),cu.push(e),ii(e),t.circle=null)}function Xn(t){for(var e,n=ru,i=Re(t[0][0],t[0][1],t[1][0],t[1][1]),r=n.length;r--;)e=n[r],(!Kn(e,t)||!i(e)||xa(e.a.x-e.b.x)<Wa&&xa(e.a.y-e.b.y)<Wa)&&(e.a=e.b=null,n.splice(r,1))}function Kn(t,e){var n=t.b;if(n)return!0;var i,r,o=t.a,a=e[0][0],s=e[1][0],u=e[0][1],l=e[1][1],c=t.l,d=t.r,h=c.x,f=c.y,p=d.x,g=d.y,m=(h+p)/2,v=(f+g)/2;if(g===f){if(a>m||m>=s)return;if(h>p){if(o){if(o.y>=l)return}else o={x:m,y:u};n={x:m,y:l}}else{if(o){if(o.y<u)return}else o={x:m,y:l};n={x:m,y:u}}}else if(i=(h-p)/(g-f),r=v-i*m,-1>i||i>1)if(h>p){if(o){if(o.y>=l)return}else o={x:(u-r)/i,y:u};n={x:(l-r)/i,y:l}}else{if(o){if(o.y<u)return}else o={x:(l-r)/i,y:l};n={x:(u-r)/i,y:u}}else if(g>f){if(o){if(o.x>=s)return}else o={x:a,y:i*a+r};n={x:s,y:i*s+r}}else{if(o){if(o.x<a)return}else o={x:s,y:i*s+r};n={x:a,y:i*a+r}}return t.a=o,t.b=n,!0}function Zn(t,e){this.l=t,this.r=e,this.a=this.b=null}function Qn(t,e,n,i){var r=new Zn(t,e);return ru.push(r),n&&ti(r,t,e,n),i&&ti(r,e,t,i),ou[t.i].edges.push(new ei(r,t,e)),ou[e.i].edges.push(new ei(r,e,t)),r}function Jn(t,e,n){var i=new Zn(t,null);return i.a=e,i.b=n,ru.push(i),i}function ti(t,e,n,i){t.a||t.b?t.l===n?t.b=i:t.a=i:(t.a=i,t.l=e,t.r=n)}function ei(t,e,n){var i=t.a,r=t.b;this.edge=t,this.site=e,this.angle=n?Math.atan2(n.y-e.y,n.x-e.x):t.l===e?Math.atan2(r.x-i.x,i.y-r.y):Math.atan2(i.x-r.x,r.y-i.y)}function ni(){this._=null}function ii(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function ri(t,e){var n=e,i=e.R,r=n.U;r?r.L===n?r.L=i:r.R=i:t._=i,i.U=r,n.U=i,n.R=i.L,n.R&&(n.R.U=n),i.L=n}function oi(t,e){var n=e,i=e.L,r=n.U;r?r.L===n?r.L=i:r.R=i:t._=i,i.U=r,n.U=i,n.L=i.R,n.L&&(n.L.U=n),i.R=n}function ai(t){for(;t.L;)t=t.L;return t}function si(t,e){var n,i,r,o=t.sort(ui).pop();for(ru=[],ou=new Array(t.length),au=new ni,uu=new ni;;)if(r=su,o&&(!r||o.y<r.y||o.y===r.y&&o.x<r.x))(o.x!==n||o.y!==i)&&(ou[o.i]=new Un(o),zn(o),n=o.x,i=o.y),o=t.pop();else{if(!r)break;Ln(r.arc)}e&&(Xn(e),qn(e));var a={cells:ou,edges:ru};return au=uu=ru=ou=null,a}function ui(t,e){return e.y-t.y||e.x-t.x}function li(t,e,n){return(t.x-n.x)*(e.y-t.y)-(t.x-e.x)*(n.y-t.y)}function ci(t){return t.x}function di(t){return t.y}function hi(){return{leaf:!0,nodes:[],point:null,x:null,y:null}}function fi(t,e,n,i,r,o){if(!t(e,n,i,r,o)){var a=.5*(n+r),s=.5*(i+o),u=e.nodes;u[0]&&fi(t,u[0],n,i,a,s),u[1]&&fi(t,u[1],a,i,r,s),u[2]&&fi(t,u[2],n,s,a,o),u[3]&&fi(t,u[3],a,s,r,o)}}function pi(t,e,n,i,r,o,a){var s,u=1/0;return function l(t,c,d,h,f){if(!(c>o||d>a||i>h||r>f)){if(p=t.point){var p,g=e-t.x,m=n-t.y,v=g*g+m*m;if(u>v){var y=Math.sqrt(u=v);i=e-y,r=n-y,o=e+y,a=n+y,s=p}}for(var b=t.nodes,x=.5*(c+h),w=.5*(d+f),_=e>=x,$=n>=w,k=$<<1|_,C=k+4;C>k;++k)if(t=b[3&k])switch(3&k){case 0:l(t,c,d,x,w);break;case 1:l(t,x,d,h,w);break;case 2:l(t,c,w,x,f);break;case 3:l(t,x,w,h,f)}}}(t,i,r,o,a),s}function gi(t,e){t=ua.rgb(t),e=ua.rgb(e);var n=t.r,i=t.g,r=t.b,o=e.r-n,a=e.g-i,s=e.b-r;return function(t){return"#"+xt(Math.round(n+o*t))+xt(Math.round(i+a*t))+xt(Math.round(r+s*t))}}function mi(t,e){var n,i={},r={};for(n in t)n in e?i[n]=bi(t[n],e[n]):r[n]=t[n];for(n in e)n in t||(r[n]=e[n]);return function(t){for(n in i)r[n]=i[n](t);return r}}function vi(t,e){return t=+t,e=+e,function(n){return t*(1-n)+e*n}}function yi(t,e){var n,i,r,o=hu.lastIndex=fu.lastIndex=0,a=-1,s=[],u=[];for(t+="",e+="";(n=hu.exec(t))&&(i=fu.exec(e));)(r=i.index)>o&&(r=e.slice(o,r),s[a]?s[a]+=r:s[++a]=r),(n=n[0])===(i=i[0])?s[a]?s[a]+=i:s[++a]=i:(s[++a]=null,u.push({i:a,x:vi(n,i)})),o=fu.lastIndex;return o<e.length&&(r=e.slice(o),s[a]?s[a]+=r:s[++a]=r),s.length<2?u[0]?(e=u[0].x,function(t){return e(t)+""}):function(){return e}:(e=u.length,function(t){for(var n,i=0;e>i;++i)s[(n=u[i]).i]=n.x(t);return s.join("")})}function bi(t,e){for(var n,i=ua.interpolators.length;--i>=0&&!(n=ua.interpolators[i](t,e)););return n}function xi(t,e){var n,i=[],r=[],o=t.length,a=e.length,s=Math.min(t.length,e.length);for(n=0;s>n;++n)i.push(bi(t[n],e[n]));for(;o>n;++n)r[n]=t[n];for(;a>n;++n)r[n]=e[n];return function(t){for(n=0;s>n;++n)r[n]=i[n](t);return r}}function wi(t){return function(e){return 0>=e?0:e>=1?1:t(e)}}function _i(t){return function(e){return 1-t(1-e)}}function $i(t){return function(e){return.5*(.5>e?t(2*e):2-t(2-2*e))}}function ki(t){return t*t}function Ci(t){return t*t*t}function Mi(t){if(0>=t)return 0;if(t>=1)return 1;var e=t*t,n=e*t;return 4*(.5>t?n:3*(t-e)+n-.75)}function Di(t){return function(e){return Math.pow(e,t)}}function Si(t){return 1-Math.cos(t*Ra)}function Ti(t){return Math.pow(2,10*(t-1))}function Ai(t){return 1-Math.sqrt(1-t*t)}function Ei(t,e){var n;return arguments.length<2&&(e=.45),arguments.length?n=e/za*Math.asin(1/t):(t=1,n=e/4),function(i){return 1+t*Math.pow(2,-10*i)*Math.sin((i-n)*za/e)}}function Oi(t){return t||(t=1.70158),function(e){return e*e*((t+1)*e-t)}}function Ni(t){return 1/2.75>t?7.5625*t*t:2/2.75>t?7.5625*(t-=1.5/2.75)*t+.75:2.5/2.75>t?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function Ii(t,e){t=ua.hcl(t),e=ua.hcl(e);var n=t.h,i=t.c,r=t.l,o=e.h-n,a=e.c-i,s=e.l-r;return isNaN(a)&&(a=0,i=isNaN(i)?e.c:i),isNaN(o)?(o=0,n=isNaN(n)?e.h:n):o>180?o-=360:-180>o&&(o+=360),function(t){return ct(n+o*t,i+a*t,r+s*t)+""}}function Pi(t,e){t=ua.hsl(t),e=ua.hsl(e);var n=t.h,i=t.s,r=t.l,o=e.h-n,a=e.s-i,s=e.l-r;return isNaN(a)&&(a=0,i=isNaN(i)?e.s:i),isNaN(o)?(o=0,n=isNaN(n)?e.h:n):o>180?o-=360:-180>o&&(o+=360),function(t){return ut(n+o*t,i+a*t,r+s*t)+""}}function Fi(t,e){t=ua.lab(t),e=ua.lab(e);var n=t.l,i=t.a,r=t.b,o=e.l-n,a=e.a-i,s=e.b-r;return function(t){return ht(n+o*t,i+a*t,r+s*t)+""}}function Wi(t,e){return e-=t,function(n){return Math.round(t+e*n)}}function Hi(t){var e=[t.a,t.b],n=[t.c,t.d],i=zi(e),r=Li(e,n),o=zi(ji(n,e,-r))||0;e[0]*n[1]<n[0]*e[1]&&(e[0]*=-1,e[1]*=-1,i*=-1,r*=-1),this.rotate=(i?Math.atan2(e[1],e[0]):Math.atan2(-n[0],n[1]))*qa,this.translate=[t.e,t.f],this.scale=[i,o],this.skew=o?Math.atan2(r,o)*qa:0}function Li(t,e){return t[0]*e[0]+t[1]*e[1]}function zi(t){var e=Math.sqrt(Li(t,t));return e&&(t[0]/=e,t[1]/=e),e}function ji(t,e,n){return t[0]+=n*e[0],t[1]+=n*e[1],t}function Ri(t){return t.length?t.pop()+",":""}function Ui(t,e,n,i){if(t[0]!==e[0]||t[1]!==e[1]){var r=n.push("translate(",null,",",null,")");i.push({i:r-4,x:vi(t[0],e[0])},{i:r-2,x:vi(t[1],e[1])})}else(e[0]||e[1])&&n.push("translate("+e+")")}function qi(t,e,n,i){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),i.push({i:n.push(Ri(n)+"rotate(",null,")")-2,x:vi(t,e)})):e&&n.push(Ri(n)+"rotate("+e+")")}function Bi(t,e,n,i){t!==e?i.push({i:n.push(Ri(n)+"skewX(",null,")")-2,x:vi(t,e)}):e&&n.push(Ri(n)+"skewX("+e+")")}function Vi(t,e,n,i){if(t[0]!==e[0]||t[1]!==e[1]){var r=n.push(Ri(n)+"scale(",null,",",null,")");i.push({i:r-4,x:vi(t[0],e[0])},{i:r-2,x:vi(t[1],e[1])})}else(1!==e[0]||1!==e[1])&&n.push(Ri(n)+"scale("+e+")")}function Yi(t,e){var n=[],i=[];return t=ua.transform(t),e=ua.transform(e),Ui(t.translate,e.translate,n,i),qi(t.rotate,e.rotate,n,i),Bi(t.skew,e.skew,n,i),Vi(t.scale,e.scale,n,i),t=e=null,function(t){for(var e,r=-1,o=i.length;++r<o;)n[(e=i[r]).i]=e.x(t);return n.join("")}}function Gi(t,e){return e=(e-=t=+t)||1/e,function(n){return(n-t)/e}}function Xi(t,e){return e=(e-=t=+t)||1/e,function(n){return Math.max(0,Math.min(1,(n-t)/e))}}function Ki(t){for(var e=t.source,n=t.target,i=Qi(e,n),r=[e];e!==i;)e=e.parent,r.push(e);for(var o=r.length;n!==i;)r.splice(o,0,n),n=n.parent;return r}function Zi(t){for(var e=[],n=t.parent;null!=n;)e.push(t),t=n,n=n.parent;return e.push(t),e}function Qi(t,e){if(t===e)return t;for(var n=Zi(t),i=Zi(e),r=n.pop(),o=i.pop(),a=null;r===o;)a=r,r=n.pop(),o=i.pop();return a}function Ji(t){t.fixed|=2}function tr(t){t.fixed&=-7}function er(t){t.fixed|=4,t.px=t.x,t.py=t.y}function nr(t){t.fixed&=-5}function ir(t,e,n){var i=0,r=0;if(t.charge=0,!t.leaf)for(var o,a=t.nodes,s=a.length,u=-1;++u<s;)o=a[u],null!=o&&(ir(o,e,n),t.charge+=o.charge,i+=o.charge*o.cx,r+=o.charge*o.cy);if(t.point){t.leaf||(t.point.x+=Math.random()-.5,t.point.y+=Math.random()-.5);var l=e*n[t.point.index];t.charge+=t.pointCharge=l,i+=l*t.point.x,r+=l*t.point.y}t.cx=i/t.charge,t.cy=r/t.charge}function rr(t,e){return ua.rebind(t,e,"sort","children","value"),t.nodes=t,t.links=cr,t}function or(t,e){for(var n=[t];null!=(t=n.pop());)if(e(t),(r=t.children)&&(i=r.length))for(var i,r;--i>=0;)n.push(r[i])}function ar(t,e){for(var n=[t],i=[];null!=(t=n.pop());)if(i.push(t),(o=t.children)&&(r=o.length))for(var r,o,a=-1;++a<r;)n.push(o[a]);for(;null!=(t=i.pop());)e(t)}function sr(t){return t.children}function ur(t){return t.value}function lr(t,e){return e.value-t.value}function cr(t){return ua.merge(t.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}function dr(t){return t.x}function hr(t){return t.y}function fr(t,e,n){t.y0=e,t.y=n}function pr(t){return ua.range(t.length)}function gr(t){for(var e=-1,n=t[0].length,i=[];++e<n;)i[e]=0;return i}function mr(t){for(var e,n=1,i=0,r=t[0][1],o=t.length;o>n;++n)(e=t[n][1])>r&&(i=n,r=e);return i}function vr(t){return t.reduce(yr,0)}function yr(t,e){return t+e[1]}function br(t,e){return xr(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function xr(t,e){for(var n=-1,i=+t[0],r=(t[1]-i)/e,o=[];++n<=e;)o[n]=r*n+i;return o}function wr(t){return[ua.min(t),ua.max(t)]}function _r(t,e){return t.value-e.value}function $r(t,e){var n=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=n,n._pack_prev=e}function kr(t,e){t._pack_next=e,e._pack_prev=t}function Cr(t,e){var n=e.x-t.x,i=e.y-t.y,r=t.r+e.r;return.999*r*r>n*n+i*i}function Mr(t){function e(t){c=Math.min(t.x-t.r,c),d=Math.max(t.x+t.r,d),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}if((n=t.children)&&(l=n.length)){var n,i,r,o,a,s,u,l,c=1/0,d=-(1/0),h=1/0,f=-(1/0);if(n.forEach(Dr),i=n[0],i.x=-i.r,i.y=0,e(i),l>1&&(r=n[1],r.x=r.r,r.y=0,e(r),l>2))for(o=n[2],Ar(i,r,o),e(o),$r(i,o),i._pack_prev=o,$r(o,r),r=i._pack_next,a=3;l>a;a++){Ar(i,r,o=n[a]);var p=0,g=1,m=1;for(s=r._pack_next;s!==r;s=s._pack_next,g++)if(Cr(s,o)){p=1;break}if(1==p)for(u=i._pack_prev;u!==s._pack_prev&&!Cr(u,o);u=u._pack_prev,m++);p?(m>g||g==m&&r.r<i.r?kr(i,r=s):kr(i=u,r),a--):($r(i,o),r=o,e(o))}var v=(c+d)/2,y=(h+f)/2,b=0;for(a=0;l>a;a++)o=n[a],o.x-=v,o.y-=y,b=Math.max(b,o.r+Math.sqrt(o.x*o.x+o.y*o.y));t.r=b,n.forEach(Sr)}}function Dr(t){t._pack_next=t._pack_prev=t}function Sr(t){delete t._pack_next,delete t._pack_prev}function Tr(t,e,n,i){var r=t.children;if(t.x=e+=i*t.x,t.y=n+=i*t.y,t.r*=i,r)for(var o=-1,a=r.length;++o<a;)Tr(r[o],e,n,i)}function Ar(t,e,n){var i=t.r+n.r,r=e.x-t.x,o=e.y-t.y;if(i&&(r||o)){var a=e.r+n.r,s=r*r+o*o;a*=a,i*=i;var u=.5+(i-a)/(2*s),l=Math.sqrt(Math.max(0,2*a*(i+s)-(i-=s)*i-a*a))/(2*s);n.x=t.x+u*r+l*o,n.y=t.y+u*o-l*r}else n.x=t.x+i,n.y=t.y}function Er(t,e){return t.parent==e.parent?1:2}function Or(t){var e=t.children;return e.length?e[0]:t.t}function Nr(t){var e,n=t.children;return(e=n.length)?n[e-1]:t.t}function Ir(t,e,n){var i=n/(e.i-t.i);e.c-=i,e.s+=n,t.c+=i,e.z+=n,e.m+=n}function Pr(t){for(var e,n=0,i=0,r=t.children,o=r.length;--o>=0;)e=r[o],e.z+=n,e.m+=n,n+=e.s+(i+=e.c)}function Fr(t,e,n){return t.a.parent===e.parent?t.a:n}function Wr(t){return 1+ua.max(t,function(t){return t.y})}function Hr(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}function Lr(t){var e=t.children;return e&&e.length?Lr(e[0]):t}function zr(t){var e,n=t.children;return n&&(e=n.length)?zr(n[e-1]):t}function jr(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function Rr(t,e){var n=t.x+e[3],i=t.y+e[0],r=t.dx-e[1]-e[3],o=t.dy-e[0]-e[2];return 0>r&&(n+=r/2,r=0),0>o&&(i+=o/2,o=0),{x:n,y:i,dx:r,dy:o}}function Ur(t){var e=t[0],n=t[t.length-1];return n>e?[e,n]:[n,e]}function qr(t){return t.rangeExtent?t.rangeExtent():Ur(t.range())}function Br(t,e,n,i){var r=n(t[0],t[1]),o=i(e[0],e[1]);return function(t){return o(r(t))}}function Vr(t,e){var n,i=0,r=t.length-1,o=t[i],a=t[r];return o>a&&(n=i,i=r,r=n,n=o,o=a,a=n),t[i]=e.floor(o),t[r]=e.ceil(a),t}function Yr(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:ku}function Gr(t,e,n,i){var r=[],o=[],a=0,s=Math.min(t.length,e.length)-1;for(t[s]<t[0]&&(t=t.slice().reverse(),e=e.slice().reverse());++a<=s;)r.push(n(t[a-1],t[a])),o.push(i(e[a-1],e[a]));return function(e){var n=ua.bisect(t,e,1,s)-1;return o[n](r[n](e))}}function Xr(t,e,n,i){function r(){var r=Math.min(t.length,e.length)>2?Gr:Br,u=i?Xi:Gi;return a=r(t,e,u,n),s=r(e,t,u,bi),o}function o(t){return a(t)}var a,s;return o.invert=function(t){return s(t)},o.domain=function(e){return arguments.length?(t=e.map(Number),r()):t},o.range=function(t){return arguments.length?(e=t,r()):e},o.rangeRound=function(t){return o.range(t).interpolate(Wi)},o.clamp=function(t){return arguments.length?(i=t,r()):i},o.interpolate=function(t){return arguments.length?(n=t,r()):n},o.ticks=function(e){return Jr(t,e)},o.tickFormat=function(e,n){return to(t,e,n)},o.nice=function(e){return Zr(t,e),r()},o.copy=function(){return Xr(t,e,n,i)},r()}function Kr(t,e){return ua.rebind(t,e,"range","rangeRound","interpolate","clamp")}function Zr(t,e){return Vr(t,Yr(Qr(t,e)[2])),Vr(t,Yr(Qr(t,e)[2])),t}function Qr(t,e){null==e&&(e=10);var n=Ur(t),i=n[1]-n[0],r=Math.pow(10,Math.floor(Math.log(i/e)/Math.LN10)),o=e/i*r;return.15>=o?r*=10:.35>=o?r*=5:.75>=o&&(r*=2),n[0]=Math.ceil(n[0]/r)*r,n[1]=Math.floor(n[1]/r)*r+.5*r,n[2]=r,n}function Jr(t,e){return ua.range.apply(ua,Qr(t,e))}function to(t,e,n){var i=Qr(t,e);if(n){var r=hs.exec(n);if(r.shift(),"s"===r[8]){var o=ua.formatPrefix(Math.max(xa(i[0]),xa(i[1])));return r[7]||(r[7]="."+eo(o.scale(i[2]))),r[8]="f",n=ua.format(r.join("")),function(t){return n(o.scale(t))+o.symbol}}r[7]||(r[7]="."+no(r[8],i)),n=r.join("")}else n=",."+eo(i[2])+"f";return ua.format(n)}function eo(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}function no(t,e){var n=eo(e[2]);return t in Cu?Math.abs(n-eo(Math.max(xa(e[0]),xa(e[1]))))+ +("e"!==t):n-2*("%"===t)}function io(t,e,n,i){function r(t){return(n?Math.log(0>t?0:t):-Math.log(t>0?0:-t))/Math.log(e)}function o(t){return n?Math.pow(e,t):-Math.pow(e,-t)}function a(e){return t(r(e))}return a.invert=function(e){return o(t.invert(e))},a.domain=function(e){return arguments.length?(n=e[0]>=0,t.domain((i=e.map(Number)).map(r)),a):i},a.base=function(n){return arguments.length?(e=+n,t.domain(i.map(r)),a):e},a.nice=function(){var e=Vr(i.map(r),n?Math:Du);return t.domain(e),i=e.map(o),a},a.ticks=function(){var t=Ur(i),a=[],s=t[0],u=t[1],l=Math.floor(r(s)),c=Math.ceil(r(u)),d=e%1?2:e;if(isFinite(c-l)){if(n){for(;c>l;l++)for(var h=1;d>h;h++)a.push(o(l)*h);a.push(o(l))}else for(a.push(o(l));l++<c;)for(var h=d-1;h>0;h--)a.push(o(l)*h);for(l=0;a[l]<s;l++);for(c=a.length;a[c-1]>u;c--);a=a.slice(l,c)}return a},a.tickFormat=function(t,n){if(!arguments.length)return Mu;arguments.length<2?n=Mu:"function"!=typeof n&&(n=ua.format(n));var i=Math.max(1,e*t/a.ticks().length);return function(t){var a=t/o(Math.round(r(t)));return e-.5>a*e&&(a*=e),i>=a?n(t):""}},a.copy=function(){return io(t.copy(),e,n,i)},Kr(a,t)}function ro(t,e,n){function i(e){return t(r(e))}var r=oo(e),o=oo(1/e);return i.invert=function(e){return o(t.invert(e))},i.domain=function(e){return arguments.length?(t.domain((n=e.map(Number)).map(r)),i):n},i.ticks=function(t){return Jr(n,t)},i.tickFormat=function(t,e){return to(n,t,e)},i.nice=function(t){return i.domain(Zr(n,t))},i.exponent=function(a){return arguments.length?(r=oo(e=a),o=oo(1/e),t.domain(n.map(r)),i):e},i.copy=function(){return ro(t.copy(),e,n)},Kr(i,t)}function oo(t){return function(e){return 0>e?-Math.pow(-e,t):Math.pow(e,t)}}function ao(t,e){function n(n){return o[((r.get(n)||("range"===e.t?r.set(n,t.push(n)):NaN))-1)%o.length]}function i(e,n){return ua.range(t.length).map(function(t){return e+n*t})}var r,o,a;return n.domain=function(i){if(!arguments.length)return t;t=[],r=new l;for(var o,a=-1,s=i.length;++a<s;)r.has(o=i[a])||r.set(o,t.push(o));return n[e.t].apply(n,e.a)},n.range=function(t){return arguments.length?(o=t,a=0,e={t:"range",a:arguments},n):o},n.rangePoints=function(r,s){arguments.length<2&&(s=0);var u=r[0],l=r[1],c=t.length<2?(u=(u+l)/2,0):(l-u)/(t.length-1+s);return o=i(u+c*s/2,c),a=0,e={t:"rangePoints",a:arguments},n},n.rangeRoundPoints=function(r,s){arguments.length<2&&(s=0);var u=r[0],l=r[1],c=t.length<2?(u=l=Math.round((u+l)/2),0):(l-u)/(t.length-1+s)|0;return o=i(u+Math.round(c*s/2+(l-u-(t.length-1+s)*c)/2),c),a=0,e={t:"rangeRoundPoints",a:arguments},n},n.rangeBands=function(r,s,u){arguments.length<2&&(s=0),arguments.length<3&&(u=s);var l=r[1]<r[0],c=r[l-0],d=r[1-l],h=(d-c)/(t.length-s+2*u);return o=i(c+h*u,h),l&&o.reverse(),a=h*(1-s),e={t:"rangeBands",a:arguments},n},n.rangeRoundBands=function(r,s,u){arguments.length<2&&(s=0),arguments.length<3&&(u=s);var l=r[1]<r[0],c=r[l-0],d=r[1-l],h=Math.floor((d-c)/(t.length-s+2*u));return o=i(c+Math.round((d-c-(t.length-s)*h)/2),h),l&&o.reverse(),a=Math.round(h*(1-s)),e={t:"rangeRoundBands",a:arguments},n},n.rangeBand=function(){return a},n.rangeExtent=function(){return Ur(e.a[0])},n.copy=function(){return ao(t,e)},n.domain(t)}function so(t,e){function o(){var n=0,i=e.length;for(s=[];++n<i;)s[n-1]=ua.quantile(t,n/i);return a}function a(t){return isNaN(t=+t)?void 0:e[ua.bisect(s,t)]}var s;return a.domain=function(e){return arguments.length?(t=e.map(i).filter(r).sort(n),o()):t},a.range=function(t){return arguments.length?(e=t,o()):e},a.quantiles=function(){return s},a.invertExtent=function(n){return n=e.indexOf(n),0>n?[NaN,NaN]:[n>0?s[n-1]:t[0],n<s.length?s[n]:t[t.length-1]]},a.copy=function(){return so(t,e)},o()}function uo(t,e,n){function i(e){return n[Math.max(0,Math.min(a,Math.floor(o*(e-t))))]}function r(){return o=n.length/(e-t),a=n.length-1,i}var o,a;return i.domain=function(n){return arguments.length?(t=+n[0],e=+n[n.length-1],r()):[t,e]},i.range=function(t){return arguments.length?(n=t,r()):n},i.invertExtent=function(e){return e=n.indexOf(e),e=0>e?NaN:e/o+t,[e,e+1/o]},i.copy=function(){return uo(t,e,n)},r()}function lo(t,e){function n(n){return n>=n?e[ua.bisect(t,n)]:void 0}return n.domain=function(e){return arguments.length?(t=e,n):t},n.range=function(t){return arguments.length?(e=t,n):e},n.invertExtent=function(n){return n=e.indexOf(n),[t[n-1],t[n]]},n.copy=function(){return lo(t,e)},n}function co(t){function e(t){return+t}return e.invert=e,e.domain=e.range=function(n){return arguments.length?(t=n.map(e),e):t},e.ticks=function(e){return Jr(t,e)},e.tickFormat=function(e,n){return to(t,e,n)},e.copy=function(){return co(t)},e}function ho(){return 0}function fo(t){return t.innerRadius}function po(t){return t.outerRadius}function go(t){return t.startAngle}function mo(t){return t.endAngle}function vo(t){return t&&t.padAngle}function yo(t,e,n,i){return(t-n)*e-(e-i)*t>0?0:1}function bo(t,e,n,i,r){var o=t[0]-e[0],a=t[1]-e[1],s=(r?i:-i)/Math.sqrt(o*o+a*a),u=s*a,l=-s*o,c=t[0]+u,d=t[1]+l,h=e[0]+u,f=e[1]+l,p=(c+h)/2,g=(d+f)/2,m=h-c,v=f-d,y=m*m+v*v,b=n-i,x=c*f-h*d,w=(0>v?-1:1)*Math.sqrt(Math.max(0,b*b*y-x*x)),_=(x*v-m*w)/y,$=(-x*m-v*w)/y,k=(x*v+m*w)/y,C=(-x*m+v*w)/y,M=_-p,D=$-g,S=k-p,T=C-g;return M*M+D*D>S*S+T*T&&(_=k,$=C),[[_-u,$-l],[_*n/b,$*n/b]]}function xo(t){function e(e){function a(){l.push("M",o(t(c),s))}for(var u,l=[],c=[],d=-1,h=e.length,f=Mt(n),p=Mt(i);++d<h;)r.call(this,u=e[d],d)?c.push([+f.call(this,u,d),+p.call(this,u,d)]):c.length&&(a(),c=[]);return c.length&&a(),l.length?l.join(""):null}var n=Tn,i=An,r=Te,o=wo,a=o.key,s=.7;return e.x=function(t){return arguments.length?(n=t,e):n},e.y=function(t){return arguments.length?(i=t,e):i},e.defined=function(t){return arguments.length?(r=t,e):r},e.interpolate=function(t){return arguments.length?(a="function"==typeof t?o=t:(o=Nu.get(t)||wo).key,e):a},e.tension=function(t){return arguments.length?(s=t,e):s},e}function wo(t){return t.length>1?t.join("L"):t+"Z"}function _o(t){return t.join("L")+"Z"}function $o(t){for(var e=0,n=t.length,i=t[0],r=[i[0],",",i[1]];++e<n;)r.push("H",(i[0]+(i=t[e])[0])/2,"V",i[1]);return n>1&&r.push("H",i[0]),r.join("")}function ko(t){for(var e=0,n=t.length,i=t[0],r=[i[0],",",i[1]];++e<n;)r.push("V",(i=t[e])[1],"H",i[0]);return r.join("")}function Co(t){for(var e=0,n=t.length,i=t[0],r=[i[0],",",i[1]];++e<n;)r.push("H",(i=t[e])[0],"V",i[1]);return r.join("")}function Mo(t,e){return t.length<4?wo(t):t[1]+To(t.slice(1,-1),Ao(t,e))}function Do(t,e){return t.length<3?_o(t):t[0]+To((t.push(t[0]),t),Ao([t[t.length-2]].concat(t,[t[1]]),e))}function So(t,e){return t.length<3?wo(t):t[0]+To(t,Ao(t,e))}function To(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return wo(t);var n=t.length!=e.length,i="",r=t[0],o=t[1],a=e[0],s=a,u=1;if(n&&(i+="Q"+(o[0]-2*a[0]/3)+","+(o[1]-2*a[1]/3)+","+o[0]+","+o[1],r=t[1],u=2),e.length>1){s=e[1],o=t[u],u++,i+="C"+(r[0]+a[0])+","+(r[1]+a[1])+","+(o[0]-s[0])+","+(o[1]-s[1])+","+o[0]+","+o[1];for(var l=2;l<e.length;l++,u++)o=t[u],s=e[l],i+="S"+(o[0]-s[0])+","+(o[1]-s[1])+","+o[0]+","+o[1]}if(n){var c=t[u];i+="Q"+(o[0]+2*s[0]/3)+","+(o[1]+2*s[1]/3)+","+c[0]+","+c[1]}return i}function Ao(t,e){for(var n,i=[],r=(1-e)/2,o=t[0],a=t[1],s=1,u=t.length;++s<u;)n=o,o=a,a=t[s],i.push([r*(a[0]-n[0]),r*(a[1]-n[1])]);return i}function Eo(t){if(t.length<3)return wo(t);var e=1,n=t.length,i=t[0],r=i[0],o=i[1],a=[r,r,r,(i=t[1])[0]],s=[o,o,o,i[1]],u=[r,",",o,"L",Po(Fu,a),",",Po(Fu,s)];for(t.push(t[n-1]);++e<=n;)i=t[e],a.shift(),a.push(i[0]),s.shift(),s.push(i[1]),Fo(u,a,s);return t.pop(),u.push("L",i),u.join("")}function Oo(t){if(t.length<4)return wo(t);for(var e,n=[],i=-1,r=t.length,o=[0],a=[0];++i<3;)e=t[i],o.push(e[0]),a.push(e[1]);for(n.push(Po(Fu,o)+","+Po(Fu,a)),--i;++i<r;)e=t[i],o.shift(),o.push(e[0]),a.shift(),a.push(e[1]),Fo(n,o,a);return n.join("")}function No(t){for(var e,n,i=-1,r=t.length,o=r+4,a=[],s=[];++i<4;)n=t[i%r],a.push(n[0]),s.push(n[1]);for(e=[Po(Fu,a),",",Po(Fu,s)],--i;++i<o;)n=t[i%r],a.shift(),a.push(n[0]),s.shift(),s.push(n[1]),Fo(e,a,s);return e.join("")}function Io(t,e){var n=t.length-1;if(n)for(var i,r,o=t[0][0],a=t[0][1],s=t[n][0]-o,u=t[n][1]-a,l=-1;++l<=n;)i=t[l],r=l/n,i[0]=e*i[0]+(1-e)*(o+r*s),i[1]=e*i[1]+(1-e)*(a+r*u);return Eo(t)}function Po(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}function Fo(t,e,n){t.push("C",Po(Iu,e),",",Po(Iu,n),",",Po(Pu,e),",",Po(Pu,n),",",Po(Fu,e),",",Po(Fu,n))}function Wo(t,e){return(e[1]-t[1])/(e[0]-t[0])}function Ho(t){for(var e=0,n=t.length-1,i=[],r=t[0],o=t[1],a=i[0]=Wo(r,o);++e<n;)i[e]=(a+(a=Wo(r=o,o=t[e+1])))/2;return i[e]=a,i}function Lo(t){for(var e,n,i,r,o=[],a=Ho(t),s=-1,u=t.length-1;++s<u;)e=Wo(t[s],t[s+1]),xa(e)<Wa?a[s]=a[s+1]=0:(n=a[s]/e,i=a[s+1]/e,r=n*n+i*i,r>9&&(r=3*e/Math.sqrt(r),a[s]=r*n,a[s+1]=r*i));for(s=-1;++s<=u;)r=(t[Math.min(u,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+a[s]*a[s])),o.push([r||0,a[s]*r||0]);return o}function zo(t){return t.length<3?wo(t):t[0]+To(t,Lo(t))}function jo(t){for(var e,n,i,r=-1,o=t.length;++r<o;)e=t[r],n=e[0],i=e[1]-Ra,e[0]=n*Math.cos(i),e[1]=n*Math.sin(i);return t}function Ro(t){function e(e){function u(){g.push("M",s(t(v),d),c,l(t(m.reverse()),d),"Z")}for(var h,f,p,g=[],m=[],v=[],y=-1,b=e.length,x=Mt(n),w=Mt(r),_=n===i?function(){return f}:Mt(i),$=r===o?function(){return p}:Mt(o);++y<b;)a.call(this,h=e[y],y)?(m.push([f=+x.call(this,h,y),p=+w.call(this,h,y)]),v.push([+_.call(this,h,y),+$.call(this,h,y)])):m.length&&(u(),m=[],v=[]);return m.length&&u(),g.length?g.join(""):null}var n=Tn,i=Tn,r=0,o=An,a=Te,s=wo,u=s.key,l=s,c="L",d=.7;return e.x=function(t){return arguments.length?(n=i=t,e):i},e.x0=function(t){return arguments.length?(n=t,e):n},e.x1=function(t){return arguments.length?(i=t,e):i},e.y=function(t){return arguments.length?(r=o=t,e):o},e.y0=function(t){return arguments.length?(r=t,e):r},e.y1=function(t){return arguments.length?(o=t,e):o},e.defined=function(t){return arguments.length?(a=t,e):a},e.interpolate=function(t){return arguments.length?(u="function"==typeof t?s=t:(s=Nu.get(t)||wo).key,l=s.reverse||s,c=s.closed?"M":"L",e):u},e.tension=function(t){return arguments.length?(d=t,e):d},e}function Uo(t){return t.radius}function qo(t){return[t.x,t.y]}function Bo(t){return function(){var e=t.apply(this,arguments),n=e[0],i=e[1]-Ra;return[n*Math.cos(i),n*Math.sin(i)]}}function Vo(){return 64}function Yo(){return"circle"}function Go(t){var e=Math.sqrt(t/La);return"M0,"+e+"A"+e+","+e+" 0 1,1 0,"+-e+"A"+e+","+e+" 0 1,1 0,"+e+"Z"}function Xo(t){return function(){var e,n,i;(e=this[t])&&(i=e[n=e.active])&&(i.timer.c=null,i.timer.t=NaN,--e.count?delete e[n]:delete this[t],e.active+=.5,i.event&&i.event.interrupt.call(this,this.__data__,i.index))}}function Ko(t,e,n){return Ca(t,Uu),t.namespace=e,t.id=n,t}function Zo(t,e,n,i){var r=t.id,o=t.namespace;return U(t,"function"==typeof n?function(t,a,s){t[o][r].tween.set(e,i(n.call(t,t.__data__,a,s)))}:(n=i(n),function(t){t[o][r].tween.set(e,n)}))}function Qo(t){return null==t&&(t=""),function(){this.textContent=t}}function Jo(t){return null==t?"__transition__":"__transition_"+t+"__"}function ta(t,e,n,i,r){function o(t){var e=g.delay;return c.t=e+u,t>=e?a(t-e):void(c.c=a)}function a(n){var r=p.active,o=p[r];o&&(o.timer.c=null,o.timer.t=NaN,--p.count,delete p[r],o.event&&o.event.interrupt.call(t,t.__data__,o.index));for(var a in p)if(i>+a){var l=p[a];l.timer.c=null,l.timer.t=NaN,--p.count,delete p[a]}c.c=s,Et(function(){return c.c&&s(n||1)&&(c.c=null,c.t=NaN),1},0,u),p.active=i,g.event&&g.event.start.call(t,t.__data__,e),f=[],g.tween.forEach(function(n,i){(i=i.call(t,t.__data__,e))&&f.push(i)}),h=g.ease,d=g.duration}function s(r){for(var o=r/d,a=h(o),s=f.length;s>0;)f[--s].call(t,a);return o>=1?(g.event&&g.event.end.call(t,t.__data__,e),--p.count?delete p[i]:delete t[n],1):void 0}var u,c,d,h,f,p=t[n]||(t[n]={active:0,count:0}),g=p[i];g||(u=r.time,c=Et(o,0,u),g=p[i]={tween:new l,time:u,timer:c,delay:r.delay,duration:r.duration,ease:r.ease,index:e},r=null,++p.count)}function ea(t,e,n){t.attr("transform",function(t){var i=e(t);return"translate("+(isFinite(i)?i:n(t))+",0)"})}function na(t,e,n){t.attr("transform",function(t){var i=e(t);return"translate(0,"+(isFinite(i)?i:n(t))+")"})}function ia(t){return t.toISOString()}function ra(t,e,n){function i(e){return t(e)}function r(t,n){var i=t[1]-t[0],r=i/n,o=ua.bisect(Qu,r);return o==Qu.length?[e.year,Qr(t.map(function(t){return t/31536e6}),n)[2]]:o?e[r/Qu[o-1]<Qu[o]/r?o-1:o]:[el,Qr(t,n)[2]]}return i.invert=function(e){return oa(t.invert(e))},i.domain=function(e){
return arguments.length?(t.domain(e),i):t.domain().map(oa)},i.nice=function(t,e){function n(n){return!isNaN(n)&&!t.range(n,oa(+n+1),e).length}var o=i.domain(),a=Ur(o),s=null==t?r(a,10):"number"==typeof t&&r(a,t);return s&&(t=s[0],e=s[1]),i.domain(Vr(o,e>1?{floor:function(e){for(;n(e=t.floor(e));)e=oa(e-1);return e},ceil:function(e){for(;n(e=t.ceil(e));)e=oa(+e+1);return e}}:t))},i.ticks=function(t,e){var n=Ur(i.domain()),o=null==t?r(n,10):"number"==typeof t?r(n,t):!t.range&&[{range:t},e];return o&&(t=o[0],e=o[1]),t.range(n[0],oa(+n[1]+1),1>e?1:e)},i.tickFormat=function(){return n},i.copy=function(){return ra(t.copy(),e,n)},Kr(i,t)}function oa(t){return new Date(t)}function aa(t){return JSON.parse(t.responseText)}function sa(t){var e=da.createRange();return e.selectNode(da.body),e.createContextualFragment(t.responseText)}var ua={version:"3.5.16"},la=[].slice,ca=function(t){return la.call(t)},da=this.document;if(da)try{ca(da.documentElement.childNodes)[0].nodeType}catch(ha){ca=function(t){for(var e=t.length,n=new Array(e);e--;)n[e]=t[e];return n}}if(Date.now||(Date.now=function(){return+new Date}),da)try{da.createElement("DIV").style.setProperty("opacity",0,"")}catch(fa){var pa=this.Element.prototype,ga=pa.setAttribute,ma=pa.setAttributeNS,va=this.CSSStyleDeclaration.prototype,ya=va.setProperty;pa.setAttribute=function(t,e){ga.call(this,t,e+"")},pa.setAttributeNS=function(t,e,n){ma.call(this,t,e,n+"")},va.setProperty=function(t,e,n){ya.call(this,t,e+"",n)}}ua.ascending=n,ua.descending=function(t,e){return t>e?-1:e>t?1:e>=t?0:NaN},ua.min=function(t,e){var n,i,r=-1,o=t.length;if(1===arguments.length){for(;++r<o;)if(null!=(i=t[r])&&i>=i){n=i;break}for(;++r<o;)null!=(i=t[r])&&n>i&&(n=i)}else{for(;++r<o;)if(null!=(i=e.call(t,t[r],r))&&i>=i){n=i;break}for(;++r<o;)null!=(i=e.call(t,t[r],r))&&n>i&&(n=i)}return n},ua.max=function(t,e){var n,i,r=-1,o=t.length;if(1===arguments.length){for(;++r<o;)if(null!=(i=t[r])&&i>=i){n=i;break}for(;++r<o;)null!=(i=t[r])&&i>n&&(n=i)}else{for(;++r<o;)if(null!=(i=e.call(t,t[r],r))&&i>=i){n=i;break}for(;++r<o;)null!=(i=e.call(t,t[r],r))&&i>n&&(n=i)}return n},ua.extent=function(t,e){var n,i,r,o=-1,a=t.length;if(1===arguments.length){for(;++o<a;)if(null!=(i=t[o])&&i>=i){n=r=i;break}for(;++o<a;)null!=(i=t[o])&&(n>i&&(n=i),i>r&&(r=i))}else{for(;++o<a;)if(null!=(i=e.call(t,t[o],o))&&i>=i){n=r=i;break}for(;++o<a;)null!=(i=e.call(t,t[o],o))&&(n>i&&(n=i),i>r&&(r=i))}return[n,r]},ua.sum=function(t,e){var n,i=0,o=t.length,a=-1;if(1===arguments.length)for(;++a<o;)r(n=+t[a])&&(i+=n);else for(;++a<o;)r(n=+e.call(t,t[a],a))&&(i+=n);return i},ua.mean=function(t,e){var n,o=0,a=t.length,s=-1,u=a;if(1===arguments.length)for(;++s<a;)r(n=i(t[s]))?o+=n:--u;else for(;++s<a;)r(n=i(e.call(t,t[s],s)))?o+=n:--u;return u?o/u:void 0},ua.quantile=function(t,e){var n=(t.length-1)*e+1,i=Math.floor(n),r=+t[i-1],o=n-i;return o?r+o*(t[i]-r):r},ua.median=function(t,e){var o,a=[],s=t.length,u=-1;if(1===arguments.length)for(;++u<s;)r(o=i(t[u]))&&a.push(o);else for(;++u<s;)r(o=i(e.call(t,t[u],u)))&&a.push(o);return a.length?ua.quantile(a.sort(n),.5):void 0},ua.variance=function(t,e){var n,o,a=t.length,s=0,u=0,l=-1,c=0;if(1===arguments.length)for(;++l<a;)r(n=i(t[l]))&&(o=n-s,s+=o/++c,u+=o*(n-s));else for(;++l<a;)r(n=i(e.call(t,t[l],l)))&&(o=n-s,s+=o/++c,u+=o*(n-s));return c>1?u/(c-1):void 0},ua.deviation=function(){var t=ua.variance.apply(this,arguments);return t?Math.sqrt(t):t};var ba=o(n);ua.bisectLeft=ba.left,ua.bisect=ua.bisectRight=ba.right,ua.bisector=function(t){return o(1===t.length?function(e,i){return n(t(e),i)}:t)},ua.shuffle=function(t,e,n){(o=arguments.length)<3&&(n=t.length,2>o&&(e=0));for(var i,r,o=n-e;o;)r=Math.random()*o--|0,i=t[o+e],t[o+e]=t[r+e],t[r+e]=i;return t},ua.permute=function(t,e){for(var n=e.length,i=new Array(n);n--;)i[n]=t[e[n]];return i},ua.pairs=function(t){for(var e,n=0,i=t.length-1,r=t[0],o=new Array(0>i?0:i);i>n;)o[n]=[e=r,r=t[++n]];return o},ua.transpose=function(t){if(!(r=t.length))return[];for(var e=-1,n=ua.min(t,a),i=new Array(n);++e<n;)for(var r,o=-1,s=i[e]=new Array(r);++o<r;)s[o]=t[o][e];return i},ua.zip=function(){return ua.transpose(arguments)},ua.keys=function(t){var e=[];for(var n in t)e.push(n);return e},ua.values=function(t){var e=[];for(var n in t)e.push(t[n]);return e},ua.entries=function(t){var e=[];for(var n in t)e.push({key:n,value:t[n]});return e},ua.merge=function(t){for(var e,n,i,r=t.length,o=-1,a=0;++o<r;)a+=t[o].length;for(n=new Array(a);--r>=0;)for(i=t[r],e=i.length;--e>=0;)n[--a]=i[e];return n};var xa=Math.abs;ua.range=function(t,e,n){if(arguments.length<3&&(n=1,arguments.length<2&&(e=t,t=0)),(e-t)/n===1/0)throw new Error("infinite range");var i,r=[],o=s(xa(n)),a=-1;if(t*=o,e*=o,n*=o,0>n)for(;(i=t+n*++a)>e;)r.push(i/o);else for(;(i=t+n*++a)<e;)r.push(i/o);return r},ua.map=function(t,e){var n=new l;if(t instanceof l)t.forEach(function(t,e){n.set(t,e)});else if(Array.isArray(t)){var i,r=-1,o=t.length;if(1===arguments.length)for(;++r<o;)n.set(r,t[r]);else for(;++r<o;)n.set(e.call(t,i=t[r],r),i)}else for(var a in t)n.set(a,t[a]);return n};var wa="__proto__",_a="\x00";u(l,{has:h,get:function(t){return this._[c(t)]},set:function(t,e){return this._[c(t)]=e},remove:f,keys:p,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:d(e),value:this._[e]});return t},size:g,empty:m,forEach:function(t){for(var e in this._)t.call(this,d(e),this._[e])}}),ua.nest=function(){function t(e,a,s){if(s>=o.length)return i?i.call(r,a):n?a.sort(n):a;for(var u,c,d,h,f=-1,p=a.length,g=o[s++],m=new l;++f<p;)(h=m.get(u=g(c=a[f])))?h.push(c):m.set(u,[c]);return e?(c=e(),d=function(n,i){c.set(n,t(e,i,s))}):(c={},d=function(n,i){c[n]=t(e,i,s)}),m.forEach(d),c}function e(t,n){if(n>=o.length)return t;var i=[],r=a[n++];return t.forEach(function(t,r){i.push({key:t,values:e(r,n)})}),r?i.sort(function(t,e){return r(t.key,e.key)}):i}var n,i,r={},o=[],a=[];return r.map=function(e,n){return t(n,e,0)},r.entries=function(n){return e(t(ua.map,n,0),0)},r.key=function(t){return o.push(t),r},r.sortKeys=function(t){return a[o.length-1]=t,r},r.sortValues=function(t){return n=t,r},r.rollup=function(t){return i=t,r},r},ua.set=function(t){var e=new v;if(t)for(var n=0,i=t.length;i>n;++n)e.add(t[n]);return e},u(v,{has:h,add:function(t){return this._[c(t+="")]=!0,t},remove:f,values:p,size:g,empty:m,forEach:function(t){for(var e in this._)t.call(this,d(e))}}),ua.behavior={},ua.rebind=function(t,e){for(var n,i=1,r=arguments.length;++i<r;)t[n=arguments[i]]=b(t,e,e[n]);return t};var $a=["webkit","ms","moz","Moz","o","O"];ua.dispatch=function(){for(var t=new _,e=-1,n=arguments.length;++e<n;)t[arguments[e]]=$(t);return t},_.prototype.on=function(t,e){var n=t.indexOf("."),i="";if(n>=0&&(i=t.slice(n+1),t=t.slice(0,n)),t)return arguments.length<2?this[t].on(i):this[t].on(i,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(i,null);return this}},ua.event=null,ua.requote=function(t){return t.replace(ka,"\\$&")};var ka=/[\\\^\$\*\+\?\|\[\]\(\)\.\{\}]/g,Ca={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var n in e)t[n]=e[n]},Ma=function(t,e){return e.querySelector(t)},Da=function(t,e){return e.querySelectorAll(t)},Sa=function(t,e){var n=t.matches||t[x(t,"matchesSelector")];return(Sa=function(t,e){return n.call(t,e)})(t,e)};"function"==typeof Sizzle&&(Ma=function(t,e){return Sizzle(t,e)[0]||null},Da=Sizzle,Sa=Sizzle.matchesSelector),ua.selection=function(){return ua.select(da.documentElement)};var Ta=ua.selection.prototype=[];Ta.select=function(t){var e,n,i,r,o=[];t=S(t);for(var a=-1,s=this.length;++a<s;){o.push(e=[]),e.parentNode=(i=this[a]).parentNode;for(var u=-1,l=i.length;++u<l;)(r=i[u])?(e.push(n=t.call(r,r.__data__,u,a)),n&&"__data__"in r&&(n.__data__=r.__data__)):e.push(null)}return D(o)},Ta.selectAll=function(t){var e,n,i=[];t=T(t);for(var r=-1,o=this.length;++r<o;)for(var a=this[r],s=-1,u=a.length;++s<u;)(n=a[s])&&(i.push(e=ca(t.call(n,n.__data__,s,r))),e.parentNode=n);return D(i)};var Aa="http://www.w3.org/1999/xhtml",Ea={svg:"http://www.w3.org/2000/svg",xhtml:Aa,xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"};ua.ns={prefix:Ea,qualify:function(t){var e=t.indexOf(":"),n=t;return e>=0&&"xmlns"!==(n=t.slice(0,e))&&(t=t.slice(e+1)),Ea.hasOwnProperty(n)?{space:Ea[n],local:t}:t}},Ta.attr=function(t,e){if(arguments.length<2){if("string"==typeof t){var n=this.node();return t=ua.ns.qualify(t),t.local?n.getAttributeNS(t.space,t.local):n.getAttribute(t)}for(e in t)this.each(A(e,t[e]));return this}return this.each(A(t,e))},Ta.classed=function(t,e){if(arguments.length<2){if("string"==typeof t){var n=this.node(),i=(t=N(t)).length,r=-1;if(e=n.classList){for(;++r<i;)if(!e.contains(t[r]))return!1}else for(e=n.getAttribute("class");++r<i;)if(!O(t[r]).test(e))return!1;return!0}for(e in t)this.each(I(e,t[e]));return this}return this.each(I(t,e))},Ta.style=function(t,n,i){var r=arguments.length;if(3>r){if("string"!=typeof t){2>r&&(n="");for(i in t)this.each(F(i,t[i],n));return this}if(2>r){var o=this.node();return e(o).getComputedStyle(o,null).getPropertyValue(t)}i=""}return this.each(F(t,n,i))},Ta.property=function(t,e){if(arguments.length<2){if("string"==typeof t)return this.node()[t];for(e in t)this.each(W(e,t[e]));return this}return this.each(W(t,e))},Ta.text=function(t){return arguments.length?this.each("function"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?"":e}:null==t?function(){this.textContent=""}:function(){this.textContent=t}):this.node().textContent},Ta.html=function(t){return arguments.length?this.each("function"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?"":e}:null==t?function(){this.innerHTML=""}:function(){this.innerHTML=t}):this.node().innerHTML},Ta.append=function(t){return t=H(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},Ta.insert=function(t,e){return t=H(t),e=S(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},Ta.remove=function(){return this.each(L)},Ta.data=function(t,e){function n(t,n){var i,r,o,a=t.length,d=n.length,h=Math.min(a,d),f=new Array(d),p=new Array(d),g=new Array(a);if(e){var m,v=new l,y=new Array(a);for(i=-1;++i<a;)(r=t[i])&&(v.has(m=e.call(r,r.__data__,i))?g[i]=r:v.set(m,r),y[i]=m);for(i=-1;++i<d;)(r=v.get(m=e.call(n,o=n[i],i)))?r!==!0&&(f[i]=r,r.__data__=o):p[i]=z(o),v.set(m,!0);for(i=-1;++i<a;)i in y&&v.get(y[i])!==!0&&(g[i]=t[i])}else{for(i=-1;++i<h;)r=t[i],o=n[i],r?(r.__data__=o,f[i]=r):p[i]=z(o);for(;d>i;++i)p[i]=z(n[i]);for(;a>i;++i)g[i]=t[i]}p.update=f,p.parentNode=f.parentNode=g.parentNode=t.parentNode,s.push(p),u.push(f),c.push(g)}var i,r,o=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(i=this[0]).length);++o<a;)(r=i[o])&&(t[o]=r.__data__);return t}var s=q([]),u=D([]),c=D([]);if("function"==typeof t)for(;++o<a;)n(i=this[o],t.call(i,i.parentNode.__data__,o));else for(;++o<a;)n(i=this[o],t);return u.enter=function(){return s},u.exit=function(){return c},u},Ta.datum=function(t){return arguments.length?this.property("__data__",t):this.property("__data__")},Ta.filter=function(t){var e,n,i,r=[];"function"!=typeof t&&(t=j(t));for(var o=0,a=this.length;a>o;o++){r.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var s=0,u=n.length;u>s;s++)(i=n[s])&&t.call(i,i.__data__,s,o)&&e.push(i)}return D(r)},Ta.order=function(){for(var t=-1,e=this.length;++t<e;)for(var n,i=this[t],r=i.length-1,o=i[r];--r>=0;)(n=i[r])&&(o&&o!==n.nextSibling&&o.parentNode.insertBefore(n,o),o=n);return this},Ta.sort=function(t){t=R.apply(this,arguments);for(var e=-1,n=this.length;++e<n;)this[e].sort(t);return this.order()},Ta.each=function(t){return U(this,function(e,n,i){t.call(e,e.__data__,n,i)})},Ta.call=function(t){var e=ca(arguments);return t.apply(e[0]=this,e),this},Ta.empty=function(){return!this.node()},Ta.node=function(){for(var t=0,e=this.length;e>t;t++)for(var n=this[t],i=0,r=n.length;r>i;i++){var o=n[i];if(o)return o}return null},Ta.size=function(){var t=0;return U(this,function(){++t}),t};var Oa=[];ua.selection.enter=q,ua.selection.enter.prototype=Oa,Oa.append=Ta.append,Oa.empty=Ta.empty,Oa.node=Ta.node,Oa.call=Ta.call,Oa.size=Ta.size,Oa.select=function(t){for(var e,n,i,r,o,a=[],s=-1,u=this.length;++s<u;){i=(r=this[s]).update,a.push(e=[]),e.parentNode=r.parentNode;for(var l=-1,c=r.length;++l<c;)(o=r[l])?(e.push(i[l]=n=t.call(r.parentNode,o.__data__,l,s)),n.__data__=o.__data__):e.push(null)}return D(a)},Oa.insert=function(t,e){return arguments.length<2&&(e=B(this)),Ta.insert.call(this,t,e)},ua.select=function(e){var n;return"string"==typeof e?(n=[Ma(e,da)],n.parentNode=da.documentElement):(n=[e],n.parentNode=t(e)),D([n])},ua.selectAll=function(t){var e;return"string"==typeof t?(e=ca(Da(t,da)),e.parentNode=da.documentElement):(e=ca(t),e.parentNode=null),D([e])},Ta.on=function(t,e,n){var i=arguments.length;if(3>i){if("string"!=typeof t){2>i&&(e=!1);for(n in t)this.each(V(n,t[n],e));return this}if(2>i)return(i=this.node()["__on"+t])&&i._;n=!1}return this.each(V(t,e,n))};var Na=ua.map({mouseenter:"mouseover",mouseleave:"mouseout"});da&&Na.forEach(function(t){"on"+t in da&&Na.remove(t)});var Ia,Pa=0;ua.mouse=function(t){return K(t,C())};var Fa=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;ua.touch=function(t,e,n){if(arguments.length<3&&(n=e,e=C().changedTouches),e)for(var i,r=0,o=e.length;o>r;++r)if((i=e[r]).identifier===n)return K(t,i)},ua.behavior.drag=function(){function t(){this.on("mousedown.drag",o).on("touchstart.drag",a)}function n(t,e,n,o,a){return function(){function s(){var t,n,i=e(h,g);i&&(t=i[0]-b[0],n=i[1]-b[1],p|=t|n,b=i,f({type:"drag",x:i[0]+l[0],y:i[1]+l[1],dx:t,dy:n}))}function u(){e(h,g)&&(v.on(o+m,null).on(a+m,null),y(p),f({type:"dragend"}))}var l,c=this,d=ua.event.target.correspondingElement||ua.event.target,h=c.parentNode,f=i.of(c,arguments),p=0,g=t(),m=".drag"+(null==g?"":"-"+g),v=ua.select(n(d)).on(o+m,s).on(a+m,u),y=X(d),b=e(h,g);r?(l=r.apply(c,arguments),l=[l.x-b[0],l.y-b[1]]):l=[0,0],f({type:"dragstart"})}}var i=M(t,"drag","dragstart","dragend"),r=null,o=n(w,ua.mouse,e,"mousemove","mouseup"),a=n(Z,ua.touch,y,"touchmove","touchend");return t.origin=function(e){return arguments.length?(r=e,t):r},ua.rebind(t,i,"on")},ua.touches=function(t,e){return arguments.length<2&&(e=C().touches),e?ca(e).map(function(e){var n=K(t,e);return n.identifier=e.identifier,n}):[]};var Wa=1e-6,Ha=Wa*Wa,La=Math.PI,za=2*La,ja=za-Wa,Ra=La/2,Ua=La/180,qa=180/La,Ba=Math.SQRT2,Va=2,Ya=4;ua.interpolateZoom=function(t,e){var n,i,r=t[0],o=t[1],a=t[2],s=e[0],u=e[1],l=e[2],c=s-r,d=u-o,h=c*c+d*d;if(Ha>h)i=Math.log(l/a)/Ba,n=function(t){return[r+t*c,o+t*d,a*Math.exp(Ba*t*i)]};else{var f=Math.sqrt(h),p=(l*l-a*a+Ya*h)/(2*a*Va*f),g=(l*l-a*a-Ya*h)/(2*l*Va*f),m=Math.log(Math.sqrt(p*p+1)-p),v=Math.log(Math.sqrt(g*g+1)-g);i=(v-m)/Ba,n=function(t){var e=t*i,n=it(m),s=a/(Va*f)*(n*rt(Ba*e+m)-nt(m));return[r+s*c,o+s*d,a*n/it(Ba*e+m)]}}return n.duration=1e3*i,n},ua.behavior.zoom=function(){function t(t){t.on(E,d).on(Xa+".zoom",f).on("dblclick.zoom",p).on(I,h)}function n(t){return[(t[0]-C.x)/C.k,(t[1]-C.y)/C.k]}function i(t){return[t[0]*C.k+C.x,t[1]*C.k+C.y]}function r(t){C.k=Math.max(S[0],Math.min(S[1],t))}function o(t,e){e=i(e),C.x+=t[0]-e[0],C.y+=t[1]-e[1]}function a(e,n,i,a){e.__chart__={x:C.x,y:C.y,k:C.k},r(Math.pow(2,a)),o(m=n,i),e=ua.select(e),T>0&&(e=e.transition().duration(T)),e.call(t.event)}function s(){w&&w.domain(x.range().map(function(t){return(t-C.x)/C.k}).map(x.invert)),$&&$.domain(_.range().map(function(t){return(t-C.y)/C.k}).map(_.invert))}function u(t){A++||t({type:"zoomstart"})}function l(t){s(),t({type:"zoom",scale:C.k,translate:[C.x,C.y]})}function c(t){--A||(t({type:"zoomend"}),m=null)}function d(){function t(){s=1,o(ua.mouse(r),h),l(a)}function i(){d.on(O,null).on(N,null),f(s),c(a)}var r=this,a=P.of(r,arguments),s=0,d=ua.select(e(r)).on(O,t).on(N,i),h=n(ua.mouse(r)),f=X(r);Ru.call(r),u(a)}function h(){function t(){var t=ua.touches(p);return f=C.k,t.forEach(function(t){t.identifier in m&&(m[t.identifier]=n(t))}),t}function e(){var e=ua.event.target;ua.select(e).on(x,i).on(w,s),_.push(e);for(var n=ua.event.changedTouches,r=0,o=n.length;o>r;++r)m[n[r].identifier]=null;var u=t(),l=Date.now();if(1===u.length){if(500>l-b){var c=u[0];a(p,c,m[c.identifier],Math.floor(Math.log(C.k)/Math.LN2)+1),k()}b=l}else if(u.length>1){var c=u[0],d=u[1],h=c[0]-d[0],f=c[1]-d[1];v=h*h+f*f}}function i(){var t,e,n,i,a=ua.touches(p);Ru.call(p);for(var s=0,u=a.length;u>s;++s,i=null)if(n=a[s],i=m[n.identifier]){if(e)break;t=n,e=i}if(i){var c=(c=n[0]-t[0])*c+(c=n[1]-t[1])*c,d=v&&Math.sqrt(c/v);t=[(t[0]+n[0])/2,(t[1]+n[1])/2],e=[(e[0]+i[0])/2,(e[1]+i[1])/2],r(d*f)}b=null,o(t,e),l(g)}function s(){if(ua.event.touches.length){for(var e=ua.event.changedTouches,n=0,i=e.length;i>n;++n)delete m[e[n].identifier];for(var r in m)return void t()}ua.selectAll(_).on(y,null),$.on(E,d).on(I,h),M(),c(g)}var f,p=this,g=P.of(p,arguments),m={},v=0,y=".zoom-"+ua.event.changedTouches[0].identifier,x="touchmove"+y,w="touchend"+y,_=[],$=ua.select(p),M=X(p);e(),u(g),$.on(E,null).on(I,e)}function f(){var t=P.of(this,arguments);y?clearTimeout(y):(Ru.call(this),g=n(m=v||ua.mouse(this)),u(t)),y=setTimeout(function(){y=null,c(t)},50),k(),r(Math.pow(2,.002*Ga())*C.k),o(m,g),l(t)}function p(){var t=ua.mouse(this),e=Math.log(C.k)/Math.LN2;a(this,t,n(t),ua.event.shiftKey?Math.ceil(e)-1:Math.floor(e)+1)}var g,m,v,y,b,x,w,_,$,C={x:0,y:0,k:1},D=[960,500],S=Ka,T=250,A=0,E="mousedown.zoom",O="mousemove.zoom",N="mouseup.zoom",I="touchstart.zoom",P=M(t,"zoomstart","zoom","zoomend");return Xa||(Xa="onwheel"in da?(Ga=function(){return-ua.event.deltaY*(ua.event.deltaMode?120:1)},"wheel"):"onmousewheel"in da?(Ga=function(){return ua.event.wheelDelta},"mousewheel"):(Ga=function(){return-ua.event.detail},"MozMousePixelScroll")),t.event=function(t){t.each(function(){var t=P.of(this,arguments),e=C;zu?ua.select(this).transition().each("start.zoom",function(){C=this.__chart__||{x:0,y:0,k:1},u(t)}).tween("zoom:zoom",function(){var n=D[0],i=D[1],r=m?m[0]:n/2,o=m?m[1]:i/2,a=ua.interpolateZoom([(r-C.x)/C.k,(o-C.y)/C.k,n/C.k],[(r-e.x)/e.k,(o-e.y)/e.k,n/e.k]);return function(e){var i=a(e),s=n/i[2];this.__chart__=C={x:r-i[0]*s,y:o-i[1]*s,k:s},l(t)}}).each("interrupt.zoom",function(){c(t)}).each("end.zoom",function(){c(t)}):(this.__chart__=C,u(t),l(t),c(t))})},t.translate=function(e){return arguments.length?(C={x:+e[0],y:+e[1],k:C.k},s(),t):[C.x,C.y]},t.scale=function(e){return arguments.length?(C={x:C.x,y:C.y,k:null},r(+e),s(),t):C.k},t.scaleExtent=function(e){return arguments.length?(S=null==e?Ka:[+e[0],+e[1]],t):S},t.center=function(e){return arguments.length?(v=e&&[+e[0],+e[1]],t):v},t.size=function(e){return arguments.length?(D=e&&[+e[0],+e[1]],t):D},t.duration=function(e){return arguments.length?(T=+e,t):T},t.x=function(e){return arguments.length?(w=e,x=e.copy(),C={x:0,y:0,k:1},t):w},t.y=function(e){return arguments.length?($=e,_=e.copy(),C={x:0,y:0,k:1},t):$},ua.rebind(t,P,"on")};var Ga,Xa,Ka=[0,1/0];ua.color=at,at.prototype.toString=function(){return this.rgb()+""},ua.hsl=st;var Za=st.prototype=new at;Za.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new st(this.h,this.s,this.l/t)},Za.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new st(this.h,this.s,t*this.l)},Za.rgb=function(){return ut(this.h,this.s,this.l)},ua.hcl=lt;var Qa=lt.prototype=new at;Qa.brighter=function(t){return new lt(this.h,this.c,Math.min(100,this.l+Ja*(arguments.length?t:1)))},Qa.darker=function(t){return new lt(this.h,this.c,Math.max(0,this.l-Ja*(arguments.length?t:1)))},Qa.rgb=function(){return ct(this.h,this.c,this.l).rgb()},ua.lab=dt;var Ja=18,ts=.95047,es=1,ns=1.08883,is=dt.prototype=new at;is.brighter=function(t){return new dt(Math.min(100,this.l+Ja*(arguments.length?t:1)),this.a,this.b)},is.darker=function(t){return new dt(Math.max(0,this.l-Ja*(arguments.length?t:1)),this.a,this.b)},is.rgb=function(){return ht(this.l,this.a,this.b)},ua.rgb=vt;var rs=vt.prototype=new at;rs.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,n=this.g,i=this.b,r=30;return e||n||i?(e&&r>e&&(e=r),n&&r>n&&(n=r),i&&r>i&&(i=r),new vt(Math.min(255,e/t),Math.min(255,n/t),Math.min(255,i/t))):new vt(r,r,r)},rs.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new vt(t*this.r,t*this.g,t*this.b)},rs.hsl=function(){return _t(this.r,this.g,this.b)},rs.toString=function(){return"#"+xt(this.r)+xt(this.g)+xt(this.b)};var os=ua.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});os.forEach(function(t,e){os.set(t,yt(e))}),ua.functor=Mt,ua.xhr=Dt(y),ua.dsv=function(t,e){function n(t,n,o){arguments.length<3&&(o=n,n=null);var a=St(t,e,null==n?i:r(n),o);return a.row=function(t){return arguments.length?a.response(null==(n=t)?i:r(t)):n},a}function i(t){return n.parse(t.responseText)}function r(t){return function(e){return n.parse(e.responseText,t)}}function o(e){return e.map(a).join(t)}function a(t){return s.test(t)?'"'+t.replace(/\"/g,'""')+'"':t}var s=new RegExp('["'+t+"\n]"),u=t.charCodeAt(0);return n.parse=function(t,e){var i;return n.parseRows(t,function(t,n){if(i)return i(t,n-1);var r=new Function("d","return {"+t.map(function(t,e){return JSON.stringify(t)+": d["+e+"]"}).join(",")+"}");i=e?function(t,n){return e(r(t),n)}:r})},n.parseRows=function(t,e){function n(){if(c>=l)return a;if(r)return r=!1,o;var e=c;if(34===t.charCodeAt(e)){for(var n=e;n++<l;)if(34===t.charCodeAt(n)){if(34!==t.charCodeAt(n+1))break;++n}c=n+2;var i=t.charCodeAt(n+1);return 13===i?(r=!0,10===t.charCodeAt(n+2)&&++c):10===i&&(r=!0),t.slice(e+1,n).replace(/""/g,'"')}for(;l>c;){var i=t.charCodeAt(c++),s=1;if(10===i)r=!0;else if(13===i)r=!0,10===t.charCodeAt(c)&&(++c,++s);else if(i!==u)continue;return t.slice(e,c-s)}return t.slice(e)}for(var i,r,o={},a={},s=[],l=t.length,c=0,d=0;(i=n())!==a;){for(var h=[];i!==o&&i!==a;)h.push(i),i=n();e&&null==(h=e(h,d++))||s.push(h)}return s},n.format=function(e){if(Array.isArray(e[0]))return n.formatRows(e);var i=new v,r=[];return e.forEach(function(t){for(var e in t)i.has(e)||r.push(i.add(e))}),[r.map(a).join(t)].concat(e.map(function(e){return r.map(function(t){return a(e[t])}).join(t)})).join("\n")},n.formatRows=function(t){return t.map(o).join("\n")},n},ua.csv=ua.dsv(",","text/csv"),ua.tsv=ua.dsv("	","text/tab-separated-values");var as,ss,us,ls,cs=this[x(this,"requestAnimationFrame")]||function(t){setTimeout(t,17)};ua.timer=function(){Et.apply(this,arguments)},ua.timer.flush=function(){Nt(),It()},ua.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var ds=["y","z","a","f","p","n","µ","m","","k","M","G","T","P","E","Z","Y"].map(Ft);ua.formatPrefix=function(t,e){var n=0;return(t=+t)&&(0>t&&(t*=-1),e&&(t=ua.round(t,Pt(t,e))),n=1+Math.floor(1e-12+Math.log(t)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),ds[8+n/3]};var hs=/(?:([^{])?([<>=^]))?([+\- ])?([$#])?(0)?(\d+)?(,)?(\.-?\d+)?([a-z%])?/i,fs=ua.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(t,e){return(t=ua.round(t,Pt(t,e))).toFixed(Math.max(0,Math.min(20,Pt(t*(1+1e-15),e))))}}),ps=ua.time={},gs=Date;Lt.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){ms.setUTCDate.apply(this._,arguments)},setDay:function(){ms.setUTCDay.apply(this._,arguments)},setFullYear:function(){ms.setUTCFullYear.apply(this._,arguments)},setHours:function(){ms.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){ms.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){ms.setUTCMinutes.apply(this._,arguments)},setMonth:function(){ms.setUTCMonth.apply(this._,arguments)},setSeconds:function(){ms.setUTCSeconds.apply(this._,arguments)},setTime:function(){ms.setTime.apply(this._,arguments)}};var ms=Date.prototype;ps.year=zt(function(t){return t=ps.day(t),t.setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ps.years=ps.year.range,ps.years.utc=ps.year.utc.range,ps.day=zt(function(t){var e=new gs(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ps.days=ps.day.range,ps.days.utc=ps.day.utc.range,ps.dayOfYear=function(t){var e=ps.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},["sunday","monday","tuesday","wednesday","thursday","friday","saturday"].forEach(function(t,e){e=7-e;var n=ps[t]=zt(function(t){return(t=ps.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var n=ps.year(t).getDay();return Math.floor((ps.dayOfYear(t)+(n+e)%7)/7)-(n!==e)});ps[t+"s"]=n.range,ps[t+"s"].utc=n.utc.range,ps[t+"OfYear"]=function(t){var n=ps.year(t).getDay();return Math.floor((ps.dayOfYear(t)+(n+e)%7)/7)}}),ps.week=ps.sunday,ps.weeks=ps.sunday.range,ps.weeks.utc=ps.sunday.utc.range,ps.weekOfYear=ps.sundayOfYear;var vs={"-":"",_:" ",0:"0"},ys=/^\s*\d+/,bs=/^%/;ua.locale=function(t){return{numberFormat:Wt(t),timeFormat:Rt(t)}};var xs=ua.locale({decimal:".",thousands:",",grouping:[3],currency:["$",""],dateTime:"%a %b %e %X %Y",date:"%m/%d/%Y",time:"%H:%M:%S",periods:["AM","PM"],days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]});ua.format=xs.numberFormat,ua.geo={},le.prototype={s:0,t:0,add:function(t){ce(t,this.t,ws),ce(ws.s,this.s,this),this.s?this.t+=ws.t:this.s=ws.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var ws=new le;ua.geo.stream=function(t,e){t&&_s.hasOwnProperty(t.type)?_s[t.type](t,e):de(t,e)};var _s={Feature:function(t,e){de(t.geometry,e)},FeatureCollection:function(t,e){for(var n=t.features,i=-1,r=n.length;++i<r;)de(n[i].geometry,e)}},$s={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var n=t.coordinates,i=-1,r=n.length;++i<r;)t=n[i],e.point(t[0],t[1],t[2])},LineString:function(t,e){he(t.coordinates,e,0)},MultiLineString:function(t,e){for(var n=t.coordinates,i=-1,r=n.length;++i<r;)he(n[i],e,0)},Polygon:function(t,e){fe(t.coordinates,e)},MultiPolygon:function(t,e){for(var n=t.coordinates,i=-1,r=n.length;++i<r;)fe(n[i],e)},GeometryCollection:function(t,e){for(var n=t.geometries,i=-1,r=n.length;++i<r;)de(n[i],e)}};ua.geo.area=function(t){return ks=0,ua.geo.stream(t,Ms),ks};var ks,Cs=new le,Ms={sphere:function(){ks+=4*La},point:w,lineStart:w,lineEnd:w,polygonStart:function(){Cs.reset(),Ms.lineStart=pe},polygonEnd:function(){var t=2*Cs;ks+=0>t?4*La+t:t,Ms.lineStart=Ms.lineEnd=Ms.point=w}};ua.geo.bounds=function(){function t(t,e){b.push(x=[c=t,h=t]),d>e&&(d=e),e>f&&(f=e)}function e(e,n){var i=ge([e*Ua,n*Ua]);if(v){var r=ve(v,i),o=[r[1],-r[0],0],a=ve(o,r);xe(a),a=we(a);var u=e-p,l=u>0?1:-1,g=a[0]*qa*l,m=xa(u)>180;if(m^(g>l*p&&l*e>g)){var y=a[1]*qa;y>f&&(f=y)}else if(g=(g+360)%360-180,m^(g>l*p&&l*e>g)){var y=-a[1]*qa;d>y&&(d=y)}else d>n&&(d=n),n>f&&(f=n);m?p>e?s(c,e)>s(c,h)&&(h=e):s(e,h)>s(c,h)&&(c=e):h>=c?(c>e&&(c=e),e>h&&(h=e)):e>p?s(c,e)>s(c,h)&&(h=e):s(e,h)>s(c,h)&&(c=e)}else t(e,n);v=i,p=e}function n(){w.point=e}function i(){x[0]=c,x[1]=h,w.point=t,v=null}function r(t,n){if(v){var i=t-p;y+=xa(i)>180?i+(i>0?360:-360):i}else g=t,m=n;Ms.point(t,n),e(t,n)}function o(){Ms.lineStart()}function a(){r(g,m),Ms.lineEnd(),xa(y)>Wa&&(c=-(h=180)),x[0]=c,x[1]=h,v=null}function s(t,e){return(e-=t)<0?e+360:e}function u(t,e){return t[0]-e[0]}function l(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}var c,d,h,f,p,g,m,v,y,b,x,w={point:t,lineStart:n,lineEnd:i,polygonStart:function(){w.point=r,w.lineStart=o,w.lineEnd=a,y=0,Ms.polygonStart()},polygonEnd:function(){Ms.polygonEnd(),w.point=t,w.lineStart=n,w.lineEnd=i,0>Cs?(c=-(h=180),d=-(f=90)):y>Wa?f=90:-Wa>y&&(d=-90),x[0]=c,x[1]=h}};return function(t){f=h=-(c=d=1/0),b=[],ua.geo.stream(t,w);var e=b.length;if(e){b.sort(u);for(var n,i=1,r=b[0],o=[r];e>i;++i)n=b[i],l(n[0],r)||l(n[1],r)?(s(r[0],n[1])>s(r[0],r[1])&&(r[1]=n[1]),s(n[0],r[1])>s(r[0],r[1])&&(r[0]=n[0])):o.push(r=n);for(var a,n,p=-(1/0),e=o.length-1,i=0,r=o[e];e>=i;r=n,++i)n=o[i],(a=s(r[1],n[0]))>p&&(p=a,c=n[0],h=r[1])}return b=x=null,c===1/0||d===1/0?[[NaN,NaN],[NaN,NaN]]:[[c,d],[h,f]]}}(),ua.geo.centroid=function(t){
Ds=Ss=Ts=As=Es=Os=Ns=Is=Ps=Fs=Ws=0,ua.geo.stream(t,Hs);var e=Ps,n=Fs,i=Ws,r=e*e+n*n+i*i;return Ha>r&&(e=Os,n=Ns,i=Is,Wa>Ss&&(e=Ts,n=As,i=Es),r=e*e+n*n+i*i,Ha>r)?[NaN,NaN]:[Math.atan2(n,e)*qa,et(i/Math.sqrt(r))*qa]};var Ds,Ss,Ts,As,Es,Os,Ns,Is,Ps,Fs,Ws,Hs={sphere:w,point:$e,lineStart:Ce,lineEnd:Me,polygonStart:function(){Hs.lineStart=De},polygonEnd:function(){Hs.lineStart=Ce}},Ls=Ne(Te,We,Le,[-La,-La/2]),zs=1e9;ua.geo.clipExtent=function(){var t,e,n,i,r,o,a={stream:function(t){return r&&(r.valid=!1),r=o(t),r.valid=!0,r},extent:function(s){return arguments.length?(o=Ue(t=+s[0][0],e=+s[0][1],n=+s[1][0],i=+s[1][1]),r&&(r.valid=!1,r=null),a):[[t,e],[n,i]]}};return a.extent([[0,0],[960,500]])},(ua.geo.conicEqualArea=function(){return qe(Be)}).raw=Be,ua.geo.albers=function(){return ua.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},ua.geo.albersUsa=function(){function t(t){var o=t[0],a=t[1];return e=null,n(o,a),e||(i(o,a),e)||r(o,a),e}var e,n,i,r,o=ua.geo.albers(),a=ua.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=ua.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),u={point:function(t,n){e=[t,n]}};return t.invert=function(t){var e=o.scale(),n=o.translate(),i=(t[0]-n[0])/e,r=(t[1]-n[1])/e;return(r>=.12&&.234>r&&i>=-.425&&-.214>i?a:r>=.166&&.234>r&&i>=-.214&&-.115>i?s:o).invert(t)},t.stream=function(t){var e=o.stream(t),n=a.stream(t),i=s.stream(t);return{point:function(t,r){e.point(t,r),n.point(t,r),i.point(t,r)},sphere:function(){e.sphere(),n.sphere(),i.sphere()},lineStart:function(){e.lineStart(),n.lineStart(),i.lineStart()},lineEnd:function(){e.lineEnd(),n.lineEnd(),i.lineEnd()},polygonStart:function(){e.polygonStart(),n.polygonStart(),i.polygonStart()},polygonEnd:function(){e.polygonEnd(),n.polygonEnd(),i.polygonEnd()}}},t.precision=function(e){return arguments.length?(o.precision(e),a.precision(e),s.precision(e),t):o.precision()},t.scale=function(e){return arguments.length?(o.scale(e),a.scale(.35*e),s.scale(e),t.translate(o.translate())):o.scale()},t.translate=function(e){if(!arguments.length)return o.translate();var l=o.scale(),c=+e[0],d=+e[1];return n=o.translate(e).clipExtent([[c-.455*l,d-.238*l],[c+.455*l,d+.238*l]]).stream(u).point,i=a.translate([c-.307*l,d+.201*l]).clipExtent([[c-.425*l+Wa,d+.12*l+Wa],[c-.214*l-Wa,d+.234*l-Wa]]).stream(u).point,r=s.translate([c-.205*l,d+.212*l]).clipExtent([[c-.214*l+Wa,d+.166*l+Wa],[c-.115*l-Wa,d+.234*l-Wa]]).stream(u).point,t},t.scale(1070)};var js,Rs,Us,qs,Bs,Vs,Ys={point:w,lineStart:w,lineEnd:w,polygonStart:function(){Rs=0,Ys.lineStart=Ve},polygonEnd:function(){Ys.lineStart=Ys.lineEnd=Ys.point=w,js+=xa(Rs/2)}},Gs={point:Ye,lineStart:w,lineEnd:w,polygonStart:w,polygonEnd:w},Xs={point:Ke,lineStart:Ze,lineEnd:Qe,polygonStart:function(){Xs.lineStart=Je},polygonEnd:function(){Xs.point=Ke,Xs.lineStart=Ze,Xs.lineEnd=Qe}};ua.geo.path=function(){function t(t){return t&&("function"==typeof s&&o.pointRadius(+s.apply(this,arguments)),a&&a.valid||(a=r(o)),ua.geo.stream(t,a)),o.result()}function e(){return a=null,t}var n,i,r,o,a,s=4.5;return t.area=function(t){return js=0,ua.geo.stream(t,r(Ys)),js},t.centroid=function(t){return Ts=As=Es=Os=Ns=Is=Ps=Fs=Ws=0,ua.geo.stream(t,r(Xs)),Ws?[Ps/Ws,Fs/Ws]:Is?[Os/Is,Ns/Is]:Es?[Ts/Es,As/Es]:[NaN,NaN]},t.bounds=function(t){return Bs=Vs=-(Us=qs=1/0),ua.geo.stream(t,r(Gs)),[[Us,qs],[Bs,Vs]]},t.projection=function(t){return arguments.length?(r=(n=t)?t.stream||nn(t):y,e()):n},t.context=function(t){return arguments.length?(o=null==(i=t)?new Ge:new tn(t),"function"!=typeof s&&o.pointRadius(s),e()):i},t.pointRadius=function(e){return arguments.length?(s="function"==typeof e?e:(o.pointRadius(+e),+e),t):s},t.projection(ua.geo.albersUsa()).context(null)},ua.geo.transform=function(t){return{stream:function(e){var n=new rn(e);for(var i in t)n[i]=t[i];return n}}},rn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},ua.geo.projection=an,ua.geo.projectionMutator=sn,(ua.geo.equirectangular=function(){return an(ln)}).raw=ln.invert=ln,ua.geo.rotation=function(t){function e(e){return e=t(e[0]*Ua,e[1]*Ua),e[0]*=qa,e[1]*=qa,e}return t=dn(t[0]%360*Ua,t[1]*Ua,t.length>2?t[2]*Ua:0),e.invert=function(e){return e=t.invert(e[0]*Ua,e[1]*Ua),e[0]*=qa,e[1]*=qa,e},e},cn.invert=ln,ua.geo.circle=function(){function t(){var t="function"==typeof i?i.apply(this,arguments):i,e=dn(-t[0]*Ua,-t[1]*Ua,0).invert,r=[];return n(null,null,1,{point:function(t,n){r.push(t=e(t,n)),t[0]*=qa,t[1]*=qa}}),{type:"Polygon",coordinates:[r]}}var e,n,i=[0,0],r=6;return t.origin=function(e){return arguments.length?(i=e,t):i},t.angle=function(i){return arguments.length?(n=gn((e=+i)*Ua,r*Ua),t):e},t.precision=function(i){return arguments.length?(n=gn(e*Ua,(r=+i)*Ua),t):r},t.angle(90)},ua.geo.distance=function(t,e){var n,i=(e[0]-t[0])*Ua,r=t[1]*Ua,o=e[1]*Ua,a=Math.sin(i),s=Math.cos(i),u=Math.sin(r),l=Math.cos(r),c=Math.sin(o),d=Math.cos(o);return Math.atan2(Math.sqrt((n=d*a)*n+(n=l*c-u*d*s)*n),u*c+l*d*s)},ua.geo.graticule=function(){function t(){return{type:"MultiLineString",coordinates:e()}}function e(){return ua.range(Math.ceil(o/m)*m,r,m).map(h).concat(ua.range(Math.ceil(l/v)*v,u,v).map(f)).concat(ua.range(Math.ceil(i/p)*p,n,p).filter(function(t){return xa(t%m)>Wa}).map(c)).concat(ua.range(Math.ceil(s/g)*g,a,g).filter(function(t){return xa(t%v)>Wa}).map(d))}var n,i,r,o,a,s,u,l,c,d,h,f,p=10,g=p,m=90,v=360,y=2.5;return t.lines=function(){return e().map(function(t){return{type:"LineString",coordinates:t}})},t.outline=function(){return{type:"Polygon",coordinates:[h(o).concat(f(u).slice(1),h(r).reverse().slice(1),f(l).reverse().slice(1))]}},t.extent=function(e){return arguments.length?t.majorExtent(e).minorExtent(e):t.minorExtent()},t.majorExtent=function(e){return arguments.length?(o=+e[0][0],r=+e[1][0],l=+e[0][1],u=+e[1][1],o>r&&(e=o,o=r,r=e),l>u&&(e=l,l=u,u=e),t.precision(y)):[[o,l],[r,u]]},t.minorExtent=function(e){return arguments.length?(i=+e[0][0],n=+e[1][0],s=+e[0][1],a=+e[1][1],i>n&&(e=i,i=n,n=e),s>a&&(e=s,s=a,a=e),t.precision(y)):[[i,s],[n,a]]},t.step=function(e){return arguments.length?t.majorStep(e).minorStep(e):t.minorStep()},t.majorStep=function(e){return arguments.length?(m=+e[0],v=+e[1],t):[m,v]},t.minorStep=function(e){return arguments.length?(p=+e[0],g=+e[1],t):[p,g]},t.precision=function(e){return arguments.length?(y=+e,c=vn(s,a,90),d=yn(i,n,y),h=vn(l,u,90),f=yn(o,r,y),t):y},t.majorExtent([[-180,-90+Wa],[180,90-Wa]]).minorExtent([[-180,-80-Wa],[180,80+Wa]])},ua.geo.greatArc=function(){function t(){return{type:"LineString",coordinates:[e||i.apply(this,arguments),n||r.apply(this,arguments)]}}var e,n,i=bn,r=xn;return t.distance=function(){return ua.geo.distance(e||i.apply(this,arguments),n||r.apply(this,arguments))},t.source=function(n){return arguments.length?(i=n,e="function"==typeof n?null:n,t):i},t.target=function(e){return arguments.length?(r=e,n="function"==typeof e?null:e,t):r},t.precision=function(){return arguments.length?t:0},t},ua.geo.interpolate=function(t,e){return wn(t[0]*Ua,t[1]*Ua,e[0]*Ua,e[1]*Ua)},ua.geo.length=function(t){return Ks=0,ua.geo.stream(t,Zs),Ks};var Ks,Zs={sphere:w,point:w,lineStart:_n,lineEnd:w,polygonStart:w,polygonEnd:w},Qs=$n(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(ua.geo.azimuthalEqualArea=function(){return an(Qs)}).raw=Qs;var Js=$n(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},y);(ua.geo.azimuthalEquidistant=function(){return an(Js)}).raw=Js,(ua.geo.conicConformal=function(){return qe(kn)}).raw=kn,(ua.geo.conicEquidistant=function(){return qe(Cn)}).raw=Cn;var tu=$n(function(t){return 1/t},Math.atan);(ua.geo.gnomonic=function(){return an(tu)}).raw=tu,Mn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Ra]},(ua.geo.mercator=function(){return Dn(Mn)}).raw=Mn;var eu=$n(function(){return 1},Math.asin);(ua.geo.orthographic=function(){return an(eu)}).raw=eu;var nu=$n(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});(ua.geo.stereographic=function(){return an(nu)}).raw=nu,Sn.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Ra]},(ua.geo.transverseMercator=function(){var t=Dn(Sn),e=t.center,n=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):(t=e(),[t[1],-t[0]])},t.rotate=function(t){return t?n([t[0],t[1],t.length>2?t[2]+90:90]):(t=n(),[t[0],t[1],t[2]-90])},n([0,0,90])}).raw=Sn,ua.geom={},ua.geom.hull=function(t){function e(t){if(t.length<3)return[];var e,r=Mt(n),o=Mt(i),a=t.length,s=[],u=[];for(e=0;a>e;e++)s.push([+r.call(this,t[e],e),+o.call(this,t[e],e),e]);for(s.sort(On),e=0;a>e;e++)u.push([s[e][0],-s[e][1]]);var l=En(s),c=En(u),d=c[0]===l[0],h=c[c.length-1]===l[l.length-1],f=[];for(e=l.length-1;e>=0;--e)f.push(t[s[l[e]][2]]);for(e=+d;e<c.length-h;++e)f.push(t[s[c[e]][2]]);return f}var n=Tn,i=An;return arguments.length?e(t):(e.x=function(t){return arguments.length?(n=t,e):n},e.y=function(t){return arguments.length?(i=t,e):i},e)},ua.geom.polygon=function(t){return Ca(t,iu),t};var iu=ua.geom.polygon.prototype=[];iu.area=function(){for(var t,e=-1,n=this.length,i=this[n-1],r=0;++e<n;)t=i,i=this[e],r+=t[1]*i[0]-t[0]*i[1];return.5*r},iu.centroid=function(t){var e,n,i=-1,r=this.length,o=0,a=0,s=this[r-1];for(arguments.length||(t=-1/(6*this.area()));++i<r;)e=s,s=this[i],n=e[0]*s[1]-s[0]*e[1],o+=(e[0]+s[0])*n,a+=(e[1]+s[1])*n;return[o*t,a*t]},iu.clip=function(t){for(var e,n,i,r,o,a,s=Pn(t),u=-1,l=this.length-Pn(this),c=this[l-1];++u<l;){for(e=t.slice(),t.length=0,r=this[u],o=e[(i=e.length-s)-1],n=-1;++n<i;)a=e[n],Nn(a,c,r)?(Nn(o,c,r)||t.push(In(o,a,c,r)),t.push(a)):Nn(o,c,r)&&t.push(In(o,a,c,r)),o=a;s&&t.push(t[0]),c=r}return t};var ru,ou,au,su,uu,lu=[],cu=[];Un.prototype.prepare=function(){for(var t,e=this.edges,n=e.length;n--;)t=e[n].edge,t.b&&t.a||e.splice(n,1);return e.sort(Bn),e.length},ei.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},ni.prototype={insert:function(t,e){var n,i,r;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;n=t}else this._?(t=ai(this._),e.P=null,e.N=t,t.P=t.L=e,n=t):(e.P=e.N=null,this._=e,n=null);for(e.L=e.R=null,e.U=n,e.C=!0,t=e;n&&n.C;)i=n.U,n===i.L?(r=i.R,r&&r.C?(n.C=r.C=!1,i.C=!0,t=i):(t===n.R&&(ri(this,n),t=n,n=t.U),n.C=!1,i.C=!0,oi(this,i))):(r=i.L,r&&r.C?(n.C=r.C=!1,i.C=!0,t=i):(t===n.L&&(oi(this,n),t=n,n=t.U),n.C=!1,i.C=!0,ri(this,i))),n=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,n,i,r=t.U,o=t.L,a=t.R;if(n=o?a?ai(a):o:a,r?r.L===t?r.L=n:r.R=n:this._=n,o&&a?(i=n.C,n.C=t.C,n.L=o,o.U=n,n!==a?(r=n.U,n.U=t.U,t=n.R,r.L=t,n.R=a,a.U=n):(n.U=r,r=n,t=n.R)):(i=t.C,t=n),t&&(t.U=r),!i){if(t&&t.C)return void(t.C=!1);do{if(t===this._)break;if(t===r.L){if(e=r.R,e.C&&(e.C=!1,r.C=!0,ri(this,r),e=r.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,oi(this,e),e=r.R),e.C=r.C,r.C=e.R.C=!1,ri(this,r),t=this._;break}}else if(e=r.L,e.C&&(e.C=!1,r.C=!0,oi(this,r),e=r.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,ri(this,e),e=r.L),e.C=r.C,r.C=e.L.C=!1,oi(this,r),t=this._;break}e.C=!0,t=r,r=r.U}while(!t.C);t&&(t.C=!1)}}},ua.geom.voronoi=function(t){function e(t){var e=new Array(t.length),i=s[0][0],r=s[0][1],o=s[1][0],a=s[1][1];return si(n(t),s).cells.forEach(function(n,s){var u=n.edges,l=n.site,c=e[s]=u.length?u.map(function(t){var e=t.start();return[e.x,e.y]}):l.x>=i&&l.x<=o&&l.y>=r&&l.y<=a?[[i,a],[o,a],[o,r],[i,r]]:[];c.point=t[s]}),e}function n(t){return t.map(function(t,e){return{x:Math.round(o(t,e)/Wa)*Wa,y:Math.round(a(t,e)/Wa)*Wa,i:e}})}var i=Tn,r=An,o=i,a=r,s=du;return t?e(t):(e.links=function(t){return si(n(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},e.triangles=function(t){var e=[];return si(n(t)).cells.forEach(function(n,i){for(var r,o,a=n.site,s=n.edges.sort(Bn),u=-1,l=s.length,c=s[l-1].edge,d=c.l===a?c.r:c.l;++u<l;)r=c,o=d,c=s[u].edge,d=c.l===a?c.r:c.l,i<o.i&&i<d.i&&li(a,o,d)<0&&e.push([t[i],t[o.i],t[d.i]])}),e},e.x=function(t){return arguments.length?(o=Mt(i=t),e):i},e.y=function(t){return arguments.length?(a=Mt(r=t),e):r},e.clipExtent=function(t){return arguments.length?(s=null==t?du:t,e):s===du?null:s},e.size=function(t){return arguments.length?e.clipExtent(t&&[[0,0],t]):s===du?null:s&&s[1]},e)};var du=[[-1e6,-1e6],[1e6,1e6]];ua.geom.delaunay=function(t){return ua.geom.voronoi().triangles(t)},ua.geom.quadtree=function(t,e,n,i,r){function o(t){function o(t,e,n,i,r,o,a,s){if(!isNaN(n)&&!isNaN(i))if(t.leaf){var u=t.x,c=t.y;if(null!=u)if(xa(u-n)+xa(c-i)<.01)l(t,e,n,i,r,o,a,s);else{var d=t.point;t.x=t.y=t.point=null,l(t,d,u,c,r,o,a,s),l(t,e,n,i,r,o,a,s)}else t.x=n,t.y=i,t.point=e}else l(t,e,n,i,r,o,a,s)}function l(t,e,n,i,r,a,s,u){var l=.5*(r+s),c=.5*(a+u),d=n>=l,h=i>=c,f=h<<1|d;t.leaf=!1,t=t.nodes[f]||(t.nodes[f]=hi()),d?r=l:s=l,h?a=c:u=c,o(t,e,n,i,r,a,s,u)}var c,d,h,f,p,g,m,v,y,b=Mt(s),x=Mt(u);if(null!=e)g=e,m=n,v=i,y=r;else if(v=y=-(g=m=1/0),d=[],h=[],p=t.length,a)for(f=0;p>f;++f)c=t[f],c.x<g&&(g=c.x),c.y<m&&(m=c.y),c.x>v&&(v=c.x),c.y>y&&(y=c.y),d.push(c.x),h.push(c.y);else for(f=0;p>f;++f){var w=+b(c=t[f],f),_=+x(c,f);g>w&&(g=w),m>_&&(m=_),w>v&&(v=w),_>y&&(y=_),d.push(w),h.push(_)}var $=v-g,k=y-m;$>k?y=m+$:v=g+k;var C=hi();if(C.add=function(t){o(C,t,+b(t,++f),+x(t,f),g,m,v,y)},C.visit=function(t){fi(t,C,g,m,v,y)},C.find=function(t){return pi(C,t[0],t[1],g,m,v,y)},f=-1,null==e){for(;++f<p;)o(C,t[f],d[f],h[f],g,m,v,y);--f}else t.forEach(C.add);return d=h=t=c=null,C}var a,s=Tn,u=An;return(a=arguments.length)?(s=ci,u=di,3===a&&(r=n,i=e,n=e=0),o(t)):(o.x=function(t){return arguments.length?(s=t,o):s},o.y=function(t){return arguments.length?(u=t,o):u},o.extent=function(t){return arguments.length?(null==t?e=n=i=r=null:(e=+t[0][0],n=+t[0][1],i=+t[1][0],r=+t[1][1]),o):null==e?null:[[e,n],[i,r]]},o.size=function(t){return arguments.length?(null==t?e=n=i=r=null:(e=n=0,i=+t[0],r=+t[1]),o):null==e?null:[i-e,r-n]},o)},ua.interpolateRgb=gi,ua.interpolateObject=mi,ua.interpolateNumber=vi,ua.interpolateString=yi;var hu=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,fu=new RegExp(hu.source,"g");ua.interpolate=bi,ua.interpolators=[function(t,e){var n=typeof e;return("string"===n?os.has(e.toLowerCase())||/^(#|rgb\(|hsl\()/i.test(e)?gi:yi:e instanceof at?gi:Array.isArray(e)?xi:"object"===n&&isNaN(e)?mi:vi)(t,e)}],ua.interpolateArray=xi;var pu=function(){return y},gu=ua.map({linear:pu,poly:Di,quad:function(){return ki},cubic:function(){return Ci},sin:function(){return Si},exp:function(){return Ti},circle:function(){return Ai},elastic:Ei,back:Oi,bounce:function(){return Ni}}),mu=ua.map({"in":y,out:_i,"in-out":$i,"out-in":function(t){return $i(_i(t))}});ua.ease=function(t){var e=t.indexOf("-"),n=e>=0?t.slice(0,e):t,i=e>=0?t.slice(e+1):"in";return n=gu.get(n)||pu,i=mu.get(i)||y,wi(i(n.apply(null,la.call(arguments,1))))},ua.interpolateHcl=Ii,ua.interpolateHsl=Pi,ua.interpolateLab=Fi,ua.interpolateRound=Wi,ua.transform=function(t){var e=da.createElementNS(ua.ns.prefix.svg,"g");return(ua.transform=function(t){if(null!=t){e.setAttribute("transform",t);var n=e.transform.baseVal.consolidate()}return new Hi(n?n.matrix:vu)})(t)},Hi.prototype.toString=function(){return"translate("+this.translate+")rotate("+this.rotate+")skewX("+this.skew+")scale("+this.scale+")"};var vu={a:1,b:0,c:0,d:1,e:0,f:0};ua.interpolateTransform=Yi,ua.layout={},ua.layout.bundle=function(){return function(t){for(var e=[],n=-1,i=t.length;++n<i;)e.push(Ki(t[n]));return e}},ua.layout.chord=function(){function t(){var t,l,d,h,f,p={},g=[],m=ua.range(o),v=[];for(n=[],i=[],t=0,h=-1;++h<o;){for(l=0,f=-1;++f<o;)l+=r[h][f];g.push(l),v.push(ua.range(o)),t+=l}for(a&&m.sort(function(t,e){return a(g[t],g[e])}),s&&v.forEach(function(t,e){t.sort(function(t,n){return s(r[e][t],r[e][n])})}),t=(za-c*o)/t,l=0,h=-1;++h<o;){for(d=l,f=-1;++f<o;){var y=m[h],b=v[y][f],x=r[y][b],w=l,_=l+=x*t;p[y+"-"+b]={index:y,subindex:b,startAngle:w,endAngle:_,value:x}}i[y]={index:y,startAngle:d,endAngle:l,value:g[y]},l+=c}for(h=-1;++h<o;)for(f=h-1;++f<o;){var $=p[h+"-"+f],k=p[f+"-"+h];($.value||k.value)&&n.push($.value<k.value?{source:k,target:$}:{source:$,target:k})}u&&e()}function e(){n.sort(function(t,e){return u((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}var n,i,r,o,a,s,u,l={},c=0;return l.matrix=function(t){return arguments.length?(o=(r=t)&&r.length,n=i=null,l):r},l.padding=function(t){return arguments.length?(c=t,n=i=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,n=i=null,l):a},l.sortSubgroups=function(t){return arguments.length?(s=t,n=null,l):s},l.sortChords=function(t){return arguments.length?(u=t,n&&e(),l):u},l.chords=function(){return n||t(),n},l.groups=function(){return i||t(),i},l},ua.layout.force=function(){function t(t){return function(e,n,i,r){if(e.point!==t){var o=e.cx-t.x,a=e.cy-t.y,s=r-n,u=o*o+a*a;if(u>s*s/v){if(g>u){var l=e.charge/u;t.px-=o*l,t.py-=a*l}return!0}if(e.point&&u&&g>u){var l=e.pointCharge/u;t.px-=o*l,t.py-=a*l}}return!e.charge}}function e(t){t.px=ua.event.x,t.py=ua.event.y,u.resume()}var n,i,r,o,a,s,u={},l=ua.dispatch("start","tick","end"),c=[1,1],d=.9,h=yu,f=bu,p=-30,g=xu,m=.1,v=.64,b=[],x=[];return u.tick=function(){if((r*=.99)<.005)return n=null,l.end({type:"end",alpha:r=0}),!0;var e,i,u,h,f,g,v,y,w,_=b.length,$=x.length;for(i=0;$>i;++i)u=x[i],h=u.source,f=u.target,y=f.x-h.x,w=f.y-h.y,(g=y*y+w*w)&&(g=r*a[i]*((g=Math.sqrt(g))-o[i])/g,y*=g,w*=g,f.x-=y*(v=h.weight+f.weight?h.weight/(h.weight+f.weight):.5),f.y-=w*v,h.x+=y*(v=1-v),h.y+=w*v);if((v=r*m)&&(y=c[0]/2,w=c[1]/2,i=-1,v))for(;++i<_;)u=b[i],u.x+=(y-u.x)*v,u.y+=(w-u.y)*v;if(p)for(ir(e=ua.geom.quadtree(b),r,s),i=-1;++i<_;)(u=b[i]).fixed||e.visit(t(u));for(i=-1;++i<_;)u=b[i],u.fixed?(u.x=u.px,u.y=u.py):(u.x-=(u.px-(u.px=u.x))*d,u.y-=(u.py-(u.py=u.y))*d);l.tick({type:"tick",alpha:r})},u.nodes=function(t){return arguments.length?(b=t,u):b},u.links=function(t){return arguments.length?(x=t,u):x},u.size=function(t){return arguments.length?(c=t,u):c},u.linkDistance=function(t){return arguments.length?(h="function"==typeof t?t:+t,u):h},u.distance=u.linkDistance,u.linkStrength=function(t){return arguments.length?(f="function"==typeof t?t:+t,u):f},u.friction=function(t){return arguments.length?(d=+t,u):d},u.charge=function(t){return arguments.length?(p="function"==typeof t?t:+t,u):p},u.chargeDistance=function(t){return arguments.length?(g=t*t,u):Math.sqrt(g)},u.gravity=function(t){return arguments.length?(m=+t,u):m},u.theta=function(t){return arguments.length?(v=t*t,u):Math.sqrt(v)},u.alpha=function(t){return arguments.length?(t=+t,r?t>0?r=t:(n.c=null,n.t=NaN,n=null,l.end({type:"end",alpha:r=0})):t>0&&(l.start({type:"start",alpha:r=t}),n=Et(u.tick)),u):r},u.start=function(){function t(t,i){if(!n){for(n=new Array(r),u=0;r>u;++u)n[u]=[];for(u=0;l>u;++u){var o=x[u];n[o.source.index].push(o.target),n[o.target.index].push(o.source)}}for(var a,s=n[e],u=-1,c=s.length;++u<c;)if(!isNaN(a=s[u][t]))return a;return Math.random()*i}var e,n,i,r=b.length,l=x.length,d=c[0],g=c[1];for(e=0;r>e;++e)(i=b[e]).index=e,i.weight=0;for(e=0;l>e;++e)i=x[e],"number"==typeof i.source&&(i.source=b[i.source]),"number"==typeof i.target&&(i.target=b[i.target]),++i.source.weight,++i.target.weight;for(e=0;r>e;++e)i=b[e],isNaN(i.x)&&(i.x=t("x",d)),isNaN(i.y)&&(i.y=t("y",g)),isNaN(i.px)&&(i.px=i.x),isNaN(i.py)&&(i.py=i.y);if(o=[],"function"==typeof h)for(e=0;l>e;++e)o[e]=+h.call(this,x[e],e);else for(e=0;l>e;++e)o[e]=h;if(a=[],"function"==typeof f)for(e=0;l>e;++e)a[e]=+f.call(this,x[e],e);else for(e=0;l>e;++e)a[e]=f;if(s=[],"function"==typeof p)for(e=0;r>e;++e)s[e]=+p.call(this,b[e],e);else for(e=0;r>e;++e)s[e]=p;return u.resume()},u.resume=function(){return u.alpha(.1)},u.stop=function(){return u.alpha(0)},u.drag=function(){return i||(i=ua.behavior.drag().origin(y).on("dragstart.force",Ji).on("drag.force",e).on("dragend.force",tr)),arguments.length?void this.on("mouseover.force",er).on("mouseout.force",nr).call(i):i},ua.rebind(u,l,"on")};var yu=20,bu=1,xu=1/0;ua.layout.hierarchy=function(){function t(r){var o,a=[r],s=[];for(r.depth=0;null!=(o=a.pop());)if(s.push(o),(l=n.call(t,o,o.depth))&&(u=l.length)){for(var u,l,c;--u>=0;)a.push(c=l[u]),c.parent=o,c.depth=o.depth+1;i&&(o.value=0),o.children=l}else i&&(o.value=+i.call(t,o,o.depth)||0),delete o.children;return ar(r,function(t){var n,r;e&&(n=t.children)&&n.sort(e),i&&(r=t.parent)&&(r.value+=t.value)}),s}var e=lr,n=sr,i=ur;return t.sort=function(n){return arguments.length?(e=n,t):e},t.children=function(e){return arguments.length?(n=e,t):n},t.value=function(e){return arguments.length?(i=e,t):i},t.revalue=function(e){return i&&(or(e,function(t){t.children&&(t.value=0)}),ar(e,function(e){var n;e.children||(e.value=+i.call(t,e,e.depth)||0),(n=e.parent)&&(n.value+=e.value)})),e},t},ua.layout.partition=function(){function t(e,n,i,r){var o=e.children;if(e.x=n,e.y=e.depth*r,e.dx=i,e.dy=r,o&&(a=o.length)){var a,s,u,l=-1;for(i=e.value?i/e.value:0;++l<a;)t(s=o[l],n,u=s.value*i,r),n+=u}}function e(t){var n=t.children,i=0;if(n&&(r=n.length))for(var r,o=-1;++o<r;)i=Math.max(i,e(n[o]));return 1+i}function n(n,o){var a=i.call(this,n,o);return t(a[0],0,r[0],r[1]/e(a[0])),a}var i=ua.layout.hierarchy(),r=[1,1];return n.size=function(t){return arguments.length?(r=t,n):r},rr(n,i)},ua.layout.pie=function(){function t(a){var s,u=a.length,l=a.map(function(n,i){return+e.call(t,n,i)}),c=+("function"==typeof i?i.apply(this,arguments):i),d=("function"==typeof r?r.apply(this,arguments):r)-c,h=Math.min(Math.abs(d)/u,+("function"==typeof o?o.apply(this,arguments):o)),f=h*(0>d?-1:1),p=ua.sum(l),g=p?(d-u*f)/p:0,m=ua.range(u),v=[];return null!=n&&m.sort(n===wu?function(t,e){return l[e]-l[t]}:function(t,e){return n(a[t],a[e])}),m.forEach(function(t){v[t]={data:a[t],value:s=l[t],startAngle:c,endAngle:c+=s*g+f,padAngle:h}}),v}var e=Number,n=wu,i=0,r=za,o=0;return t.value=function(n){return arguments.length?(e=n,t):e},t.sort=function(e){return arguments.length?(n=e,t):n},t.startAngle=function(e){return arguments.length?(i=e,t):i},t.endAngle=function(e){return arguments.length?(r=e,t):r},t.padAngle=function(e){return arguments.length?(o=e,t):o},t};var wu={};ua.layout.stack=function(){function t(s,u){if(!(h=s.length))return s;var l=s.map(function(n,i){return e.call(t,n,i)}),c=l.map(function(e){return e.map(function(e,n){return[o.call(t,e,n),a.call(t,e,n)]})}),d=n.call(t,c,u);l=ua.permute(l,d),c=ua.permute(c,d);var h,f,p,g,m=i.call(t,c,u),v=l[0].length;for(p=0;v>p;++p)for(r.call(t,l[0][p],g=m[p],c[0][p][1]),f=1;h>f;++f)r.call(t,l[f][p],g+=c[f-1][p][1],c[f][p][1]);return s}var e=y,n=pr,i=gr,r=fr,o=dr,a=hr;return t.values=function(n){return arguments.length?(e=n,t):e},t.order=function(e){return arguments.length?(n="function"==typeof e?e:_u.get(e)||pr,t):n},t.offset=function(e){return arguments.length?(i="function"==typeof e?e:$u.get(e)||gr,t):i},t.x=function(e){return arguments.length?(o=e,t):o},t.y=function(e){return arguments.length?(a=e,t):a},t.out=function(e){return arguments.length?(r=e,t):r},t};var _u=ua.map({"inside-out":function(t){var e,n,i=t.length,r=t.map(mr),o=t.map(vr),a=ua.range(i).sort(function(t,e){return r[t]-r[e]}),s=0,u=0,l=[],c=[];for(e=0;i>e;++e)n=a[e],u>s?(s+=o[n],l.push(n)):(u+=o[n],c.push(n));return c.reverse().concat(l)},reverse:function(t){return ua.range(t.length).reverse()},"default":pr}),$u=ua.map({silhouette:function(t){var e,n,i,r=t.length,o=t[0].length,a=[],s=0,u=[];for(n=0;o>n;++n){for(e=0,i=0;r>e;e++)i+=t[e][n][1];i>s&&(s=i),a.push(i)}for(n=0;o>n;++n)u[n]=(s-a[n])/2;return u},wiggle:function(t){var e,n,i,r,o,a,s,u,l,c=t.length,d=t[0],h=d.length,f=[];for(f[0]=u=l=0,n=1;h>n;++n){for(e=0,r=0;c>e;++e)r+=t[e][n][1];for(e=0,o=0,s=d[n][0]-d[n-1][0];c>e;++e){for(i=0,a=(t[e][n][1]-t[e][n-1][1])/(2*s);e>i;++i)a+=(t[i][n][1]-t[i][n-1][1])/s;o+=a*t[e][n][1]}f[n]=u-=r?o/r*s:0,l>u&&(l=u)}for(n=0;h>n;++n)f[n]-=l;return f},expand:function(t){var e,n,i,r=t.length,o=t[0].length,a=1/r,s=[];for(n=0;o>n;++n){for(e=0,i=0;r>e;e++)i+=t[e][n][1];if(i)for(e=0;r>e;e++)t[e][n][1]/=i;else for(e=0;r>e;e++)t[e][n][1]=a}for(n=0;o>n;++n)s[n]=0;return s},zero:gr});ua.layout.histogram=function(){function t(t,o){for(var a,s,u=[],l=t.map(n,this),c=i.call(this,l,o),d=r.call(this,c,l,o),o=-1,h=l.length,f=d.length-1,p=e?1:1/h;++o<f;)a=u[o]=[],a.dx=d[o+1]-(a.x=d[o]),a.y=0;if(f>0)for(o=-1;++o<h;)s=l[o],s>=c[0]&&s<=c[1]&&(a=u[ua.bisect(d,s,1,f)-1],a.y+=p,a.push(t[o]));return u}var e=!0,n=Number,i=wr,r=br;return t.value=function(e){return arguments.length?(n=e,t):n},t.range=function(e){return arguments.length?(i=Mt(e),t):i},t.bins=function(e){return arguments.length?(r="number"==typeof e?function(t){return xr(t,e)}:Mt(e),t):r},t.frequency=function(n){return arguments.length?(e=!!n,t):e},t},ua.layout.pack=function(){function t(t,o){var a=n.call(this,t,o),s=a[0],u=r[0],l=r[1],c=null==e?Math.sqrt:"function"==typeof e?e:function(){return e};if(s.x=s.y=0,ar(s,function(t){t.r=+c(t.value)}),ar(s,Mr),i){var d=i*(e?1:Math.max(2*s.r/u,2*s.r/l))/2;ar(s,function(t){t.r+=d}),ar(s,Mr),ar(s,function(t){t.r-=d})}return Tr(s,u/2,l/2,e?1:1/Math.max(2*s.r/u,2*s.r/l)),a}var e,n=ua.layout.hierarchy().sort(_r),i=0,r=[1,1];return t.size=function(e){return arguments.length?(r=e,t):r},t.radius=function(n){return arguments.length?(e=null==n||"function"==typeof n?n:+n,t):e},t.padding=function(e){return arguments.length?(i=+e,t):i},rr(t,n)},ua.layout.tree=function(){function t(t,r){var c=a.call(this,t,r),d=c[0],h=e(d);if(ar(h,n),h.parent.m=-h.z,or(h,i),l)or(d,o);else{var f=d,p=d,g=d;or(d,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>g.depth&&(g=t)});var m=s(f,p)/2-f.x,v=u[0]/(p.x+s(p,f)/2+m),y=u[1]/(g.depth||1);or(d,function(t){t.x=(t.x+m)*v,t.y=t.depth*y})}return c}function e(t){for(var e,n={A:null,children:[t]},i=[n];null!=(e=i.pop());)for(var r,o=e.children,a=0,s=o.length;s>a;++a)i.push((o[a]=r={_:o[a],parent:e,children:(r=o[a].children)&&r.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:a}).a=r);return n.children[0]}function n(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){Pr(t);var o=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+s(t._,i._),t.m=t.z-o):t.z=o}else i&&(t.z=i.z+s(t._,i._));t.parent.A=r(t,i,t.parent.A||n[0])}function i(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function r(t,e,n){if(e){for(var i,r=t,o=t,a=e,u=r.parent.children[0],l=r.m,c=o.m,d=a.m,h=u.m;a=Nr(a),r=Or(r),a&&r;)u=Or(u),o=Nr(o),o.a=t,i=a.z+d-r.z-l+s(a._,r._),i>0&&(Ir(Fr(a,t,n),t,i),l+=i,c+=i),d+=a.m,l+=r.m,h+=u.m,c+=o.m;a&&!Nr(o)&&(o.t=a,o.m+=d-c),r&&!Or(u)&&(u.t=r,u.m+=l-h,n=t)}return n}function o(t){t.x*=u[0],t.y=t.depth*u[1]}var a=ua.layout.hierarchy().sort(null).value(null),s=Er,u=[1,1],l=null;return t.separation=function(e){return arguments.length?(s=e,t):s},t.size=function(e){return arguments.length?(l=null==(u=e)?o:null,t):l?null:u},t.nodeSize=function(e){return arguments.length?(l=null==(u=e)?null:o,t):l?u:null},rr(t,a)},ua.layout.cluster=function(){function t(t,o){var a,s=e.call(this,t,o),u=s[0],l=0;ar(u,function(t){var e=t.children;e&&e.length?(t.x=Hr(e),t.y=Wr(e)):(t.x=a?l+=n(t,a):0,t.y=0,a=t)});var c=Lr(u),d=zr(u),h=c.x-n(c,d)/2,f=d.x+n(d,c)/2;return ar(u,r?function(t){t.x=(t.x-u.x)*i[0],t.y=(u.y-t.y)*i[1]}:function(t){t.x=(t.x-h)/(f-h)*i[0],t.y=(1-(u.y?t.y/u.y:1))*i[1]}),s}var e=ua.layout.hierarchy().sort(null).value(null),n=Er,i=[1,1],r=!1;return t.separation=function(e){return arguments.length?(n=e,t):n},t.size=function(e){return arguments.length?(r=null==(i=e),t):r?null:i},t.nodeSize=function(e){return arguments.length?(r=null!=(i=e),t):r?i:null},rr(t,e)},ua.layout.treemap=function(){function t(t,e){for(var n,i,r=-1,o=t.length;++r<o;)i=(n=t[r]).value*(0>e?0:e),n.area=isNaN(i)||0>=i?0:i}function e(n){var o=n.children;if(o&&o.length){var a,s,u,l=d(n),c=[],h=o.slice(),p=1/0,g="slice"===f?l.dx:"dice"===f?l.dy:"slice-dice"===f?1&n.depth?l.dy:l.dx:Math.min(l.dx,l.dy);for(t(h,l.dx*l.dy/n.value),c.area=0;(u=h.length)>0;)c.push(a=h[u-1]),c.area+=a.area,"squarify"!==f||(s=i(c,g))<=p?(h.pop(),p=s):(c.area-=c.pop().area,r(c,g,l,!1),g=Math.min(l.dx,l.dy),c.length=c.area=0,p=1/0);c.length&&(r(c,g,l,!0),c.length=c.area=0),o.forEach(e)}}function n(e){var i=e.children;if(i&&i.length){var o,a=d(e),s=i.slice(),u=[];for(t(s,a.dx*a.dy/e.value),u.area=0;o=s.pop();)u.push(o),u.area+=o.area,null!=o.z&&(r(u,o.z?a.dx:a.dy,a,!s.length),u.length=u.area=0);i.forEach(n)}}function i(t,e){for(var n,i=t.area,r=0,o=1/0,a=-1,s=t.length;++a<s;)(n=t[a].area)&&(o>n&&(o=n),n>r&&(r=n));return i*=i,e*=e,i?Math.max(e*r*p/i,i/(e*o*p)):1/0}function r(t,e,n,i){var r,o=-1,a=t.length,s=n.x,l=n.y,c=e?u(t.area/e):0;if(e==n.dx){for((i||c>n.dy)&&(c=n.dy);++o<a;)r=t[o],r.x=s,r.y=l,r.dy=c,s+=r.dx=Math.min(n.x+n.dx-s,c?u(r.area/c):0);r.z=!0,r.dx+=n.x+n.dx-s,n.y+=c,n.dy-=c}else{for((i||c>n.dx)&&(c=n.dx);++o<a;)r=t[o],r.x=s,r.y=l,r.dx=c,l+=r.dy=Math.min(n.y+n.dy-l,c?u(r.area/c):0);r.z=!1,r.dy+=n.y+n.dy-l,n.x+=c,n.dx-=c}}function o(i){var r=a||s(i),o=r[0];return o.x=o.y=0,o.value?(o.dx=l[0],o.dy=l[1]):o.dx=o.dy=0,a&&s.revalue(o),t([o],o.dx*o.dy/o.value),(a?n:e)(o),h&&(a=r),r}var a,s=ua.layout.hierarchy(),u=Math.round,l=[1,1],c=null,d=jr,h=!1,f="squarify",p=.5*(1+Math.sqrt(5));return o.size=function(t){return arguments.length?(l=t,o):l},o.padding=function(t){function e(e){var n=t.call(o,e,e.depth);return null==n?jr(e):Rr(e,"number"==typeof n?[n,n,n,n]:n)}function n(e){return Rr(e,t)}if(!arguments.length)return c;var i;return d=null==(c=t)?jr:"function"==(i=typeof t)?e:"number"===i?(t=[t,t,t,t],n):n,o},o.round=function(t){return arguments.length?(u=t?Math.round:Number,o):u!=Number},o.sticky=function(t){return arguments.length?(h=t,a=null,o):h},o.ratio=function(t){return arguments.length?(p=t,o):p},o.mode=function(t){return arguments.length?(f=t+"",o):f},rr(o,s)},ua.random={normal:function(t,e){var n=arguments.length;return 2>n&&(e=1),1>n&&(t=0),function(){var n,i,r;do n=2*Math.random()-1,i=2*Math.random()-1,r=n*n+i*i;while(!r||r>1);return t+e*n*Math.sqrt(-2*Math.log(r)/r)}},logNormal:function(){var t=ua.random.normal.apply(ua,arguments);return function(){return Math.exp(t())}},bates:function(t){var e=ua.random.irwinHall(t);return function(){return e()/t}},irwinHall:function(t){return function(){for(var e=0,n=0;t>n;n++)e+=Math.random();return e}}},ua.scale={};var ku={floor:y,ceil:y};ua.scale.linear=function(){return Xr([0,1],[0,1],bi,!1)};var Cu={s:1,g:1,p:1,r:1,e:1};ua.scale.log=function(){return io(ua.scale.linear().domain([0,1]),10,!0,[1,10])};var Mu=ua.format(".0e"),Du={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};ua.scale.pow=function(){return ro(ua.scale.linear(),1,[0,1])},ua.scale.sqrt=function(){return ua.scale.pow().exponent(.5)},ua.scale.ordinal=function(){return ao([],{t:"range",a:[[]]})},ua.scale.category10=function(){return ua.scale.ordinal().range(Su)},ua.scale.category20=function(){return ua.scale.ordinal().range(Tu)},ua.scale.category20b=function(){return ua.scale.ordinal().range(Au)},ua.scale.category20c=function(){return ua.scale.ordinal().range(Eu)};var Su=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(bt),Tu=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(bt),Au=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(bt),Eu=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(bt);ua.scale.quantile=function(){return so([],[])},ua.scale.quantize=function(){return uo(0,1,[0,1]);
},ua.scale.threshold=function(){return lo([.5],[0,1])},ua.scale.identity=function(){return co([0,1])},ua.svg={},ua.svg.arc=function(){function t(){var t=Math.max(0,+n.apply(this,arguments)),l=Math.max(0,+i.apply(this,arguments)),c=a.apply(this,arguments)-Ra,d=s.apply(this,arguments)-Ra,h=Math.abs(d-c),f=c>d?0:1;if(t>l&&(p=l,l=t,t=p),h>=ja)return e(l,f)+(t?e(t,1-f):"")+"Z";var p,g,m,v,y,b,x,w,_,$,k,C,M=0,D=0,S=[];if((v=(+u.apply(this,arguments)||0)/2)&&(m=o===Ou?Math.sqrt(t*t+l*l):+o.apply(this,arguments),f||(D*=-1),l&&(D=et(m/l*Math.sin(v))),t&&(M=et(m/t*Math.sin(v)))),l){y=l*Math.cos(c+D),b=l*Math.sin(c+D),x=l*Math.cos(d-D),w=l*Math.sin(d-D);var T=Math.abs(d-c-2*D)<=La?0:1;if(D&&yo(y,b,x,w)===f^T){var A=(c+d)/2;y=l*Math.cos(A),b=l*Math.sin(A),x=w=null}}else y=b=0;if(t){_=t*Math.cos(d-M),$=t*Math.sin(d-M),k=t*Math.cos(c+M),C=t*Math.sin(c+M);var E=Math.abs(c-d+2*M)<=La?0:1;if(M&&yo(_,$,k,C)===1-f^E){var O=(c+d)/2;_=t*Math.cos(O),$=t*Math.sin(O),k=C=null}}else _=$=0;if(h>Wa&&(p=Math.min(Math.abs(l-t)/2,+r.apply(this,arguments)))>.001){g=l>t^f?0:1;var N=p,I=p;if(La>h){var P=null==k?[_,$]:null==x?[y,b]:In([y,b],[k,C],[x,w],[_,$]),F=y-P[0],W=b-P[1],H=x-P[0],L=w-P[1],z=1/Math.sin(Math.acos((F*H+W*L)/(Math.sqrt(F*F+W*W)*Math.sqrt(H*H+L*L)))/2),j=Math.sqrt(P[0]*P[0]+P[1]*P[1]);I=Math.min(p,(t-j)/(z-1)),N=Math.min(p,(l-j)/(z+1))}if(null!=x){var R=bo(null==k?[_,$]:[k,C],[y,b],l,N,f),U=bo([x,w],[_,$],l,N,f);p===N?S.push("M",R[0],"A",N,",",N," 0 0,",g," ",R[1],"A",l,",",l," 0 ",1-f^yo(R[1][0],R[1][1],U[1][0],U[1][1]),",",f," ",U[1],"A",N,",",N," 0 0,",g," ",U[0]):S.push("M",R[0],"A",N,",",N," 0 1,",g," ",U[0])}else S.push("M",y,",",b);if(null!=k){var q=bo([y,b],[k,C],t,-I,f),B=bo([_,$],null==x?[y,b]:[x,w],t,-I,f);p===I?S.push("L",B[0],"A",I,",",I," 0 0,",g," ",B[1],"A",t,",",t," 0 ",f^yo(B[1][0],B[1][1],q[1][0],q[1][1]),",",1-f," ",q[1],"A",I,",",I," 0 0,",g," ",q[0]):S.push("L",B[0],"A",I,",",I," 0 0,",g," ",q[0])}else S.push("L",_,",",$)}else S.push("M",y,",",b),null!=x&&S.push("A",l,",",l," 0 ",T,",",f," ",x,",",w),S.push("L",_,",",$),null!=k&&S.push("A",t,",",t," 0 ",E,",",1-f," ",k,",",C);return S.push("Z"),S.join("")}function e(t,e){return"M0,"+t+"A"+t+","+t+" 0 1,"+e+" 0,"+-t+"A"+t+","+t+" 0 1,"+e+" 0,"+t}var n=fo,i=po,r=ho,o=Ou,a=go,s=mo,u=vo;return t.innerRadius=function(e){return arguments.length?(n=Mt(e),t):n},t.outerRadius=function(e){return arguments.length?(i=Mt(e),t):i},t.cornerRadius=function(e){return arguments.length?(r=Mt(e),t):r},t.padRadius=function(e){return arguments.length?(o=e==Ou?Ou:Mt(e),t):o},t.startAngle=function(e){return arguments.length?(a=Mt(e),t):a},t.endAngle=function(e){return arguments.length?(s=Mt(e),t):s},t.padAngle=function(e){return arguments.length?(u=Mt(e),t):u},t.centroid=function(){var t=(+n.apply(this,arguments)+ +i.apply(this,arguments))/2,e=(+a.apply(this,arguments)+ +s.apply(this,arguments))/2-Ra;return[Math.cos(e)*t,Math.sin(e)*t]},t};var Ou="auto";ua.svg.line=function(){return xo(y)};var Nu=ua.map({linear:wo,"linear-closed":_o,step:$o,"step-before":ko,"step-after":Co,basis:Eo,"basis-open":Oo,"basis-closed":No,bundle:Io,cardinal:So,"cardinal-open":Mo,"cardinal-closed":Do,monotone:zo});Nu.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Iu=[0,2/3,1/3,0],Pu=[0,1/3,2/3,0],Fu=[0,1/6,2/3,1/6];ua.svg.line.radial=function(){var t=xo(jo);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},ko.reverse=Co,Co.reverse=ko,ua.svg.area=function(){return Ro(y)},ua.svg.area.radial=function(){var t=Ro(jo);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},ua.svg.chord=function(){function t(t,s){var u=e(this,o,t,s),l=e(this,a,t,s);return"M"+u.p0+i(u.r,u.p1,u.a1-u.a0)+(n(u,l)?r(u.r,u.p1,u.r,u.p0):r(u.r,u.p1,l.r,l.p0)+i(l.r,l.p1,l.a1-l.a0)+r(l.r,l.p1,u.r,u.p0))+"Z"}function e(t,e,n,i){var r=e.call(t,n,i),o=s.call(t,r,i),a=u.call(t,r,i)-Ra,c=l.call(t,r,i)-Ra;return{r:o,a0:a,a1:c,p0:[o*Math.cos(a),o*Math.sin(a)],p1:[o*Math.cos(c),o*Math.sin(c)]}}function n(t,e){return t.a0==e.a0&&t.a1==e.a1}function i(t,e,n){return"A"+t+","+t+" 0 "+ +(n>La)+",1 "+e}function r(t,e,n,i){return"Q 0,0 "+i}var o=bn,a=xn,s=Uo,u=go,l=mo;return t.radius=function(e){return arguments.length?(s=Mt(e),t):s},t.source=function(e){return arguments.length?(o=Mt(e),t):o},t.target=function(e){return arguments.length?(a=Mt(e),t):a},t.startAngle=function(e){return arguments.length?(u=Mt(e),t):u},t.endAngle=function(e){return arguments.length?(l=Mt(e),t):l},t},ua.svg.diagonal=function(){function t(t,r){var o=e.call(this,t,r),a=n.call(this,t,r),s=(o.y+a.y)/2,u=[o,{x:o.x,y:s},{x:a.x,y:s},a];return u=u.map(i),"M"+u[0]+"C"+u[1]+" "+u[2]+" "+u[3]}var e=bn,n=xn,i=qo;return t.source=function(n){return arguments.length?(e=Mt(n),t):e},t.target=function(e){return arguments.length?(n=Mt(e),t):n},t.projection=function(e){return arguments.length?(i=e,t):i},t},ua.svg.diagonal.radial=function(){var t=ua.svg.diagonal(),e=qo,n=t.projection;return t.projection=function(t){return arguments.length?n(Bo(e=t)):e},t},ua.svg.symbol=function(){function t(t,i){return(Wu.get(e.call(this,t,i))||Go)(n.call(this,t,i))}var e=Yo,n=Vo;return t.type=function(n){return arguments.length?(e=Mt(n),t):e},t.size=function(e){return arguments.length?(n=Mt(e),t):n},t};var Wu=ua.map({circle:Go,cross:function(t){var e=Math.sqrt(t/5)/2;return"M"+-3*e+","+-e+"H"+-e+"V"+-3*e+"H"+e+"V"+-e+"H"+3*e+"V"+e+"H"+e+"V"+3*e+"H"+-e+"V"+e+"H"+-3*e+"Z"},diamond:function(t){var e=Math.sqrt(t/(2*Lu)),n=e*Lu;return"M0,"+-e+"L"+n+",0 0,"+e+" "+-n+",0Z"},square:function(t){var e=Math.sqrt(t)/2;return"M"+-e+","+-e+"L"+e+","+-e+" "+e+","+e+" "+-e+","+e+"Z"},"triangle-down":function(t){var e=Math.sqrt(t/Hu),n=e*Hu/2;return"M0,"+n+"L"+e+","+-n+" "+-e+","+-n+"Z"},"triangle-up":function(t){var e=Math.sqrt(t/Hu),n=e*Hu/2;return"M0,"+-n+"L"+e+","+n+" "+-e+","+n+"Z"}});ua.svg.symbolTypes=Wu.keys();var Hu=Math.sqrt(3),Lu=Math.tan(30*Ua);Ta.transition=function(t){for(var e,n,i=zu||++qu,r=Jo(t),o=[],a=ju||{time:Date.now(),ease:Mi,delay:0,duration:250},s=-1,u=this.length;++s<u;){o.push(e=[]);for(var l=this[s],c=-1,d=l.length;++c<d;)(n=l[c])&&ta(n,c,r,i,a),e.push(n)}return Ko(o,r,i)},Ta.interrupt=function(t){return this.each(null==t?Ru:Xo(Jo(t)))};var zu,ju,Ru=Xo(Jo()),Uu=[],qu=0;Uu.call=Ta.call,Uu.empty=Ta.empty,Uu.node=Ta.node,Uu.size=Ta.size,ua.transition=function(t,e){return t&&t.transition?zu?t.transition(e):t:ua.selection().transition(t)},ua.transition.prototype=Uu,Uu.select=function(t){var e,n,i,r=this.id,o=this.namespace,a=[];t=S(t);for(var s=-1,u=this.length;++s<u;){a.push(e=[]);for(var l=this[s],c=-1,d=l.length;++c<d;)(i=l[c])&&(n=t.call(i,i.__data__,c,s))?("__data__"in i&&(n.__data__=i.__data__),ta(n,c,o,r,i[o][r]),e.push(n)):e.push(null)}return Ko(a,o,r)},Uu.selectAll=function(t){var e,n,i,r,o,a=this.id,s=this.namespace,u=[];t=T(t);for(var l=-1,c=this.length;++l<c;)for(var d=this[l],h=-1,f=d.length;++h<f;)if(i=d[h]){o=i[s][a],n=t.call(i,i.__data__,h,l),u.push(e=[]);for(var p=-1,g=n.length;++p<g;)(r=n[p])&&ta(r,p,s,a,o),e.push(r)}return Ko(u,s,a)},Uu.filter=function(t){var e,n,i,r=[];"function"!=typeof t&&(t=j(t));for(var o=0,a=this.length;a>o;o++){r.push(e=[]);for(var n=this[o],s=0,u=n.length;u>s;s++)(i=n[s])&&t.call(i,i.__data__,s,o)&&e.push(i)}return Ko(r,this.namespace,this.id)},Uu.tween=function(t,e){var n=this.id,i=this.namespace;return arguments.length<2?this.node()[i][n].tween.get(t):U(this,null==e?function(e){e[i][n].tween.remove(t)}:function(r){r[i][n].tween.set(t,e)})},Uu.attr=function(t,e){function n(){this.removeAttribute(s)}function i(){this.removeAttributeNS(s.space,s.local)}function r(t){return null==t?n:(t+="",function(){var e,n=this.getAttribute(s);return n!==t&&(e=a(n,t),function(t){this.setAttribute(s,e(t))})})}function o(t){return null==t?i:(t+="",function(){var e,n=this.getAttributeNS(s.space,s.local);return n!==t&&(e=a(n,t),function(t){this.setAttributeNS(s.space,s.local,e(t))})})}if(arguments.length<2){for(e in t)this.attr(e,t[e]);return this}var a="transform"==t?Yi:bi,s=ua.ns.qualify(t);return Zo(this,"attr."+t,e,s.local?o:r)},Uu.attrTween=function(t,e){function n(t,n){var i=e.call(this,t,n,this.getAttribute(r));return i&&function(t){this.setAttribute(r,i(t))}}function i(t,n){var i=e.call(this,t,n,this.getAttributeNS(r.space,r.local));return i&&function(t){this.setAttributeNS(r.space,r.local,i(t))}}var r=ua.ns.qualify(t);return this.tween("attr."+t,r.local?i:n)},Uu.style=function(t,n,i){function r(){this.style.removeProperty(t)}function o(n){return null==n?r:(n+="",function(){var r,o=e(this).getComputedStyle(this,null).getPropertyValue(t);return o!==n&&(r=bi(o,n),function(e){this.style.setProperty(t,r(e),i)})})}var a=arguments.length;if(3>a){if("string"!=typeof t){2>a&&(n="");for(i in t)this.style(i,t[i],n);return this}i=""}return Zo(this,"style."+t,n,o)},Uu.styleTween=function(t,n,i){function r(r,o){var a=n.call(this,r,o,e(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),i)}}return arguments.length<3&&(i=""),this.tween("style."+t,r)},Uu.text=function(t){return Zo(this,"text",t,Qo)},Uu.remove=function(){var t=this.namespace;return this.each("end.transition",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},Uu.ease=function(t){var e=this.id,n=this.namespace;return arguments.length<1?this.node()[n][e].ease:("function"!=typeof t&&(t=ua.ease.apply(ua,arguments)),U(this,function(i){i[n][e].ease=t}))},Uu.delay=function(t){var e=this.id,n=this.namespace;return arguments.length<1?this.node()[n][e].delay:U(this,"function"==typeof t?function(i,r,o){i[n][e].delay=+t.call(i,i.__data__,r,o)}:(t=+t,function(i){i[n][e].delay=t}))},Uu.duration=function(t){var e=this.id,n=this.namespace;return arguments.length<1?this.node()[n][e].duration:U(this,"function"==typeof t?function(i,r,o){i[n][e].duration=Math.max(1,t.call(i,i.__data__,r,o))}:(t=Math.max(1,t),function(i){i[n][e].duration=t}))},Uu.each=function(t,e){var n=this.id,i=this.namespace;if(arguments.length<2){var r=ju,o=zu;try{zu=n,U(this,function(e,r,o){ju=e[i][n],t.call(e,e.__data__,r,o)})}finally{ju=r,zu=o}}else U(this,function(r){var o=r[i][n];(o.event||(o.event=ua.dispatch("start","end","interrupt"))).on(t,e)});return this},Uu.transition=function(){for(var t,e,n,i,r=this.id,o=++qu,a=this.namespace,s=[],u=0,l=this.length;l>u;u++){s.push(t=[]);for(var e=this[u],c=0,d=e.length;d>c;c++)(n=e[c])&&(i=n[a][r],ta(n,c,a,o,{time:i.time,ease:i.ease,delay:i.delay+i.duration,duration:i.duration})),t.push(n)}return Ko(s,a,o)},ua.svg.axis=function(){function t(t){t.each(function(){var t,l=ua.select(this),c=this.__chart__||n,d=this.__chart__=n.copy(),h=null==u?d.ticks?d.ticks.apply(d,s):d.domain():u,f=null==e?d.tickFormat?d.tickFormat.apply(d,s):y:e,p=l.selectAll(".tick").data(h,d),g=p.enter().insert("g",".domain").attr("class","tick").style("opacity",Wa),m=ua.transition(p.exit()).style("opacity",Wa).remove(),v=ua.transition(p.order()).style("opacity",1),b=Math.max(r,0)+a,x=qr(d),w=l.selectAll(".domain").data([0]),_=(w.enter().append("path").attr("class","domain"),ua.transition(w));g.append("line"),g.append("text");var $,k,C,M,D=g.select("line"),S=v.select("line"),T=p.select("text").text(f),A=g.select("text"),E=v.select("text"),O="top"===i||"left"===i?-1:1;if("bottom"===i||"top"===i?(t=ea,$="x",C="y",k="x2",M="y2",T.attr("dy",0>O?"0em":".71em").style("text-anchor","middle"),_.attr("d","M"+x[0]+","+O*o+"V0H"+x[1]+"V"+O*o)):(t=na,$="y",C="x",k="y2",M="x2",T.attr("dy",".32em").style("text-anchor",0>O?"end":"start"),_.attr("d","M"+O*o+","+x[0]+"H0V"+x[1]+"H"+O*o)),D.attr(M,O*r),A.attr(C,O*b),S.attr(k,0).attr(M,O*r),E.attr($,0).attr(C,O*b),d.rangeBand){var N=d,I=N.rangeBand()/2;c=d=function(t){return N(t)+I}}else c.rangeBand?c=d:m.call(t,d,c);g.call(t,c,d),v.call(t,d,d)})}var e,n=ua.scale.linear(),i=Bu,r=6,o=6,a=3,s=[10],u=null;return t.scale=function(e){return arguments.length?(n=e,t):n},t.orient=function(e){return arguments.length?(i=e in Vu?e+"":Bu,t):i},t.ticks=function(){return arguments.length?(s=ca(arguments),t):s},t.tickValues=function(e){return arguments.length?(u=e,t):u},t.tickFormat=function(n){return arguments.length?(e=n,t):e},t.tickSize=function(e){var n=arguments.length;return n?(r=+e,o=+arguments[n-1],t):r},t.innerTickSize=function(e){return arguments.length?(r=+e,t):r},t.outerTickSize=function(e){return arguments.length?(o=+e,t):o},t.tickPadding=function(e){return arguments.length?(a=+e,t):a},t.tickSubdivide=function(){return arguments.length&&t},t};var Bu="bottom",Vu={top:1,right:1,bottom:1,left:1};ua.svg.brush=function(){function t(e){e.each(function(){var e=ua.select(this).style("pointer-events","all").style("-webkit-tap-highlight-color","rgba(0,0,0,0)").on("mousedown.brush",o).on("touchstart.brush",o),a=e.selectAll(".background").data([0]);a.enter().append("rect").attr("class","background").style("visibility","hidden").style("cursor","crosshair"),e.selectAll(".extent").data([0]).enter().append("rect").attr("class","extent").style("cursor","move");var s=e.selectAll(".resize").data(g,y);s.exit().remove(),s.enter().append("g").attr("class",function(t){return"resize "+t}).style("cursor",function(t){return Yu[t]}).append("rect").attr("x",function(t){return/[ew]$/.test(t)?-3:null}).attr("y",function(t){return/^[ns]/.test(t)?-3:null}).attr("width",6).attr("height",6).style("visibility","hidden"),s.style("display",t.empty()?"none":null);var u,d=ua.transition(e),h=ua.transition(a);l&&(u=qr(l),h.attr("x",u[0]).attr("width",u[1]-u[0]),i(d)),c&&(u=qr(c),h.attr("y",u[0]).attr("height",u[1]-u[0]),r(d)),n(d)})}function n(t){t.selectAll(".resize").attr("transform",function(t){return"translate("+d[+/e$/.test(t)]+","+h[+/^s/.test(t)]+")"})}function i(t){t.select(".extent").attr("x",d[0]),t.selectAll(".extent,.n>rect,.s>rect").attr("width",d[1]-d[0])}function r(t){t.select(".extent").attr("y",h[0]),t.selectAll(".extent,.e>rect,.w>rect").attr("height",h[1]-h[0])}function o(){function o(){32==ua.event.keyCode&&(T||(b=null,E[0]-=d[1],E[1]-=h[1],T=2),k())}function g(){32==ua.event.keyCode&&2==T&&(E[0]+=d[1],E[1]+=h[1],T=0,k())}function m(){var t=ua.mouse(w),e=!1;x&&(t[0]+=x[0],t[1]+=x[1]),T||(ua.event.altKey?(b||(b=[(d[0]+d[1])/2,(h[0]+h[1])/2]),E[0]=d[+(t[0]<b[0])],E[1]=h[+(t[1]<b[1])]):b=null),D&&v(t,l,0)&&(i(C),e=!0),S&&v(t,c,1)&&(r(C),e=!0),e&&(n(C),$({type:"brush",mode:T?"move":"resize"}))}function v(t,e,n){var i,r,o=qr(e),u=o[0],l=o[1],c=E[n],g=n?h:d,m=g[1]-g[0];return T&&(u-=c,l-=m+c),i=(n?p:f)?Math.max(u,Math.min(l,t[n])):t[n],T?r=(i+=c)+m:(b&&(c=Math.max(u,Math.min(l,2*b[n]-i))),i>c?(r=i,i=c):r=c),g[0]!=i||g[1]!=r?(n?s=null:a=null,g[0]=i,g[1]=r,!0):void 0}function y(){m(),C.style("pointer-events","all").selectAll(".resize").style("display",t.empty()?"none":null),ua.select("body").style("cursor",null),O.on("mousemove.brush",null).on("mouseup.brush",null).on("touchmove.brush",null).on("touchend.brush",null).on("keydown.brush",null).on("keyup.brush",null),A(),$({type:"brushend"})}var b,x,w=this,_=ua.select(ua.event.target),$=u.of(w,arguments),C=ua.select(w),M=_.datum(),D=!/^(n|s)$/.test(M)&&l,S=!/^(e|w)$/.test(M)&&c,T=_.classed("extent"),A=X(w),E=ua.mouse(w),O=ua.select(e(w)).on("keydown.brush",o).on("keyup.brush",g);if(ua.event.changedTouches?O.on("touchmove.brush",m).on("touchend.brush",y):O.on("mousemove.brush",m).on("mouseup.brush",y),C.interrupt().selectAll("*").interrupt(),T)E[0]=d[0]-E[0],E[1]=h[0]-E[1];else if(M){var N=+/w$/.test(M),I=+/^n/.test(M);x=[d[1-N]-E[0],h[1-I]-E[1]],E[0]=d[N],E[1]=h[I]}else ua.event.altKey&&(b=E.slice());C.style("pointer-events","none").selectAll(".resize").style("display",null),ua.select("body").style("cursor",_.style("cursor")),$({type:"brushstart"}),m()}var a,s,u=M(t,"brushstart","brush","brushend"),l=null,c=null,d=[0,0],h=[0,0],f=!0,p=!0,g=Gu[0];return t.event=function(t){t.each(function(){var t=u.of(this,arguments),e={x:d,y:h,i:a,j:s},n=this.__chart__||e;this.__chart__=e,zu?ua.select(this).transition().each("start.brush",function(){a=n.i,s=n.j,d=n.x,h=n.y,t({type:"brushstart"})}).tween("brush:brush",function(){var n=xi(d,e.x),i=xi(h,e.y);return a=s=null,function(r){d=e.x=n(r),h=e.y=i(r),t({type:"brush",mode:"resize"})}}).each("end.brush",function(){a=e.i,s=e.j,t({type:"brush",mode:"resize"}),t({type:"brushend"})}):(t({type:"brushstart"}),t({type:"brush",mode:"resize"}),t({type:"brushend"}))})},t.x=function(e){return arguments.length?(l=e,g=Gu[!l<<1|!c],t):l},t.y=function(e){return arguments.length?(c=e,g=Gu[!l<<1|!c],t):c},t.clamp=function(e){return arguments.length?(l&&c?(f=!!e[0],p=!!e[1]):l?f=!!e:c&&(p=!!e),t):l&&c?[f,p]:l?f:c?p:null},t.extent=function(e){var n,i,r,o,u;return arguments.length?(l&&(n=e[0],i=e[1],c&&(n=n[0],i=i[0]),a=[n,i],l.invert&&(n=l(n),i=l(i)),n>i&&(u=n,n=i,i=u),(n!=d[0]||i!=d[1])&&(d=[n,i])),c&&(r=e[0],o=e[1],l&&(r=r[1],o=o[1]),s=[r,o],c.invert&&(r=c(r),o=c(o)),r>o&&(u=r,r=o,o=u),(r!=h[0]||o!=h[1])&&(h=[r,o])),t):(l&&(a?(n=a[0],i=a[1]):(n=d[0],i=d[1],l.invert&&(n=l.invert(n),i=l.invert(i)),n>i&&(u=n,n=i,i=u))),c&&(s?(r=s[0],o=s[1]):(r=h[0],o=h[1],c.invert&&(r=c.invert(r),o=c.invert(o)),r>o&&(u=r,r=o,o=u))),l&&c?[[n,r],[i,o]]:l?[n,i]:c&&[r,o])},t.clear=function(){return t.empty()||(d=[0,0],h=[0,0],a=s=null),t},t.empty=function(){return!!l&&d[0]==d[1]||!!c&&h[0]==h[1]},ua.rebind(t,u,"on")};var Yu={n:"ns-resize",e:"ew-resize",s:"ns-resize",w:"ew-resize",nw:"nwse-resize",ne:"nesw-resize",se:"nwse-resize",sw:"nesw-resize"},Gu=[["n","e","s","w","nw","ne","se","sw"],["e","w"],["n","s"],[]],Xu=ps.format=xs.timeFormat,Ku=Xu.utc,Zu=Ku("%Y-%m-%dT%H:%M:%S.%LZ");Xu.iso=Date.prototype.toISOString&&+new Date("2000-01-01T00:00:00.000Z")?ia:Zu,ia.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},ia.toString=Zu.toString,ps.second=zt(function(t){return new gs(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ps.seconds=ps.second.range,ps.seconds.utc=ps.second.utc.range,ps.minute=zt(function(t){return new gs(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ps.minutes=ps.minute.range,ps.minutes.utc=ps.minute.utc.range,ps.hour=zt(function(t){var e=t.getTimezoneOffset()/60;return new gs(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ps.hours=ps.hour.range,ps.hours.utc=ps.hour.utc.range,ps.month=zt(function(t){return t=ps.day(t),t.setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ps.months=ps.month.range,ps.months.utc=ps.month.utc.range;var Qu=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ju=[[ps.second,1],[ps.second,5],[ps.second,15],[ps.second,30],[ps.minute,1],[ps.minute,5],[ps.minute,15],[ps.minute,30],[ps.hour,1],[ps.hour,3],[ps.hour,6],[ps.hour,12],[ps.day,1],[ps.day,2],[ps.week,1],[ps.month,1],[ps.month,3],[ps.year,1]],tl=Xu.multi([[".%L",function(t){return t.getMilliseconds()}],[":%S",function(t){return t.getSeconds()}],["%I:%M",function(t){return t.getMinutes()}],["%I %p",function(t){return t.getHours()}],["%a %d",function(t){return t.getDay()&&1!=t.getDate()}],["%b %d",function(t){return 1!=t.getDate()}],["%B",function(t){return t.getMonth()}],["%Y",Te]]),el={range:function(t,e,n){return ua.range(Math.ceil(t/n)*n,+e,n).map(oa)},floor:y,ceil:y};Ju.year=ps.year,ps.scale=function(){return ra(ua.scale.linear(),Ju,tl)};var nl=Ju.map(function(t){return[t[0].utc,t[1]]}),il=Ku.multi([[".%L",function(t){return t.getUTCMilliseconds()}],[":%S",function(t){return t.getUTCSeconds()}],["%I:%M",function(t){return t.getUTCMinutes()}],["%I %p",function(t){return t.getUTCHours()}],["%a %d",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],["%b %d",function(t){return 1!=t.getUTCDate()}],["%B",function(t){return t.getUTCMonth()}],["%Y",Te]]);nl.year=ps.year.utc,ps.scale.utc=function(){return ra(ua.scale.linear(),nl,il)},ua.text=Dt(function(t){return t.responseText}),ua.json=function(t,e){return St(t,"application/json",aa,e)},ua.html=function(t,e){return St(t,"text/html",sa,e)},ua.xml=Dt(function(t){return t.responseXML}),"function"==typeof define&&define.amd?(this.d3=ua,define(ua)):"object"==typeof module&&module.exports?module.exports=ua:this.d3=ua}(),function(){var t={};t.dev=!1,t.tooltip=t.tooltip||{},t.utils=t.utils||{},t.models=t.models||{},t.charts={},t.logs={},t.dom={},t.dispatch=d3.dispatch("render_start","render_end"),Function.prototype.bind||(Function.prototype.bind=function(t){if("function"!=typeof this)throw new TypeError("Function.prototype.bind - what is trying to be bound is not callable");var e=Array.prototype.slice.call(arguments,1),n=this,i=function(){},r=function(){return n.apply(this instanceof i&&t?this:t,e.concat(Array.prototype.slice.call(arguments)))};return i.prototype=this.prototype,r.prototype=new i,r}),t.dev&&(t.dispatch.on("render_start",function(e){t.logs.startTime=+new Date}),t.dispatch.on("render_end",function(e){t.logs.endTime=+new Date,t.logs.totalTime=t.logs.endTime-t.logs.startTime,t.log("total",t.logs.totalTime)})),t.log=function(){if(t.dev&&window.console&&console.log&&console.log.apply)console.log.apply(console,arguments);else if(t.dev&&window.console&&"function"==typeof console.log&&Function.prototype.bind){var e=Function.prototype.bind.call(console.log,console);e.apply(console,arguments)}return arguments[arguments.length-1]},t.deprecated=function(t,e){console&&console.warn&&console.warn("nvd3 warning: `"+t+"` has been deprecated. ",e||"")},t.render=function(e){e=e||1,t.render.active=!0,t.dispatch.render_start();var n=function(){for(var i,r,o=0;e>o&&(r=t.render.queue[o]);o++)i=r.generate(),typeof r.callback==typeof Function&&r.callback(i);t.render.queue.splice(0,o),t.render.queue.length?setTimeout(n):(t.dispatch.render_end(),t.render.active=!1)};setTimeout(n)},t.render.active=!1,t.render.queue=[],t.addGraph=function(e){typeof arguments[0]==typeof Function&&(e={generate:arguments[0],callback:arguments[1]}),t.render.queue.push(e),t.render.active||t.render()},"undefined"!=typeof module&&"undefined"!=typeof exports&&(module.exports=t),"undefined"!=typeof window&&(window.nv=t),t.dom.write=function(t){return void 0!==window.fastdom?fastdom.write(t):t()},t.dom.read=function(t){return void 0!==window.fastdom?fastdom.read(t):t()},t.interactiveGuideline=function(){"use strict";function e(d){d.each(function(d){function h(){var t=d3.mouse(this),i=t[0],r=t[1],s=!0,u=!1;if(c&&(i=d3.event.offsetX,r=d3.event.offsetY,"svg"!==d3.event.target.tagName&&(s=!1),d3.event.target.className.baseVal.match("nv-legend")&&(u=!0)),s&&(i-=n.left,r-=n.top),0>i||0>r||i>p||r>g||d3.event.relatedTarget&&void 0===d3.event.relatedTarget.ownerSVGElement||u){if(c&&d3.event.relatedTarget&&void 0===d3.event.relatedTarget.ownerSVGElement&&(void 0===d3.event.relatedTarget.className||d3.event.relatedTarget.className.match(l.nvPointerEventsClass)))return;return a.elementMouseout({mouseX:i,mouseY:r}),e.renderGuideLine(null),void l.hidden(!0)}l.hidden(!1);var d="function"==typeof o.rangeBands,h=void 0;if(d){var f=d3.bisect(o.range(),i)-1;if(!(o.range()[f]+o.rangeBand()>=i))return a.elementMouseout({mouseX:i,mouseY:r}),e.renderGuideLine(null),void l.hidden(!0);h=o.domain()[d3.bisect(o.range(),i)-1]}else h=o.invert(i);a.elementMousemove({mouseX:i,mouseY:r,pointXValue:h}),"dblclick"===d3.event.type&&a.elementDblclick({mouseX:i,mouseY:r,pointXValue:h}),"click"===d3.event.type&&a.elementClick({mouseX:i,mouseY:r,pointXValue:h}),"mousedown"===d3.event.type&&a.elementMouseDown({mouseX:i,mouseY:r,pointXValue:h}),"mouseup"===d3.event.type&&a.elementMouseUp({mouseX:i,mouseY:r,pointXValue:h})}var f=d3.select(this),p=i||960,g=r||400,m=f.selectAll("g.nv-wrap.nv-interactiveLineLayer").data([d]),v=m.enter().append("g").attr("class"," nv-wrap nv-interactiveLineLayer");v.append("g").attr("class","nv-interactiveGuideLine"),u&&(u.on("touchmove",h).on("mousemove",h,!0).on("mouseout",h,!0).on("mousedown",h,!0).on("mouseup",h,!0).on("dblclick",h).on("click",h),e.guideLine=null,e.renderGuideLine=function(n){s&&(e.guideLine&&e.guideLine.attr("x1")===n||t.dom.write(function(){var e=m.select(".nv-interactiveGuideLine").selectAll("line").data(null!=n?[t.utils.NaNtoZero(n)]:[],String);e.enter().append("line").attr("class","nv-guideline").attr("x1",function(t){return t}).attr("x2",function(t){return t}).attr("y1",g).attr("y2",0),e.exit().remove()}))})})}var n={left:0,top:0},i=null,r=null,o=d3.scale.linear(),a=d3.dispatch("elementMousemove","elementMouseout","elementClick","elementDblclick","elementMouseDown","elementMouseUp"),s=!0,u=null,l=t.models.tooltip(),c="ActiveXObject"in window;return l.duration(0).hideDelay(0).hidden(!1),e.dispatch=a,e.tooltip=l,e.margin=function(t){return arguments.length?(n.top="undefined"!=typeof t.top?t.top:n.top,n.left="undefined"!=typeof t.left?t.left:n.left,e):n},e.width=function(t){return arguments.length?(i=t,e):i},e.height=function(t){return arguments.length?(r=t,e):r},e.xScale=function(t){return arguments.length?(o=t,e):o},e.showGuideLine=function(t){return arguments.length?(s=t,e):s},e.svgContainer=function(t){return arguments.length?(u=t,e):u},e},t.interactiveBisect=function(t,e,n){"use strict";if(!(t instanceof Array))return null;var i;i="function"!=typeof n?function(t){return t.x}:n;var r=function(t,e){return i(t)-e},o=d3.bisector(r).left,a=d3.max([0,o(t,e)-1]),s=i(t[a]);if("undefined"==typeof s&&(s=a),s===e)return a;var u=d3.min([a+1,t.length-1]),l=i(t[u]);return"undefined"==typeof l&&(l=u),Math.abs(l-e)>=Math.abs(s-e)?a:u},t.nearestValueIndex=function(t,e,n){"use strict";var i=1/0,r=null;return t.forEach(function(t,o){var a=Math.abs(e-t);null!=t&&i>=a&&n>a&&(i=a,r=o)}),r},t.models.tooltip=function(){"use strict";function e(){if(!h){var t=l?l:document.body;h=d3.select(t).append("div").attr("class","nvtooltip "+(u?u:"xy-tooltip")).attr("id",i),h.style("top",0).style("left",0),h.style("opacity",0),h.style("position","fixed"),h.selectAll("div, table, td, tr").classed(v,!0),h.classed(v,!0)}}function n(){return p&&$(r)?(t.dom.write(function(){e();var t=_(r);t&&(h.node().innerHTML=t),C()}),n):void 0}var i="nvtooltip-"+Math.floor(1e5*Math.random()),r=null,o="w",a=25,s=0,u=null,l=null,c=!0,d=200,h=null,f={left:null,top:null},p=!0,g=100,m=!0,v="nv-pointer-events-none",y=function(){return{left:null!==d3.event?d3.event.clientX:0,top:null!==d3.event?d3.event.clientY:0}},b=function(t,e){return t},x=function(t){return t},w=function(t,e){return t},_=function(t){if(null===t)return"";var e=d3.select(document.createElement("table"));if(m){var n=e.selectAll("thead").data([t]).enter().append("thead");n.append("tr").append("td").attr("colspan",3).append("strong").classed("x-value",!0).html(x(t.value))}var i=e.selectAll("tbody").data([t]).enter().append("tbody"),r=i.selectAll("tr").data(function(t){return t.series}).enter().append("tr").classed("highlight",function(t){return t.highlight});r.append("td").classed("legend-color-guide",!0).append("div").style("background-color",function(t){return t.color}),r.append("td").classed("key",!0).classed("total",function(t){return!!t.total}).html(function(t,e){return w(t.key,e)}),r.append("td").classed("value",!0).html(function(t,e){return b(t.value,e)}),r.selectAll("td").each(function(t){if(t.highlight){var e=d3.scale.linear().domain([0,1]).range(["#fff",t.color]),n=.6;d3.select(this).style("border-bottom-color",e(n)).style("border-top-color",e(n))}});var o=e.node().outerHTML;return void 0!==t.footer&&(o+="<div class='footer'>"+t.footer+"</div>"),o},$=function(t){if(t&&t.series){if(t.series instanceof Array)return!!t.series.length;if(t.series instanceof Object)return t.series=[t.series],!0}return!1},k=function(t){var e,n,i,r=h.node().offsetHeight,s=h.node().offsetWidth,u=document.documentElement.clientWidth,l=document.documentElement.clientHeight;switch(o){case"e":e=-s-a,n=-(r/2),t.left+e<0&&(e=a),(i=t.top+n)<0&&(n-=i),(i=t.top+n+r)>l&&(n-=i-l);break;case"w":e=a,n=-(r/2),t.left+e+s>u&&(e=-s-a),(i=t.top+n)<0&&(n-=i),(i=t.top+n+r)>l&&(n-=i-l);break;case"n":e=-(s/2)-5,n=a,t.top+n+r>l&&(n=-r-a),(i=t.left+e)<0&&(e-=i),(i=t.left+e+s)>u&&(e-=i-u);break;case"s":e=-(s/2),n=-r-a,t.top+n<0&&(n=a),(i=t.left+e)<0&&(e-=i),(i=t.left+e+s)>u&&(e-=i-u);break;case"center":e=-(s/2),n=-(r/2);break;default:e=0,n=0}return{left:e,top:n}},C=function(){t.dom.read(function(){var t=y(),e=k(t),n=t.left+e.left,i=t.top+e.top;if(c)h.interrupt().transition().delay(d).duration(0).style("opacity",0);else{var r="translate("+f.left+"px, "+f.top+"px)",o="translate("+n+"px, "+i+"px)",a=d3.interpolateString(r,o),s=h.style("opacity")<.1;h.interrupt().transition().duration(s?0:g).styleTween("transform",function(t){return a},"important").styleTween("-webkit-transform",function(t){return a}).style("-ms-transform",o).style("opacity",1)}f.left=n,f.top=i})};return n.nvPointerEventsClass=v,n.options=t.utils.optionsFunc.bind(n),n._options=Object.create({},{duration:{get:function(){return g},set:function(t){g=t}},gravity:{get:function(){return o},set:function(t){o=t}},distance:{get:function(){return a},set:function(t){a=t}},snapDistance:{get:function(){return s},set:function(t){s=t}},classes:{get:function(){return u},set:function(t){u=t}},chartContainer:{get:function(){return l},set:function(t){l=t}},enabled:{get:function(){return p},set:function(t){p=t}},hideDelay:{get:function(){return d},set:function(t){d=t}},contentGenerator:{get:function(){return _},set:function(t){_=t}},valueFormatter:{get:function(){return b},set:function(t){b=t}},headerFormatter:{get:function(){return x},set:function(t){x=t}},keyFormatter:{get:function(){return w},set:function(t){w=t}},headerEnabled:{get:function(){return m},set:function(t){m=t}},position:{get:function(){return y},set:function(t){y=t}},fixedTop:{get:function(){return null},set:function(e){t.deprecated("fixedTop","feature removed after 1.8.1")}},offset:{get:function(){return{left:0,top:0}},set:function(e){t.deprecated("offset","use chart.tooltip.distance() instead")}},hidden:{get:function(){return c},set:function(t){c!=t&&(c=!!t,n())}},data:{get:function(){return r},set:function(t){t.point&&(t.value=t.point.x,t.series=t.series||{},t.series.value=t.point.y,t.series.color=t.point.color||t.series.color),r=t}},node:{get:function(){return h.node()},set:function(t){}},id:{get:function(){return i},set:function(t){}}}),t.utils.initOptions(n),n},t.utils.windowSize=function(){var t={width:640,height:480};return window.innerWidth&&window.innerHeight?(t.width=window.innerWidth,t.height=window.innerHeight,t):"CSS1Compat"==document.compatMode&&document.documentElement&&document.documentElement.offsetWidth?(t.width=document.documentElement.offsetWidth,t.height=document.documentElement.offsetHeight,t):document.body&&document.body.offsetWidth?(t.width=document.body.offsetWidth,t.height=document.body.offsetHeight,t):t},t.utils.windowResize=function(e){return window.addEventListener?window.addEventListener("resize",e):t.log("ERROR: Failed to bind to window.resize with: ",e),{callback:e,clear:function(){window.removeEventListener("resize",e)}}},t.utils.getColor=function(e){if(void 0===e)return t.utils.defaultColor();if(Array.isArray(e)){var n=d3.scale.ordinal().range(e);return function(t,e){var i=void 0===e?t:e;return t.color||n(i)}}return e},t.utils.defaultColor=function(){return t.utils.getColor(d3.scale.category20().range())},t.utils.customTheme=function(t,e,n){e=e||function(t){return t.key},n=n||d3.scale.category20().range();var i=n.length;return function(r,o){var a=e(r);return"function"==typeof t[a]?t[a]():void 0!==t[a]?t[a]:(i||(i=n.length),i-=1,n[i])}},t.utils.pjax=function(e,n){var i=function(i){d3.html(i,function(i){var r=d3.select(n).node();r.parentNode.replaceChild(d3.select(i).select(n).node(),r),t.utils.pjax(e,n)})};d3.selectAll(e).on("click",function(){history.pushState(this.href,this.textContent,this.href),i(this.href),d3.event.preventDefault()}),
d3.select(window).on("popstate",function(){d3.event.state&&i(d3.event.state)})},t.utils.calcApproxTextWidth=function(t){if("function"==typeof t.style&&"function"==typeof t.text){var e=parseInt(t.style("font-size").replace("px",""),10),n=t.text().length;return n*e*.5}return 0},t.utils.NaNtoZero=function(t){return"number"!=typeof t||isNaN(t)||null===t||t===1/0||t===-(1/0)?0:t},d3.selection.prototype.watchTransition=function(t){var e=[this].concat([].slice.call(arguments,1));return t.transition.apply(t,e)},t.utils.renderWatch=function(e,n){if(!(this instanceof t.utils.renderWatch))return new t.utils.renderWatch(e,n);var i=void 0!==n?n:250,r=[],o=this;this.models=function(t){return t=[].slice.call(arguments,0),t.forEach(function(t){t.__rendered=!1,function(t){t.dispatch.on("renderEnd",function(e){t.__rendered=!0,o.renderEnd("model")})}(t),r.indexOf(t)<0&&r.push(t)}),this},this.reset=function(t){void 0!==t&&(i=t),r=[]},this.transition=function(t,e,n){if(e=arguments.length>1?[].slice.call(arguments,1):[],n=e.length>1?e.pop():void 0!==i?i:250,t.__rendered=!1,r.indexOf(t)<0&&r.push(t),0===n)return t.__rendered=!0,t.delay=function(){return this},t.duration=function(){return this},t;0===t.length?t.__rendered=!0:t.every(function(t){return!t.length})?t.__rendered=!0:t.__rendered=!1;var a=0;return t.transition().duration(n).each(function(){++a}).each("end",function(n,i){0===--a&&(t.__rendered=!0,o.renderEnd.apply(this,e))})},this.renderEnd=function(){r.every(function(t){return t.__rendered})&&(r.forEach(function(t){t.__rendered=!1}),e.renderEnd.apply(this,arguments))}},t.utils.deepExtend=function(e){var n=arguments.length>1?[].slice.call(arguments,1):[];n.forEach(function(n){for(var i in n){var r=e[i]instanceof Array,o="object"==typeof e[i],a="object"==typeof n[i];o&&!r&&a?t.utils.deepExtend(e[i],n[i]):e[i]=n[i]}})},t.utils.state=function(){if(!(this instanceof t.utils.state))return new t.utils.state;var e={},n=function(){},i=function(){return{}},r=null,o=null;this.dispatch=d3.dispatch("change","set"),this.dispatch.on("set",function(t){n(t,!0)}),this.getter=function(t){return i=t,this},this.setter=function(t,e){return e||(e=function(){}),n=function(n,i){t(n),i&&e()},this},this.init=function(e){r=r||{},t.utils.deepExtend(r,e)};var a=function(){var t=i();if(JSON.stringify(t)===JSON.stringify(e))return!1;for(var n in t)void 0===e[n]&&(e[n]={}),e[n]=t[n],o=!0;return!0};this.update=function(){r&&(n(r,!1),r=null),a.call(this)&&this.dispatch.change(e)}},t.utils.optionsFunc=function(t){return t&&d3.map(t).forEach(function(t,e){"function"==typeof this[t]&&this[t](e)}.bind(this)),this},t.utils.calcTicksX=function(e,n){var i=1,r=0;for(r;r<n.length;r+=1){var o=n[r]&&n[r].values?n[r].values.length:0;i=o>i?o:i}return t.log("Requested number of ticks: ",e),t.log("Calculated max values to be: ",i),e=e>i?e=i-1:e,e=1>e?1:e,e=Math.floor(e),t.log("Calculating tick count as: ",e),e},t.utils.calcTicksY=function(e,n){return t.utils.calcTicksX(e,n)},t.utils.initOption=function(t,e){t._calls&&t._calls[e]?t[e]=t._calls[e]:(t[e]=function(n){return arguments.length?(t._overrides[e]=!0,t._options[e]=n,t):t._options[e]},t["_"+e]=function(n){return arguments.length?(t._overrides[e]||(t._options[e]=n),t):t._options[e]})},t.utils.initOptions=function(e){e._overrides=e._overrides||{};var n=Object.getOwnPropertyNames(e._options||{}),i=Object.getOwnPropertyNames(e._calls||{});n=n.concat(i);for(var r in n)t.utils.initOption(e,n[r])},t.utils.inheritOptionsD3=function(t,e,n){t._d3options=n.concat(t._d3options||[]),n.unshift(e),n.unshift(t),d3.rebind.apply(this,n)},t.utils.arrayUnique=function(t){return t.sort().filter(function(e,n){return!n||e!=t[n-1]})},t.utils.symbolMap=d3.map(),t.utils.symbol=function(){function e(e,r){var o=n.call(this,e,r),a=i.call(this,e,r);return-1!==d3.svg.symbolTypes.indexOf(o)?d3.svg.symbol().type(o).size(a)():t.utils.symbolMap.get(o)(a)}var n,i=64;return e.type=function(t){return arguments.length?(n=d3.functor(t),e):n},e.size=function(t){return arguments.length?(i=d3.functor(t),e):i},e},t.utils.inheritOptions=function(e,n){var i=Object.getOwnPropertyNames(n._options||{}),r=Object.getOwnPropertyNames(n._calls||{}),o=n._inherited||[],a=n._d3options||[],s=i.concat(r).concat(o).concat(a);s.unshift(n),s.unshift(e),d3.rebind.apply(this,s),e._inherited=t.utils.arrayUnique(i.concat(r).concat(o).concat(i).concat(e._inherited||[])),e._d3options=t.utils.arrayUnique(a.concat(e._d3options||[]))},t.utils.initSVG=function(t){t.classed({"nvd3-svg":!0})},t.utils.sanitizeHeight=function(t,e){return t||parseInt(e.style("height"),10)||400},t.utils.sanitizeWidth=function(t,e){return t||parseInt(e.style("width"),10)||960},t.utils.availableHeight=function(e,n,i){return Math.max(0,t.utils.sanitizeHeight(e,n)-i.top-i.bottom)},t.utils.availableWidth=function(e,n,i){return Math.max(0,t.utils.sanitizeWidth(e,n)-i.left-i.right)},t.utils.noData=function(e,n){var i=e.options(),r=i.margin(),o=i.noData(),a=null==o?["No Data Available."]:[o],s=t.utils.availableHeight(null,n,r),u=t.utils.availableWidth(null,n,r),l=r.left+u/2,c=r.top+s/2;n.selectAll("g").remove();var d=n.selectAll(".nv-noData").data(a);d.enter().append("text").attr("class","nvd3 nv-noData").attr("dy","-.7em").style("text-anchor","middle"),d.attr("x",l).attr("y",c).text(function(t){return t})},t.utils.wrapTicks=function(t,e){t.each(function(){for(var t,n=d3.select(this),i=n.text().split(/\s+/).reverse(),r=[],o=0,a=1.1,s=n.attr("y"),u=parseFloat(n.attr("dy")),l=n.text(null).append("tspan").attr("x",0).attr("y",s).attr("dy",u+"em");t=i.pop();)r.push(t),l.text(r.join(" ")),l.node().getComputedTextLength()>e&&(r.pop(),l.text(r.join(" ")),r=[t],l=n.append("tspan").attr("x",0).attr("y",s).attr("dy",++o*a+u+"em").text(t))})},t.utils.arrayEquals=function(e,n){if(e===n)return!0;if(!e||!n)return!1;if(e.length!=n.length)return!1;for(var i=0,r=e.length;r>i;i++)if(e[i]instanceof Array&&n[i]instanceof Array){if(!t.arrayEquals(e[i],n[i]))return!1}else if(e[i]!=n[i])return!1;return!0},t.models.axis=function(){"use strict";function e(a){return y.reset(),a.each(function(e){var a=d3.select(this);t.utils.initSVG(a);var g=a.selectAll("g.nv-wrap.nv-axis").data([e]),m=g.enter().append("g").attr("class","nvd3 nv-wrap nv-axis"),b=(m.append("g"),g.select("g"));null!==f?n.ticks(f):("top"==n.orient()||"bottom"==n.orient())&&n.ticks(Math.abs(i.range()[1]-i.range()[0])/100),b.watchTransition(y,"axis").call(n),v=v||n.scale();var x=n.tickFormat();null==x&&(x=v.tickFormat());var w=b.selectAll("text.nv-axislabel").data([s||null]);w.exit().remove();var _,$,k;switch(n.orient()){case"top":w.enter().append("text").attr("class","nv-axislabel"),k=0,1===i.range().length?k=h?2*i.range()[0]+i.rangeBand():0:2===i.range().length?k=h?i.range()[0]+i.range()[1]+i.rangeBand():i.range()[1]:i.range().length>2&&(k=i.range()[i.range().length-1]+(i.range()[1]-i.range()[0])),w.attr("text-anchor","middle").attr("y",0).attr("x",k/2),u&&($=g.selectAll("g.nv-axisMaxMin").data(i.domain()),$.enter().append("g").attr("class",function(t,e){return["nv-axisMaxMin","nv-axisMaxMin-x",0==e?"nv-axisMin-x":"nv-axisMax-x"].join(" ")}).append("text"),$.exit().remove(),$.attr("transform",function(e,n){return"translate("+t.utils.NaNtoZero(i(e))+",0)"}).select("text").attr("dy","-0.5em").attr("y",-n.tickPadding()).attr("text-anchor","middle").text(function(t,e){var n=x(t);return(""+n).match("NaN")?"":n}),$.watchTransition(y,"min-max top").attr("transform",function(e,n){return"translate("+t.utils.NaNtoZero(i.range()[n])+",0)"}));break;case"bottom":_=p+36;var C=30,M=0,D=b.selectAll("g").select("text"),S="";if(l%360){D.each(function(t,e){var n=this.getBoundingClientRect(),i=n.width;M=n.height,i>C&&(C=i)}),S="rotate("+l+" 0,"+(M/2+n.tickPadding())+")";var T=Math.abs(Math.sin(l*Math.PI/180));_=(T?T*C:C)+30,D.attr("transform",S).style("text-anchor",l%360>0?"start":"end")}else d?D.attr("transform",function(t,e){return"translate(0,"+(e%2==0?"0":"12")+")"}):D.attr("transform","translate(0,0)");w.enter().append("text").attr("class","nv-axislabel"),k=0,1===i.range().length?k=h?2*i.range()[0]+i.rangeBand():0:2===i.range().length?k=h?i.range()[0]+i.range()[1]+i.rangeBand():i.range()[1]:i.range().length>2&&(k=i.range()[i.range().length-1]+(i.range()[1]-i.range()[0])),w.attr("text-anchor","middle").attr("y",_).attr("x",k/2),u&&($=g.selectAll("g.nv-axisMaxMin").data([i.domain()[0],i.domain()[i.domain().length-1]]),$.enter().append("g").attr("class",function(t,e){return["nv-axisMaxMin","nv-axisMaxMin-x",0==e?"nv-axisMin-x":"nv-axisMax-x"].join(" ")}).append("text"),$.exit().remove(),$.attr("transform",function(e,n){return"translate("+t.utils.NaNtoZero(i(e)+(h?i.rangeBand()/2:0))+",0)"}).select("text").attr("dy",".71em").attr("y",n.tickPadding()).attr("transform",S).style("text-anchor",l?l%360>0?"start":"end":"middle").text(function(t,e){var n=x(t);return(""+n).match("NaN")?"":n}),$.watchTransition(y,"min-max bottom").attr("transform",function(e,n){return"translate("+t.utils.NaNtoZero(i(e)+(h?i.rangeBand()/2:0))+",0)"}));break;case"right":w.enter().append("text").attr("class","nv-axislabel"),w.style("text-anchor",c?"middle":"begin").attr("transform",c?"rotate(90)":"").attr("y",c?-Math.max(r.right,o)+12:-10).attr("x",c?d3.max(i.range())/2:n.tickPadding()),u&&($=g.selectAll("g.nv-axisMaxMin").data(i.domain()),$.enter().append("g").attr("class",function(t,e){return["nv-axisMaxMin","nv-axisMaxMin-y",0==e?"nv-axisMin-y":"nv-axisMax-y"].join(" ")}).append("text").style("opacity",0),$.exit().remove(),$.attr("transform",function(e,n){return"translate(0,"+t.utils.NaNtoZero(i(e))+")"}).select("text").attr("dy",".32em").attr("y",0).attr("x",n.tickPadding()).style("text-anchor","start").text(function(t,e){var n=x(t);return(""+n).match("NaN")?"":n}),$.watchTransition(y,"min-max right").attr("transform",function(e,n){return"translate(0,"+t.utils.NaNtoZero(i.range()[n])+")"}).select("text").style("opacity",1));break;case"left":w.enter().append("text").attr("class","nv-axislabel"),w.style("text-anchor",c?"middle":"end").attr("transform",c?"rotate(-90)":"").attr("y",c?-Math.max(r.left,o)+25-(p||0):-10).attr("x",c?-d3.max(i.range())/2:-n.tickPadding()),u&&($=g.selectAll("g.nv-axisMaxMin").data(i.domain()),$.enter().append("g").attr("class",function(t,e){return["nv-axisMaxMin","nv-axisMaxMin-y",0==e?"nv-axisMin-y":"nv-axisMax-y"].join(" ")}).append("text").style("opacity",0),$.exit().remove(),$.attr("transform",function(e,n){return"translate(0,"+t.utils.NaNtoZero(v(e))+")"}).select("text").attr("dy",".32em").attr("y",0).attr("x",-n.tickPadding()).attr("text-anchor","end").text(function(t,e){var n=x(t);return(""+n).match("NaN")?"":n}),$.watchTransition(y,"min-max right").attr("transform",function(e,n){return"translate(0,"+t.utils.NaNtoZero(i.range()[n])+")"}).select("text").style("opacity",1))}if(w.text(function(t){return t}),!u||"left"!==n.orient()&&"right"!==n.orient()||(b.selectAll("g").each(function(t,e){d3.select(this).select("text").attr("opacity",1),(i(t)<i.range()[1]+10||i(t)>i.range()[0]-10)&&((t>1e-10||-1e-10>t)&&d3.select(this).attr("opacity",0),d3.select(this).select("text").attr("opacity",0))}),i.domain()[0]==i.domain()[1]&&0==i.domain()[0]&&g.selectAll("g.nv-axisMaxMin").style("opacity",function(t,e){return e?0:1})),u&&("top"===n.orient()||"bottom"===n.orient())){var A=[];g.selectAll("g.nv-axisMaxMin").each(function(t,e){try{e?A.push(i(t)-this.getBoundingClientRect().width-4):A.push(i(t)+this.getBoundingClientRect().width+4)}catch(n){e?A.push(i(t)-4):A.push(i(t)+4)}}),b.selectAll("g").each(function(t,e){(i(t)<A[0]||i(t)>A[1])&&(t>1e-10||-1e-10>t?d3.select(this).remove():d3.select(this).select("text").remove())})}b.selectAll(".tick").filter(function(t){return!parseFloat(Math.round(1e5*t)/1e6)&&void 0!==t}).classed("zero",!0),v=i.copy()}),y.renderEnd("axis immediate"),e}var n=d3.svg.axis(),i=d3.scale.linear(),r={top:0,right:0,bottom:0,left:0},o=75,a=60,s=null,u=!0,l=0,c=!0,d=!1,h=!1,f=null,p=0,g=250,m=d3.dispatch("renderEnd");n.scale(i).orient("bottom").tickFormat(function(t){return t});var v,y=t.utils.renderWatch(m,g);return e.axis=n,e.dispatch=m,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{axisLabelDistance:{get:function(){return p},set:function(t){p=t}},staggerLabels:{get:function(){return d},set:function(t){d=t}},rotateLabels:{get:function(){return l},set:function(t){l=t}},rotateYLabel:{get:function(){return c},set:function(t){c=t}},showMaxMin:{get:function(){return u},set:function(t){u=t}},axisLabel:{get:function(){return s},set:function(t){s=t}},height:{get:function(){return a},set:function(t){a=t}},ticks:{get:function(){return f},set:function(t){f=t}},width:{get:function(){return o},set:function(t){o=t}},margin:{get:function(){return r},set:function(t){r.top=void 0!==t.top?t.top:r.top,r.right=void 0!==t.right?t.right:r.right,r.bottom=void 0!==t.bottom?t.bottom:r.bottom,r.left=void 0!==t.left?t.left:r.left}},duration:{get:function(){return g},set:function(t){g=t,y.reset(g)}},scale:{get:function(){return i},set:function(r){i=r,n.scale(i),h="function"==typeof i.rangeBands,t.utils.inheritOptionsD3(e,i,["domain","range","rangeBand","rangeBands"])}}}),t.utils.initOptions(e),t.utils.inheritOptionsD3(e,n,["orient","tickValues","tickSubdivide","tickSize","tickPadding","tickFormat"]),t.utils.inheritOptionsD3(e,i,["domain","range","rangeBand","rangeBands"]),e},t.models.boxPlot=function(){"use strict";function e(d){return w.reset(),d.each(function(e){var d=l-u.left-u.right,g=c-u.top-u.bottom;v=d3.select(this),t.utils.initSVG(v),h.domain(n||e.map(function(t,e){return p(t,e)})).rangeBands(r||[0,d],.1);var _=[];if(!i){var $=d3.min(e.map(function(t){var e=[];return e.push(t.values.Q1),t.values.hasOwnProperty("whisker_low")&&null!==t.values.whisker_low&&e.push(t.values.whisker_low),t.values.hasOwnProperty("outliers")&&null!==t.values.outliers&&(e=e.concat(t.values.outliers)),d3.min(e)})),k=d3.max(e.map(function(t){var e=[];return e.push(t.values.Q3),t.values.hasOwnProperty("whisker_high")&&null!==t.values.whisker_high&&e.push(t.values.whisker_high),t.values.hasOwnProperty("outliers")&&null!==t.values.outliers&&(e=e.concat(t.values.outliers)),d3.max(e)}));_=[$,k]}f.domain(i||_),f.range(o||[g,0]),a=a||h,s=s||f.copy().range([f(0),f(0)]);var C=v.selectAll("g.nv-wrap").data([e]);C.enter().append("g").attr("class","nvd3 nv-wrap");C.attr("transform","translate("+u.left+","+u.top+")");var M=C.selectAll(".nv-boxplot").data(function(t){return t}),D=M.enter().append("g").style("stroke-opacity",1e-6).style("fill-opacity",1e-6);M.attr("class","nv-boxplot").attr("transform",function(t,e,n){return"translate("+(h(p(t,e))+.05*h.rangeBand())+", 0)"}).classed("hover",function(t){return t.hover}),M.watchTransition(w,"nv-boxplot: boxplots").style("stroke-opacity",1).style("fill-opacity",.75).delay(function(t,n){return n*b/e.length}).attr("transform",function(t,e){return"translate("+(h(p(t,e))+.05*h.rangeBand())+", 0)"}),M.exit().remove(),D.each(function(t,e){var n=d3.select(this);["low","high"].forEach(function(i){t.values.hasOwnProperty("whisker_"+i)&&null!==t.values["whisker_"+i]&&(n.append("line").style("stroke",t.color?t.color:m(t,e)).attr("class","nv-boxplot-whisker nv-boxplot-"+i),n.append("line").style("stroke",t.color?t.color:m(t,e)).attr("class","nv-boxplot-tick nv-boxplot-"+i))})});var S=M.selectAll(".nv-boxplot-outlier").data(function(t){return t.values.hasOwnProperty("outliers")&&null!==t.values.outliers?t.values.outliers:[]});S.enter().append("circle").style("fill",function(t,e,n){return m(t,n)}).style("stroke",function(t,e,n){return m(t,n)}).on("mouseover",function(t,e,n){d3.select(this).classed("hover",!0),y.elementMouseover({series:{key:t,color:m(t,n)},e:d3.event})}).on("mouseout",function(t,e,n){d3.select(this).classed("hover",!1),y.elementMouseout({series:{key:t,color:m(t,n)},e:d3.event})}).on("mousemove",function(t,e){y.elementMousemove({e:d3.event})}),S.attr("class","nv-boxplot-outlier"),S.watchTransition(w,"nv-boxplot: nv-boxplot-outlier").attr("cx",.45*h.rangeBand()).attr("cy",function(t,e,n){return f(t)}).attr("r","3"),S.exit().remove();var T=function(){return null===x?.9*h.rangeBand():Math.min(75,.9*h.rangeBand())},A=function(){return.45*h.rangeBand()-T()/2},E=function(){return.45*h.rangeBand()+T()/2};["low","high"].forEach(function(t){var e="low"===t?"Q1":"Q3";M.select("line.nv-boxplot-whisker.nv-boxplot-"+t).watchTransition(w,"nv-boxplot: boxplots").attr("x1",.45*h.rangeBand()).attr("y1",function(e,n){return f(e.values["whisker_"+t])}).attr("x2",.45*h.rangeBand()).attr("y2",function(t,n){return f(t.values[e])}),M.select("line.nv-boxplot-tick.nv-boxplot-"+t).watchTransition(w,"nv-boxplot: boxplots").attr("x1",A).attr("y1",function(e,n){return f(e.values["whisker_"+t])}).attr("x2",E).attr("y2",function(e,n){return f(e.values["whisker_"+t])})}),["low","high"].forEach(function(t){D.selectAll(".nv-boxplot-"+t).on("mouseover",function(e,n,i){d3.select(this).classed("hover",!0),y.elementMouseover({series:{key:e.values["whisker_"+t],color:m(e,i)},e:d3.event})}).on("mouseout",function(e,n,i){d3.select(this).classed("hover",!1),y.elementMouseout({series:{key:e.values["whisker_"+t],color:m(e,i)},e:d3.event})}).on("mousemove",function(t,e){y.elementMousemove({e:d3.event})})}),D.append("rect").attr("class","nv-boxplot-box").on("mouseover",function(t,e){d3.select(this).classed("hover",!0),y.elementMouseover({key:t.label,value:t.label,series:[{key:"Q3",value:t.values.Q3,color:t.color||m(t,e)},{key:"Q2",value:t.values.Q2,color:t.color||m(t,e)},{key:"Q1",value:t.values.Q1,color:t.color||m(t,e)}],data:t,index:e,e:d3.event})}).on("mouseout",function(t,e){d3.select(this).classed("hover",!1),y.elementMouseout({key:t.label,value:t.label,series:[{key:"Q3",value:t.values.Q3,color:t.color||m(t,e)},{key:"Q2",value:t.values.Q2,color:t.color||m(t,e)},{key:"Q1",value:t.values.Q1,color:t.color||m(t,e)}],data:t,index:e,e:d3.event})}).on("mousemove",function(t,e){y.elementMousemove({e:d3.event})}),M.select("rect.nv-boxplot-box").watchTransition(w,"nv-boxplot: boxes").attr("y",function(t,e){return f(t.values.Q3)}).attr("width",T).attr("x",A).attr("height",function(t,e){return Math.abs(f(t.values.Q3)-f(t.values.Q1))||1}).style("fill",function(t,e){return t.color||m(t,e)}).style("stroke",function(t,e){return t.color||m(t,e)}),D.append("line").attr("class","nv-boxplot-median"),M.select("line.nv-boxplot-median").watchTransition(w,"nv-boxplot: boxplots line").attr("x1",A).attr("y1",function(t,e){return f(t.values.Q2)}).attr("x2",E).attr("y2",function(t,e){return f(t.values.Q2)}),a=h.copy(),s=f.copy()}),w.renderEnd("nv-boxplot immediate"),e}var n,i,r,o,a,s,u={top:0,right:0,bottom:0,left:0},l=960,c=500,d=Math.floor(1e4*Math.random()),h=d3.scale.ordinal(),f=d3.scale.linear(),p=function(t){return t.x},g=function(t){return t.y},m=t.utils.defaultColor(),v=null,y=d3.dispatch("elementMouseover","elementMouseout","elementMousemove","renderEnd"),b=250,x=null,w=t.utils.renderWatch(y,b);return e.dispatch=y,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return l},set:function(t){l=t}},height:{get:function(){return c},set:function(t){c=t}},maxBoxWidth:{get:function(){return x},set:function(t){x=t}},x:{get:function(){return p},set:function(t){p=t}},y:{get:function(){return g},set:function(t){g=t}},xScale:{get:function(){return h},set:function(t){h=t}},yScale:{get:function(){return f},set:function(t){f=t}},xDomain:{get:function(){return n},set:function(t){n=t}},yDomain:{get:function(){return i},set:function(t){i=t}},xRange:{get:function(){return r},set:function(t){r=t}},yRange:{get:function(){return o},set:function(t){o=t}},id:{get:function(){return d},set:function(t){d=t}},margin:{get:function(){return u},set:function(t){u.top=void 0!==t.top?t.top:u.top,u.right=void 0!==t.right?t.right:u.right,u.bottom=void 0!==t.bottom?t.bottom:u.bottom,u.left=void 0!==t.left?t.left:u.left}},color:{get:function(){return m},set:function(e){m=t.utils.getColor(e)}},duration:{get:function(){return b},set:function(t){b=t,w.reset(b)}}}),t.utils.initOptions(e),e},t.models.boxPlotChart=function(){"use strict";function e(c){return b.reset(),b.models(r),d&&b.models(o),h&&b.models(a),c.each(function(c){var g=d3.select(this);t.utils.initSVG(g);var b=(u||parseInt(g.style("width"))||960)-s.left-s.right,x=(l||parseInt(g.style("height"))||400)-s.top-s.bottom;if(e.update=function(){v.beforeUpdate(),g.transition().duration(y).call(e)},e.container=this,!(c&&c.length&&c.filter(function(t){return t.values.hasOwnProperty("Q1")&&t.values.hasOwnProperty("Q2")&&t.values.hasOwnProperty("Q3")}).length)){var w=g.selectAll(".nv-noData").data([m]);return w.enter().append("text").attr("class","nvd3 nv-noData").attr("dy","-.7em").style("text-anchor","middle"),w.attr("x",s.left+b/2).attr("y",s.top+x/2).text(function(t){return t}),e}g.selectAll(".nv-noData").remove(),n=r.xScale(),i=r.yScale().clamp(!0);var _=g.selectAll("g.nv-wrap.nv-boxPlotWithAxes").data([c]),$=_.enter().append("g").attr("class","nvd3 nv-wrap nv-boxPlotWithAxes").append("g"),k=$.append("defs"),C=_.select("g");$.append("g").attr("class","nv-x nv-axis"),$.append("g").attr("class","nv-y nv-axis").append("g").attr("class","nv-zeroLine").append("line"),$.append("g").attr("class","nv-barsWrap"),C.attr("transform","translate("+s.left+","+s.top+")"),f&&C.select(".nv-y.nv-axis").attr("transform","translate("+b+",0)"),r.width(b).height(x);var M=C.select(".nv-barsWrap").datum(c.filter(function(t){return!t.disabled}));if(M.transition().call(r),k.append("clipPath").attr("id","nv-x-label-clip-"+r.id()).append("rect"),C.select("#nv-x-label-clip-"+r.id()+" rect").attr("width",n.rangeBand()*(p?2:1)).attr("height",16).attr("x",-n.rangeBand()/(p?1:2)),d){o.scale(n).ticks(t.utils.calcTicksX(b/100,c)).tickSize(-x,0),C.select(".nv-x.nv-axis").attr("transform","translate(0,"+i.range()[0]+")"),C.select(".nv-x.nv-axis").call(o);var D=C.select(".nv-x.nv-axis").selectAll("g");p&&D.selectAll("text").attr("transform",function(t,e,n){return"translate(0,"+(n%2==0?"5":"17")+")"})}h&&(a.scale(i).ticks(Math.floor(x/36)).tickSize(-b,0),C.select(".nv-y.nv-axis").call(a)),C.select(".nv-zeroLine line").attr("x1",0).attr("x2",b).attr("y1",i(0)).attr("y2",i(0))}),b.renderEnd("nv-boxplot chart immediate"),e}var n,i,r=t.models.boxPlot(),o=t.models.axis(),a=t.models.axis(),s={top:15,right:10,bottom:50,left:60},u=null,l=null,c=t.utils.getColor(),d=!0,h=!0,f=!1,p=!1,g=t.models.tooltip(),m="No Data Available.",v=d3.dispatch("beforeUpdate","renderEnd"),y=250;o.orient("bottom").showMaxMin(!1).tickFormat(function(t){return t}),a.orient(f?"right":"left").tickFormat(d3.format(",.1f")),g.duration(0);var b=t.utils.renderWatch(v,y);return r.dispatch.on("elementMouseover.tooltip",function(t){g.data(t).hidden(!1)}),r.dispatch.on("elementMouseout.tooltip",function(t){g.data(t).hidden(!0)}),r.dispatch.on("elementMousemove.tooltip",function(t){g()}),e.dispatch=v,e.boxplot=r,e.xAxis=o,e.yAxis=a,e.tooltip=g,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return u},set:function(t){u=t}},height:{get:function(){return l},set:function(t){l=t}},staggerLabels:{get:function(){return p},set:function(t){p=t}},showXAxis:{get:function(){return d},set:function(t){d=t}},showYAxis:{get:function(){return h},set:function(t){h=t}},tooltipContent:{get:function(){return g},set:function(t){g=t}},noData:{get:function(){return m},set:function(t){m=t}},margin:{get:function(){return s},set:function(t){s.top=void 0!==t.top?t.top:s.top,s.right=void 0!==t.right?t.right:s.right,s.bottom=void 0!==t.bottom?t.bottom:s.bottom,s.left=void 0!==t.left?t.left:s.left}},duration:{get:function(){return y},set:function(t){y=t,b.reset(y),r.duration(y),o.duration(y),a.duration(y)}},color:{get:function(){return c},set:function(e){c=t.utils.getColor(e),r.color(c)}},rightAlignYAxis:{get:function(){return f},set:function(t){f=t,a.orient(t?"right":"left")}}}),t.utils.inheritOptions(e,r),t.utils.initOptions(e),e},t.models.bullet=function(){"use strict";function e(i){return i.each(function(e,i){var g=h-n.left-n.right,y=f-n.top-n.bottom;p=d3.select(this),t.utils.initSVG(p);var b=o.call(this,e,i).slice().sort(d3.descending),x=a.call(this,e,i).slice().sort(d3.descending),w=s.call(this,e,i).slice().sort(d3.descending),_=u.call(this,e,i).slice(),$=l.call(this,e,i).slice(),k=c.call(this,e,i).slice(),C=d3.scale.linear().domain(d3.extent(d3.merge([d,b]))).range(r?[g,0]:[0,g]);this.__chart__||d3.scale.linear().domain([0,1/0]).range(C.range());this.__chart__=C;var M=d3.min(b),D=d3.max(b),S=b[1],T=p.selectAll("g.nv-wrap.nv-bullet").data([e]),A=T.enter().append("g").attr("class","nvd3 nv-wrap nv-bullet"),E=A.append("g"),O=T.select("g");E.append("rect").attr("class","nv-range nv-rangeMax"),E.append("rect").attr("class","nv-range nv-rangeAvg"),E.append("rect").attr("class","nv-range nv-rangeMin"),E.append("rect").attr("class","nv-measure"),T.attr("transform","translate("+n.left+","+n.top+")");var N=function(t){return Math.abs(C(t)-C(0))},I=function(t){return C(0>t?t:0)};O.select("rect.nv-rangeMax").attr("height",y).attr("width",N(D>0?D:M)).attr("x",I(D>0?D:M)).datum(D>0?D:M),O.select("rect.nv-rangeAvg").attr("height",y).attr("width",N(S)).attr("x",I(S)).datum(S),O.select("rect.nv-rangeMin").attr("height",y).attr("width",N(D)).attr("x",I(D)).attr("width",N(D>0?M:D)).attr("x",I(D>0?M:D)).datum(D>0?M:D),O.select("rect.nv-measure").style("fill",m).attr("height",y/3).attr("y",y/3).attr("width",0>w?C(0)-C(w[0]):C(w[0])-C(0)).attr("x",I(w)).on("mouseover",function(){v.elementMouseover({value:w[0],label:k[0]||"Current",color:d3.select(this).style("fill")})}).on("mousemove",function(){v.elementMousemove({value:w[0],label:k[0]||"Current",color:d3.select(this).style("fill")})}).on("mouseout",function(){v.elementMouseout({value:w[0],label:k[0]||"Current",color:d3.select(this).style("fill")})});var P=y/6,F=x.map(function(t,e){return{value:t,label:$[e]}});E.selectAll("path.nv-markerTriangle").data(F).enter().append("path").attr("class","nv-markerTriangle").attr("d","M0,"+P+"L"+P+","+-P+" "+-P+","+-P+"Z").on("mouseover",function(t){v.elementMouseover({value:t.value,label:t.label||"Previous",color:d3.select(this).style("fill"),pos:[C(t.value),y/2]})}).on("mousemove",function(t){v.elementMousemove({value:t.value,label:t.label||"Previous",color:d3.select(this).style("fill")})}).on("mouseout",function(t,e){v.elementMouseout({value:t.value,label:t.label||"Previous",color:d3.select(this).style("fill")})}),O.selectAll("path.nv-markerTriangle").data(F).attr("transform",function(t){return"translate("+C(t.value)+","+y/2+")"}),T.selectAll(".nv-range").on("mouseover",function(t,e){var n=_[e]||(e?1==e?"Mean":"Minimum":"Maximum");v.elementMouseover({value:t,label:n,color:d3.select(this).style("fill")})}).on("mousemove",function(){v.elementMousemove({value:w[0],label:k[0]||"Previous",color:d3.select(this).style("fill")})}).on("mouseout",function(t,e){var n=_[e]||(e?1==e?"Mean":"Minimum":"Maximum");v.elementMouseout({value:t,label:n,color:d3.select(this).style("fill")})})}),e}var n={top:0,right:0,bottom:0,left:0},i="left",r=!1,o=function(t){return t.ranges},a=function(t){return t.markers?t.markers:[]},s=function(t){return t.measures},u=function(t){return t.rangeLabels?t.rangeLabels:[]},l=function(t){return t.markerLabels?t.markerLabels:[]},c=function(t){return t.measureLabels?t.measureLabels:[]},d=[0],h=380,f=30,p=null,g=null,m=t.utils.getColor(["#1f77b4"]),v=d3.dispatch("elementMouseover","elementMouseout","elementMousemove");return e.dispatch=v,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{ranges:{get:function(){return o},set:function(t){o=t}},markers:{get:function(){return a},set:function(t){a=t}},measures:{get:function(){return s},set:function(t){s=t}},forceX:{get:function(){return d},set:function(t){d=t}},width:{get:function(){return h},set:function(t){h=t}},height:{get:function(){return f},set:function(t){f=t}},tickFormat:{get:function(){return g},set:function(t){g=t}},margin:{get:function(){return n},set:function(t){n.top=void 0!==t.top?t.top:n.top,n.right=void 0!==t.right?t.right:n.right,n.bottom=void 0!==t.bottom?t.bottom:n.bottom,n.left=void 0!==t.left?t.left:n.left}},orient:{get:function(){return i},set:function(t){i=t,r="right"==i||"bottom"==i}},color:{get:function(){return m},set:function(e){m=t.utils.getColor(e)}}}),t.utils.initOptions(e),e},t.models.bulletChart=function(){"use strict";function e(i){return i.each(function(r,p){var g=d3.select(this);t.utils.initSVG(g);var m=t.utils.availableWidth(c,g,a),v=d-a.top-a.bottom;if(e.update=function(){e(i)},e.container=this,!r||!s.call(this,r,p))return t.utils.noData(e,g),e;g.selectAll(".nv-noData").remove();var y=s.call(this,r,p).slice().sort(d3.descending),b=u.call(this,r,p).slice().sort(d3.descending),x=l.call(this,r,p).slice().sort(d3.descending),w=g.selectAll("g.nv-wrap.nv-bulletChart").data([r]),_=w.enter().append("g").attr("class","nvd3 nv-wrap nv-bulletChart"),$=_.append("g"),k=w.select("g");$.append("g").attr("class","nv-bulletWrap"),$.append("g").attr("class","nv-titles"),w.attr("transform","translate("+a.left+","+a.top+")");var C=d3.scale.linear().domain([0,Math.max(y[0],b[0]||0,x[0])]).range(o?[m,0]:[0,m]),M=this.__chart__||d3.scale.linear().domain([0,1/0]).range(C.range());this.__chart__=C;var D=$.select(".nv-titles").append("g").attr("text-anchor","end").attr("transform","translate(-6,"+(d-a.top-a.bottom)/2+")");D.append("text").attr("class","nv-title").text(function(t){return t.title}),D.append("text").attr("class","nv-subtitle").attr("dy","1em").text(function(t){return t.subtitle}),n.width(m).height(v);var S=k.select(".nv-bulletWrap");d3.transition(S).call(n);var T=h||C.tickFormat(m/100),A=k.selectAll("g.nv-tick").data(C.ticks(f?f:m/50),function(t){return this.textContent||T(t)}),E=A.enter().append("g").attr("class","nv-tick").attr("transform",function(t){return"translate("+M(t)+",0)"}).style("opacity",1e-6);E.append("line").attr("y1",v).attr("y2",7*v/6),E.append("text").attr("text-anchor","middle").attr("dy","1em").attr("y",7*v/6).text(T);var O=d3.transition(A).attr("transform",function(t){return"translate("+C(t)+",0)"}).style("opacity",1);O.select("line").attr("y1",v).attr("y2",7*v/6),O.select("text").attr("y",7*v/6),d3.transition(A.exit()).attr("transform",function(t){return"translate("+C(t)+",0)"}).style("opacity",1e-6).remove()}),d3.timer.flush(),e}var n=t.models.bullet(),i=t.models.tooltip(),r="left",o=!1,a={top:5,right:40,bottom:20,left:120},s=function(t){return t.ranges},u=function(t){return t.markers?t.markers:[]},l=function(t){return t.measures},c=null,d=55,h=null,f=null,p=null,g=d3.dispatch();return i.duration(0).headerEnabled(!1),n.dispatch.on("elementMouseover.tooltip",function(t){t.series={key:t.label,value:t.value,color:t.color},i.data(t).hidden(!1)}),n.dispatch.on("elementMouseout.tooltip",function(t){i.hidden(!0)}),n.dispatch.on("elementMousemove.tooltip",function(t){i()}),e.bullet=n,e.dispatch=g,e.tooltip=i,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{ranges:{get:function(){return s},set:function(t){s=t}},markers:{get:function(){return u},set:function(t){u=t}},measures:{get:function(){return l},set:function(t){l=t}},width:{get:function(){return c},set:function(t){c=t}},height:{get:function(){return d},set:function(t){d=t}},tickFormat:{get:function(){return h},set:function(t){h=t}},ticks:{get:function(){return f},set:function(t){f=t}},noData:{get:function(){return p},set:function(t){p=t}},margin:{get:function(){return a},set:function(t){a.top=void 0!==t.top?t.top:a.top,a.right=void 0!==t.right?t.right:a.right,a.bottom=void 0!==t.bottom?t.bottom:a.bottom,a.left=void 0!==t.left?t.left:a.left}},orient:{get:function(){return r},set:function(t){r=t,o="right"==r||"bottom"==r}}}),t.utils.inheritOptions(e,n),t.utils.initOptions(e),e},t.models.candlestickBar=function(){"use strict";function e($){return $.each(function(e){n=d3.select(this);var $=t.utils.availableWidth(u,n,s),k=t.utils.availableHeight(l,n,s);t.utils.initSVG(n);var M=$/e[0].values.length*.45;
d.domain(i||d3.extent(e[0].values.map(f).concat(b))),w?d.range(o||[.5*$/e[0].values.length,$*(e[0].values.length-.5)/e[0].values.length]):d.range(o||[5+M/2,$-M/2-5]),h.domain(r||[d3.min(e[0].values.map(y).concat(x)),d3.max(e[0].values.map(v).concat(x))]).range(a||[k,0]),d.domain()[0]===d.domain()[1]&&(d.domain()[0]?d.domain([d.domain()[0]-.01*d.domain()[0],d.domain()[1]+.01*d.domain()[1]]):d.domain([-1,1])),h.domain()[0]===h.domain()[1]&&(h.domain()[0]?h.domain([h.domain()[0]+.01*h.domain()[0],h.domain()[1]-.01*h.domain()[1]]):h.domain([-1,1]));var D=d3.select(this).selectAll("g.nv-wrap.nv-candlestickBar").data([e[0].values]),S=D.enter().append("g").attr("class","nvd3 nv-wrap nv-candlestickBar"),T=S.append("defs"),A=S.append("g"),E=D.select("g");A.append("g").attr("class","nv-ticks"),D.attr("transform","translate("+s.left+","+s.top+")"),n.on("click",function(t,e){C.chartClick({data:t,index:e,pos:d3.event,id:c})}),T.append("clipPath").attr("id","nv-chart-clip-path-"+c).append("rect"),D.select("#nv-chart-clip-path-"+c+" rect").attr("width",$).attr("height",k),E.attr("clip-path",_?"url(#nv-chart-clip-path-"+c+")":"");var O=D.select(".nv-ticks").selectAll(".nv-tick").data(function(t){return t});O.exit().remove();var N=O.enter().append("g");O.attr("class",function(t,e,n){return(g(t,e)>m(t,e)?"nv-tick negative":"nv-tick positive")+" nv-tick-"+n+"-"+e});N.append("line").attr("class","nv-candlestick-lines").attr("transform",function(t,e){return"translate("+d(f(t,e))+",0)"}).attr("x1",0).attr("y1",function(t,e){return h(v(t,e))}).attr("x2",0).attr("y2",function(t,e){return h(y(t,e))}),N.append("rect").attr("class","nv-candlestick-rects nv-bars").attr("transform",function(t,e){return"translate("+(d(f(t,e))-M/2)+","+(h(p(t,e))-(g(t,e)>m(t,e)?h(m(t,e))-h(g(t,e)):0))+")"}).attr("x",0).attr("y",0).attr("width",M).attr("height",function(t,e){var n=g(t,e),i=m(t,e);return n>i?h(i)-h(n):h(n)-h(i)});O.select(".nv-candlestick-lines").transition().attr("transform",function(t,e){return"translate("+d(f(t,e))+",0)"}).attr("x1",0).attr("y1",function(t,e){return h(v(t,e))}).attr("x2",0).attr("y2",function(t,e){return h(y(t,e))}),O.select(".nv-candlestick-rects").transition().attr("transform",function(t,e){return"translate("+(d(f(t,e))-M/2)+","+(h(p(t,e))-(g(t,e)>m(t,e)?h(m(t,e))-h(g(t,e)):0))+")"}).attr("x",0).attr("y",0).attr("width",M).attr("height",function(t,e){var n=g(t,e),i=m(t,e);return n>i?h(i)-h(n):h(n)-h(i)})}),e}var n,i,r,o,a,s={top:0,right:0,bottom:0,left:0},u=null,l=null,c=Math.floor(1e4*Math.random()),d=d3.scale.linear(),h=d3.scale.linear(),f=function(t){return t.x},p=function(t){return t.y},g=function(t){return t.open},m=function(t){return t.close},v=function(t){return t.high},y=function(t){return t.low},b=[],x=[],w=!1,_=!0,$=t.utils.defaultColor(),k=!1,C=d3.dispatch("stateChange","changeState","renderEnd","chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove");return e.highlightPoint=function(t,i){e.clearHighlights(),n.select(".nv-candlestickBar .nv-tick-0-"+t).classed("hover",i)},e.clearHighlights=function(){n.select(".nv-candlestickBar .nv-tick.hover").classed("hover",!1)},e.dispatch=C,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return u},set:function(t){u=t}},height:{get:function(){return l},set:function(t){l=t}},xScale:{get:function(){return d},set:function(t){d=t}},yScale:{get:function(){return h},set:function(t){h=t}},xDomain:{get:function(){return i},set:function(t){i=t}},yDomain:{get:function(){return r},set:function(t){r=t}},xRange:{get:function(){return o},set:function(t){o=t}},yRange:{get:function(){return a},set:function(t){a=t}},forceX:{get:function(){return b},set:function(t){b=t}},forceY:{get:function(){return x},set:function(t){x=t}},padData:{get:function(){return w},set:function(t){w=t}},clipEdge:{get:function(){return _},set:function(t){_=t}},id:{get:function(){return c},set:function(t){c=t}},interactive:{get:function(){return k},set:function(t){k=t}},x:{get:function(){return f},set:function(t){f=t}},y:{get:function(){return p},set:function(t){p=t}},open:{get:function(){return g()},set:function(t){g=t}},close:{get:function(){return m()},set:function(t){m=t}},high:{get:function(){return v},set:function(t){v=t}},low:{get:function(){return y},set:function(t){y=t}},margin:{get:function(){return s},set:function(t){s.top=void 0!=t.top?t.top:s.top,s.right=void 0!=t.right?t.right:s.right,s.bottom=void 0!=t.bottom?t.bottom:s.bottom,s.left=void 0!=t.left?t.left:s.left}},color:{get:function(){return $},set:function(e){$=t.utils.getColor(e)}}}),t.utils.initOptions(e),e},t.models.cumulativeLineChart=function(){"use strict";function e(d){return N.reset(),N.models(o),v&&N.models(a),y&&N.models(s),d.each(function(d){function M(t,n){d3.select(e.container).style("cursor","ew-resize")}function A(t,e){O.x=d3.event.x,O.i=Math.round(E.invert(O.x)),F()}function N(t,n){d3.select(e.container).style("cursor","auto"),k.index=O.i,S.stateChange(k)}function F(){et.data([O]);var t=e.duration();e.duration(0),e.update(),e.duration(t)}var W=d3.select(this);t.utils.initSVG(W),W.classed("nv-chart-"+$,!0);var H=this,L=t.utils.availableWidth(p,W,h),z=t.utils.availableHeight(g,W,h);if(e.update=function(){0===T?W.call(e):W.transition().duration(T).call(e)},e.container=this,k.setter(P(d),e.update).getter(I(d)).update(),k.disabled=d.map(function(t){return!!t.disabled}),!C){var j;C={};for(j in k)k[j]instanceof Array?C[j]=k[j].slice(0):C[j]=k[j]}var R=d3.behavior.drag().on("dragstart",M).on("drag",A).on("dragend",N);if(!(d&&d.length&&d.filter(function(t){return t.values.length}).length))return t.utils.noData(e,W),e;if(W.selectAll(".nv-noData").remove(),i=o.xScale(),r=o.yScale(),_)o.yDomain(null);else{var U=d.filter(function(t){return!t.disabled}).map(function(t,e){var n=d3.extent(t.values,o.y());return n[0]<-.95&&(n[0]=-.95),[(n[0]-n[1])/(1+n[1]),(n[1]-n[0])/(1+n[0])]}),q=[d3.min(U,function(t){return t[0]}),d3.max(U,function(t){return t[1]})];o.yDomain(q)}E.domain([0,d[0].values.length-1]).range([0,L]).clamp(!0);var d=n(O.i,d),B=w?"none":"all",V=W.selectAll("g.nv-wrap.nv-cumulativeLine").data([d]),Y=V.enter().append("g").attr("class","nvd3 nv-wrap nv-cumulativeLine").append("g"),G=V.select("g");if(Y.append("g").attr("class","nv-interactive"),Y.append("g").attr("class","nv-x nv-axis").style("pointer-events","none"),Y.append("g").attr("class","nv-y nv-axis"),Y.append("g").attr("class","nv-background"),Y.append("g").attr("class","nv-linesWrap").style("pointer-events",B),Y.append("g").attr("class","nv-avgLinesWrap").style("pointer-events","none"),Y.append("g").attr("class","nv-legendWrap"),Y.append("g").attr("class","nv-controlsWrap"),m&&(u.width(L),G.select(".nv-legendWrap").datum(d).call(u),h.top!=u.height()&&(h.top=u.height(),z=t.utils.availableHeight(g,W,h)),G.select(".nv-legendWrap").attr("transform","translate(0,"+-h.top+")")),x){var X=[{key:"Re-scale y-axis",disabled:!_}];l.width(140).color(["#444","#444","#444"]).rightAlign(!1).margin({top:5,right:0,bottom:5,left:20}),G.select(".nv-controlsWrap").datum(X).attr("transform","translate(0,"+-h.top+")").call(l)}V.attr("transform","translate("+h.left+","+h.top+")"),b&&G.select(".nv-y.nv-axis").attr("transform","translate("+L+",0)");var K=d.filter(function(t){return t.tempDisabled});V.select(".tempDisabled").remove(),K.length&&V.append("text").attr("class","tempDisabled").attr("x",L/2).attr("y","-.71em").style("text-anchor","end").text(K.map(function(t){return t.key}).join(", ")+" values cannot be calculated for this time period."),w&&(c.width(L).height(z).margin({left:h.left,top:h.top}).svgContainer(W).xScale(i),V.select(".nv-interactive").call(c)),Y.select(".nv-background").append("rect"),G.select(".nv-background rect").attr("width",L).attr("height",z),o.y(function(t){return t.display.y}).width(L).height(z).color(d.map(function(t,e){return t.color||f(t,e)}).filter(function(t,e){return!d[e].disabled&&!d[e].tempDisabled}));var Z=G.select(".nv-linesWrap").datum(d.filter(function(t){return!t.disabled&&!t.tempDisabled}));Z.call(o),d.forEach(function(t,e){t.seriesIndex=e});var Q=d.filter(function(t){return!t.disabled&&!!D(t)}),J=G.select(".nv-avgLinesWrap").selectAll("line").data(Q,function(t){return t.key}),tt=function(t){var e=r(D(t));return 0>e?0:e>z?z:e};J.enter().append("line").style("stroke-width",2).style("stroke-dasharray","10,10").style("stroke",function(t,e){return o.color()(t,t.seriesIndex)}).attr("x1",0).attr("x2",L).attr("y1",tt).attr("y2",tt),J.style("stroke-opacity",function(t){var e=r(D(t));return 0>e||e>z?0:1}).attr("x1",0).attr("x2",L).attr("y1",tt).attr("y2",tt),J.exit().remove();var et=Z.selectAll(".nv-indexLine").data([O]);et.enter().append("rect").attr("class","nv-indexLine").attr("width",3).attr("x",-2).attr("fill","red").attr("fill-opacity",.5).style("pointer-events","all").call(R),et.attr("transform",function(t){return"translate("+E(t.i)+",0)"}).attr("height",z),v&&(a.scale(i)._ticks(t.utils.calcTicksX(L/70,d)).tickSize(-z,0),G.select(".nv-x.nv-axis").attr("transform","translate(0,"+r.range()[0]+")"),G.select(".nv-x.nv-axis").call(a)),y&&(s.scale(r)._ticks(t.utils.calcTicksY(z/36,d)).tickSize(-L,0),G.select(".nv-y.nv-axis").call(s)),G.select(".nv-background rect").on("click",function(){O.x=d3.mouse(this)[0],O.i=Math.round(E.invert(O.x)),k.index=O.i,S.stateChange(k),F()}),o.dispatch.on("elementClick",function(t){O.i=t.pointIndex,O.x=E(O.i),k.index=O.i,S.stateChange(k),F()}),l.dispatch.on("legendClick",function(t,n){t.disabled=!t.disabled,_=!t.disabled,k.rescaleY=_,S.stateChange(k),e.update()}),u.dispatch.on("stateChange",function(t){for(var n in t)k[n]=t[n];S.stateChange(k),e.update()}),c.dispatch.on("elementMousemove",function(n){o.clearHighlights();var i,r,u,l=[];if(d.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(a,s){r=t.interactiveBisect(a.values,n.pointXValue,e.x()),o.highlightPoint(s,r,!0);var c=a.values[r];"undefined"!=typeof c&&("undefined"==typeof i&&(i=c),"undefined"==typeof u&&(u=e.xScale()(e.x()(c,r))),l.push({key:a.key,value:e.y()(c,r),color:f(a,a.seriesIndex)}))}),l.length>2){var h=e.yScale().invert(n.mouseY),p=Math.abs(e.yScale().domain()[0]-e.yScale().domain()[1]),g=.03*p,m=t.nearestValueIndex(l.map(function(t){return t.value}),h,g);null!==m&&(l[m].highlight=!0)}var v=a.tickFormat()(e.x()(i,r),r);c.tooltip.chartContainer(H.parentNode).valueFormatter(function(t,e){return s.tickFormat()(t)}).data({value:v,series:l})(),c.renderGuideLine(u)}),c.dispatch.on("elementMouseout",function(t){o.clearHighlights()}),S.on("changeState",function(t){"undefined"!=typeof t.disabled&&(d.forEach(function(e,n){e.disabled=t.disabled[n]}),k.disabled=t.disabled),"undefined"!=typeof t.index&&(O.i=t.index,O.x=E(O.i),k.index=t.index,et.data([O])),"undefined"!=typeof t.rescaleY&&(_=t.rescaleY),e.update()})}),N.renderEnd("cumulativeLineChart immediate"),e}function n(t,e){return F||(F=o.y()),e.map(function(e,n){if(!e.values)return e;var i=e.values[t];if(null==i)return e;var r=F(i,t);return-.95>r&&!A?(e.tempDisabled=!0,e):(e.tempDisabled=!1,e.values=e.values.map(function(t,e){return t.display={y:(F(t,e)-r)/(1+r)},t}),e)})}var i,r,o=t.models.line(),a=t.models.axis(),s=t.models.axis(),u=t.models.legend(),l=t.models.legend(),c=t.interactiveGuideline(),d=t.models.tooltip(),h={top:30,right:30,bottom:50,left:60},f=t.utils.defaultColor(),p=null,g=null,m=!0,v=!0,y=!0,b=!1,x=!0,w=!1,_=!0,$=o.id(),k=t.utils.state(),C=null,M=null,D=function(t){return t.average},S=d3.dispatch("stateChange","changeState","renderEnd"),T=250,A=!1;k.index=0,k.rescaleY=_,a.orient("bottom").tickPadding(7),s.orient(b?"right":"left"),d.valueFormatter(function(t,e){return s.tickFormat()(t,e)}).headerFormatter(function(t,e){return a.tickFormat()(t,e)}),l.updateState(!1);var E=d3.scale.linear(),O={i:0,x:0},N=t.utils.renderWatch(S,T),I=function(t){return function(){return{active:t.map(function(t){return!t.disabled}),index:O.i,rescaleY:_}}},P=function(t){return function(e){void 0!==e.index&&(O.i=e.index),void 0!==e.rescaleY&&(_=e.rescaleY),void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};o.dispatch.on("elementMouseover.tooltip",function(t){var n={x:e.x()(t.point),y:e.y()(t.point),color:t.point.color};t.point=n,d.data(t).hidden(!1)}),o.dispatch.on("elementMouseout.tooltip",function(t){d.hidden(!0)});var F=null;return e.dispatch=S,e.lines=o,e.legend=u,e.controls=l,e.xAxis=a,e.yAxis=s,e.interactiveLayer=c,e.state=k,e.tooltip=d,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return p},set:function(t){p=t}},height:{get:function(){return g},set:function(t){g=t}},rescaleY:{get:function(){return _},set:function(t){_=t}},showControls:{get:function(){return x},set:function(t){x=t}},showLegend:{get:function(){return m},set:function(t){m=t}},average:{get:function(){return D},set:function(t){D=t}},defaultState:{get:function(){return C},set:function(t){C=t}},noData:{get:function(){return M},set:function(t){M=t}},showXAxis:{get:function(){return v},set:function(t){v=t}},showYAxis:{get:function(){return y},set:function(t){y=t}},noErrorCheck:{get:function(){return A},set:function(t){A=t}},margin:{get:function(){return h},set:function(t){h.top=void 0!==t.top?t.top:h.top,h.right=void 0!==t.right?t.right:h.right,h.bottom=void 0!==t.bottom?t.bottom:h.bottom,h.left=void 0!==t.left?t.left:h.left}},color:{get:function(){return f},set:function(e){f=t.utils.getColor(e),u.color(f)}},useInteractiveGuideline:{get:function(){return w},set:function(t){w=t,t===!0&&(e.interactive(!1),e.useVoronoi(!1))}},rightAlignYAxis:{get:function(){return b},set:function(t){b=t,s.orient(t?"right":"left")}},duration:{get:function(){return T},set:function(t){T=t,o.duration(T),a.duration(T),s.duration(T),N.reset(T)}}}),t.utils.inheritOptions(e,o),t.utils.initOptions(e),e},t.models.discreteBar=function(){"use strict";function e(h){return k.reset(),h.each(function(e){var h=c-l.left-l.right,$=d-l.top-l.bottom;n=d3.select(this),t.utils.initSVG(n),e.forEach(function(t,e){t.values.forEach(function(t){t.series=e})});var C=i&&r?[]:e.map(function(t){return t.values.map(function(t,e){return{x:g(t,e),y:m(t,e),y0:t.y0}})});f.domain(i||d3.merge(C).map(function(t){return t.x})).rangeBands(o||[0,h],.1),p.domain(r||d3.extent(d3.merge(C).map(function(t){return t.y}).concat(v))),b?p.range(a||[$-(p.domain()[0]<0?12:0),p.domain()[1]>0?12:0]):p.range(a||[$,0]),s=s||f,u=u||p.copy().range([p(0),p(0)]);var M=n.selectAll("g.nv-wrap.nv-discretebar").data([e]),D=M.enter().append("g").attr("class","nvd3 nv-wrap nv-discretebar"),S=D.append("g");M.select("g");S.append("g").attr("class","nv-groups"),M.attr("transform","translate("+l.left+","+l.top+")");var T=M.select(".nv-groups").selectAll(".nv-group").data(function(t){return t},function(t){return t.key});T.enter().append("g").style("stroke-opacity",1e-6).style("fill-opacity",1e-6),T.exit().watchTransition(k,"discreteBar: exit groups").style("stroke-opacity",1e-6).style("fill-opacity",1e-6).remove(),T.attr("class",function(t,e){return"nv-group nv-series-"+e}).classed("hover",function(t){return t.hover}),T.watchTransition(k,"discreteBar: groups").style("stroke-opacity",1).style("fill-opacity",.75);var A=T.selectAll("g.nv-bar").data(function(t){return t.values});A.exit().remove();var E=A.enter().append("g").attr("transform",function(t,e,n){return"translate("+(f(g(t,e))+.05*f.rangeBand())+", "+p(0)+")"}).on("mouseover",function(t,e){d3.select(this).classed("hover",!0),w.elementMouseover({data:t,index:e,color:d3.select(this).style("fill")})}).on("mouseout",function(t,e){d3.select(this).classed("hover",!1),w.elementMouseout({data:t,index:e,color:d3.select(this).style("fill")})}).on("mousemove",function(t,e){w.elementMousemove({data:t,index:e,color:d3.select(this).style("fill")})}).on("click",function(t,e){var n=this;w.elementClick({data:t,index:e,color:d3.select(this).style("fill"),event:d3.event,element:n}),d3.event.stopPropagation()}).on("dblclick",function(t,e){w.elementDblClick({data:t,index:e,color:d3.select(this).style("fill")}),d3.event.stopPropagation()});E.append("rect").attr("height",0).attr("width",.9*f.rangeBand()/e.length),b?(E.append("text").attr("text-anchor","middle"),A.select("text").text(function(t,e){return x(m(t,e))}).watchTransition(k,"discreteBar: bars text").attr("x",.9*f.rangeBand()/2).attr("y",function(t,e){return m(t,e)<0?p(m(t,e))-p(0)+12:-4})):A.selectAll("text").remove(),A.attr("class",function(t,e){return m(t,e)<0?"nv-bar negative":"nv-bar positive"}).style("fill",function(t,e){return t.color||y(t,e)}).style("stroke",function(t,e){return t.color||y(t,e)}).select("rect").attr("class",_).watchTransition(k,"discreteBar: bars rect").attr("width",.9*f.rangeBand()/e.length),A.watchTransition(k,"discreteBar: bars").attr("transform",function(t,e){var n=f(g(t,e))+.05*f.rangeBand(),i=m(t,e)<0?p(0):p(0)-p(m(t,e))<1?p(0)-1:p(m(t,e));return"translate("+n+", "+i+")"}).select("rect").attr("height",function(t,e){return Math.max(Math.abs(p(m(t,e))-p(0)),1)}),s=f.copy(),u=p.copy()}),k.renderEnd("discreteBar immediate"),e}var n,i,r,o,a,s,u,l={top:0,right:0,bottom:0,left:0},c=960,d=500,h=Math.floor(1e4*Math.random()),f=d3.scale.ordinal(),p=d3.scale.linear(),g=function(t){return t.x},m=function(t){return t.y},v=[0],y=t.utils.defaultColor(),b=!1,x=d3.format(",.2f"),w=d3.dispatch("chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove","renderEnd"),_="discreteBar",$=250,k=t.utils.renderWatch(w,$);return e.dispatch=w,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return c},set:function(t){c=t}},height:{get:function(){return d},set:function(t){d=t}},forceY:{get:function(){return v},set:function(t){v=t}},showValues:{get:function(){return b},set:function(t){b=t}},x:{get:function(){return g},set:function(t){g=t}},y:{get:function(){return m},set:function(t){m=t}},xScale:{get:function(){return f},set:function(t){f=t}},yScale:{get:function(){return p},set:function(t){p=t}},xDomain:{get:function(){return i},set:function(t){i=t}},yDomain:{get:function(){return r},set:function(t){r=t}},xRange:{get:function(){return o},set:function(t){o=t}},yRange:{get:function(){return a},set:function(t){a=t}},valueFormat:{get:function(){return x},set:function(t){x=t}},id:{get:function(){return h},set:function(t){h=t}},rectClass:{get:function(){return _},set:function(t){_=t}},margin:{get:function(){return l},set:function(t){l.top=void 0!==t.top?t.top:l.top,l.right=void 0!==t.right?t.right:l.right,l.bottom=void 0!==t.bottom?t.bottom:l.bottom,l.left=void 0!==t.left?t.left:l.left}},color:{get:function(){return y},set:function(e){y=t.utils.getColor(e)}},duration:{get:function(){return $},set:function(t){$=t,k.reset($)}}}),t.utils.initOptions(e),e},t.models.discreteBarChart=function(){"use strict";function e(u){return $.reset(),$.models(r),p&&$.models(o),g&&$.models(a),u.each(function(u){var h=d3.select(this);t.utils.initSVG(h);var x=t.utils.availableWidth(c,h,l),$=t.utils.availableHeight(d,h,l);if(e.update=function(){w.beforeUpdate(),h.transition().duration(_).call(e)},e.container=this,!(u&&u.length&&u.filter(function(t){return t.values.length}).length))return t.utils.noData(e,h),e;h.selectAll(".nv-noData").remove(),n=r.xScale(),i=r.yScale().clamp(!0);var k=h.selectAll("g.nv-wrap.nv-discreteBarWithAxes").data([u]),C=k.enter().append("g").attr("class","nvd3 nv-wrap nv-discreteBarWithAxes").append("g"),M=C.append("defs"),D=k.select("g");C.append("g").attr("class","nv-x nv-axis"),C.append("g").attr("class","nv-y nv-axis").append("g").attr("class","nv-zeroLine").append("line"),C.append("g").attr("class","nv-barsWrap"),C.append("g").attr("class","nv-legendWrap"),D.attr("transform","translate("+l.left+","+l.top+")"),f&&(s.width(x),D.select(".nv-legendWrap").datum(u).call(s),l.top!=s.height()&&(l.top=s.height(),$=t.utils.availableHeight(d,h,l)),k.select(".nv-legendWrap").attr("transform","translate(0,"+-l.top+")")),m&&D.select(".nv-y.nv-axis").attr("transform","translate("+x+",0)"),m&&D.select(".nv-y.nv-axis").attr("transform","translate("+x+",0)"),r.width(x).height($);var S=D.select(".nv-barsWrap").datum(u.filter(function(t){return!t.disabled}));if(S.transition().call(r),M.append("clipPath").attr("id","nv-x-label-clip-"+r.id()).append("rect"),D.select("#nv-x-label-clip-"+r.id()+" rect").attr("width",n.rangeBand()*(v?2:1)).attr("height",16).attr("x",-n.rangeBand()/(v?1:2)),p){o.scale(n)._ticks(t.utils.calcTicksX(x/100,u)).tickSize(-$,0),D.select(".nv-x.nv-axis").attr("transform","translate(0,"+(i.range()[0]+(r.showValues()&&i.domain()[0]<0?16:0))+")"),D.select(".nv-x.nv-axis").call(o);var T=D.select(".nv-x.nv-axis").selectAll("g");v&&T.selectAll("text").attr("transform",function(t,e,n){return"translate(0,"+(n%2==0?"5":"17")+")"}),b&&T.selectAll(".tick text").attr("transform","rotate("+b+" 0,0)").style("text-anchor",b>0?"start":"end"),y&&D.selectAll(".tick text").call(t.utils.wrapTicks,e.xAxis.rangeBand())}g&&(a.scale(i)._ticks(t.utils.calcTicksY($/36,u)).tickSize(-x,0),D.select(".nv-y.nv-axis").call(a)),D.select(".nv-zeroLine line").attr("x1",0).attr("x2",m?-x:x).attr("y1",i(0)).attr("y2",i(0))}),$.renderEnd("discreteBar chart immediate"),e}var n,i,r=t.models.discreteBar(),o=t.models.axis(),a=t.models.axis(),s=t.models.legend(),u=t.models.tooltip(),l={top:15,right:10,bottom:50,left:60},c=null,d=null,h=t.utils.getColor(),f=!1,p=!0,g=!0,m=!1,v=!1,y=!1,b=0,x=null,w=d3.dispatch("beforeUpdate","renderEnd"),_=250;o.orient("bottom").showMaxMin(!1).tickFormat(function(t){return t}),a.orient(m?"right":"left").tickFormat(d3.format(",.1f")),u.duration(0).headerEnabled(!1).valueFormatter(function(t,e){return a.tickFormat()(t,e)}).keyFormatter(function(t,e){return o.tickFormat()(t,e)});var $=t.utils.renderWatch(w,_);return r.dispatch.on("elementMouseover.tooltip",function(t){t.series={key:e.x()(t.data),value:e.y()(t.data),color:t.color},u.data(t).hidden(!1)}),r.dispatch.on("elementMouseout.tooltip",function(t){u.hidden(!0)}),r.dispatch.on("elementMousemove.tooltip",function(t){u()}),e.dispatch=w,e.discretebar=r,e.legend=s,e.xAxis=o,e.yAxis=a,e.tooltip=u,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return c},set:function(t){c=t}},height:{get:function(){return d},set:function(t){d=t}},showLegend:{get:function(){return f},set:function(t){f=t}},staggerLabels:{get:function(){return v},set:function(t){v=t}},rotateLabels:{get:function(){return b},set:function(t){b=t}},wrapLabels:{get:function(){return y},set:function(t){y=!!t}},showXAxis:{get:function(){return p},set:function(t){p=t}},showYAxis:{get:function(){return g},set:function(t){g=t}},noData:{get:function(){return x},set:function(t){x=t}},margin:{get:function(){return l},set:function(t){l.top=void 0!==t.top?t.top:l.top,l.right=void 0!==t.right?t.right:l.right,l.bottom=void 0!==t.bottom?t.bottom:l.bottom,l.left=void 0!==t.left?t.left:l.left}},duration:{get:function(){return _},set:function(t){_=t,$.reset(_),r.duration(_),o.duration(_),a.duration(_)}},color:{get:function(){return h},set:function(e){h=t.utils.getColor(e),r.color(h),s.color(h)}},rightAlignYAxis:{get:function(){return m},set:function(t){m=t,a.orient(t?"right":"left")}}}),t.utils.inheritOptions(e,r),t.utils.initOptions(e),e},t.models.distribution=function(){"use strict";function e(c){return h.reset(),c.each(function(e){var c=(r-("x"===a?i.left+i.right:i.top+i.bottom),"x"==a?"y":"x"),d=d3.select(this);t.utils.initSVG(d),n=n||l;var f=d.selectAll("g.nv-distribution").data([e]),p=f.enter().append("g").attr("class","nvd3 nv-distribution"),g=(p.append("g"),f.select("g"));f.attr("transform","translate("+i.left+","+i.top+")");var m=g.selectAll("g.nv-dist").data(function(t){return t},function(t){return t.key});m.enter().append("g"),m.attr("class",function(t,e){return"nv-dist nv-series-"+e}).style("stroke",function(t,e){return u(t,e)});var v=m.selectAll("line.nv-dist"+a).data(function(t){return t.values});v.enter().append("line").attr(a+"1",function(t,e){return n(s(t,e))}).attr(a+"2",function(t,e){return n(s(t,e))}),h.transition(m.exit().selectAll("line.nv-dist"+a),"dist exit").attr(a+"1",function(t,e){return l(s(t,e))}).attr(a+"2",function(t,e){return l(s(t,e))}).style("stroke-opacity",0).remove(),v.attr("class",function(t,e){return"nv-dist"+a+" nv-dist"+a+"-"+e}).attr(c+"1",0).attr(c+"2",o),h.transition(v,"dist").attr(a+"1",function(t,e){return l(s(t,e))}).attr(a+"2",function(t,e){return l(s(t,e))}),n=l.copy()}),h.renderEnd("distribution immediate"),e}var n,i={top:0,right:0,bottom:0,left:0},r=400,o=8,a="x",s=function(t){return t[a]},u=t.utils.defaultColor(),l=d3.scale.linear(),c=250,d=d3.dispatch("renderEnd"),h=t.utils.renderWatch(d,c);return e.options=t.utils.optionsFunc.bind(e),e.dispatch=d,e.margin=function(t){return arguments.length?(i.top="undefined"!=typeof t.top?t.top:i.top,i.right="undefined"!=typeof t.right?t.right:i.right,i.bottom="undefined"!=typeof t.bottom?t.bottom:i.bottom,i.left="undefined"!=typeof t.left?t.left:i.left,e):i},e.width=function(t){return arguments.length?(r=t,e):r},e.axis=function(t){return arguments.length?(a=t,e):a},e.size=function(t){return arguments.length?(o=t,e):o},e.getData=function(t){return arguments.length?(s=d3.functor(t),e):s},e.scale=function(t){return arguments.length?(l=t,e):l},e.color=function(n){return arguments.length?(u=t.utils.getColor(n),e):u},e.duration=function(t){return arguments.length?(c=t,h.reset(c),e):c},e},t.models.furiousLegend=function(){"use strict";function e(m){function v(t,e){return"furious"!=g?"#000":f?t.disengaged?a(t,e):"#fff":f?void 0:t.disabled?a(t,e):"#fff"}function y(t,e){return f&&"furious"==g?t.disengaged?"#fff":a(t,e):t.disabled?"#fff":a(t,e)}return m.each(function(e){var m=i-n.left-n.right,b=d3.select(this);t.utils.initSVG(b);var x=b.selectAll("g.nv-legend").data([e]),w=(x.enter().append("g").attr("class","nvd3 nv-legend").append("g"),x.select("g"));x.attr("transform","translate("+n.left+","+n.top+")");var _,$=w.selectAll(".nv-series").data(function(t){return"furious"!=g?t:t.filter(function(t){return f?!0:!t.disengaged})}),k=$.enter().append("g").attr("class","nv-series");if("classic"==g)k.append("circle").style("stroke-width",2).attr("class","nv-legend-symbol").attr("r",5),_=$.select("circle");else if("furious"==g){k.append("rect").style("stroke-width",2).attr("class","nv-legend-symbol").attr("rx",3).attr("ry",3),_=$.select("rect"),k.append("g").attr("class","nv-check-box").property("innerHTML",'<path d="M0.5,5 L22.5,5 L22.5,26.5 L0.5,26.5 L0.5,5 Z" class="nv-box"></path><path d="M5.5,12.8618467 L11.9185089,19.2803556 L31,0.198864511" class="nv-check"></path>').attr("transform","translate(-10,-8)scale(0.5)");var C=$.select(".nv-check-box");C.each(function(t,e){d3.select(this).selectAll("path").attr("stroke",v(t,e))})}k.append("text").attr("text-anchor","start").attr("class","nv-legend-text").attr("dy",".32em").attr("dx","8");var M=$.select("text.nv-legend-text");$.on("mouseover",function(t,e){p.legendMouseover(t,e)}).on("mouseout",function(t,e){p.legendMouseout(t,e)}).on("click",function(t,e){p.legendClick(t,e);var n=$.data();if(d){if("classic"==g)h?(n.forEach(function(t){t.disabled=!0}),t.disabled=!1):(t.disabled=!t.disabled,n.every(function(t){return t.disabled})&&n.forEach(function(t){t.disabled=!1}));else if("furious"==g)if(f)t.disengaged=!t.disengaged,t.userDisabled=void 0==t.userDisabled?!!t.disabled:t.userDisabled,t.disabled=t.disengaged||t.userDisabled;else if(!f){t.disabled=!t.disabled,t.userDisabled=t.disabled;var i=n.filter(function(t){return!t.disengaged});i.every(function(t){return t.userDisabled})&&n.forEach(function(t){t.disabled=t.userDisabled=!1})}p.stateChange({disabled:n.map(function(t){return!!t.disabled}),disengaged:n.map(function(t){return!!t.disengaged})})}}).on("dblclick",function(t,e){if(("furious"!=g||!f)&&(p.legendDblclick(t,e),d)){var n=$.data();n.forEach(function(t){t.disabled=!0,"furious"==g&&(t.userDisabled=t.disabled)}),t.disabled=!1,"furious"==g&&(t.userDisabled=t.disabled),p.stateChange({disabled:n.map(function(t){return!!t.disabled})})}}),$.classed("nv-disabled",function(t){return t.userDisabled}),$.exit().remove(),M.attr("fill",v).text(o);var D;switch(g){case"furious":D=23;break;case"classic":D=20}if(u){var S=[];$.each(function(e,n){var i;if(o(e).length>s){var r=o(e).substring(0,s);i=d3.select(this).select("text").text(r+"..."),d3.select(this).append("svg:title").text(o(e))}else i=d3.select(this).select("text");var a;try{if(a=i.node().getComputedTextLength(),0>=a)throw Error()}catch(u){a=t.utils.calcApproxTextWidth(i)}S.push(a+l)});for(var T=0,A=0,E=[];m>A&&T<S.length;)E[T]=S[T],A+=S[T++];for(0===T&&(T=1);A>m&&T>1;){E=[],T--;for(var O=0;O<S.length;O++)S[O]>(E[O%T]||0)&&(E[O%T]=S[O]);A=E.reduce(function(t,e,n,i){return t+e})}for(var N=[],I=0,P=0;T>I;I++)N[I]=P,P+=E[I];$.attr("transform",function(t,e){return"translate("+N[e%T]+","+(5+Math.floor(e/T)*D)+")"}),c?w.attr("transform","translate("+(i-n.right-A)+","+n.top+")"):w.attr("transform","translate(0,"+n.top+")"),r=n.top+n.bottom+Math.ceil(S.length/T)*D}else{var F,W=5,H=5,L=0;$.attr("transform",function(t,e){var r=d3.select(this).select("text").node().getComputedTextLength()+l;return F=H,i<n.left+n.right+F+r&&(H=F=5,W+=D),H+=r,H>L&&(L=H),"translate("+F+","+W+")"}),w.attr("transform","translate("+(i-n.right-L)+","+n.top+")"),r=n.top+n.bottom+W+15}"furious"==g&&_.attr("width",function(t,e){return M[0][e].getComputedTextLength()+27}).attr("height",18).attr("y",-9).attr("x",-15),_.style("fill",y).style("stroke",function(t,e){return t.color||a(t,e)})}),e}var n={top:5,right:0,bottom:5,left:0},i=400,r=20,o=function(t){return t.key},a=t.utils.getColor(),s=20,u=!0,l=28,c=!0,d=!0,h=!1,f=!1,p=d3.dispatch("legendClick","legendDblclick","legendMouseover","legendMouseout","stateChange"),g="classic";return e.dispatch=p,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return i},set:function(t){i=t}},height:{get:function(){return r},set:function(t){r=t}},key:{get:function(){return o},set:function(t){o=t}},align:{get:function(){return u},set:function(t){u=t}},rightAlign:{get:function(){return c},set:function(t){c=t}},maxKeyLength:{get:function(){return s},set:function(t){s=t}},padding:{get:function(){return l},set:function(t){l=t}},updateState:{get:function(){return d},set:function(t){d=t}},radioButtonMode:{get:function(){return h},set:function(t){h=t}},expanded:{get:function(){return f},set:function(t){f=t}},vers:{get:function(){return g},set:function(t){g=t}},margin:{get:function(){return n},set:function(t){n.top=void 0!==t.top?t.top:n.top,n.right=void 0!==t.right?t.right:n.right,n.bottom=void 0!==t.bottom?t.bottom:n.bottom,n.left=void 0!==t.left?t.left:n.left}},color:{get:function(){return a},set:function(e){a=t.utils.getColor(e)}}}),t.utils.initOptions(e),e},t.models.historicalBar=function(){"use strict";function e($){return $.each(function(e){_.reset(),c=d3.select(this);var $=t.utils.availableWidth(s,c,a),k=t.utils.availableHeight(u,c,a);t.utils.initSVG(c),d.domain(n||d3.extent(e[0].values.map(f).concat(g))),v?d.range(r||[.5*$/e[0].values.length,$*(e[0].values.length-.5)/e[0].values.length]):d.range(r||[0,$]),h.domain(i||d3.extent(e[0].values.map(p).concat(m))).range(o||[k,0]),d.domain()[0]===d.domain()[1]&&(d.domain()[0]?d.domain([d.domain()[0]-.01*d.domain()[0],d.domain()[1]+.01*d.domain()[1]]):d.domain([-1,1])),h.domain()[0]===h.domain()[1]&&(h.domain()[0]?h.domain([h.domain()[0]+.01*h.domain()[0],h.domain()[1]-.01*h.domain()[1]]):h.domain([-1,1]));var C=c.selectAll("g.nv-wrap.nv-historicalBar-"+l).data([e[0].values]),M=C.enter().append("g").attr("class","nvd3 nv-wrap nv-historicalBar-"+l),D=M.append("defs"),S=M.append("g"),T=C.select("g");S.append("g").attr("class","nv-bars"),C.attr("transform","translate("+a.left+","+a.top+")"),c.on("click",function(t,e){x.chartClick({data:t,index:e,pos:d3.event,id:l})}),D.append("clipPath").attr("id","nv-chart-clip-path-"+l).append("rect"),C.select("#nv-chart-clip-path-"+l+" rect").attr("width",$).attr("height",k),
T.attr("clip-path",y?"url(#nv-chart-clip-path-"+l+")":"");var A=C.select(".nv-bars").selectAll(".nv-bar").data(function(t){return t},function(t,e){return f(t,e)});A.exit().remove(),A.enter().append("rect").attr("x",0).attr("y",function(e,n){return t.utils.NaNtoZero(h(Math.max(0,p(e,n))))}).attr("height",function(e,n){return t.utils.NaNtoZero(Math.abs(h(p(e,n))-h(0)))}).attr("transform",function(t,n){return"translate("+(d(f(t,n))-$/e[0].values.length*.45)+",0)"}).on("mouseover",function(t,e){w&&(d3.select(this).classed("hover",!0),x.elementMouseover({data:t,index:e,color:d3.select(this).style("fill")}))}).on("mouseout",function(t,e){w&&(d3.select(this).classed("hover",!1),x.elementMouseout({data:t,index:e,color:d3.select(this).style("fill")}))}).on("mousemove",function(t,e){w&&x.elementMousemove({data:t,index:e,color:d3.select(this).style("fill")})}).on("click",function(t,e){w&&(x.elementClick({data:t,index:e,color:d3.select(this).style("fill")}),d3.event.stopPropagation())}).on("dblclick",function(t,e){w&&(x.elementDblClick({data:t,index:e,color:d3.select(this).style("fill")}),d3.event.stopPropagation())}),A.attr("fill",function(t,e){return b(t,e)}).attr("class",function(t,e,n){return(p(t,e)<0?"nv-bar negative":"nv-bar positive")+" nv-bar-"+n+"-"+e}).watchTransition(_,"bars").attr("transform",function(t,n){return"translate("+(d(f(t,n))-$/e[0].values.length*.45)+",0)"}).attr("width",$/e[0].values.length*.9),A.watchTransition(_,"bars").attr("y",function(e,n){var i=p(e,n)<0?h(0):h(0)-h(p(e,n))<1?h(0)-1:h(p(e,n));return t.utils.NaNtoZero(i)}).attr("height",function(e,n){return t.utils.NaNtoZero(Math.max(Math.abs(h(p(e,n))-h(0)),1))})}),_.renderEnd("historicalBar immediate"),e}var n,i,r,o,a={top:0,right:0,bottom:0,left:0},s=null,u=null,l=Math.floor(1e4*Math.random()),c=null,d=d3.scale.linear(),h=d3.scale.linear(),f=function(t){return t.x},p=function(t){return t.y},g=[],m=[0],v=!1,y=!0,b=t.utils.defaultColor(),x=d3.dispatch("chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove","renderEnd"),w=!0,_=t.utils.renderWatch(x,0);return e.highlightPoint=function(t,e){c.select(".nv-bars .nv-bar-0-"+t).classed("hover",e)},e.clearHighlights=function(){c.select(".nv-bars .nv-bar.hover").classed("hover",!1)},e.dispatch=x,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return s},set:function(t){s=t}},height:{get:function(){return u},set:function(t){u=t}},forceX:{get:function(){return g},set:function(t){g=t}},forceY:{get:function(){return m},set:function(t){m=t}},padData:{get:function(){return v},set:function(t){v=t}},x:{get:function(){return f},set:function(t){f=t}},y:{get:function(){return p},set:function(t){p=t}},xScale:{get:function(){return d},set:function(t){d=t}},yScale:{get:function(){return h},set:function(t){h=t}},xDomain:{get:function(){return n},set:function(t){n=t}},yDomain:{get:function(){return i},set:function(t){i=t}},xRange:{get:function(){return r},set:function(t){r=t}},yRange:{get:function(){return o},set:function(t){o=t}},clipEdge:{get:function(){return y},set:function(t){y=t}},id:{get:function(){return l},set:function(t){l=t}},interactive:{get:function(){return w},set:function(t){w=t}},margin:{get:function(){return a},set:function(t){a.top=void 0!==t.top?t.top:a.top,a.right=void 0!==t.right?t.right:a.right,a.bottom=void 0!==t.bottom?t.bottom:a.bottom,a.left=void 0!==t.left?t.left:a.left}},color:{get:function(){return b},set:function(e){b=t.utils.getColor(e)}}}),t.utils.initOptions(e),e},t.models.historicalBarChart=function(e){"use strict";function n(e){return e.each(function(c){C.reset(),C.models(o),m&&C.models(a),v&&C.models(s);var _=d3.select(this),M=this;t.utils.initSVG(_);var D=t.utils.availableWidth(f,_,d),S=t.utils.availableHeight(p,_,d);if(n.update=function(){_.transition().duration(k).call(n)},n.container=this,x.disabled=c.map(function(t){return!!t.disabled}),!w){var T;w={};for(T in x)x[T]instanceof Array?w[T]=x[T].slice(0):w[T]=x[T]}if(!(c&&c.length&&c.filter(function(t){return t.values.length}).length))return t.utils.noData(n,_),n;_.selectAll(".nv-noData").remove(),i=o.xScale(),r=o.yScale();var A=_.selectAll("g.nv-wrap.nv-historicalBarChart").data([c]),E=A.enter().append("g").attr("class","nvd3 nv-wrap nv-historicalBarChart").append("g"),O=A.select("g");E.append("g").attr("class","nv-x nv-axis"),E.append("g").attr("class","nv-y nv-axis"),E.append("g").attr("class","nv-barsWrap"),E.append("g").attr("class","nv-legendWrap"),E.append("g").attr("class","nv-interactive"),g&&(u.width(D),O.select(".nv-legendWrap").datum(c).call(u),d.top!=u.height()&&(d.top=u.height(),S=t.utils.availableHeight(p,_,d)),A.select(".nv-legendWrap").attr("transform","translate(0,"+-d.top+")")),A.attr("transform","translate("+d.left+","+d.top+")"),y&&O.select(".nv-y.nv-axis").attr("transform","translate("+D+",0)"),b&&(l.width(D).height(S).margin({left:d.left,top:d.top}).svgContainer(_).xScale(i),A.select(".nv-interactive").call(l)),o.width(D).height(S).color(c.map(function(t,e){return t.color||h(t,e)}).filter(function(t,e){return!c[e].disabled}));var N=O.select(".nv-barsWrap").datum(c.filter(function(t){return!t.disabled}));N.transition().call(o),m&&(a.scale(i)._ticks(t.utils.calcTicksX(D/100,c)).tickSize(-S,0),O.select(".nv-x.nv-axis").attr("transform","translate(0,"+r.range()[0]+")"),O.select(".nv-x.nv-axis").transition().call(a)),v&&(s.scale(r)._ticks(t.utils.calcTicksY(S/36,c)).tickSize(-D,0),O.select(".nv-y.nv-axis").transition().call(s)),l.dispatch.on("elementMousemove",function(e){o.clearHighlights();var i,r,u,d=[];c.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(a,s){r=t.interactiveBisect(a.values,e.pointXValue,n.x()),o.highlightPoint(r,!0);var l=a.values[r];void 0!==l&&(void 0===i&&(i=l),void 0===u&&(u=n.xScale()(n.x()(l,r))),d.push({key:a.key,value:n.y()(l,r),color:h(a,a.seriesIndex),data:a.values[r]}))});var f=a.tickFormat()(n.x()(i,r));l.tooltip.chartContainer(M.parentNode).valueFormatter(function(t,e){return s.tickFormat()(t)}).data({value:f,index:r,series:d})(),l.renderGuideLine(u)}),l.dispatch.on("elementMouseout",function(t){$.tooltipHide(),o.clearHighlights()}),u.dispatch.on("legendClick",function(t,i){t.disabled=!t.disabled,c.filter(function(t){return!t.disabled}).length||c.map(function(t){return t.disabled=!1,A.selectAll(".nv-series").classed("disabled",!1),t}),x.disabled=c.map(function(t){return!!t.disabled}),$.stateChange(x),e.transition().call(n)}),u.dispatch.on("legendDblclick",function(t){c.forEach(function(t){t.disabled=!0}),t.disabled=!1,x.disabled=c.map(function(t){return!!t.disabled}),$.stateChange(x),n.update()}),$.on("changeState",function(t){"undefined"!=typeof t.disabled&&(c.forEach(function(e,n){e.disabled=t.disabled[n]}),x.disabled=t.disabled),n.update()})}),C.renderEnd("historicalBarChart immediate"),n}var i,r,o=e||t.models.historicalBar(),a=t.models.axis(),s=t.models.axis(),u=t.models.legend(),l=t.interactiveGuideline(),c=t.models.tooltip(),d={top:30,right:90,bottom:50,left:90},h=t.utils.defaultColor(),f=null,p=null,g=!1,m=!0,v=!0,y=!1,b=!1,x={},w=null,_=null,$=d3.dispatch("tooltipHide","stateChange","changeState","renderEnd"),k=250;a.orient("bottom").tickPadding(7),s.orient(y?"right":"left"),c.duration(0).headerEnabled(!1).valueFormatter(function(t,e){return s.tickFormat()(t,e)}).headerFormatter(function(t,e){return a.tickFormat()(t,e)});var C=t.utils.renderWatch($,0);return o.dispatch.on("elementMouseover.tooltip",function(t){t.series={key:n.x()(t.data),value:n.y()(t.data),color:t.color},c.data(t).hidden(!1)}),o.dispatch.on("elementMouseout.tooltip",function(t){c.hidden(!0)}),o.dispatch.on("elementMousemove.tooltip",function(t){c()}),n.dispatch=$,n.bars=o,n.legend=u,n.xAxis=a,n.yAxis=s,n.interactiveLayer=l,n.tooltip=c,n.options=t.utils.optionsFunc.bind(n),n._options=Object.create({},{width:{get:function(){return f},set:function(t){f=t}},height:{get:function(){return p},set:function(t){p=t}},showLegend:{get:function(){return g},set:function(t){g=t}},showXAxis:{get:function(){return m},set:function(t){m=t}},showYAxis:{get:function(){return v},set:function(t){v=t}},defaultState:{get:function(){return w},set:function(t){w=t}},noData:{get:function(){return _},set:function(t){_=t}},margin:{get:function(){return d},set:function(t){d.top=void 0!==t.top?t.top:d.top,d.right=void 0!==t.right?t.right:d.right,d.bottom=void 0!==t.bottom?t.bottom:d.bottom,d.left=void 0!==t.left?t.left:d.left}},color:{get:function(){return h},set:function(e){h=t.utils.getColor(e),u.color(h),o.color(h)}},duration:{get:function(){return k},set:function(t){k=t,C.reset(k),s.duration(k),a.duration(k)}},rightAlignYAxis:{get:function(){return y},set:function(t){y=t,s.orient(t?"right":"left")}},useInteractiveGuideline:{get:function(){return b},set:function(t){b=t,t===!0&&n.interactive(!1)}}}),t.utils.inheritOptions(n,o),t.utils.initOptions(n),n},t.models.ohlcBarChart=function(){var e=t.models.historicalBarChart(t.models.ohlcBar());return e.useInteractiveGuideline(!0),e.interactiveLayer.tooltip.contentGenerator(function(t){var n=t.series[0].data,i=n.open<n.close?"2ca02c":"d62728";return'<h3 style="color: #'+i+'">'+t.value+"</h3><table><tr><td>open:</td><td>"+e.yAxis.tickFormat()(n.open)+"</td></tr><tr><td>close:</td><td>"+e.yAxis.tickFormat()(n.close)+"</td></tr><tr><td>high</td><td>"+e.yAxis.tickFormat()(n.high)+"</td></tr><tr><td>low:</td><td>"+e.yAxis.tickFormat()(n.low)+"</td></tr></table>"}),e},t.models.candlestickBarChart=function(){var e=t.models.historicalBarChart(t.models.candlestickBar());return e.useInteractiveGuideline(!0),e.interactiveLayer.tooltip.contentGenerator(function(t){var n=t.series[0].data,i=n.open<n.close?"2ca02c":"d62728";return'<h3 style="color: #'+i+'">'+t.value+"</h3><table><tr><td>open:</td><td>"+e.yAxis.tickFormat()(n.open)+"</td></tr><tr><td>close:</td><td>"+e.yAxis.tickFormat()(n.close)+"</td></tr><tr><td>high</td><td>"+e.yAxis.tickFormat()(n.high)+"</td></tr><tr><td>low:</td><td>"+e.yAxis.tickFormat()(n.low)+"</td></tr></table>"}),e},t.models.legend=function(){"use strict";function e(m){function v(t,e){return"furious"!=g?"#000":f?t.disengaged?"#000":"#fff":f?void 0:(t.color||(t.color=a(t,e)),t.disabled?t.color:"#fff")}function y(t,e){return f&&"furious"==g&&t.disengaged?"#eee":t.color||a(t,e)}function b(t,e){return f&&"furious"==g?1:t.disabled?0:1}return m.each(function(e){var a=i-n.left-n.right,m=d3.select(this);t.utils.initSVG(m);var x=m.selectAll("g.nv-legend").data([e]),w=x.enter().append("g").attr("class","nvd3 nv-legend").append("g"),_=x.select("g");x.attr("transform","translate("+n.left+","+n.top+")");var $,k,C=_.selectAll(".nv-series").data(function(t){return"furious"!=g?t:t.filter(function(t){return f?!0:!t.disengaged})}),M=C.enter().append("g").attr("class","nv-series");switch(g){case"furious":k=23;break;case"classic":k=20}if("classic"==g)M.append("circle").style("stroke-width",2).attr("class","nv-legend-symbol").attr("r",5),$=C.select("circle");else if("furious"==g){M.append("rect").style("stroke-width",2).attr("class","nv-legend-symbol").attr("rx",3).attr("ry",3),$=C.select(".nv-legend-symbol"),M.append("g").attr("class","nv-check-box").property("innerHTML",'<path d="M0.5,5 L22.5,5 L22.5,26.5 L0.5,26.5 L0.5,5 Z" class="nv-box"></path><path d="M5.5,12.8618467 L11.9185089,19.2803556 L31,0.198864511" class="nv-check"></path>').attr("transform","translate(-10,-8)scale(0.5)");var D=C.select(".nv-check-box");D.each(function(t,e){d3.select(this).selectAll("path").attr("stroke",v(t,e))})}M.append("text").attr("text-anchor","start").attr("class","nv-legend-text").attr("dy",".32em").attr("dx","8");var S=C.select("text.nv-legend-text");C.on("mouseover",function(t,e){p.legendMouseover(t,e)}).on("mouseout",function(t,e){p.legendMouseout(t,e)}).on("click",function(t,e){p.legendClick(t,e);var n=C.data();if(d){if("classic"==g)h?(n.forEach(function(t){t.disabled=!0}),t.disabled=!1):(t.disabled=!t.disabled,n.every(function(t){return t.disabled})&&n.forEach(function(t){t.disabled=!1}));else if("furious"==g)if(f)t.disengaged=!t.disengaged,t.userDisabled=void 0==t.userDisabled?!!t.disabled:t.userDisabled,t.disabled=t.disengaged||t.userDisabled;else if(!f){t.disabled=!t.disabled,t.userDisabled=t.disabled;var i=n.filter(function(t){return!t.disengaged});i.every(function(t){return t.userDisabled})&&n.forEach(function(t){t.disabled=t.userDisabled=!1})}p.stateChange({disabled:n.map(function(t){return!!t.disabled}),disengaged:n.map(function(t){return!!t.disengaged})})}}).on("dblclick",function(t,e){if(("furious"!=g||!f)&&(p.legendDblclick(t,e),d)){var n=C.data();n.forEach(function(t){t.disabled=!0,"furious"==g&&(t.userDisabled=t.disabled)}),t.disabled=!1,"furious"==g&&(t.userDisabled=t.disabled),p.stateChange({disabled:n.map(function(t){return!!t.disabled})})}}),C.classed("nv-disabled",function(t){return t.userDisabled}),C.exit().remove(),S.attr("fill",v).text(o);var T=0;if(u){var A=[];C.each(function(e,n){var i;if(o(e).length>s){var r=o(e).substring(0,s);i=d3.select(this).select("text").text(r+"..."),d3.select(this).append("svg:title").text(o(e))}else i=d3.select(this).select("text");var a;try{if(a=i.node().getComputedTextLength(),0>=a)throw Error()}catch(u){a=t.utils.calcApproxTextWidth(i)}A.push(a+l)});var E=0,O=[];for(T=0;a>T&&E<A.length;)O[E]=A[E],T+=A[E++];for(0===E&&(E=1);T>a&&E>1;){O=[],E--;for(var N=0;N<A.length;N++)A[N]>(O[N%E]||0)&&(O[N%E]=A[N]);T=O.reduce(function(t,e,n,i){return t+e})}for(var I=[],P=0,F=0;E>P;P++)I[P]=F,F+=O[P];C.attr("transform",function(t,e){return"translate("+I[e%E]+","+(5+Math.floor(e/E)*k)+")"}),c?_.attr("transform","translate("+(i-n.right-T)+","+n.top+")"):_.attr("transform","translate(0,"+n.top+")"),r=n.top+n.bottom+Math.ceil(A.length/E)*k}else{var W,H=5,L=5,z=0;C.attr("transform",function(t,e){var r=d3.select(this).select("text").node().getComputedTextLength()+l;return W=L,i<n.left+n.right+W+r&&(L=W=5,H+=k),L+=r,L>z&&(z=L),W+z>T&&(T=W+z),"translate("+W+","+H+")"}),_.attr("transform","translate("+(i-n.right-z)+","+n.top+")"),r=n.top+n.bottom+H+15}if("furious"==g){$.attr("width",function(t,e){return S[0][e].getComputedTextLength()+27}).attr("height",18).attr("y",-9).attr("x",-15),w.insert("rect",":first-child").attr("class","nv-legend-bg").attr("fill","#eee").attr("opacity",0);var j=_.select(".nv-legend-bg");j.transition().duration(300).attr("x",-k).attr("width",T+k-12).attr("height",r+10).attr("y",-n.top-10).attr("opacity",f?1:0)}$.style("fill",y).style("fill-opacity",b).style("stroke",y)}),e}var n={top:5,right:0,bottom:5,left:0},i=400,r=20,o=function(t){return t.key},a=t.utils.getColor(),s=20,u=!0,l=32,c=!0,d=!0,h=!1,f=!1,p=d3.dispatch("legendClick","legendDblclick","legendMouseover","legendMouseout","stateChange"),g="classic";return e.dispatch=p,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return i},set:function(t){i=t}},height:{get:function(){return r},set:function(t){r=t}},key:{get:function(){return o},set:function(t){o=t}},align:{get:function(){return u},set:function(t){u=t}},maxKeyLength:{get:function(){return s},set:function(t){s=t}},rightAlign:{get:function(){return c},set:function(t){c=t}},padding:{get:function(){return l},set:function(t){l=t}},updateState:{get:function(){return d},set:function(t){d=t}},radioButtonMode:{get:function(){return h},set:function(t){h=t}},expanded:{get:function(){return f},set:function(t){f=t}},vers:{get:function(){return g},set:function(t){g=t}},margin:{get:function(){return n},set:function(t){n.top=void 0!==t.top?t.top:n.top,n.right=void 0!==t.right?t.right:n.right,n.bottom=void 0!==t.bottom?t.bottom:n.bottom,n.left=void 0!==t.left?t.left:n.left}},color:{get:function(){return a},set:function(e){a=t.utils.getColor(e)}}}),t.utils.initOptions(e),e},t.models.line=function(){"use strict";function e(v){return w.reset(),w.models(r),v.each(function(e){u=d3.select(this);var v=t.utils.availableWidth(a,u,o),y=t.utils.availableHeight(s,u,o);t.utils.initSVG(u),n=r.xScale(),i=r.yScale(),b=b||n,x=x||i;var _=u.selectAll("g.nv-wrap.nv-line").data([e]),$=_.enter().append("g").attr("class","nvd3 nv-wrap nv-line"),k=$.append("defs"),C=$.append("g"),M=_.select("g");C.append("g").attr("class","nv-groups"),C.append("g").attr("class","nv-scatterWrap"),_.attr("transform","translate("+o.left+","+o.top+")"),r.width(v).height(y);var D=_.select(".nv-scatterWrap");D.call(r),k.append("clipPath").attr("id","nv-edge-clip-"+r.id()).append("rect"),_.select("#nv-edge-clip-"+r.id()+" rect").attr("width",v).attr("height",y>0?y:0),M.attr("clip-path",g?"url(#nv-edge-clip-"+r.id()+")":""),D.attr("clip-path",g?"url(#nv-edge-clip-"+r.id()+")":"");var S=_.select(".nv-groups").selectAll(".nv-group").data(function(t){return t},function(t){return t.key});S.enter().append("g").style("stroke-opacity",1e-6).style("stroke-width",function(t){return t.strokeWidth||l}).style("fill-opacity",1e-6),S.exit().remove(),S.attr("class",function(t,e){return(t.classed||"")+" nv-group nv-series-"+e}).classed("hover",function(t){return t.hover}).style("fill",function(t,e){return c(t,e)}).style("stroke",function(t,e){return c(t,e)}),S.watchTransition(w,"line: groups").style("stroke-opacity",1).style("fill-opacity",function(t){return t.fillOpacity||.5});var T=S.selectAll("path.nv-area").data(function(t){return p(t)?[t]:[]});T.enter().append("path").attr("class","nv-area").attr("d",function(e){return d3.svg.area().interpolate(m).defined(f).x(function(e,n){return t.utils.NaNtoZero(b(d(e,n)))}).y0(function(e,n){return t.utils.NaNtoZero(x(h(e,n)))}).y1(function(t,e){return x(i.domain()[0]<=0?i.domain()[1]>=0?0:i.domain()[1]:i.domain()[0])}).apply(this,[e.values])}),S.exit().selectAll("path.nv-area").remove(),T.watchTransition(w,"line: areaPaths").attr("d",function(e){return d3.svg.area().interpolate(m).defined(f).x(function(e,i){return t.utils.NaNtoZero(n(d(e,i)))}).y0(function(e,n){return t.utils.NaNtoZero(i(h(e,n)))}).y1(function(t,e){return i(i.domain()[0]<=0?i.domain()[1]>=0?0:i.domain()[1]:i.domain()[0])}).apply(this,[e.values])});var A=S.selectAll("path.nv-line").data(function(t){return[t.values]});A.enter().append("path").attr("class","nv-line").attr("d",d3.svg.line().interpolate(m).defined(f).x(function(e,n){return t.utils.NaNtoZero(b(d(e,n)))}).y(function(e,n){return t.utils.NaNtoZero(x(h(e,n)))})),A.watchTransition(w,"line: linePaths").attr("d",d3.svg.line().interpolate(m).defined(f).x(function(e,i){return t.utils.NaNtoZero(n(d(e,i)))}).y(function(e,n){return t.utils.NaNtoZero(i(h(e,n)))})),b=n.copy(),x=i.copy()}),w.renderEnd("line immediate"),e}var n,i,r=t.models.scatter(),o={top:0,right:0,bottom:0,left:0},a=960,s=500,u=null,l=1.5,c=t.utils.defaultColor(),d=function(t){return t.x},h=function(t){return t.y},f=function(t,e){return!isNaN(h(t,e))&&null!==h(t,e)},p=function(t){return t.area},g=!1,m="linear",v=250,y=d3.dispatch("elementClick","elementMouseover","elementMouseout","renderEnd");r.pointSize(16).pointDomain([16,256]);var b,x,w=t.utils.renderWatch(y,v);return e.dispatch=y,e.scatter=r,r.dispatch.on("elementClick",function(){y.elementClick.apply(this,arguments)}),r.dispatch.on("elementMouseover",function(){y.elementMouseover.apply(this,arguments)}),r.dispatch.on("elementMouseout",function(){y.elementMouseout.apply(this,arguments)}),e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return a},set:function(t){a=t}},height:{get:function(){return s},set:function(t){s=t}},defined:{get:function(){return f},set:function(t){f=t}},interpolate:{get:function(){return m},set:function(t){m=t}},clipEdge:{get:function(){return g},set:function(t){g=t}},margin:{get:function(){return o},set:function(t){o.top=void 0!==t.top?t.top:o.top,o.right=void 0!==t.right?t.right:o.right,o.bottom=void 0!==t.bottom?t.bottom:o.bottom,o.left=void 0!==t.left?t.left:o.left}},duration:{get:function(){return v},set:function(t){v=t,w.reset(v),r.duration(v)}},isArea:{get:function(){return p},set:function(t){p=d3.functor(t)}},x:{get:function(){return d},set:function(t){d=t,r.x(t)}},y:{get:function(){return h},set:function(t){h=t,r.y(t)}},color:{get:function(){return c},set:function(e){c=t.utils.getColor(e),r.color(c)}}}),t.utils.inheritOptions(e,r),t.utils.initOptions(e),e},t.models.lineChart=function(){"use strict";function e(d){return F.reset(),F.models(a),F.models(h),_&&F.models(s),$&&F.models(u),S&&F.models(f),D&&F.models(p),d.each(function(d){function N(){_&&X.select(".nv-focus .nv-x.nv-axis").transition().duration(P).call(s)}function F(){$&&X.select(".nv-focus .nv-y.nv-axis").transition().duration(P).call(u)}function L(t){var e=+("e"==t),n=e?1:-1,i=B/3;return"M"+.5*n+","+i+"A6,6 0 0 "+e+" "+6.5*n+","+(i+6)+"V"+(2*i-6)+"A6,6 0 0 "+e+" "+.5*n+","+2*i+"ZM"+2.5*n+","+(i+8)+"V"+(2*i-8)+"M"+4.5*n+","+(i+8)+"V"+(2*i-8)}function z(){g.empty()||g.extent(A),tt.data([g.empty()?r.domain():A]).each(function(t,e){var i=r(t[0])-n.range()[0],o=U-r(t[1]);d3.select(this).select(".left").attr("width",0>i?0:i),d3.select(this).select(".right").attr("x",r(t[1])).attr("width",0>o?0:o)})}function j(){A=g.empty()?null:g.extent();var t=g.empty()?r.domain():g.extent();if(!(Math.abs(t[0]-t[1])<=1)){I.brush({extent:t,brush:g}),z();var e=X.select(".nv-focus .nv-linesWrap").datum(d.filter(function(t){return!t.disabled}).map(function(e,n){return{key:e.key,area:e.area,classed:e.classed,values:e.values.filter(function(e,n){return a.x()(e,n)>=t[0]&&a.x()(e,n)<=t[1]}),disableTooltip:e.disableTooltip}}));e.transition().duration(P).call(a),N(),F()}}var R=d3.select(this);t.utils.initSVG(R);var U=t.utils.availableWidth(b,R,m),q=t.utils.availableHeight(x,R,m)-(M?T:0),B=T-v.top-v.bottom;if(e.update=function(){0===P?R.call(e):R.transition().duration(P).call(e)},e.container=this,E.setter(H(d),e.update).getter(W(d)).update(),E.disabled=d.map(function(t){return!!t.disabled}),!O){var V;O={};for(V in E)E[V]instanceof Array?O[V]=E[V].slice(0):O[V]=E[V]}if(!(d&&d.length&&d.filter(function(t){return t.values.length}).length))return t.utils.noData(e,R),e;R.selectAll(".nv-noData").remove(),n=a.xScale(),i=a.yScale(),r=h.xScale(),o=h.yScale();var Y=R.selectAll("g.nv-wrap.nv-lineChart").data([d]),G=Y.enter().append("g").attr("class","nvd3 nv-wrap nv-lineChart").append("g"),X=Y.select("g");G.append("g").attr("class","nv-legendWrap");var K=G.append("g").attr("class","nv-focus");K.append("g").attr("class","nv-background").append("rect"),K.append("g").attr("class","nv-x nv-axis"),K.append("g").attr("class","nv-y nv-axis"),K.append("g").attr("class","nv-linesWrap"),K.append("g").attr("class","nv-interactive");var Z=G.append("g").attr("class","nv-context");Z.append("g").attr("class","nv-background").append("rect"),Z.append("g").attr("class","nv-x nv-axis"),Z.append("g").attr("class","nv-y nv-axis"),Z.append("g").attr("class","nv-linesWrap"),Z.append("g").attr("class","nv-brushBackground"),Z.append("g").attr("class","nv-x nv-brush"),w&&(l.width(U),X.select(".nv-legendWrap").datum(d).call(l),m.top!=l.height()&&(m.top=l.height(),q=t.utils.availableHeight(x,R,m)-(M?T:0)),Y.select(".nv-legendWrap").attr("transform","translate(0,"+-m.top+")")),Y.attr("transform","translate("+m.left+","+m.top+")"),k&&X.select(".nv-y.nv-axis").attr("transform","translate("+U+",0)"),C&&(c.width(U).height(q).margin({left:m.left,top:m.top}).svgContainer(R).xScale(n),Y.select(".nv-interactive").call(c)),X.select(".nv-focus .nv-background rect").attr("width",U).attr("height",q),a.width(U).height(q).color(d.map(function(t,e){return t.color||y(t,e)}).filter(function(t,e){return!d[e].disabled}));var Q=X.select(".nv-linesWrap").datum(d.filter(function(t){return!t.disabled}));if(_&&s.scale(n)._ticks(t.utils.calcTicksX(U/100,d)).tickSize(-q,0),$&&u.scale(i)._ticks(t.utils.calcTicksY(q/36,d)).tickSize(-U,0),X.select(".nv-focus .nv-x.nv-axis").attr("transform","translate(0,"+q+")"),M){h.defined(a.defined()).width(U).height(B).color(d.map(function(t,e){return t.color||y(t,e)}).filter(function(t,e){return!d[e].disabled})),X.select(".nv-context").attr("transform","translate(0,"+(q+m.bottom+v.top)+")").style("display",M?"initial":"none");var J=X.select(".nv-context .nv-linesWrap").datum(d.filter(function(t){return!t.disabled}));d3.transition(J).call(h),g.x(r).on("brush",function(){j()}),A&&g.extent(A);var tt=X.select(".nv-brushBackground").selectAll("g").data([A||g.extent()]),et=tt.enter().append("g");et.append("rect").attr("class","left").attr("x",0).attr("y",0).attr("height",B),et.append("rect").attr("class","right").attr("x",0).attr("y",0).attr("height",B);var nt=X.select(".nv-x.nv-brush").call(g);nt.selectAll("rect").attr("height",B),nt.selectAll(".resize").append("path").attr("d",L),j(),X.select(".nv-context .nv-background rect").attr("width",U).attr("height",B),S&&(f.scale(r)._ticks(t.utils.calcTicksX(U/100,d)).tickSize(-B,0),X.select(".nv-context .nv-x.nv-axis").attr("transform","translate(0,"+o.range()[0]+")"),d3.transition(X.select(".nv-context .nv-x.nv-axis")).call(f)),D&&(p.scale(o)._ticks(t.utils.calcTicksY(B/36,d)).tickSize(-U,0),d3.transition(X.select(".nv-context .nv-y.nv-axis")).call(p)),X.select(".nv-context .nv-x.nv-axis").attr("transform","translate(0,"+o.range()[0]+")")}else Q.call(a),N(),F();l.dispatch.on("stateChange",function(t){for(var n in t)E[n]=t[n];I.stateChange(E),e.update()}),c.dispatch.on("elementMousemove",function(i){a.clearHighlights();var o,s,l,h=[];if(d.filter(function(t,e){return t.seriesIndex=e,!t.disabled&&!t.disableTooltip}).forEach(function(u,c){var d=M?g.empty()?r.domain():g.extent():n.domain(),f=u.values.filter(function(t,e){return a.x()(t,e)>=d[0]&&a.x()(t,e)<=d[1]});s=t.interactiveBisect(f,i.pointXValue,a.x());var p=f[s],m=e.y()(p,s);null!==m&&a.highlightPoint(u.seriesIndex,s,!0),void 0!==p&&(void 0===o&&(o=p),void 0===l&&(l=e.xScale()(e.x()(p,s))),h.push({key:u.key,value:m,color:y(u,u.seriesIndex),data:p}))}),h.length>2){var f=e.yScale().invert(i.mouseY),p=Math.abs(e.yScale().domain()[0]-e.yScale().domain()[1]),m=.03*p,v=t.nearestValueIndex(h.map(function(t){return t.value}),f,m);null!==v&&(h[v].highlight=!0)}c.tooltip.chartContainer(e.container.parentNode).valueFormatter(function(t,e){return null===t?"N/A":u.tickFormat()(t)}).data({value:e.x()(o,s),index:s,series:h})(),c.renderGuideLine(l)}),c.dispatch.on("elementClick",function(n){var i,r=[];d.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(o){var a=t.interactiveBisect(o.values,n.pointXValue,e.x()),s=o.values[a];if("undefined"!=typeof s){"undefined"==typeof i&&(i=e.xScale()(e.x()(s,a)));var u=e.yScale()(e.y()(s,a));r.push({point:s,pointIndex:a,pos:[i,u],seriesIndex:o.seriesIndex,series:o})}}),a.dispatch.elementClick(r)}),c.dispatch.on("elementMouseout",function(t){a.clearHighlights()}),I.on("changeState",function(t){"undefined"!=typeof t.disabled&&d.length===t.disabled.length&&(d.forEach(function(e,n){e.disabled=t.disabled[n]}),E.disabled=t.disabled),e.update()})}),F.renderEnd("lineChart immediate"),e}var n,i,r,o,a=t.models.line(),s=t.models.axis(),u=t.models.axis(),l=t.models.legend(),c=t.interactiveGuideline(),d=t.models.tooltip(),h=t.models.line(),f=t.models.axis(),p=t.models.axis(),g=d3.svg.brush(),m={top:30,right:20,bottom:50,left:60},v={top:0,right:20,bottom:20,left:60},y=t.utils.defaultColor(),b=null,x=null,w=!0,_=!0,$=!0,k=!1,C=!1,M=!1,D=!1,S=!0,T=50,A=null,E=t.utils.state(),O=null,N=null,I=d3.dispatch("tooltipShow","tooltipHide","brush","stateChange","changeState","renderEnd"),P=250;s.orient("bottom").tickPadding(7),u.orient(k?"right":"left"),a.clipEdge(!0).duration(0),h.interactive(!1),h.pointActive(function(t){return!1}),f.orient("bottom").tickPadding(5),p.orient(k?"right":"left"),d.valueFormatter(function(t,e){return u.tickFormat()(t,e)}).headerFormatter(function(t,e){return s.tickFormat()(t,e)}),c.tooltip.valueFormatter(function(t,e){return u.tickFormat()(t,e)}).headerFormatter(function(t,e){return s.tickFormat()(t,e)});var F=t.utils.renderWatch(I,P),W=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},H=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return a.dispatch.on("elementMouseover.tooltip",function(t){t.series.disableTooltip||d.data(t).hidden(!1)}),a.dispatch.on("elementMouseout.tooltip",function(t){d.hidden(!0)}),e.dispatch=I,e.lines=a,e.lines2=h,e.legend=l,e.xAxis=s,e.x2Axis=f,e.yAxis=u,e.y2Axis=p,e.interactiveLayer=c,e.tooltip=d,e.state=E,e.dispatch=I,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return b},set:function(t){b=t}},height:{get:function(){return x},set:function(t){x=t}},showLegend:{get:function(){return w},set:function(t){w=t}},showXAxis:{get:function(){return _},set:function(t){_=t}},showYAxis:{get:function(){return $},set:function(t){$=t}},focusEnable:{get:function(){return M},set:function(t){M=t}},focusHeight:{get:function(){return height2},set:function(t){T=t}},focusShowAxisX:{get:function(){return S},set:function(t){S=t}},focusShowAxisY:{get:function(){return D},set:function(t){D=t}},brushExtent:{get:function(){return A},set:function(t){A=t}},defaultState:{get:function(){return O},set:function(t){O=t}},noData:{get:function(){return N},set:function(t){N=t}},margin:{get:function(){return m},set:function(t){m.top=void 0!==t.top?t.top:m.top,m.right=void 0!==t.right?t.right:m.right,m.bottom=void 0!==t.bottom?t.bottom:m.bottom,m.left=void 0!==t.left?t.left:m.left}},duration:{get:function(){return P},set:function(t){P=t,F.reset(P),a.duration(P),s.duration(P),f.duration(P),u.duration(P),p.duration(P)}},focusMargin:{get:function(){return v},set:function(t){v.top=void 0!==t.top?t.top:v.top,v.right=void 0!==t.right?t.right:v.right,v.bottom=void 0!==t.bottom?t.bottom:v.bottom,v.left=void 0!==t.left?t.left:v.left}},color:{get:function(){return y},set:function(e){y=t.utils.getColor(e),l.color(y),a.color(y)}},interpolate:{get:function(){return a.interpolate()},set:function(t){a.interpolate(t),h.interpolate(t)}},xTickFormat:{get:function(){return s.tickFormat()},set:function(t){s.tickFormat(t),f.tickFormat(t)}},yTickFormat:{get:function(){return u.tickFormat()},set:function(t){u.tickFormat(t),p.tickFormat(t)}},x:{get:function(){return a.x()},set:function(t){a.x(t),h.x(t)}},y:{get:function(){return a.y()},set:function(t){a.y(t),h.y(t)}},rightAlignYAxis:{get:function(){return k},set:function(t){k=t,u.orient(k?"right":"left")}},useInteractiveGuideline:{get:function(){return C},set:function(t){C=t,C&&(a.interactive(!1),a.useVoronoi(!1))}}}),t.utils.inheritOptions(e,a),t.utils.initOptions(e),e},t.models.lineWithFocusChart=function(){return t.models.lineChart().margin({bottom:30}).focusEnable(!0)},t.models.linePlusBarChart=function(){"use strict";function e(w){return w.each(function(w){function P(t){var e=+("e"==t),n=e?1:-1,i=Z/3;return"M"+.5*n+","+i+"A6,6 0 0 "+e+" "+6.5*n+","+(i+6)+"V"+(2*i-6)+"A6,6 0 0 "+e+" "+.5*n+","+2*i+"ZM"+2.5*n+","+(i+8)+"V"+(2*i-8)+"M"+4.5*n+","+(i+8)+"V"+(2*i-8)}function U(){x.empty()||x.extent(I),ht.data([x.empty()?r.domain():I]).each(function(t,e){var n=r(t[0])-r.range()[0],i=r.range()[1]-r(t[1]);d3.select(this).select(".left").attr("width",0>n?0:n),d3.select(this).select(".right").attr("x",r(t[1])).attr("width",0>i?0:i)})}function q(){I=x.empty()?null:x.extent(),n=x.empty()?r.domain():x.extent(),F.brush({extent:n,brush:x}),U(),d.width(X).height(K).color(w.map(function(t,e){return t.color||S(t,e)}).filter(function(t,e){return!w[e].disabled&&w[e].bar})),l.width(X).height(K).color(w.map(function(t,e){return t.color||S(t,e)}).filter(function(t,e){return!w[e].disabled&&!w[e].bar}));var e=ot.select(".nv-focus .nv-barsWrap").datum(J.length?J.map(function(t,e){return{key:t.key,values:t.values.filter(function(t,e){return d.x()(t,e)>=n[0]&&d.x()(t,e)<=n[1]})}}):[{values:[]}]),s=ot.select(".nv-focus .nv-linesWrap").datum(Y(tt)?[{values:[]}]:tt.filter(function(t){return!t.disabled}).map(function(t,e){return{area:t.area,fillOpacity:t.fillOpacity,key:t.key,values:t.values.filter(function(t,e){return l.x()(t,e)>=n[0]&&l.x()(t,e)<=n[1];
})}}));i=J.length&&!R?d.xScale():l.xScale(),f.scale(i)._ticks(t.utils.calcTicksX(X/100,w)).tickSize(-K,0),f.domain([Math.ceil(n[0]),Math.floor(n[1])]),ot.select(".nv-x.nv-axis").transition().duration(W).call(f),e.transition().duration(W).call(d),s.transition().duration(W).call(l),ot.select(".nv-focus .nv-x.nv-axis").attr("transform","translate(0,"+o.range()[0]+")"),g.scale(o)._ticks(t.utils.calcTicksY(K/36,w)).tickSize(-X,0),m.scale(a)._ticks(t.utils.calcTicksY(K/36,w)).tickSize(J.length?0:-X,0);var u=J.length?1:0,c=tt.length&&!Y(tt)?1:0,h=R?c:u,p=R?u:c;ot.select(".nv-focus .nv-y1.nv-axis").style("opacity",h),ot.select(".nv-focus .nv-y2.nv-axis").style("opacity",p).attr("transform","translate("+i.range()[1]+",0)"),ot.select(".nv-focus .nv-y1.nv-axis").transition().duration(W).call(g),ot.select(".nv-focus .nv-y2.nv-axis").transition().duration(W).call(m)}var G=d3.select(this);t.utils.initSVG(G);var X=t.utils.availableWidth(k,G,_),K=t.utils.availableHeight(C,G,_)-(A?N:0),Z=N-$.top-$.bottom;if(e.update=function(){G.transition().duration(W).call(e)},e.container=this,H.setter(V(w),e.update).getter(B(w)).update(),H.disabled=w.map(function(t){return!!t.disabled}),!L){var Q;L={};for(Q in H)H[Q]instanceof Array?L[Q]=H[Q].slice(0):L[Q]=H[Q]}if(!(w&&w.length&&w.filter(function(t){return t.values.length}).length))return t.utils.noData(e,G),e;G.selectAll(".nv-noData").remove();var J=w.filter(function(t){return!t.disabled&&t.bar}),tt=w.filter(function(t){return!t.bar});i=d.xScale(),r=p.scale(),o=R?l.yScale():d.yScale(),a=R?d.yScale():l.yScale(),s=R?c.yScale():h.yScale(),u=R?h.yScale():c.yScale();var et=w.filter(function(t){return!t.disabled&&(R?!t.bar:t.bar)}).map(function(t){return t.values.map(function(t,e){return{x:M(t,e),y:D(t,e)}})}),nt=w.filter(function(t){return!t.disabled&&(R?t.bar:!t.bar)}).map(function(t){return t.values.map(function(t,e){return{x:M(t,e),y:D(t,e)}})});i.range([0,X]),r.domain(d3.extent(d3.merge(et.concat(nt)),function(t){return t.x})).range([0,X]);var it=G.selectAll("g.nv-wrap.nv-linePlusBar").data([w]),rt=it.enter().append("g").attr("class","nvd3 nv-wrap nv-linePlusBar").append("g"),ot=it.select("g");rt.append("g").attr("class","nv-legendWrap");var at=rt.append("g").attr("class","nv-focus");at.append("g").attr("class","nv-x nv-axis"),at.append("g").attr("class","nv-y1 nv-axis"),at.append("g").attr("class","nv-y2 nv-axis"),at.append("g").attr("class","nv-barsWrap"),at.append("g").attr("class","nv-linesWrap");var st=rt.append("g").attr("class","nv-context");if(st.append("g").attr("class","nv-x nv-axis"),st.append("g").attr("class","nv-y1 nv-axis"),st.append("g").attr("class","nv-y2 nv-axis"),st.append("g").attr("class","nv-barsWrap"),st.append("g").attr("class","nv-linesWrap"),st.append("g").attr("class","nv-brushBackground"),st.append("g").attr("class","nv-x nv-brush"),T){var ut=b.align()?X/2:X,lt=b.align()?ut:0;b.width(ut),ot.select(".nv-legendWrap").datum(w.map(function(t){return t.originalKey=void 0===t.originalKey?t.key:t.originalKey,R?t.key=t.originalKey+(t.bar?j:z):t.key=t.originalKey+(t.bar?z:j),t})).call(b),_.top!=b.height()&&(_.top=b.height(),K=t.utils.availableHeight(C,G,_)-N),ot.select(".nv-legendWrap").attr("transform","translate("+lt+","+-_.top+")")}it.attr("transform","translate("+_.left+","+_.top+")"),ot.select(".nv-context").style("display",A?"initial":"none"),h.width(X).height(Z).color(w.map(function(t,e){return t.color||S(t,e)}).filter(function(t,e){return!w[e].disabled&&w[e].bar})),c.width(X).height(Z).color(w.map(function(t,e){return t.color||S(t,e)}).filter(function(t,e){return!w[e].disabled&&!w[e].bar}));var ct=ot.select(".nv-context .nv-barsWrap").datum(J.length?J:[{values:[]}]),dt=ot.select(".nv-context .nv-linesWrap").datum(Y(tt)?[{values:[]}]:tt.filter(function(t){return!t.disabled}));ot.select(".nv-context").attr("transform","translate(0,"+(K+_.bottom+$.top)+")"),ct.transition().call(h),dt.transition().call(c),O&&(p._ticks(t.utils.calcTicksX(X/100,w)).tickSize(-Z,0),ot.select(".nv-context .nv-x.nv-axis").attr("transform","translate(0,"+s.range()[0]+")"),ot.select(".nv-context .nv-x.nv-axis").transition().call(p)),E&&(v.scale(s)._ticks(Z/36).tickSize(-X,0),y.scale(u)._ticks(Z/36).tickSize(J.length?0:-X,0),ot.select(".nv-context .nv-y3.nv-axis").style("opacity",J.length?1:0).attr("transform","translate(0,"+r.range()[0]+")"),ot.select(".nv-context .nv-y2.nv-axis").style("opacity",tt.length?1:0).attr("transform","translate("+r.range()[1]+",0)"),ot.select(".nv-context .nv-y1.nv-axis").transition().call(v),ot.select(".nv-context .nv-y2.nv-axis").transition().call(y)),x.x(r).on("brush",q),I&&x.extent(I);var ht=ot.select(".nv-brushBackground").selectAll("g").data([I||x.extent()]),ft=ht.enter().append("g");ft.append("rect").attr("class","left").attr("x",0).attr("y",0).attr("height",Z),ft.append("rect").attr("class","right").attr("x",0).attr("y",0).attr("height",Z);var pt=ot.select(".nv-x.nv-brush").call(x);pt.selectAll("rect").attr("height",Z),pt.selectAll(".resize").append("path").attr("d",P),b.dispatch.on("stateChange",function(t){for(var n in t)H[n]=t[n];F.stateChange(H),e.update()}),F.on("changeState",function(t){"undefined"!=typeof t.disabled&&(w.forEach(function(e,n){e.disabled=t.disabled[n]}),H.disabled=t.disabled),e.update()}),q()}),e}var n,i,r,o,a,s,u,l=t.models.line(),c=t.models.line(),d=t.models.historicalBar(),h=t.models.historicalBar(),f=t.models.axis(),p=t.models.axis(),g=t.models.axis(),m=t.models.axis(),v=t.models.axis(),y=t.models.axis(),b=t.models.legend(),x=d3.svg.brush(),w=t.models.tooltip(),_={top:30,right:30,bottom:30,left:60},$={top:0,right:30,bottom:20,left:60},k=null,C=null,M=function(t){return t.x},D=function(t){return t.y},S=t.utils.defaultColor(),T=!0,A=!0,E=!1,O=!0,N=50,I=null,P=null,F=d3.dispatch("brush","stateChange","changeState"),W=0,H=t.utils.state(),L=null,z=" (left axis)",j=" (right axis)",R=!1;l.clipEdge(!0),c.interactive(!1),c.pointActive(function(t){return!1}),f.orient("bottom").tickPadding(5),g.orient("left"),m.orient("right"),p.orient("bottom").tickPadding(5),v.orient("left"),y.orient("right"),w.headerEnabled(!0).headerFormatter(function(t,e){return f.tickFormat()(t,e)});var U=function(){return R?{main:g,focus:v}:{main:m,focus:y}},q=function(){return R?{main:m,focus:y}:{main:g,focus:v}},B=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},V=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}},Y=function(t){return t.every(function(t){return t.disabled})};return l.dispatch.on("elementMouseover.tooltip",function(t){w.duration(100).valueFormatter(function(t,e){return q().main.tickFormat()(t,e)}).data(t).hidden(!1)}),l.dispatch.on("elementMouseout.tooltip",function(t){w.hidden(!0)}),d.dispatch.on("elementMouseover.tooltip",function(t){t.value=e.x()(t.data),t.series={value:e.y()(t.data),color:t.color},w.duration(0).valueFormatter(function(t,e){return U().main.tickFormat()(t,e)}).data(t).hidden(!1)}),d.dispatch.on("elementMouseout.tooltip",function(t){w.hidden(!0)}),d.dispatch.on("elementMousemove.tooltip",function(t){w()}),e.dispatch=F,e.legend=b,e.lines=l,e.lines2=c,e.bars=d,e.bars2=h,e.xAxis=f,e.x2Axis=p,e.y1Axis=g,e.y2Axis=m,e.y3Axis=v,e.y4Axis=y,e.tooltip=w,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return k},set:function(t){k=t}},height:{get:function(){return C},set:function(t){C=t}},showLegend:{get:function(){return T},set:function(t){T=t}},brushExtent:{get:function(){return I},set:function(t){I=t}},noData:{get:function(){return P},set:function(t){P=t}},focusEnable:{get:function(){return A},set:function(t){A=t}},focusHeight:{get:function(){return N},set:function(t){N=t}},focusShowAxisX:{get:function(){return O},set:function(t){O=t}},focusShowAxisY:{get:function(){return E},set:function(t){E=t}},legendLeftAxisHint:{get:function(){return z},set:function(t){z=t}},legendRightAxisHint:{get:function(){return j},set:function(t){j=t}},margin:{get:function(){return _},set:function(t){_.top=void 0!==t.top?t.top:_.top,_.right=void 0!==t.right?t.right:_.right,_.bottom=void 0!==t.bottom?t.bottom:_.bottom,_.left=void 0!==t.left?t.left:_.left}},focusMargin:{get:function(){return $},set:function(t){$.top=void 0!==t.top?t.top:$.top,$.right=void 0!==t.right?t.right:$.right,$.bottom=void 0!==t.bottom?t.bottom:$.bottom,$.left=void 0!==t.left?t.left:$.left}},duration:{get:function(){return W},set:function(t){W=t}},color:{get:function(){return S},set:function(e){S=t.utils.getColor(e),b.color(S)}},x:{get:function(){return M},set:function(t){M=t,l.x(t),c.x(t),d.x(t),h.x(t)}},y:{get:function(){return D},set:function(t){D=t,l.y(t),c.y(t),d.y(t),h.y(t)}},switchYAxisOrder:{get:function(){return R},set:function(t){if(R!==t){var e=g.tickFormat();g.tickFormat(m.tickFormat()),m.tickFormat(e)}R=t}}}),t.utils.inheritOptions(e,l),t.utils.initOptions(e),e},t.models.multiBar=function(){"use strict";function e(A){return S.reset(),A.each(function(e){var A=c-l.left-l.right,E=d-l.top-l.bottom;g=d3.select(this),t.utils.initSVG(g);var O=0;if($&&e.length&&($=[{values:e[0].values.map(function(t){return{x:t.x,y:0,series:t.series,size:.01}})}]),x){var N=d3.layout.stack().offset(w).values(function(t){return t.values}).y(v)(!e.length&&$?$:e);N.forEach(function(t,n){t.nonStackable?(e[n].nonStackableSeries=O++,N[n]=e[n]):n>0&&N[n-1].nonStackable&&N[n].values.map(function(t,e){t.y0-=N[n-1].values[e].y,t.y1=t.y0+t.y})}),e=N}e.forEach(function(t,e){t.values.forEach(function(n){n.series=e,n.key=t.key})}),x&&e[0].values.map(function(t,n){var i=0,r=0;e.map(function(t,o){if(!e[o].nonStackable){var a=t.values[n];a.size=Math.abs(a.y),a.y<0?(a.y1=r,r-=a.size):(a.y1=a.size+i,i+=a.size)}})});var I=i&&r?[]:e.map(function(t,e){return t.values.map(function(t,n){return{x:m(t,n),y:v(t,n),y0:t.y0,y1:t.y1,idx:e}})});h.domain(i||d3.merge(I).map(function(t){return t.x})).rangeBands(o||[0,A],M),f.domain(r||d3.extent(d3.merge(I).map(function(t){var n=t.y;return x&&!e[t.idx].nonStackable&&(n=t.y>0?t.y1:t.y1+t.y),n}).concat(y))).range(a||[E,0]),h.domain()[0]===h.domain()[1]&&(h.domain()[0]?h.domain([h.domain()[0]-.01*h.domain()[0],h.domain()[1]+.01*h.domain()[1]]):h.domain([-1,1])),f.domain()[0]===f.domain()[1]&&(f.domain()[0]?f.domain([f.domain()[0]+.01*f.domain()[0],f.domain()[1]-.01*f.domain()[1]]):f.domain([-1,1])),s=s||h,u=u||f;var P=g.selectAll("g.nv-wrap.nv-multibar").data([e]),F=P.enter().append("g").attr("class","nvd3 nv-wrap nv-multibar"),W=F.append("defs"),H=F.append("g"),L=P.select("g");H.append("g").attr("class","nv-groups"),P.attr("transform","translate("+l.left+","+l.top+")"),W.append("clipPath").attr("id","nv-edge-clip-"+p).append("rect"),P.select("#nv-edge-clip-"+p+" rect").attr("width",A).attr("height",E),L.attr("clip-path",b?"url(#nv-edge-clip-"+p+")":"");var z=P.select(".nv-groups").selectAll(".nv-group").data(function(t){return t},function(t,e){return e});z.enter().append("g").style("stroke-opacity",1e-6).style("fill-opacity",1e-6);var j=S.transition(z.exit().selectAll("rect.nv-bar"),"multibarExit",Math.min(100,C)).attr("y",function(t,n,i){var r=u(0)||0;return x&&e[t.series]&&!e[t.series].nonStackable&&(r=u(t.y0)),r}).attr("height",0).remove();j.delay&&j.delay(function(t,e){var n=e*(C/(T+1))-e;return n}),z.attr("class",function(t,e){return"nv-group nv-series-"+e}).classed("hover",function(t){return t.hover}).style("fill",function(t,e){return _(t,e)}).style("stroke",function(t,e){return _(t,e)}),z.style("stroke-opacity",1).style("fill-opacity",.75);var R=z.selectAll("rect.nv-bar").data(function(t){return $&&!e.length?$.values:t.values});R.exit().remove();R.enter().append("rect").attr("class",function(t,e){return v(t,e)<0?"nv-bar negative":"nv-bar positive"}).attr("x",function(t,n,i){return x&&!e[i].nonStackable?0:i*h.rangeBand()/e.length}).attr("y",function(t,n,i){return u(x&&!e[i].nonStackable?t.y0:0)||0}).attr("height",0).attr("width",function(t,n,i){return h.rangeBand()/(x&&!e[i].nonStackable?1:e.length)}).attr("transform",function(t,e){return"translate("+h(m(t,e))+",0)"});R.style("fill",function(t,e,n){return _(t,n,e)}).style("stroke",function(t,e,n){return _(t,n,e)}).on("mouseover",function(t,e){d3.select(this).classed("hover",!0),D.elementMouseover({data:t,index:e,color:d3.select(this).style("fill")})}).on("mouseout",function(t,e){d3.select(this).classed("hover",!1),D.elementMouseout({data:t,index:e,color:d3.select(this).style("fill")})}).on("mousemove",function(t,e){D.elementMousemove({data:t,index:e,color:d3.select(this).style("fill")})}).on("click",function(t,e){var n=this;D.elementClick({data:t,index:e,color:d3.select(this).style("fill"),event:d3.event,element:n}),d3.event.stopPropagation()}).on("dblclick",function(t,e){D.elementDblClick({data:t,index:e,color:d3.select(this).style("fill")}),d3.event.stopPropagation()}),R.attr("class",function(t,e){return v(t,e)<0?"nv-bar negative":"nv-bar positive"}).attr("transform",function(t,e){return"translate("+h(m(t,e))+",0)"}),k&&(n||(n=e.map(function(){return!0})),R.style("fill",function(t,e,i){return d3.rgb(k(t,e)).darker(n.map(function(t,e){return e}).filter(function(t,e){return!n[e]})[i]).toString()}).style("stroke",function(t,e,i){return d3.rgb(k(t,e)).darker(n.map(function(t,e){return e}).filter(function(t,e){return!n[e]})[i]).toString()}));var U=R.watchTransition(S,"multibar",Math.min(250,C)).delay(function(t,n){return n*C/e[0].values.length});x?U.attr("y",function(t,n,i){var r=0;return r=e[i].nonStackable?v(t,n)<0?f(0):f(0)-f(v(t,n))<-1?f(0)-1:f(v(t,n))||0:f(t.y1)}).attr("height",function(t,n,i){return e[i].nonStackable?Math.max(Math.abs(f(v(t,n))-f(0)),0)||0:Math.max(Math.abs(f(t.y+t.y0)-f(t.y0)),0)}).attr("x",function(t,n,i){var r=0;return e[i].nonStackable&&(r=t.series*h.rangeBand()/e.length,e.length!==O&&(r=e[i].nonStackableSeries*h.rangeBand()/(2*O))),r}).attr("width",function(t,n,i){if(e[i].nonStackable){var r=h.rangeBand()/O;return e.length!==O&&(r=h.rangeBand()/(2*O)),r}return h.rangeBand()}):U.attr("x",function(t,n){return t.series*h.rangeBand()/e.length}).attr("width",h.rangeBand()/e.length).attr("y",function(t,e){return v(t,e)<0?f(0):f(0)-f(v(t,e))<1?f(0)-1:f(v(t,e))||0}).attr("height",function(t,e){return Math.max(Math.abs(f(v(t,e))-f(0)),1)||0}),s=h.copy(),u=f.copy(),e[0]&&e[0].values&&(T=e[0].values.length)}),S.renderEnd("multibar immediate"),e}var n,i,r,o,a,s,u,l={top:0,right:0,bottom:0,left:0},c=960,d=500,h=d3.scale.ordinal(),f=d3.scale.linear(),p=Math.floor(1e4*Math.random()),g=null,m=function(t){return t.x},v=function(t){return t.y},y=[0],b=!0,x=!1,w="zero",_=t.utils.defaultColor(),$=!1,k=null,C=500,M=.1,D=d3.dispatch("chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove","renderEnd"),S=t.utils.renderWatch(D,C),T=0;return e.dispatch=D,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return c},set:function(t){c=t}},height:{get:function(){return d},set:function(t){d=t}},x:{get:function(){return m},set:function(t){m=t}},y:{get:function(){return v},set:function(t){v=t}},xScale:{get:function(){return h},set:function(t){h=t}},yScale:{get:function(){return f},set:function(t){f=t}},xDomain:{get:function(){return i},set:function(t){i=t}},yDomain:{get:function(){return r},set:function(t){r=t}},xRange:{get:function(){return o},set:function(t){o=t}},yRange:{get:function(){return a},set:function(t){a=t}},forceY:{get:function(){return y},set:function(t){y=t}},stacked:{get:function(){return x},set:function(t){x=t}},stackOffset:{get:function(){return w},set:function(t){w=t}},clipEdge:{get:function(){return b},set:function(t){b=t}},disabled:{get:function(){return n},set:function(t){n=t}},id:{get:function(){return p},set:function(t){p=t}},hideable:{get:function(){return $},set:function(t){$=t}},groupSpacing:{get:function(){return M},set:function(t){M=t}},margin:{get:function(){return l},set:function(t){l.top=void 0!==t.top?t.top:l.top,l.right=void 0!==t.right?t.right:l.right,l.bottom=void 0!==t.bottom?t.bottom:l.bottom,l.left=void 0!==t.left?t.left:l.left}},duration:{get:function(){return C},set:function(t){C=t,S.reset(C)}},color:{get:function(){return _},set:function(e){_=t.utils.getColor(e)}},barColor:{get:function(){return k},set:function(e){k=e?t.utils.getColor(e):null}}}),t.utils.initOptions(e),e},t.models.multiBarChart=function(){"use strict";function e(D){return O.reset(),O.models(r),y&&O.models(o),b&&O.models(a),D.each(function(D){var O=d3.select(this),F=this;t.utils.initSVG(O);var W=t.utils.availableWidth(h,O,d),H=t.utils.availableHeight(f,O,d);if(e.update=function(){0===A?O.call(e):O.transition().duration(A).call(e)},e.container=this,C.setter(P(D),e.update).getter(I(D)).update(),C.disabled=D.map(function(t){return!!t.disabled}),!M){var L;M={};for(L in C)C[L]instanceof Array?M[L]=C[L].slice(0):M[L]=C[L]}if(!(D&&D.length&&D.filter(function(t){return t.values.length}).length))return t.utils.noData(e,O),e;O.selectAll(".nv-noData").remove(),n=r.xScale(),i=r.yScale();var z=O.selectAll("g.nv-wrap.nv-multiBarWithLegend").data([D]),j=z.enter().append("g").attr("class","nvd3 nv-wrap nv-multiBarWithLegend").append("g"),R=z.select("g");if(j.append("g").attr("class","nv-x nv-axis"),j.append("g").attr("class","nv-y nv-axis"),j.append("g").attr("class","nv-barsWrap"),j.append("g").attr("class","nv-legendWrap"),j.append("g").attr("class","nv-controlsWrap"),j.append("g").attr("class","nv-interactive"),v&&(u.width(W-T()),R.select(".nv-legendWrap").datum(D).call(u),d.top!=u.height()&&(d.top=u.height(),H=t.utils.availableHeight(f,O,d)),R.select(".nv-legendWrap").attr("transform","translate("+T()+","+-d.top+")")),g){var U=[{key:m.grouped||"Grouped",disabled:r.stacked()},{key:m.stacked||"Stacked",disabled:!r.stacked()}];l.width(T()).color(["#444","#444","#444"]),R.select(".nv-controlsWrap").datum(U).attr("transform","translate(0,"+-d.top+")").call(l)}z.attr("transform","translate("+d.left+","+d.top+")"),x&&R.select(".nv-y.nv-axis").attr("transform","translate("+W+",0)"),r.disabled(D.map(function(t){return t.disabled})).width(W).height(H).color(D.map(function(t,e){return t.color||p(t,e)}).filter(function(t,e){return!D[e].disabled}));var q=R.select(".nv-barsWrap").datum(D.filter(function(t){return!t.disabled}));if(q.call(r),y){o.scale(n)._ticks(t.utils.calcTicksX(W/100,D)).tickSize(-H,0),R.select(".nv-x.nv-axis").attr("transform","translate(0,"+i.range()[0]+")"),R.select(".nv-x.nv-axis").call(o);var B=R.select(".nv-x.nv-axis > g").selectAll("g");if(B.selectAll("line, text").style("opacity",1),_){var V=function(t,e){return"translate("+t+","+e+")"},Y=5,G=17;B.selectAll("text").attr("transform",function(t,e,n){return V(0,n%2==0?Y:G)});var X=d3.selectAll(".nv-x.nv-axis .nv-wrap g g text")[0].length;R.selectAll(".nv-x.nv-axis .nv-axisMaxMin text").attr("transform",function(t,e){return V(0,0===e||X%2!==0?G:Y)})}$&&R.selectAll(".tick text").call(t.utils.wrapTicks,e.xAxis.rangeBand()),w&&B.filter(function(t,e){return e%Math.ceil(D[0].values.length/(W/100))!==0}).selectAll("text, line").style("opacity",0),k&&B.selectAll(".tick text").attr("transform","rotate("+k+" 0,0)").style("text-anchor",k>0?"start":"end"),R.select(".nv-x.nv-axis").selectAll("g.nv-axisMaxMin text").style("opacity",1)}b&&(a.scale(i)._ticks(t.utils.calcTicksY(H/36,D)).tickSize(-W,0),R.select(".nv-y.nv-axis").call(a)),E&&(s.width(W).height(H).margin({left:d.left,top:d.top}).svgContainer(O).xScale(n),z.select(".nv-interactive").call(s)),u.dispatch.on("stateChange",function(t){for(var n in t)C[n]=t[n];S.stateChange(C),e.update()}),l.dispatch.on("legendClick",function(t,n){if(t.disabled){switch(U=U.map(function(t){return t.disabled=!0,t}),t.disabled=!1,t.key){case"Grouped":case m.grouped:r.stacked(!1);break;case"Stacked":case m.stacked:r.stacked(!0)}C.stacked=r.stacked(),S.stateChange(C),e.update()}}),S.on("changeState",function(t){"undefined"!=typeof t.disabled&&(D.forEach(function(e,n){e.disabled=t.disabled[n]}),C.disabled=t.disabled),"undefined"!=typeof t.stacked&&(r.stacked(t.stacked),C.stacked=t.stacked,N=t.stacked),e.update()}),E?(s.dispatch.on("elementMousemove",function(t){if(void 0!=t.pointXValue){var i,r,o,a,u=[];D.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(s,l){r=n.domain().indexOf(t.pointXValue);var c=s.values[r];void 0!==c&&(a=c.x,void 0===i&&(i=c),void 0===o&&(o=t.mouseX),u.push({key:s.key,value:e.y()(c,r),color:p(s,s.seriesIndex),data:s.values[r]}))}),s.tooltip.chartContainer(F.parentNode).data({value:a,index:r,series:u})(),s.renderGuideLine(o)}}),s.dispatch.on("elementMouseout",function(t){s.tooltip.hidden(!0)})):(r.dispatch.on("elementMouseover.tooltip",function(t){t.value=e.x()(t.data),t.series={key:t.data.key,value:e.y()(t.data),color:t.color},c.data(t).hidden(!1)}),r.dispatch.on("elementMouseout.tooltip",function(t){c.hidden(!0)}),r.dispatch.on("elementMousemove.tooltip",function(t){c()}))}),O.renderEnd("multibarchart immediate"),e}var n,i,r=t.models.multiBar(),o=t.models.axis(),a=t.models.axis(),s=t.interactiveGuideline(),u=t.models.legend(),l=t.models.legend(),c=t.models.tooltip(),d={top:30,right:20,bottom:50,left:60},h=null,f=null,p=t.utils.defaultColor(),g=!0,m={},v=!0,y=!0,b=!0,x=!1,w=!0,_=!1,$=!1,k=0,C=t.utils.state(),M=null,D=null,S=d3.dispatch("stateChange","changeState","renderEnd"),T=function(){return g?180:0},A=250,E=!1;C.stacked=!1,r.stacked(!1),o.orient("bottom").tickPadding(7).showMaxMin(!1).tickFormat(function(t){return t}),a.orient(x?"right":"left").tickFormat(d3.format(",.1f")),c.duration(0).valueFormatter(function(t,e){return a.tickFormat()(t,e)}).headerFormatter(function(t,e){return o.tickFormat()(t,e)}),l.updateState(!1);var O=t.utils.renderWatch(S),N=!1,I=function(t){return function(){return{active:t.map(function(t){return!t.disabled}),stacked:N}}},P=function(t){return function(e){void 0!==e.stacked&&(N=e.stacked),void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return e.dispatch=S,e.multibar=r,e.legend=u,e.controls=l,e.xAxis=o,e.yAxis=a,e.state=C,e.tooltip=c,e.interactiveLayer=s,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return h},set:function(t){h=t}},height:{get:function(){return f},set:function(t){f=t}},showLegend:{get:function(){return v},set:function(t){v=t}},showControls:{get:function(){return g},set:function(t){g=t}},controlLabels:{get:function(){return m},set:function(t){m=t}},showXAxis:{get:function(){return y},set:function(t){y=t}},showYAxis:{get:function(){return b},set:function(t){b=t}},defaultState:{get:function(){return M},set:function(t){M=t}},noData:{get:function(){return D},set:function(t){D=t}},reduceXTicks:{get:function(){return w},set:function(t){w=t}},rotateLabels:{get:function(){return k},set:function(t){k=t}},staggerLabels:{get:function(){return _},set:function(t){_=t}},wrapLabels:{get:function(){return $},set:function(t){$=!!t}},margin:{get:function(){return d},set:function(t){d.top=void 0!==t.top?t.top:d.top,d.right=void 0!==t.right?t.right:d.right,d.bottom=void 0!==t.bottom?t.bottom:d.bottom,d.left=void 0!==t.left?t.left:d.left}},duration:{get:function(){return A},set:function(t){A=t,r.duration(A),o.duration(A),a.duration(A),O.reset(A)}},color:{get:function(){return p},set:function(e){p=t.utils.getColor(e),u.color(p)}},rightAlignYAxis:{get:function(){return x},set:function(t){x=t,a.orient(x?"right":"left")}},useInteractiveGuideline:{get:function(){return E},set:function(t){E=t}},barColor:{get:function(){return r.barColor},set:function(t){r.barColor(t),u.color(function(t,e){return d3.rgb("#ccc").darker(1.5*e).toString()})}}}),t.utils.inheritOptions(e,r),t.utils.initOptions(e),e},t.models.multiBarHorizontal=function(){"use strict";function e(h){return A.reset(),h.each(function(e){var h=c-l.left-l.right,S=d-l.top-l.bottom;f=d3.select(this),t.utils.initSVG(f),_&&(e=d3.layout.stack().offset("zero").values(function(t){return t.values}).y(v)(e)),e.forEach(function(t,e){t.values.forEach(function(n){n.series=e,n.key=t.key})}),_&&e[0].values.map(function(t,n){var i=0,r=0;e.map(function(t){var e=t.values[n];e.size=Math.abs(e.y),e.y<0?(e.y1=r-e.size,r-=e.size):(e.y1=i,i+=e.size)})});var E=i&&r?[]:e.map(function(t){return t.values.map(function(t,e){return{x:m(t,e),y:v(t,e),y0:t.y0,y1:t.y1}})});p.domain(i||d3.merge(E).map(function(t){return t.x})).rangeBands(o||[0,S],M),g.domain(r||d3.extent(d3.merge(E).map(function(t){return _?t.y>0?t.y1+t.y:t.y1:t.y}).concat(b))),$&&!_?g.range(a||[g.domain()[0]<0?C:0,h-(g.domain()[1]>0?C:0)]):g.range(a||[0,h]),s=s||p,u=u||d3.scale.linear().domain(g.domain()).range([g(0),g(0)]);var O=d3.select(this).selectAll("g.nv-wrap.nv-multibarHorizontal").data([e]),N=O.enter().append("g").attr("class","nvd3 nv-wrap nv-multibarHorizontal"),I=(N.append("defs"),N.append("g"));O.select("g");I.append("g").attr("class","nv-groups"),O.attr("transform","translate("+l.left+","+l.top+")");var P=O.select(".nv-groups").selectAll(".nv-group").data(function(t){return t},function(t,e){return e});P.enter().append("g").style("stroke-opacity",1e-6).style("fill-opacity",1e-6),P.exit().watchTransition(A,"multibarhorizontal: exit groups").style("stroke-opacity",1e-6).style("fill-opacity",1e-6).remove(),P.attr("class",function(t,e){return"nv-group nv-series-"+e}).classed("hover",function(t){return t.hover}).style("fill",function(t,e){return x(t,e)}).style("stroke",function(t,e){return x(t,e)}),P.watchTransition(A,"multibarhorizontal: groups").style("stroke-opacity",1).style("fill-opacity",.75);var F=P.selectAll("g.nv-bar").data(function(t){return t.values});F.exit().remove();var W=F.enter().append("g").attr("transform",function(t,n,i){return"translate("+u(_?t.y0:0)+","+(_?0:i*p.rangeBand()/e.length+p(m(t,n)))+")"});W.append("rect").attr("width",0).attr("height",p.rangeBand()/(_?1:e.length)),F.on("mouseover",function(t,e){d3.select(this).classed("hover",!0),T.elementMouseover({data:t,index:e,color:d3.select(this).style("fill")})}).on("mouseout",function(t,e){d3.select(this).classed("hover",!1),T.elementMouseout({data:t,index:e,color:d3.select(this).style("fill")})}).on("mouseout",function(t,e){T.elementMouseout({data:t,index:e,color:d3.select(this).style("fill")})}).on("mousemove",function(t,e){T.elementMousemove({data:t,index:e,color:d3.select(this).style("fill")})}).on("click",function(t,e){T.elementClick({data:t,index:e,color:d3.select(this).style("fill")}),d3.event.stopPropagation()}).on("dblclick",function(t,e){T.elementDblClick({data:t,index:e,color:d3.select(this).style("fill")}),d3.event.stopPropagation()}),y(e[0],0)&&(W.append("polyline"),F.select("polyline").attr("fill","none").attr("points",function(t,n){var i=y(t,n),r=.8*p.rangeBand()/(2*(_?1:e.length));i=i.length?i:[-Math.abs(i),Math.abs(i)],i=i.map(function(t){return g(t)-g(0)});var o=[[i[0],-r],[i[0],r],[i[0],0],[i[1],0],[i[1],-r],[i[1],r]];return o.map(function(t){return t.join(",")}).join(" ")}).attr("transform",function(t,n){var i=p.rangeBand()/(2*(_?1:e.length));return"translate("+(v(t,n)<0?0:g(v(t,n))-g(0))+", "+i+")"})),W.append("text"),$&&!_?(F.select("text").attr("text-anchor",function(t,e){return v(t,e)<0?"end":"start"}).attr("y",p.rangeBand()/(2*e.length)).attr("dy",".32em").text(function(t,e){var n=D(v(t,e)),i=y(t,e);return void 0===i?n:i.length?n+"+"+D(Math.abs(i[1]))+"-"+D(Math.abs(i[0])):n+"±"+D(Math.abs(i))}),F.watchTransition(A,"multibarhorizontal: bars").select("text").attr("x",function(t,e){return v(t,e)<0?-4:g(v(t,e))-g(0)+4})):F.selectAll("text").text(""),k&&!_?(W.append("text").classed("nv-bar-label",!0),F.select("text.nv-bar-label").attr("text-anchor",function(t,e){return v(t,e)<0?"start":"end"}).attr("y",p.rangeBand()/(2*e.length)).attr("dy",".32em").text(function(t,e){return m(t,e)}),F.watchTransition(A,"multibarhorizontal: bars").select("text.nv-bar-label").attr("x",function(t,e){return v(t,e)<0?g(0)-g(v(t,e))+4:-4})):F.selectAll("text.nv-bar-label").text(""),F.attr("class",function(t,e){return v(t,e)<0?"nv-bar negative":"nv-bar positive"}),w&&(n||(n=e.map(function(){return!0})),F.style("fill",function(t,e,i){return d3.rgb(w(t,e)).darker(n.map(function(t,e){return e}).filter(function(t,e){return!n[e]})[i]).toString()}).style("stroke",function(t,e,i){return d3.rgb(w(t,e)).darker(n.map(function(t,e){return e}).filter(function(t,e){return!n[e]})[i]).toString()})),_?F.watchTransition(A,"multibarhorizontal: bars").attr("transform",function(t,e){return"translate("+g(t.y1)+","+p(m(t,e))+")"}).select("rect").attr("width",function(t,e){return Math.abs(g(v(t,e)+t.y0)-g(t.y0))||0}).attr("height",p.rangeBand()):F.watchTransition(A,"multibarhorizontal: bars").attr("transform",function(t,n){return"translate("+g(v(t,n)<0?v(t,n):0)+","+(t.series*p.rangeBand()/e.length+p(m(t,n)))+")"}).select("rect").attr("height",p.rangeBand()/e.length).attr("width",function(t,e){return Math.max(Math.abs(g(v(t,e))-g(0)),1)||0}),s=p.copy(),u=g.copy()}),A.renderEnd("multibarHorizontal immediate"),e}var n,i,r,o,a,s,u,l={top:0,right:0,bottom:0,left:0},c=960,d=500,h=Math.floor(1e4*Math.random()),f=null,p=d3.scale.ordinal(),g=d3.scale.linear(),m=function(t){return t.x},v=function(t){return t.y},y=function(t){return t.yErr},b=[0],x=t.utils.defaultColor(),w=null,_=!1,$=!1,k=!1,C=60,M=.1,D=d3.format(",.2f"),S=250,T=d3.dispatch("chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove","renderEnd"),A=t.utils.renderWatch(T,S);return e.dispatch=T,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return c},set:function(t){c=t}},height:{get:function(){return d},set:function(t){d=t}},x:{get:function(){return m},set:function(t){m=t}},y:{get:function(){return v},set:function(t){v=t}},yErr:{get:function(){return y},set:function(t){y=t}},xScale:{get:function(){return p},set:function(t){p=t}},yScale:{get:function(){return g},set:function(t){g=t}},xDomain:{get:function(){return i},set:function(t){i=t}},yDomain:{get:function(){return r},set:function(t){r=t}},xRange:{get:function(){return o},set:function(t){o=t}},yRange:{get:function(){return a},set:function(t){a=t}},forceY:{get:function(){return b},set:function(t){b=t}},stacked:{get:function(){return _},set:function(t){_=t}},showValues:{get:function(){return $},set:function(t){$=t}},disabled:{get:function(){return n},set:function(t){n=t}},id:{get:function(){return h},set:function(t){h=t}},valueFormat:{get:function(){return D},set:function(t){D=t}},valuePadding:{get:function(){return C},set:function(t){C=t}},groupSpacing:{get:function(){return M},set:function(t){M=t}},margin:{get:function(){return l},set:function(t){l.top=void 0!==t.top?t.top:l.top,l.right=void 0!==t.right?t.right:l.right,l.bottom=void 0!==t.bottom?t.bottom:l.bottom,l.left=void 0!==t.left?t.left:l.left}},duration:{get:function(){return S},set:function(t){S=t,A.reset(S)}},color:{get:function(){return x},set:function(e){x=t.utils.getColor(e)}},barColor:{get:function(){return w},set:function(e){w=e?t.utils.getColor(e):null}}}),t.utils.initOptions(e),e},t.models.multiBarHorizontalChart=function(){"use strict";function e(l){return S.reset(),S.models(r),v&&S.models(o),y&&S.models(a),l.each(function(l){var _=d3.select(this);t.utils.initSVG(_);var S=t.utils.availableWidth(d,_,c),T=t.utils.availableHeight(h,_,c);if(e.update=function(){_.transition().duration(C).call(e)},e.container=this,b=r.stacked(),x.setter(D(l),e.update).getter(M(l)).update(),x.disabled=l.map(function(t){return!!t.disabled}),!w){var A;w={};for(A in x)x[A]instanceof Array?w[A]=x[A].slice(0):w[A]=x[A]}if(!(l&&l.length&&l.filter(function(t){return t.values.length}).length))return t.utils.noData(e,_),e;_.selectAll(".nv-noData").remove(),n=r.xScale(),i=r.yScale().clamp(!0);var E=_.selectAll("g.nv-wrap.nv-multiBarHorizontalChart").data([l]),O=E.enter().append("g").attr("class","nvd3 nv-wrap nv-multiBarHorizontalChart").append("g"),N=E.select("g");if(O.append("g").attr("class","nv-x nv-axis"),O.append("g").attr("class","nv-y nv-axis").append("g").attr("class","nv-zeroLine").append("line"),O.append("g").attr("class","nv-barsWrap"),
O.append("g").attr("class","nv-legendWrap"),O.append("g").attr("class","nv-controlsWrap"),m&&(s.width(S-k()),N.select(".nv-legendWrap").datum(l).call(s),c.top!=s.height()&&(c.top=s.height(),T=t.utils.availableHeight(h,_,c)),N.select(".nv-legendWrap").attr("transform","translate("+k()+","+-c.top+")")),p){var I=[{key:g.grouped||"Grouped",disabled:r.stacked()},{key:g.stacked||"Stacked",disabled:!r.stacked()}];u.width(k()).color(["#444","#444","#444"]),N.select(".nv-controlsWrap").datum(I).attr("transform","translate(0,"+-c.top+")").call(u)}E.attr("transform","translate("+c.left+","+c.top+")"),r.disabled(l.map(function(t){return t.disabled})).width(S).height(T).color(l.map(function(t,e){return t.color||f(t,e)}).filter(function(t,e){return!l[e].disabled}));var P=N.select(".nv-barsWrap").datum(l.filter(function(t){return!t.disabled}));if(P.transition().call(r),v){o.scale(n)._ticks(t.utils.calcTicksY(T/24,l)).tickSize(-S,0),N.select(".nv-x.nv-axis").call(o);var F=N.select(".nv-x.nv-axis").selectAll("g");F.selectAll("line, text")}y&&(a.scale(i)._ticks(t.utils.calcTicksX(S/100,l)).tickSize(-T,0),N.select(".nv-y.nv-axis").attr("transform","translate(0,"+T+")"),N.select(".nv-y.nv-axis").call(a)),N.select(".nv-zeroLine line").attr("x1",i(0)).attr("x2",i(0)).attr("y1",0).attr("y2",-T),s.dispatch.on("stateChange",function(t){for(var n in t)x[n]=t[n];$.stateChange(x),e.update()}),u.dispatch.on("legendClick",function(t,n){if(t.disabled){switch(I=I.map(function(t){return t.disabled=!0,t}),t.disabled=!1,t.key){case"Grouped":case g.grouped:r.stacked(!1);break;case"Stacked":case g.stacked:r.stacked(!0)}x.stacked=r.stacked(),$.stateChange(x),b=r.stacked(),e.update()}}),$.on("changeState",function(t){"undefined"!=typeof t.disabled&&(l.forEach(function(e,n){e.disabled=t.disabled[n]}),x.disabled=t.disabled),"undefined"!=typeof t.stacked&&(r.stacked(t.stacked),x.stacked=t.stacked,b=t.stacked),e.update()})}),S.renderEnd("multibar horizontal chart immediate"),e}var n,i,r=t.models.multiBarHorizontal(),o=t.models.axis(),a=t.models.axis(),s=t.models.legend().height(30),u=t.models.legend().height(30),l=t.models.tooltip(),c={top:30,right:20,bottom:50,left:60},d=null,h=null,f=t.utils.defaultColor(),p=!0,g={},m=!0,v=!0,y=!0,b=!1,x=t.utils.state(),w=null,_=null,$=d3.dispatch("stateChange","changeState","renderEnd"),k=function(){return p?180:0},C=250;x.stacked=!1,r.stacked(b),o.orient("left").tickPadding(5).showMaxMin(!1).tickFormat(function(t){return t}),a.orient("bottom").tickFormat(d3.format(",.1f")),l.duration(0).valueFormatter(function(t,e){return a.tickFormat()(t,e)}).headerFormatter(function(t,e){return o.tickFormat()(t,e)}),u.updateState(!1);var M=function(t){return function(){return{active:t.map(function(t){return!t.disabled}),stacked:b}}},D=function(t){return function(e){void 0!==e.stacked&&(b=e.stacked),void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}},S=t.utils.renderWatch($,C);return r.dispatch.on("elementMouseover.tooltip",function(t){t.value=e.x()(t.data),t.series={key:t.data.key,value:e.y()(t.data),color:t.color},l.data(t).hidden(!1)}),r.dispatch.on("elementMouseout.tooltip",function(t){l.hidden(!0)}),r.dispatch.on("elementMousemove.tooltip",function(t){l()}),e.dispatch=$,e.multibar=r,e.legend=s,e.controls=u,e.xAxis=o,e.yAxis=a,e.state=x,e.tooltip=l,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return d},set:function(t){d=t}},height:{get:function(){return h},set:function(t){h=t}},showLegend:{get:function(){return m},set:function(t){m=t}},showControls:{get:function(){return p},set:function(t){p=t}},controlLabels:{get:function(){return g},set:function(t){g=t}},showXAxis:{get:function(){return v},set:function(t){v=t}},showYAxis:{get:function(){return y},set:function(t){y=t}},defaultState:{get:function(){return w},set:function(t){w=t}},noData:{get:function(){return _},set:function(t){_=t}},margin:{get:function(){return c},set:function(t){c.top=void 0!==t.top?t.top:c.top,c.right=void 0!==t.right?t.right:c.right,c.bottom=void 0!==t.bottom?t.bottom:c.bottom,c.left=void 0!==t.left?t.left:c.left}},duration:{get:function(){return C},set:function(t){C=t,S.reset(C),r.duration(C),o.duration(C),a.duration(C)}},color:{get:function(){return f},set:function(e){f=t.utils.getColor(e),s.color(f)}},barColor:{get:function(){return r.barColor},set:function(t){r.barColor(t),s.color(function(t,e){return d3.rgb("#ccc").darker(1.5*e).toString()})}}}),t.utils.inheritOptions(e,r),t.utils.initOptions(e),e},t.models.multiChart=function(){"use strict";function e(l){return l.each(function(l){function f(t){var e=2===l[t.seriesIndex].yAxis?A:T;t.value=t.point.x,t.series={value:t.point.y,color:t.point.color,key:t.series.key},O.duration(0).valueFormatter(function(t,n){return e.tickFormat()(t,n)}).data(t).hidden(!1)}function N(t){var e=2===l[t.seriesIndex].yAxis?A:T;t.value=t.point.x,t.series={value:t.point.y,color:t.point.color,key:t.series.key},O.duration(100).valueFormatter(function(t,n){return e.tickFormat()(t,n)}).data(t).hidden(!1)}function P(t){var e=2===l[t.seriesIndex].yAxis?A:T;t.point.x=M.x()(t.point),t.point.y=M.y()(t.point),O.duration(0).valueFormatter(function(t,n){return e.tickFormat()(t,n)}).data(t).hidden(!1)}function F(t){var e=2===l[t.data.series].yAxis?A:T;t.value=k.x()(t.data),t.series={value:k.y()(t.data),color:t.color,key:t.data.key},O.duration(0).valueFormatter(function(t,n){return e.tickFormat()(t,n)}).data(t).hidden(!1)}function W(){for(var t=0,e=I.length;e>t;t++){var n=I[t];try{n.clearHighlights()}catch(i){}}}function H(t,e,n){for(var i=0,r=I.length;r>i;i++){var o=I[i];try{o.highlightPoint(t,e,n)}catch(a){}}}var L=d3.select(this);t.utils.initSVG(L),e.update=function(){L.transition().call(e)},e.container=this;var z=t.utils.availableWidth(a,L,r),j=t.utils.availableHeight(s,L,r),R=l.filter(function(t){return"line"==t.type&&1==t.yAxis}),U=l.filter(function(t){return"line"==t.type&&2==t.yAxis}),q=l.filter(function(t){return"scatter"==t.type&&1==t.yAxis}),B=l.filter(function(t){return"scatter"==t.type&&2==t.yAxis}),V=l.filter(function(t){return"bar"==t.type&&1==t.yAxis}),Y=l.filter(function(t){return"bar"==t.type&&2==t.yAxis}),G=l.filter(function(t){return"area"==t.type&&1==t.yAxis}),X=l.filter(function(t){return"area"==t.type&&2==t.yAxis});if(!(l&&l.length&&l.filter(function(t){return t.values.length}).length))return t.utils.noData(e,L),e;L.selectAll(".nv-noData").remove();var K=l.filter(function(t){return!t.disabled&&1==t.yAxis}).map(function(t){return t.values.map(function(t,e){return{x:c(t),y:d(t)}})}),Z=l.filter(function(t){return!t.disabled&&2==t.yAxis}).map(function(t){return t.values.map(function(t,e){return{x:c(t),y:d(t)}})});v.domain(d3.extent(d3.merge(K.concat(Z)),function(t){return c(t)})).range([0,z]);var Q=L.selectAll("g.wrap.multiChart").data([l]),J=Q.enter().append("g").attr("class","wrap nvd3 multiChart").append("g");J.append("g").attr("class","nv-x nv-axis"),J.append("g").attr("class","nv-y1 nv-axis"),J.append("g").attr("class","nv-y2 nv-axis"),J.append("g").attr("class","stack1Wrap"),J.append("g").attr("class","stack2Wrap"),J.append("g").attr("class","bars1Wrap"),J.append("g").attr("class","bars2Wrap"),J.append("g").attr("class","scatters1Wrap"),J.append("g").attr("class","scatters2Wrap"),J.append("g").attr("class","lines1Wrap"),J.append("g").attr("class","lines2Wrap"),J.append("g").attr("class","legendWrap"),J.append("g").attr("class","nv-interactive");var tt=Q.select("g"),et=l.map(function(t,e){return l[e].color||o(t,e)});if(u){var nt=E.align()?z/2:z,it=E.align()?nt:0;E.width(nt),E.color(et),tt.select(".legendWrap").datum(l.map(function(t){return t.originalKey=void 0===t.originalKey?t.key:t.originalKey,t.key=t.originalKey+(1==t.yAxis?"":m),t})).call(E),r.top!=E.height()&&(r.top=E.height(),j=t.utils.availableHeight(s,L,r)),tt.select(".legendWrap").attr("transform","translate("+it+","+-r.top+")")}x.width(z).height(j).interpolate(h).color(et.filter(function(t,e){return!l[e].disabled&&1==l[e].yAxis&&"line"==l[e].type})),w.width(z).height(j).interpolate(h).color(et.filter(function(t,e){return!l[e].disabled&&2==l[e].yAxis&&"line"==l[e].type})),_.width(z).height(j).color(et.filter(function(t,e){return!l[e].disabled&&1==l[e].yAxis&&"scatter"==l[e].type})),$.width(z).height(j).color(et.filter(function(t,e){return!l[e].disabled&&2==l[e].yAxis&&"scatter"==l[e].type})),k.width(z).height(j).color(et.filter(function(t,e){return!l[e].disabled&&1==l[e].yAxis&&"bar"==l[e].type})),C.width(z).height(j).color(et.filter(function(t,e){return!l[e].disabled&&2==l[e].yAxis&&"bar"==l[e].type})),M.width(z).height(j).color(et.filter(function(t,e){return!l[e].disabled&&1==l[e].yAxis&&"area"==l[e].type})),D.width(z).height(j).color(et.filter(function(t,e){return!l[e].disabled&&2==l[e].yAxis&&"area"==l[e].type})),tt.attr("transform","translate("+r.left+","+r.top+")");var rt=tt.select(".lines1Wrap").datum(R.filter(function(t){return!t.disabled})),ot=tt.select(".scatters1Wrap").datum(q.filter(function(t){return!t.disabled})),at=tt.select(".bars1Wrap").datum(V.filter(function(t){return!t.disabled})),st=tt.select(".stack1Wrap").datum(G.filter(function(t){return!t.disabled})),ut=tt.select(".lines2Wrap").datum(U.filter(function(t){return!t.disabled})),lt=tt.select(".scatters2Wrap").datum(B.filter(function(t){return!t.disabled})),ct=tt.select(".bars2Wrap").datum(Y.filter(function(t){return!t.disabled})),dt=tt.select(".stack2Wrap").datum(X.filter(function(t){return!t.disabled})),ht=G.length?G.map(function(t){return t.values}).reduce(function(t,e){return t.map(function(t,n){return{x:t.x,y:t.y+e[n].y}})}).concat([{x:0,y:0}]):[],ft=X.length?X.map(function(t){return t.values}).reduce(function(t,e){return t.map(function(t,n){return{x:t.x,y:t.y+e[n].y}})}).concat([{x:0,y:0}]):[];y.domain(n||d3.extent(d3.merge(K).concat(ht),function(t){return t.y})).range([0,j]),b.domain(i||d3.extent(d3.merge(Z).concat(ft),function(t){return t.y})).range([0,j]),x.yDomain(y.domain()),_.yDomain(y.domain()),k.yDomain(y.domain()),M.yDomain(y.domain()),w.yDomain(b.domain()),$.yDomain(b.domain()),C.yDomain(b.domain()),D.yDomain(b.domain()),G.length&&d3.transition(st).call(M),X.length&&d3.transition(dt).call(D),V.length&&d3.transition(at).call(k),Y.length&&d3.transition(ct).call(C),R.length&&d3.transition(rt).call(x),U.length&&d3.transition(ut).call(w),q.length&&d3.transition(ot).call(_),B.length&&d3.transition(lt).call($),S._ticks(t.utils.calcTicksX(z/100,l)).tickSize(-j,0),tt.select(".nv-x.nv-axis").attr("transform","translate(0,"+j+")"),d3.transition(tt.select(".nv-x.nv-axis")).call(S),T._ticks(t.utils.calcTicksY(j/36,l)).tickSize(-z,0),d3.transition(tt.select(".nv-y1.nv-axis")).call(T),A._ticks(t.utils.calcTicksY(j/36,l)).tickSize(-z,0),d3.transition(tt.select(".nv-y2.nv-axis")).call(A),tt.select(".nv-y1.nv-axis").classed("nv-disabled",K.length?!1:!0).attr("transform","translate("+v.range()[0]+",0)"),tt.select(".nv-y2.nv-axis").classed("nv-disabled",Z.length?!1:!0).attr("transform","translate("+v.range()[1]+",0)"),E.dispatch.on("stateChange",function(t){e.update()}),g&&(p.width(z).height(j).margin({left:r.left,top:r.top}).svgContainer(L).xScale(v),Q.select(".nv-interactive").call(p)),g?(p.dispatch.on("elementMousemove",function(n){W();var i,r,a,s=[];l.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(u,l){var c=v.domain(),d=u.values.filter(function(t,n){return e.x()(t,n)>=c[0]&&e.x()(t,n)<=c[1]});r=t.interactiveBisect(d,n.pointXValue,e.x());var h=d[r],f=e.y()(h,r);null!==f&&H(l,r,!0),void 0!==h&&(void 0===i&&(i=h),void 0===a&&(a=v(e.x()(h,r))),s.push({key:u.key,value:f,color:o(u,u.seriesIndex),data:h,yAxis:2==u.yAxis?A:T}))}),p.tooltip.chartContainer(e.container.parentNode).valueFormatter(function(t,e){var n=s[e].yAxis;return null===t?"N/A":n.tickFormat()(t)}).data({value:e.x()(i,r),index:r,series:s})(),p.renderGuideLine(a)}),p.dispatch.on("elementMouseout",function(t){W()})):(x.dispatch.on("elementMouseover.tooltip",f),w.dispatch.on("elementMouseover.tooltip",f),x.dispatch.on("elementMouseout.tooltip",function(t){O.hidden(!0)}),w.dispatch.on("elementMouseout.tooltip",function(t){O.hidden(!0)}),_.dispatch.on("elementMouseover.tooltip",N),$.dispatch.on("elementMouseover.tooltip",N),_.dispatch.on("elementMouseout.tooltip",function(t){O.hidden(!0)}),$.dispatch.on("elementMouseout.tooltip",function(t){O.hidden(!0)}),M.dispatch.on("elementMouseover.tooltip",P),D.dispatch.on("elementMouseover.tooltip",P),M.dispatch.on("elementMouseout.tooltip",function(t){O.hidden(!0)}),D.dispatch.on("elementMouseout.tooltip",function(t){O.hidden(!0)}),k.dispatch.on("elementMouseover.tooltip",F),C.dispatch.on("elementMouseover.tooltip",F),k.dispatch.on("elementMouseout.tooltip",function(t){O.hidden(!0)}),C.dispatch.on("elementMouseout.tooltip",function(t){O.hidden(!0)}),k.dispatch.on("elementMousemove.tooltip",function(t){O()}),C.dispatch.on("elementMousemove.tooltip",function(t){O()}))}),e}var n,i,r={top:30,right:20,bottom:50,left:60},o=t.utils.defaultColor(),a=null,s=null,u=!0,l=null,c=function(t){return t.x},d=function(t){return t.y},h="monotone",f=!0,p=t.interactiveGuideline(),g=!1,m=" (right axis)",v=d3.scale.linear(),y=d3.scale.linear(),b=d3.scale.linear(),x=t.models.line().yScale(y),w=t.models.line().yScale(b),_=t.models.scatter().yScale(y),$=t.models.scatter().yScale(b),k=t.models.multiBar().stacked(!1).yScale(y),C=t.models.multiBar().stacked(!1).yScale(b),M=t.models.stackedArea().yScale(y),D=t.models.stackedArea().yScale(b),S=t.models.axis().scale(v).orient("bottom").tickPadding(5),T=t.models.axis().scale(y).orient("left"),A=t.models.axis().scale(b).orient("right"),E=t.models.legend().height(30),O=t.models.tooltip(),N=d3.dispatch(),I=[x,w,_,$,k,C,M,D];return e.dispatch=N,e.legend=E,e.lines1=x,e.lines2=w,e.scatters1=_,e.scatters2=$,e.bars1=k,e.bars2=C,e.stack1=M,e.stack2=D,e.xAxis=S,e.yAxis1=T,e.yAxis2=A,e.tooltip=O,e.interactiveLayer=p,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return a},set:function(t){a=t}},height:{get:function(){return s},set:function(t){s=t}},showLegend:{get:function(){return u},set:function(t){u=t}},yDomain1:{get:function(){return n},set:function(t){n=t}},yDomain2:{get:function(){return i},set:function(t){i=t}},noData:{get:function(){return l},set:function(t){l=t}},interpolate:{get:function(){return h},set:function(t){h=t}},legendRightAxisHint:{get:function(){return m},set:function(t){m=t}},margin:{get:function(){return r},set:function(t){r.top=void 0!==t.top?t.top:r.top,r.right=void 0!==t.right?t.right:r.right,r.bottom=void 0!==t.bottom?t.bottom:r.bottom,r.left=void 0!==t.left?t.left:r.left}},color:{get:function(){return o},set:function(e){o=t.utils.getColor(e)}},x:{get:function(){return c},set:function(t){c=t,x.x(t),w.x(t),_.x(t),$.x(t),k.x(t),C.x(t),M.x(t),D.x(t)}},y:{get:function(){return d},set:function(t){d=t,x.y(t),w.y(t),_.y(t),$.y(t),M.y(t),D.y(t),k.y(t),C.y(t)}},useVoronoi:{get:function(){return f},set:function(t){f=t,x.useVoronoi(t),w.useVoronoi(t),M.useVoronoi(t),D.useVoronoi(t)}},useInteractiveGuideline:{get:function(){return g},set:function(t){g=t,g&&(x.interactive(!1),x.useVoronoi(!1),w.interactive(!1),w.useVoronoi(!1),M.interactive(!1),M.useVoronoi(!1),D.interactive(!1),D.useVoronoi(!1),_.interactive(!1),$.interactive(!1))}}}),t.utils.initOptions(e),e},t.models.ohlcBar=function(){"use strict";function e(k){return k.each(function(e){c=d3.select(this);var k=t.utils.availableWidth(s,c,a),M=t.utils.availableHeight(u,c,a);t.utils.initSVG(c);var D=k/e[0].values.length*.9;d.domain(n||d3.extent(e[0].values.map(f).concat(b))),w?d.range(r||[.5*k/e[0].values.length,k*(e[0].values.length-.5)/e[0].values.length]):d.range(r||[5+D/2,k-D/2-5]),h.domain(i||[d3.min(e[0].values.map(y).concat(x)),d3.max(e[0].values.map(v).concat(x))]).range(o||[M,0]),d.domain()[0]===d.domain()[1]&&(d.domain()[0]?d.domain([d.domain()[0]-.01*d.domain()[0],d.domain()[1]+.01*d.domain()[1]]):d.domain([-1,1])),h.domain()[0]===h.domain()[1]&&(h.domain()[0]?h.domain([h.domain()[0]+.01*h.domain()[0],h.domain()[1]-.01*h.domain()[1]]):h.domain([-1,1]));var S=d3.select(this).selectAll("g.nv-wrap.nv-ohlcBar").data([e[0].values]),T=S.enter().append("g").attr("class","nvd3 nv-wrap nv-ohlcBar"),A=T.append("defs"),E=T.append("g"),O=S.select("g");E.append("g").attr("class","nv-ticks"),S.attr("transform","translate("+a.left+","+a.top+")"),c.on("click",function(t,e){C.chartClick({data:t,index:e,pos:d3.event,id:l})}),A.append("clipPath").attr("id","nv-chart-clip-path-"+l).append("rect"),S.select("#nv-chart-clip-path-"+l+" rect").attr("width",k).attr("height",M),O.attr("clip-path",_?"url(#nv-chart-clip-path-"+l+")":"");var N=S.select(".nv-ticks").selectAll(".nv-tick").data(function(t){return t});N.exit().remove(),N.enter().append("path").attr("class",function(t,e,n){return(g(t,e)>m(t,e)?"nv-tick negative":"nv-tick positive")+" nv-tick-"+n+"-"+e}).attr("d",function(t,e){return"m0,0l0,"+(h(g(t,e))-h(v(t,e)))+"l"+-D/2+",0l"+D/2+",0l0,"+(h(y(t,e))-h(g(t,e)))+"l0,"+(h(m(t,e))-h(y(t,e)))+"l"+D/2+",0l"+-D/2+",0z"}).attr("transform",function(t,e){return"translate("+d(f(t,e))+","+h(v(t,e))+")"}).attr("fill",function(t,e){return $[0]}).attr("stroke",function(t,e){return $[0]}).attr("x",0).attr("y",function(t,e){return h(Math.max(0,p(t,e)))}).attr("height",function(t,e){return Math.abs(h(p(t,e))-h(0))}),N.attr("class",function(t,e,n){return(g(t,e)>m(t,e)?"nv-tick negative":"nv-tick positive")+" nv-tick-"+n+"-"+e}),d3.transition(N).attr("transform",function(t,e){return"translate("+d(f(t,e))+","+h(v(t,e))+")"}).attr("d",function(t,n){var i=k/e[0].values.length*.9;return"m0,0l0,"+(h(g(t,n))-h(v(t,n)))+"l"+-i/2+",0l"+i/2+",0l0,"+(h(y(t,n))-h(g(t,n)))+"l0,"+(h(m(t,n))-h(y(t,n)))+"l"+i/2+",0l"+-i/2+",0z"})}),e}var n,i,r,o,a={top:0,right:0,bottom:0,left:0},s=null,u=null,l=Math.floor(1e4*Math.random()),c=null,d=d3.scale.linear(),h=d3.scale.linear(),f=function(t){return t.x},p=function(t){return t.y},g=function(t){return t.open},m=function(t){return t.close},v=function(t){return t.high},y=function(t){return t.low},b=[],x=[],w=!1,_=!0,$=t.utils.defaultColor(),k=!1,C=d3.dispatch("stateChange","changeState","renderEnd","chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove");return e.highlightPoint=function(t,n){e.clearHighlights(),c.select(".nv-ohlcBar .nv-tick-0-"+t).classed("hover",n)},e.clearHighlights=function(){c.select(".nv-ohlcBar .nv-tick.hover").classed("hover",!1)},e.dispatch=C,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return s},set:function(t){s=t}},height:{get:function(){return u},set:function(t){u=t}},xScale:{get:function(){return d},set:function(t){d=t}},yScale:{get:function(){return h},set:function(t){h=t}},xDomain:{get:function(){return n},set:function(t){n=t}},yDomain:{get:function(){return i},set:function(t){i=t}},xRange:{get:function(){return r},set:function(t){r=t}},yRange:{get:function(){return o},set:function(t){o=t}},forceX:{get:function(){return b},set:function(t){b=t}},forceY:{get:function(){return x},set:function(t){x=t}},padData:{get:function(){return w},set:function(t){w=t}},clipEdge:{get:function(){return _},set:function(t){_=t}},id:{get:function(){return l},set:function(t){l=t}},interactive:{get:function(){return k},set:function(t){k=t}},x:{get:function(){return f},set:function(t){f=t}},y:{get:function(){return p},set:function(t){p=t}},open:{get:function(){return g()},set:function(t){g=t}},close:{get:function(){return m()},set:function(t){m=t}},high:{get:function(){return v},set:function(t){v=t}},low:{get:function(){return y},set:function(t){y=t}},margin:{get:function(){return a},set:function(t){a.top=void 0!=t.top?t.top:a.top,a.right=void 0!=t.right?t.right:a.right,a.bottom=void 0!=t.bottom?t.bottom:a.bottom,a.left=void 0!=t.left?t.left:a.left}},color:{get:function(){return $},set:function(e){$=t.utils.getColor(e)}}}),t.utils.initOptions(e),e},t.models.parallelCoordinates=function(){"use strict";function e(k){return $.reset(),k.each(function(e){function $(t){return x(d.map(function(e){if(isNaN(t.values[e.key])||isNaN(parseFloat(t.values[e.key]))||H){var n=l[e.key].domain(),i=l[e.key].range(),r=n[0]-(n[1]-n[0])/9;if(y.indexOf(e.key)<0){var o=d3.scale.linear().domain([r,n[1]]).range([I-12,i[1]]);l[e.key].brush.y(o),y.push(e.key)}if(isNaN(t.values[e.key])||isNaN(parseFloat(t.values[e.key])))return[u(e.key),l[e.key](r)]}return void 0!==U&&(y.length>0||H?(U.style("display","inline"),q.style("display","inline")):(U.style("display","none"),q.style("display","none"))),[u(e.key),l[e.key](t.values[e.key])]}))}function k(t){g.forEach(function(e){var n=l[e.dimension].brush.y().domain();e.hasOnlyNaN&&(e.extent[1]=(l[e.dimension].domain()[1]-n[0])*(e.extent[1]-e.extent[0])/(W[e.dimension]-e.extent[0])+n[0]),e.hasNaN&&(e.extent[0]=n[0]),t&&l[e.dimension].brush.extent(e.extent)}),r.select(".nv-brushBackground").each(function(t){d3.select(this).call(l[t.key].brush)}).selectAll("rect").attr("x",-8).attr("width",16)}function C(){f===!1&&k(!0)}function M(){X=h.filter(function(t){return!l[t].brush.empty()}),K=X.map(function(t){return l[t].brush.extent()}),g=[],X.forEach(function(t,e){g[e]={dimension:t,extent:K[e],hasNaN:!1,hasOnlyNaN:!1}}),m=[],n.style("display",function(t){var e=X.every(function(e,n){return(isNaN(t.values[e])||isNaN(parseFloat(t.values[e])))&&K[n][0]==l[e].brush.y().domain()[0]?!0:K[n][0]<=t.values[e]&&t.values[e]<=K[n][1]&&!isNaN(parseFloat(t.values[e]))});return e&&m.push(t),e?null:"none"}),_.brush({filters:g,active:m})}function D(){var t=X.length>0?!0:!1;g.forEach(function(t){t.extent[0]===l[t.dimension].brush.y().domain()[0]&&y.indexOf(t.dimension)>=0&&(t.hasNaN=!0),t.extent[1]<l[t.dimension].domain()[0]&&(t.hasOnlyNaN=!0)}),_.brushEnd(m,t)}function S(t){v[t.key]=this.parentNode.__origin__=u(t.key),i.attr("visibility","hidden")}function T(t){v[t.key]=Math.min(N,Math.max(0,this.parentNode.__origin__+=d3.event.x)),n.attr("d",$),d.sort(function(t,e){return E(t.key)-E(e.key)}),d.forEach(function(t,e){return t.currentPosition=e}),u.domain(d.map(function(t){return t.key})),r.attr("transform",function(t){return"translate("+E(t.key)+")"})}function A(t,e){delete this.parentNode.__origin__,delete v[t.key],d3.select(this.parentNode).attr("transform","translate("+u(t.key)+")"),n.attr("d",$),i.attr("d",$).attr("visibility",null),_.dimensionsOrder(d)}function E(t){var e=v[t];return null==e?u(t):e}var O=d3.select(this),N=t.utils.availableWidth(a,O,o),I=t.utils.availableHeight(s,O,o);if(t.utils.initSVG(O),void 0===e[0].values){var P=[];e.forEach(function(t){var e={},n=Object.keys(t);n.forEach(function(n){"name"!==n&&(e[n]=t[n])}),P.push({key:t.name,values:e})}),e=P}var F=e.map(function(t){return t.values});0===m.length&&(m=e),h=c.sort(function(t,e){return t.currentPosition-e.currentPosition}).map(function(t){return t.key}),d=c.filter(function(t){return!t.disabled}),u.rangePoints([0,N],1).domain(d.map(function(t){return t.key}));var W={},H=!1;h.forEach(function(t){var e=d3.extent(F,function(e){return+e[t]}),n=e[0],i=e[1],r=!1;(isNaN(n)||isNaN(i))&&(r=!0,n=0,i=0),n===i&&(n-=1,i+=1);var o=g.filter(function(e){return e.dimension==t});0!==o.length&&(r?(n=l[t].domain()[0],i=l[t].domain()[1]):!o[0].hasOnlyNaN&&f?(n=n>o[0].extent[0]?o[0].extent[0]:n,i=i<o[0].extent[1]?o[0].extent[1]:i):o[0].hasNaN&&(i=i<o[0].extent[1]?o[0].extent[1]:i,W[t]=l[t].domain()[1],H=!0)),l[t]=d3.scale.linear().domain([n,i]).range([.9*(I-12),0]),y=[],l[t].brush=d3.svg.brush().y(l[t]).on("brushstart",C).on("brush",M).on("brushend",D)});var L=O.selectAll("g.nv-wrap.nv-parallelCoordinates").data([e]),z=L.enter().append("g").attr("class","nvd3 nv-wrap nv-parallelCoordinates"),j=z.append("g"),R=L.select("g");j.append("g").attr("class","nv-parallelCoordinates background"),j.append("g").attr("class","nv-parallelCoordinates foreground"),j.append("g").attr("class","nv-parallelCoordinates missingValuesline"),L.attr("transform","translate("+o.left+","+o.top+")"),x.interpolate("cardinal").tension(b),w.orient("left");var U,q,B=d3.behavior.drag().on("dragstart",S).on("drag",T).on("dragend",A),V=u.range()[1]-u.range()[0];if(!isNaN(V)){var Y=[0+V/2,I-12,N-V/2,I-12];U=L.select(".missingValuesline").selectAll("line").data([Y]),U.enter().append("line"),U.exit().remove(),U.attr("x1",function(t){return t[0]}).attr("y1",function(t){return t[1]}).attr("x2",function(t){return t[2]}).attr("y2",function(t){return t[3]}),q=L.select(".missingValuesline").selectAll("text").data(["undefined values"]),q.append("text").data(["undefined values"]),q.enter().append("text"),q.exit().remove(),q.attr("y",I).attr("x",N-92-V/2).text(function(t){return t})}i=L.select(".background").selectAll("path").data(e),i.enter().append("path"),i.exit().remove(),i.attr("d",$),n=L.select(".foreground").selectAll("path").data(e),n.enter().append("path"),n.exit().remove(),n.attr("d",$).style("stroke-width",function(t,e){return isNaN(t.strokeWidth)&&(t.strokeWidth=1),t.strokeWidth}).attr("stroke",function(t,e){return t.color||p(t,e)}),n.on("mouseover",function(t,e){d3.select(this).classed("hover",!0).style("stroke-width",t.strokeWidth+2+"px").style("stroke-opacity",1),_.elementMouseover({label:t.name,color:t.color||p(t,e)})}),n.on("mouseout",function(t,e){d3.select(this).classed("hover",!1).style("stroke-width",t.strokeWidth+"px").style("stroke-opacity",.7),_.elementMouseout({label:t.name,index:e})}),n.on("mousemove",function(t,e){_.elementMousemove()}),n.on("click",function(t){_.elementClick({id:t.id})}),r=R.selectAll(".dimension").data(d);var G=r.enter().append("g").attr("class","nv-parallelCoordinates dimension");r.attr("transform",function(t){return"translate("+u(t.key)+",0)"}),G.append("g").attr("class","nv-axis"),G.append("text").attr("class","nv-label").style("cursor","move").attr("dy","-1em").attr("text-anchor","middle").on("mouseover",function(t,e){_.elementMouseover({label:t.tooltip||t.key})}).on("mouseout",function(t,e){_.elementMouseout({label:t.tooltip})}).on("mousemove",function(t,e){_.elementMousemove()}).call(B),G.append("g").attr("class","nv-brushBackground"),r.exit().remove(),r.select(".nv-label").text(function(t){return t.key}),r.select(".nv-axis").each(function(t,e){d3.select(this).call(w.scale(l[t.key]).tickFormat(d3.format(t.format)))}),k(f);var X=h.filter(function(t){return!l[t].brush.empty()}),K=X.map(function(t){return l[t].brush.extent()}),Z=m.slice(0);m=[],n.style("display",function(t){var e=X.every(function(e,n){return(isNaN(t.values[e])||isNaN(parseFloat(t.values[e])))&&K[n][0]==l[e].brush.y().domain()[0]?!0:K[n][0]<=t.values[e]&&t.values[e]<=K[n][1]&&!isNaN(parseFloat(t.values[e]))});return e&&m.push(t),e?null:"none"}),(g.length>0||!t.utils.arrayEquals(m,Z))&&_.activeChanged(m)}),e}var n,i,r,o={top:30,right:0,bottom:10,left:0},a=null,s=null,u=d3.scale.ordinal(),l={},c=[],d=[],h=[],f=!0,p=t.utils.defaultColor(),g=[],m=[],v=[],y=[],b=1,x=d3.svg.line(),w=d3.svg.axis(),_=d3.dispatch("brushstart","brush","brushEnd","dimensionsOrder","stateChange","elementClick","elementMouseover","elementMouseout","elementMousemove","renderEnd","activeChanged"),$=t.utils.renderWatch(_);return e.dispatch=_,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return a},set:function(t){a=t}},height:{get:function(){return s},set:function(t){s=t}},dimensionData:{get:function(){return c},set:function(t){c=t}},displayBrush:{get:function(){return f},set:function(t){f=t}},filters:{get:function(){return g},set:function(t){g=t}},active:{get:function(){return m},set:function(t){m=t}},lineTension:{get:function(){return b},set:function(t){b=t}},dimensions:{get:function(){return c.map(function(t){return t.key})},set:function(e){t.deprecated("dimensions","use dimensionData instead"),0===c.length?e.forEach(function(t){c.push({key:t})}):e.forEach(function(t,e){c[e].key=t})}},dimensionNames:{get:function(){return c.map(function(t){return t.key})},set:function(e){t.deprecated("dimensionNames","use dimensionData instead"),h=[],0===c.length?e.forEach(function(t){c.push({key:t})}):e.forEach(function(t,e){c[e].key=t})}},dimensionFormats:{get:function(){return c.map(function(t){return t.format})},set:function(e){t.deprecated("dimensionFormats","use dimensionData instead"),0===c.length?e.forEach(function(t){c.push({format:t})}):e.forEach(function(t,e){c[e].format=t})}},margin:{get:function(){return o},set:function(t){o.top=void 0!==t.top?t.top:o.top,o.right=void 0!==t.right?t.right:o.right,o.bottom=void 0!==t.bottom?t.bottom:o.bottom,o.left=void 0!==t.left?t.left:o.left}},color:{get:function(){return p},set:function(e){p=t.utils.getColor(e)}}}),t.utils.initOptions(e),e},t.models.parallelCoordinatesChart=function(){"use strict";function e(r){return v.reset(),v.models(n),r.each(function(r){var l=d3.select(this);t.utils.initSVG(l);var g=t.utils.availableWidth(a,l,o),v=t.utils.availableHeight(s,l,o);e.update=function(){l.call(e)},e.container=this,c.setter(b(d),e.update).getter(y(d)).update(),c.disabled=d.map(function(t){return!!t.disabled}),d=d.map(function(t){return t.disabled=!!t.disabled,t}),d.forEach(function(t,e){t.originalPosition=isNaN(t.originalPosition)?e:t.originalPosition,t.currentPosition=isNaN(t.currentPosition)?e:t.currentPosition});var x=h.map(function(t){return t.key}),w=d.map(function(t){return t.key});if(d.forEach(function(t,e){var n=x.indexOf(t.key);if(0>n)h.splice(e,0,t);else{var i=h[n].currentPosition-h[n].originalPosition;h[n].originalPosition=t.originalPosition,h[n].currentPosition=t.originalPosition+i}}),h=h.filter(function(t){return w.indexOf(t.key)>=0}),!p){var _;p={};for(_ in c)c[_]instanceof Array?p[_]=c[_].slice(0):p[_]=c[_]}if(!r||!r.length)return t.utils.noData(e,l),e;l.selectAll(".nv-noData").remove();var $=l.selectAll("g.nv-wrap.nv-parallelCoordinatesChart").data([r]),k=$.enter().append("g").attr("class","nvd3 nv-wrap nv-parallelCoordinatesChart").append("g"),C=$.select("g");k.append("g").attr("class","nv-parallelCoordinatesWrap"),k.append("g").attr("class","nv-legendWrap"),C.select("rect").attr("width",g).attr("height",v>0?v:0),u&&(i.width(g).color(function(t){return"rgb(188,190,192)"}),C.select(".nv-legendWrap").datum(h.sort(function(t,e){return t.originalPosition-e.originalPosition})).call(i),o.top!=i.height()&&(o.top=i.height(),v=t.utils.availableHeight(s,l,o)),$.select(".nv-legendWrap").attr("transform","translate( 0 ,"+-o.top+")")),$.attr("transform","translate("+o.left+","+o.top+")"),n.width(g).height(v).dimensionData(h).displayBrush(f);var M=C.select(".nv-parallelCoordinatesWrap ").datum(r);M.transition().call(n),n.dispatch.on("brushEnd",function(t,e){e?(f=!0,m.brushEnd(t)):f=!1}),i.dispatch.on("stateChange",function(t){for(var n in t)c[n]=t[n];m.stateChange(c),e.update()}),n.dispatch.on("dimensionsOrder",function(t){h.sort(function(t,e){return t.currentPosition-e.currentPosition});var e=!1;h.forEach(function(t,n){t.currentPosition=n,t.currentPosition!==t.originalPosition&&(e=!0)}),m.dimensionsOrder(h,e)}),m.on("changeState",function(t){"undefined"!=typeof t.disabled&&(h.forEach(function(e,n){e.disabled=t.disabled[n]}),c.disabled=t.disabled),e.update()})}),v.renderEnd("parraleleCoordinateChart immediate"),e}var n=t.models.parallelCoordinates(),i=t.models.legend(),r=t.models.tooltip(),o=(t.models.tooltip(),{top:0,right:0,bottom:0,left:0}),a=null,s=null,u=!0,l=t.utils.defaultColor(),c=t.utils.state(),d=[],h=[],f=!0,p=null,g=null,m=d3.dispatch("dimensionsOrder","brushEnd","stateChange","changeState","renderEnd"),v=t.utils.renderWatch(m),y=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},b=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return n.dispatch.on("elementMouseover.tooltip",function(t){t.series={key:t.label,color:t.color},r.data(t).hidden(!1)}),n.dispatch.on("elementMouseout.tooltip",function(t){r.hidden(!0)}),n.dispatch.on("elementMousemove.tooltip",function(){r()}),e.dispatch=m,e.parallelCoordinates=n,e.legend=i,e.tooltip=r,
e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return a},set:function(t){a=t}},height:{get:function(){return s},set:function(t){s=t}},showLegend:{get:function(){return u},set:function(t){u=t}},defaultState:{get:function(){return p},set:function(t){p=t}},dimensionData:{get:function(){return d},set:function(t){d=t}},displayBrush:{get:function(){return f},set:function(t){f=t}},noData:{get:function(){return g},set:function(t){g=t}},margin:{get:function(){return o},set:function(t){o.top=void 0!==t.top?t.top:o.top,o.right=void 0!==t.right?t.right:o.right,o.bottom=void 0!==t.bottom?t.bottom:o.bottom,o.left=void 0!==t.left?t.left:o.left}},color:{get:function(){return l},set:function(e){l=t.utils.getColor(e),i.color(l),n.color(l)}}}),t.utils.inheritOptions(e,n),t.utils.initOptions(e),e},t.models.pie=function(){"use strict";function e(A){return T.reset(),A.each(function(e){function A(t,e){t.endAngle=isNaN(t.endAngle)?0:t.endAngle,t.startAngle=isNaN(t.startAngle)?0:t.startAngle,g||(t.innerRadius=0);var n=d3.interpolate(this._current,t);return this._current=n(0),function(t){return D[e](n(t))}}var E=i-n.left-n.right,O=r-n.top-n.bottom,N=Math.min(E,O)/2,I=[],P=[];if(u=d3.select(this),0===C.length)for(var F=N-N/5,W=k*N,H=0;H<e[0].length;H++)I.push(F),P.push(W);else I=C.map(function(t){return(t.outer-t.outer/5)*N}),P=C.map(function(t){return(t.inner-t.inner/5)*N}),k=d3.min(C.map(function(t){return t.inner-t.inner/5}));t.utils.initSVG(u);var L=u.selectAll(".nv-wrap.nv-pie").data(e),z=L.enter().append("g").attr("class","nvd3 nv-wrap nv-pie nv-chart-"+s),j=z.append("g"),R=L.select("g"),U=j.append("g").attr("class","nv-pie");j.append("g").attr("class","nv-pieLabels"),L.attr("transform","translate("+n.left+","+n.top+")"),R.select(".nv-pie").attr("transform","translate("+E/2+","+O/2+")"),R.select(".nv-pieLabels").attr("transform","translate("+E/2+","+O/2+")"),u.on("click",function(t,e){M.chartClick({data:t,index:e,pos:d3.event,id:s})}),D=[],S=[];for(var H=0;H<e[0].length;H++){var q=d3.svg.arc().outerRadius(I[H]),B=d3.svg.arc().outerRadius(I[H]+5);x!==!1&&(q.startAngle(x),B.startAngle(x)),_!==!1&&(q.endAngle(_),B.endAngle(_)),g&&(q.innerRadius(P[H]),B.innerRadius(P[H])),q.cornerRadius&&$&&(q.cornerRadius($),B.cornerRadius($)),D.push(q),S.push(B)}var V=d3.layout.pie().sort(null).value(function(t){return t.disabled?0:a(t)});V.padAngle&&w&&V.padAngle(w),g&&m&&(U.append("text").attr("class","nv-pie-title"),L.select(".nv-pie-title").style("text-anchor","middle").text(function(t){return m}).style("font-size",Math.min(E,O)*k*2/(m.length+2)+"px").attr("dy","0.35em").attr("transform",function(t,e){return"translate(0, "+y+")"}));var Y=L.select(".nv-pie").selectAll(".nv-slice").data(V),G=L.select(".nv-pieLabels").selectAll(".nv-label").data(V);Y.exit().remove(),G.exit().remove();var X=Y.enter().append("g");X.attr("class","nv-slice"),X.on("mouseover",function(t,e){d3.select(this).classed("hover",!0),v&&d3.select(this).select("path").transition().duration(70).attr("d",S[e]),M.elementMouseover({data:t.data,index:e,color:d3.select(this).style("fill")})}),X.on("mouseout",function(t,e){d3.select(this).classed("hover",!1),v&&d3.select(this).select("path").transition().duration(50).attr("d",D[e]),M.elementMouseout({data:t.data,index:e})}),X.on("mousemove",function(t,e){M.elementMousemove({data:t.data,index:e})}),X.on("click",function(t,e){var n=this;M.elementClick({data:t.data,index:e,color:d3.select(this).style("fill"),event:d3.event,element:n})}),X.on("dblclick",function(t,e){M.elementDblClick({data:t.data,index:e,color:d3.select(this).style("fill")})}),Y.attr("fill",function(t,e){return l(t.data,e)}),Y.attr("stroke",function(t,e){return l(t.data,e)});X.append("path").each(function(t){this._current=t});if(Y.select("path").transition().attr("d",function(t,e){return D[e](t)}).attrTween("d",A),d){for(var K=[],H=0;H<e[0].length;H++)K.push(D[H]),h?g&&(K[H]=d3.svg.arc().outerRadius(D[H].outerRadius()),x!==!1&&K[H].startAngle(x),_!==!1&&K[H].endAngle(_)):g||K[H].innerRadius(0);G.enter().append("g").classed("nv-label",!0).each(function(t,e){var n=d3.select(this);n.attr("transform",function(t,e){if(b){t.outerRadius=I[e]+10,t.innerRadius=I[e]+15;var n=(t.startAngle+t.endAngle)/2*(180/Math.PI);return(t.startAngle+t.endAngle)/2<Math.PI?n-=90:n+=90,"translate("+K[e].centroid(t)+") rotate("+n+")"}return t.outerRadius=N+10,t.innerRadius=N+15,"translate("+K[e].centroid(t)+")"}),n.append("rect").style("stroke","#fff").style("fill","#fff").attr("rx",3).attr("ry",3),n.append("text").style("text-anchor",b?(t.startAngle+t.endAngle)/2<Math.PI?"start":"end":"middle").style("fill","#000")});var Z={},Q=14,J=140,tt=function(t){return Math.floor(t[0]/J)*J+","+Math.floor(t[1]/Q)*Q},et=function(t){return(t.endAngle-t.startAngle)/(2*Math.PI)};G.watchTransition(T,"pie labels").attr("transform",function(t,e){if(b){t.outerRadius=I[e]+10,t.innerRadius=I[e]+15;var n=(t.startAngle+t.endAngle)/2*(180/Math.PI);return(t.startAngle+t.endAngle)/2<Math.PI?n-=90:n+=90,"translate("+K[e].centroid(t)+") rotate("+n+")"}t.outerRadius=N+10,t.innerRadius=N+15;var i=K[e].centroid(t),r=et(t);if(t.value&&r>=p){var o=tt(i);Z[o]&&(i[1]-=Q),Z[tt(i)]=!0}return"translate("+i+")"}),G.select(".nv-label text").style("text-anchor",function(t,e){return b?(t.startAngle+t.endAngle)/2<Math.PI?"start":"end":"middle"}).text(function(t,e){var n=et(t),i="";if(!t.value||p>n)return"";if("function"==typeof f)i=f(t,e,{key:o(t.data),value:a(t.data),percent:c(n)});else switch(f){case"key":i=o(t.data);break;case"value":i=c(a(t.data));break;case"percent":i=d3.format("%")(n)}return i})}}),T.renderEnd("pie immediate"),e}var n={top:0,right:0,bottom:0,left:0},i=500,r=500,o=function(t){return t.x},a=function(t){return t.y},s=Math.floor(1e4*Math.random()),u=null,l=t.utils.defaultColor(),c=d3.format(",.2f"),d=!0,h=!1,f="key",p=.02,g=!1,m=!1,v=!0,y=0,b=!1,x=!1,w=!1,_=!1,$=0,k=.5,C=[],M=d3.dispatch("chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove","renderEnd"),D=[],S=[],T=t.utils.renderWatch(M);return e.dispatch=M,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{arcsRadius:{get:function(){return C},set:function(t){C=t}},width:{get:function(){return i},set:function(t){i=t}},height:{get:function(){return r},set:function(t){r=t}},showLabels:{get:function(){return d},set:function(t){d=t}},title:{get:function(){return m},set:function(t){m=t}},titleOffset:{get:function(){return y},set:function(t){y=t}},labelThreshold:{get:function(){return p},set:function(t){p=t}},valueFormat:{get:function(){return c},set:function(t){c=t}},x:{get:function(){return o},set:function(t){o=t}},id:{get:function(){return s},set:function(t){s=t}},endAngle:{get:function(){return _},set:function(t){_=t}},startAngle:{get:function(){return x},set:function(t){x=t}},padAngle:{get:function(){return w},set:function(t){w=t}},cornerRadius:{get:function(){return $},set:function(t){$=t}},donutRatio:{get:function(){return k},set:function(t){k=t}},labelsOutside:{get:function(){return h},set:function(t){h=t}},labelSunbeamLayout:{get:function(){return b},set:function(t){b=t}},donut:{get:function(){return g},set:function(t){g=t}},growOnHover:{get:function(){return v},set:function(t){v=t}},pieLabelsOutside:{get:function(){return h},set:function(e){h=e,t.deprecated("pieLabelsOutside","use labelsOutside instead")}},donutLabelsOutside:{get:function(){return h},set:function(e){h=e,t.deprecated("donutLabelsOutside","use labelsOutside instead")}},labelFormat:{get:function(){return c},set:function(e){c=e,t.deprecated("labelFormat","use valueFormat instead")}},margin:{get:function(){return n},set:function(t){n.top="undefined"!=typeof t.top?t.top:n.top,n.right="undefined"!=typeof t.right?t.right:n.right,n.bottom="undefined"!=typeof t.bottom?t.bottom:n.bottom,n.left="undefined"!=typeof t.left?t.left:n.left}},y:{get:function(){return a},set:function(t){a=d3.functor(t)}},color:{get:function(){return l},set:function(e){l=t.utils.getColor(e)}},labelType:{get:function(){return f},set:function(t){f=t||"key"}}}),t.utils.initOptions(e),e},t.models.pieChart=function(){"use strict";function e(r){return m.reset(),m.models(n),r.each(function(r){var c=d3.select(this);t.utils.initSVG(c);var f=t.utils.availableWidth(a,c,o),p=t.utils.availableHeight(s,c,o);if(e.update=function(){c.transition().call(e)},e.container=this,d.setter(y(r),e.update).getter(v(r)).update(),d.disabled=r.map(function(t){return!!t.disabled}),!h){var m;h={};for(m in d)d[m]instanceof Array?h[m]=d[m].slice(0):h[m]=d[m]}if(!r||!r.length)return t.utils.noData(e,c),e;c.selectAll(".nv-noData").remove();var b=c.selectAll("g.nv-wrap.nv-pieChart").data([r]),x=b.enter().append("g").attr("class","nvd3 nv-wrap nv-pieChart").append("g"),w=b.select("g");if(x.append("g").attr("class","nv-pieWrap"),x.append("g").attr("class","nv-legendWrap"),u)if("top"===l)i.width(f).key(n.x()),b.select(".nv-legendWrap").datum(r).call(i),o.top!=i.height()&&(o.top=i.height(),p=t.utils.availableHeight(s,c,o)),b.select(".nv-legendWrap").attr("transform","translate(0,"+-o.top+")");else if("right"===l){var _=t.models.legend().width();_>f/2&&(_=f/2),i.height(p).key(n.x()),i.width(_),f-=i.width(),b.select(".nv-legendWrap").datum(r).call(i).attr("transform","translate("+f+",0)")}b.attr("transform","translate("+o.left+","+o.top+")"),n.width(f).height(p);var $=w.select(".nv-pieWrap").datum([r]);d3.transition($).call(n),i.dispatch.on("stateChange",function(t){for(var n in t)d[n]=t[n];g.stateChange(d),e.update()}),g.on("changeState",function(t){"undefined"!=typeof t.disabled&&(r.forEach(function(e,n){e.disabled=t.disabled[n]}),d.disabled=t.disabled),e.update()})}),m.renderEnd("pieChart immediate"),e}var n=t.models.pie(),i=t.models.legend(),r=t.models.tooltip(),o={top:30,right:20,bottom:20,left:20},a=null,s=null,u=!0,l="top",c=t.utils.defaultColor(),d=t.utils.state(),h=null,f=null,p=250,g=d3.dispatch("stateChange","changeState","renderEnd");r.duration(0).headerEnabled(!1).valueFormatter(function(t,e){return n.valueFormat()(t,e)});var m=t.utils.renderWatch(g),v=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},y=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return n.dispatch.on("elementMouseover.tooltip",function(t){t.series={key:e.x()(t.data),value:e.y()(t.data),color:t.color},r.data(t).hidden(!1)}),n.dispatch.on("elementMouseout.tooltip",function(t){r.hidden(!0)}),n.dispatch.on("elementMousemove.tooltip",function(t){r()}),e.legend=i,e.dispatch=g,e.pie=n,e.tooltip=r,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{noData:{get:function(){return f},set:function(t){f=t}},showLegend:{get:function(){return u},set:function(t){u=t}},legendPosition:{get:function(){return l},set:function(t){l=t}},defaultState:{get:function(){return h},set:function(t){h=t}},color:{get:function(){return c},set:function(t){c=t,i.color(c),n.color(c)}},duration:{get:function(){return p},set:function(t){p=t,m.reset(p)}},margin:{get:function(){return o},set:function(t){o.top=void 0!==t.top?t.top:o.top,o.right=void 0!==t.right?t.right:o.right,o.bottom=void 0!==t.bottom?t.bottom:o.bottom,o.left=void 0!==t.left?t.left:o.left}}}),t.utils.inheritOptions(e,n),t.utils.initOptions(e),e},t.models.scatter=function(){"use strict";function e(L){return R.reset(),L.each(function(L){function q(){if(j=!1,!_)return!1;if(H===!0){var t=d3.merge(L.map(function(t,e){return t.values.map(function(t,n){var i=g(t,n),r=m(t,n);return[h(i)+1e-4*Math.random(),f(r)+1e-4*Math.random(),e,n,t]}).filter(function(t,e){return $(t[4],e)})}));if(0==t.length)return!1;t.length<3&&(t.push([h.range()[0]-20,f.range()[0]-20,null,null]),t.push([h.range()[1]+20,f.range()[1]+20,null,null]),t.push([h.range()[0]-20,f.range()[0]+20,null,null]),t.push([h.range()[1]+20,f.range()[1]-20,null,null]));var e=d3.geom.polygon([[-10,-10],[-10,u+10],[s+10,u+10],[s+10,-10]]),n=d3.geom.voronoi(t).map(function(n,i){return{data:e.clip(n),series:t[i][2],point:t[i][3]}});X.select(".nv-point-paths").selectAll("path").remove();var i=X.select(".nv-point-paths").selectAll("path").data(n),r=i.enter().append("svg:path").attr("d",function(t){return t&&t.data&&0!==t.data.length?"M"+t.data.join(",")+"Z":"M 0 0"}).attr("id",function(t,e){return"nv-path-"+e}).attr("clip-path",function(t,e){return"url(#nv-clip-"+c+"-"+e+")"});if(S&&r.style("fill",d3.rgb(230,230,230)).style("fill-opacity",.4).style("stroke-opacity",1).style("stroke",d3.rgb(200,200,200)),D){X.select(".nv-point-clips").selectAll("*").remove();var o=X.select(".nv-point-clips").selectAll("clipPath").data(t);o.enter().append("svg:clipPath").attr("id",function(t,e){return"nv-clip-"+c+"-"+e}).append("svg:circle").attr("cx",function(t){return t[0]}).attr("cy",function(t){return t[1]}).attr("r",T)}var p=function(t,e){if(j)return 0;var n=L[t.series];if(void 0!==n){var i=n.values[t.point];i.color=l(n,t.series),i.x=g(i),i.y=m(i);var r=d.node().getBoundingClientRect(),o=window.pageYOffset||document.documentElement.scrollTop,s=window.pageXOffset||document.documentElement.scrollLeft,u={left:h(g(i,t.point))+r.left+s+a.left+10,top:f(m(i,t.point))+r.top+o+a.top+10};e({point:i,series:n,pos:u,relativePos:[h(g(i,t.point))+a.left,f(m(i,t.point))+a.top],seriesIndex:t.series,pointIndex:t.point})}};i.on("click",function(t){p(t,W.elementClick)}).on("dblclick",function(t){p(t,W.elementDblClick)}).on("mouseover",function(t){p(t,W.elementMouseover)}).on("mouseout",function(t,e){p(t,W.elementMouseout)})}else X.select(".nv-groups").selectAll(".nv-group").selectAll(".nv-point").on("click",function(t,e){if(j||!L[t.series])return 0;var n=L[t.series],i=n.values[e];W.elementClick({point:i,series:n,pos:[h(g(i,e))+a.left,f(m(i,e))+a.top],relativePos:[h(g(i,e))+a.left,f(m(i,e))+a.top],seriesIndex:t.series,pointIndex:e})}).on("dblclick",function(t,e){if(j||!L[t.series])return 0;var n=L[t.series],i=n.values[e];W.elementDblClick({point:i,series:n,pos:[h(g(i,e))+a.left,f(m(i,e))+a.top],relativePos:[h(g(i,e))+a.left,f(m(i,e))+a.top],seriesIndex:t.series,pointIndex:e})}).on("mouseover",function(t,e){if(j||!L[t.series])return 0;var n=L[t.series],i=n.values[e];W.elementMouseover({point:i,series:n,pos:[h(g(i,e))+a.left,f(m(i,e))+a.top],relativePos:[h(g(i,e))+a.left,f(m(i,e))+a.top],seriesIndex:t.series,pointIndex:e,color:l(t,e)})}).on("mouseout",function(t,e){if(j||!L[t.series])return 0;var n=L[t.series],i=n.values[e];W.elementMouseout({point:i,series:n,pos:[h(g(i,e))+a.left,f(m(i,e))+a.top],relativePos:[h(g(i,e))+a.left,f(m(i,e))+a.top],seriesIndex:t.series,pointIndex:e,color:l(t,e)})})}d=d3.select(this);var B=t.utils.availableWidth(s,d,a),V=t.utils.availableHeight(u,d,a);t.utils.initSVG(d),L.forEach(function(t,e){t.values.forEach(function(t){t.series=e})});var Y=A&&E&&I?[]:d3.merge(L.map(function(t){return t.values.map(function(t,e){return{x:g(t,e),y:m(t,e),size:v(t,e)}})}));if(h.domain(A||d3.extent(Y.map(function(t){return t.x}).concat(b))),k&&L[0]?h.range(O||[(B*C+B)/(2*L[0].values.length),B-B*(1+C)/(2*L[0].values.length)]):h.range(O||[0,B]),"o"===e.yScale().name){var G=d3.min(Y.map(function(t){return 0!==t.y?t.y:void 0}));f.clamp(!0).domain(E||d3.extent(Y.map(function(t){return 0!==t.y?t.y:.1*G}).concat(x))).range(N||[V,0])}else f.domain(E||d3.extent(Y.map(function(t){return t.y}).concat(x))).range(N||[V,0]);p.domain(I||d3.extent(Y.map(function(t){return t.size}).concat(w))).range(P||U),F=h.domain()[0]===h.domain()[1]||f.domain()[0]===f.domain()[1],h.domain()[0]===h.domain()[1]&&(h.domain()[0]?h.domain([h.domain()[0]-.01*h.domain()[0],h.domain()[1]+.01*h.domain()[1]]):h.domain([-1,1])),f.domain()[0]===f.domain()[1]&&(f.domain()[0]?f.domain([f.domain()[0]-.01*f.domain()[0],f.domain()[1]+.01*f.domain()[1]]):f.domain([-1,1])),isNaN(h.domain()[0])&&h.domain([-1,1]),isNaN(f.domain()[0])&&f.domain([-1,1]),n=n||h,i=i||f,r=r||p;var X=d.selectAll("g.nv-wrap.nv-scatter").data([L]),K=X.enter().append("g").attr("class","nvd3 nv-wrap nv-scatter nv-chart-"+c),Z=K.append("defs"),Q=K.append("g"),J=X.select("g");X.classed("nv-single-point",F),Q.append("g").attr("class","nv-groups"),Q.append("g").attr("class","nv-point-paths"),K.append("g").attr("class","nv-point-clips"),X.attr("transform","translate("+a.left+","+a.top+")"),Z.append("clipPath").attr("id","nv-edge-clip-"+c).append("rect"),X.select("#nv-edge-clip-"+c+" rect").attr("width",B).attr("height",V>0?V:0),J.attr("clip-path",M?"url(#nv-edge-clip-"+c+")":""),j=!0;var tt=X.select(".nv-groups").selectAll(".nv-group").data(function(t){return t},function(t){return t.key});tt.enter().append("g").style("stroke-opacity",1e-6).style("fill-opacity",1e-6),tt.exit().remove(),tt.attr("class",function(t,e){return(t.classed||"")+" nv-group nv-series-"+e}).classed("hover",function(t){return t.hover}),tt.watchTransition(R,"scatter: groups").style("fill",function(t,e){return l(t,e)}).style("stroke",function(t,e){return l(t,e)}).style("stroke-opacity",1).style("fill-opacity",.5);var et=tt.selectAll("path.nv-point").data(function(t){return t.values.map(function(t,e){return[t,e]}).filter(function(t,e){return $(t[0],e)})});et.enter().append("path").style("fill",function(t){return t.color}).style("stroke",function(t){return t.color}).attr("transform",function(e){return"translate("+t.utils.NaNtoZero(n(g(e[0],e[1])))+","+t.utils.NaNtoZero(i(m(e[0],e[1])))+")"}).attr("d",t.utils.symbol().type(function(t){return y(t[0])}).size(function(t){return p(v(t[0],t[1]))})),et.exit().remove(),tt.exit().selectAll("path.nv-point").watchTransition(R,"scatter exit").attr("transform",function(e){return"translate("+t.utils.NaNtoZero(h(g(e[0],e[1])))+","+t.utils.NaNtoZero(f(m(e[0],e[1])))+")"}).remove(),et.each(function(t){d3.select(this).classed("nv-point",!0).classed("nv-point-"+t[1],!0).classed("nv-noninteractive",!_).classed("hover",!1)}),et.watchTransition(R,"scatter points").attr("transform",function(e){return"translate("+t.utils.NaNtoZero(h(g(e[0],e[1])))+","+t.utils.NaNtoZero(f(m(e[0],e[1])))+")"}).attr("d",t.utils.symbol().type(function(t){return y(t[0])}).size(function(t){return p(v(t[0],t[1]))})),z?(clearTimeout(o),o=setTimeout(q,z)):q(),n=h.copy(),i=f.copy(),r=p.copy()}),R.renderEnd("scatter immediate"),e}var n,i,r,o,a={top:0,right:0,bottom:0,left:0},s=null,u=null,l=t.utils.defaultColor(),c=Math.floor(1e5*Math.random()),d=null,h=d3.scale.linear(),f=d3.scale.linear(),p=d3.scale.linear(),g=function(t){return t.x},m=function(t){return t.y},v=function(t){return t.size||1},y=function(t){return t.shape||"circle"},b=[],x=[],w=[],_=!0,$=function(t){return!t.notActive},k=!1,C=.1,M=!1,D=!0,S=!1,T=function(){return 25},A=null,E=null,O=null,N=null,I=null,P=null,F=!1,W=d3.dispatch("elementClick","elementDblClick","elementMouseover","elementMouseout","renderEnd"),H=!0,L=250,z=300,j=!1,R=t.utils.renderWatch(W,L),U=[16,256];return e.dispatch=W,e.options=t.utils.optionsFunc.bind(e),e._calls=new function(){this.clearHighlights=function(){return t.dom.write(function(){d.selectAll(".nv-point.hover").classed("hover",!1)}),null},this.highlightPoint=function(e,n,i){t.dom.write(function(){d.select(".nv-groups").selectAll(".nv-series-"+e).selectAll(".nv-point-"+n).classed("hover",i)})}},W.on("elementMouseover.point",function(t){_&&e._calls.highlightPoint(t.seriesIndex,t.pointIndex,!0)}),W.on("elementMouseout.point",function(t){_&&e._calls.highlightPoint(t.seriesIndex,t.pointIndex,!1)}),e._options=Object.create({},{width:{get:function(){return s},set:function(t){s=t}},height:{get:function(){return u},set:function(t){u=t}},xScale:{get:function(){return h},set:function(t){h=t}},yScale:{get:function(){return f},set:function(t){f=t}},pointScale:{get:function(){return p},set:function(t){p=t}},xDomain:{get:function(){return A},set:function(t){A=t}},yDomain:{get:function(){return E},set:function(t){E=t}},pointDomain:{get:function(){return I},set:function(t){I=t}},xRange:{get:function(){return O},set:function(t){O=t}},yRange:{get:function(){return N},set:function(t){N=t}},pointRange:{get:function(){return P},set:function(t){P=t}},forceX:{get:function(){return b},set:function(t){b=t}},forceY:{get:function(){return x},set:function(t){x=t}},forcePoint:{get:function(){return w},set:function(t){w=t}},interactive:{get:function(){return _},set:function(t){_=t}},pointActive:{get:function(){return $},set:function(t){$=t}},padDataOuter:{get:function(){return C},set:function(t){C=t}},padData:{get:function(){return k},set:function(t){k=t}},clipEdge:{get:function(){return M},set:function(t){M=t}},clipVoronoi:{get:function(){return D},set:function(t){D=t}},clipRadius:{get:function(){return T},set:function(t){T=t}},showVoronoi:{get:function(){return S},set:function(t){S=t}},id:{get:function(){return c},set:function(t){c=t}},interactiveUpdateDelay:{get:function(){return z},set:function(t){z=t}},x:{get:function(){return g},set:function(t){g=d3.functor(t)}},y:{get:function(){return m},set:function(t){m=d3.functor(t)}},pointSize:{get:function(){return v},set:function(t){v=d3.functor(t)}},pointShape:{get:function(){return y},set:function(t){y=d3.functor(t)}},margin:{get:function(){return a},set:function(t){a.top=void 0!==t.top?t.top:a.top,a.right=void 0!==t.right?t.right:a.right,a.bottom=void 0!==t.bottom?t.bottom:a.bottom,a.left=void 0!==t.left?t.left:a.left}},duration:{get:function(){return L},set:function(t){L=t,R.reset(L)}},color:{get:function(){return l},set:function(e){l=t.utils.getColor(e)}},useVoronoi:{get:function(){return H},set:function(t){H=t,H===!1&&(D=!1)}}}),t.utils.initOptions(e),e},t.models.scatterChart=function(){"use strict";function e(C){return T.reset(),T.models(n),b&&T.models(i),x&&T.models(r),m&&T.models(a),v&&T.models(s),C.each(function(C){h=d3.select(this),t.utils.initSVG(h);var O=t.utils.availableWidth(c,h,l),N=t.utils.availableHeight(d,h,l);if(e.update=function(){0===M?h.call(e):h.transition().duration(M).call(e)},e.container=this,_.setter(E(C),e.update).getter(A(C)).update(),_.disabled=C.map(function(t){return!!t.disabled}),!$){var I;$={};for(I in _)_[I]instanceof Array?$[I]=_[I].slice(0):$[I]=_[I]}if(!(C&&C.length&&C.filter(function(t){return t.values.length}).length))return t.utils.noData(e,h),T.renderEnd("scatter immediate"),e;h.selectAll(".nv-noData").remove(),p=n.xScale(),g=n.yScale();var P=h.selectAll("g.nv-wrap.nv-scatterChart").data([C]),F=P.enter().append("g").attr("class","nvd3 nv-wrap nv-scatterChart nv-chart-"+n.id()),W=F.append("g"),H=P.select("g");if(W.append("rect").attr("class","nvd3 nv-background").style("pointer-events","none"),W.append("g").attr("class","nv-x nv-axis"),W.append("g").attr("class","nv-y nv-axis"),W.append("g").attr("class","nv-scatterWrap"),W.append("g").attr("class","nv-regressionLinesWrap"),W.append("g").attr("class","nv-distWrap"),W.append("g").attr("class","nv-legendWrap"),w&&H.select(".nv-y.nv-axis").attr("transform","translate("+O+",0)"),y){var L=O;o.width(L),P.select(".nv-legendWrap").datum(C).call(o),l.top!=o.height()&&(l.top=o.height(),N=t.utils.availableHeight(d,h,l)),P.select(".nv-legendWrap").attr("transform","translate(0,"+-l.top+")")}P.attr("transform","translate("+l.left+","+l.top+")"),n.width(O).height(N).color(C.map(function(t,e){return t.color=t.color||f(t,e),t.color}).filter(function(t,e){return!C[e].disabled})),P.select(".nv-scatterWrap").datum(C.filter(function(t){return!t.disabled})).call(n),P.select(".nv-regressionLinesWrap").attr("clip-path","url(#nv-edge-clip-"+n.id()+")");var z=P.select(".nv-regressionLinesWrap").selectAll(".nv-regLines").data(function(t){return t});z.enter().append("g").attr("class","nv-regLines");var j=z.selectAll(".nv-regLine").data(function(t){return[t]});j.enter().append("line").attr("class","nv-regLine").style("stroke-opacity",0),j.filter(function(t){return t.intercept&&t.slope}).watchTransition(T,"scatterPlusLineChart: regline").attr("x1",p.range()[0]).attr("x2",p.range()[1]).attr("y1",function(t,e){return g(p.domain()[0]*t.slope+t.intercept)}).attr("y2",function(t,e){return g(p.domain()[1]*t.slope+t.intercept)}).style("stroke",function(t,e,n){return f(t,n)}).style("stroke-opacity",function(t,e){return t.disabled||"undefined"==typeof t.slope||"undefined"==typeof t.intercept?0:1}),b&&(i.scale(p)._ticks(t.utils.calcTicksX(O/100,C)).tickSize(-N,0),H.select(".nv-x.nv-axis").attr("transform","translate(0,"+g.range()[0]+")").call(i)),x&&(r.scale(g)._ticks(t.utils.calcTicksY(N/36,C)).tickSize(-O,0),H.select(".nv-y.nv-axis").call(r)),m&&(a.getData(n.x()).scale(p).width(O).color(C.map(function(t,e){return t.color||f(t,e)}).filter(function(t,e){return!C[e].disabled})),W.select(".nv-distWrap").append("g").attr("class","nv-distributionX"),H.select(".nv-distributionX").attr("transform","translate(0,"+g.range()[0]+")").datum(C.filter(function(t){return!t.disabled})).call(a)),v&&(s.getData(n.y()).scale(g).width(N).color(C.map(function(t,e){return t.color||f(t,e)}).filter(function(t,e){return!C[e].disabled})),W.select(".nv-distWrap").append("g").attr("class","nv-distributionY"),H.select(".nv-distributionY").attr("transform","translate("+(w?O:-s.size())+",0)").datum(C.filter(function(t){return!t.disabled})).call(s)),o.dispatch.on("stateChange",function(t){for(var n in t)_[n]=t[n];k.stateChange(_),e.update()}),k.on("changeState",function(t){"undefined"!=typeof t.disabled&&(C.forEach(function(e,n){e.disabled=t.disabled[n]}),_.disabled=t.disabled),e.update()}),n.dispatch.on("elementMouseout.tooltip",function(t){u.hidden(!0),h.select(".nv-chart-"+n.id()+" .nv-series-"+t.seriesIndex+" .nv-distx-"+t.pointIndex).attr("y1",0),h.select(".nv-chart-"+n.id()+" .nv-series-"+t.seriesIndex+" .nv-disty-"+t.pointIndex).attr("x2",s.size())}),n.dispatch.on("elementMouseover.tooltip",function(t){h.select(".nv-series-"+t.seriesIndex+" .nv-distx-"+t.pointIndex).attr("y1",t.relativePos[1]-N),h.select(".nv-series-"+t.seriesIndex+" .nv-disty-"+t.pointIndex).attr("x2",t.relativePos[0]+a.size()),u.data(t).hidden(!1)}),D=p.copy(),S=g.copy()}),T.renderEnd("scatter with line immediate"),e}var n=t.models.scatter(),i=t.models.axis(),r=t.models.axis(),o=t.models.legend(),a=t.models.distribution(),s=t.models.distribution(),u=t.models.tooltip(),l={top:30,right:20,bottom:50,left:75},c=null,d=null,h=null,f=t.utils.defaultColor(),p=n.xScale(),g=n.yScale(),m=!1,v=!1,y=!0,b=!0,x=!0,w=!1,_=t.utils.state(),$=null,k=d3.dispatch("stateChange","changeState","renderEnd"),C=null,M=250;n.xScale(p).yScale(g),i.orient("bottom").tickPadding(10),r.orient(w?"right":"left").tickPadding(10),a.axis("x"),s.axis("y"),u.headerFormatter(function(t,e){return i.tickFormat()(t,e)}).valueFormatter(function(t,e){return r.tickFormat()(t,e)});var D,S,T=t.utils.renderWatch(k,M),A=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},E=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return e.dispatch=k,e.scatter=n,e.legend=o,e.xAxis=i,e.yAxis=r,e.distX=a,e.distY=s,e.tooltip=u,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return c},set:function(t){c=t}},height:{get:function(){return d},set:function(t){d=t}},container:{get:function(){return h},set:function(t){h=t}},showDistX:{get:function(){return m},set:function(t){m=t}},showDistY:{get:function(){return v},set:function(t){v=t}},showLegend:{get:function(){return y},set:function(t){y=t}},showXAxis:{get:function(){return b},set:function(t){b=t}},showYAxis:{get:function(){return x},set:function(t){x=t}},defaultState:{get:function(){return $},set:function(t){$=t}},noData:{get:function(){return C},set:function(t){C=t}},duration:{get:function(){return M},set:function(t){M=t}},margin:{get:function(){return l},set:function(t){l.top=void 0!==t.top?t.top:l.top,l.right=void 0!==t.right?t.right:l.right,l.bottom=void 0!==t.bottom?t.bottom:l.bottom,l.left=void 0!==t.left?t.left:l.left}},rightAlignYAxis:{get:function(){return w},set:function(t){w=t,r.orient(t?"right":"left")}},color:{get:function(){return f},set:function(e){f=t.utils.getColor(e),o.color(f),a.color(f),s.color(f)}}}),t.utils.inheritOptions(e,n),t.utils.initOptions(e),e},t.models.sparkline=function(){"use strict";function e(c){return v.reset(),c.each(function(e){var c=s-a.left-a.right,m=u-a.top-a.bottom;l=d3.select(this),t.utils.initSVG(l),d.domain(n||d3.extent(e,f)).range(r||[0,c]),h.domain(i||d3.extent(e,p)).range(o||[m,0]);var v=l.selectAll("g.nv-wrap.nv-sparkline").data([e]),y=v.enter().append("g").attr("class","nvd3 nv-wrap nv-sparkline");y.append("g"),v.select("g");v.attr("transform","translate("+a.left+","+a.top+")");var b=v.selectAll("path").data(function(t){return[t]});b.enter().append("path"),b.exit().remove(),b.style("stroke",function(t,e){return t.color||g(t,e)}).attr("d",d3.svg.line().x(function(t,e){return d(f(t,e))}).y(function(t,e){return h(p(t,e))}));var x=v.selectAll("circle.nv-point").data(function(t){function e(e){if(-1!=e){var n=t[e];return n.pointIndex=e,n}return null}var n=t.map(function(t,e){return p(t,e)}),i=e(n.lastIndexOf(h.domain()[1])),r=e(n.indexOf(h.domain()[0])),o=e(n.length-1);return[r,i,o].filter(function(t){return null!=t})});x.enter().append("circle"),x.exit().remove(),x.attr("cx",function(t,e){return d(f(t,t.pointIndex))}).attr("cy",function(t,e){return h(p(t,t.pointIndex))}).attr("r",2).attr("class",function(t,e){return f(t,t.pointIndex)==d.domain()[1]?"nv-point nv-currentValue":p(t,t.pointIndex)==h.domain()[0]?"nv-point nv-minValue":"nv-point nv-maxValue"})}),v.renderEnd("sparkline immediate"),e}var n,i,r,o,a={top:2,right:0,bottom:2,left:0},s=400,u=32,l=null,c=!0,d=d3.scale.linear(),h=d3.scale.linear(),f=function(t){return t.x},p=function(t){return t.y},g=t.utils.getColor(["#000"]),m=d3.dispatch("renderEnd"),v=t.utils.renderWatch(m);return e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return s},set:function(t){s=t}},height:{get:function(){return u},set:function(t){u=t}},xDomain:{get:function(){return n},set:function(t){n=t}},yDomain:{get:function(){return i},set:function(t){i=t}},xRange:{get:function(){return r},set:function(t){r=t}},yRange:{get:function(){return o},set:function(t){o=t}},xScale:{get:function(){return d},set:function(t){d=t}},yScale:{get:function(){return h},set:function(t){h=t}},animate:{get:function(){return c},set:function(t){c=t}},x:{get:function(){return f},set:function(t){f=d3.functor(t)}},y:{get:function(){return p},set:function(t){p=d3.functor(t)}},margin:{get:function(){return a},set:function(t){a.top=void 0!==t.top?t.top:a.top,a.right=void 0!==t.right?t.right:a.right,a.bottom=void 0!==t.bottom?t.bottom:a.bottom,a.left=void 0!==t.left?t.left:a.left}},color:{get:function(){return g},set:function(e){g=t.utils.getColor(e)}}}),e.dispatch=m,t.utils.initOptions(e),e},t.models.sparklinePlus=function(){"use strict";function e(g){return v.reset(),v.models(r),g.each(function(g){function m(){if(!l){var t=C.selectAll(".nv-hoverValue").data(u),e=t.enter().append("g").attr("class","nv-hoverValue").style("stroke-opacity",0).style("fill-opacity",0);t.exit().transition().duration(250).style("stroke-opacity",0).style("fill-opacity",0).remove(),t.attr("transform",function(t){return"translate("+n(r.x()(g[t],t))+",0)"}).transition().duration(250).style("stroke-opacity",1).style("fill-opacity",1),u.length&&(e.append("line").attr("x1",0).attr("y1",-o.top).attr("x2",0).attr("y2",x),e.append("text").attr("class","nv-xValue").attr("x",-6).attr("y",-o.top).attr("text-anchor","end").attr("dy",".9em"),C.select(".nv-hoverValue .nv-xValue").text(c(r.x()(g[u[0]],u[0]))),e.append("text").attr("class","nv-yValue").attr("x",6).attr("y",-o.top).attr("text-anchor","start").attr("dy",".9em"),C.select(".nv-hoverValue .nv-yValue").text(d(r.y()(g[u[0]],u[0]))))}}function v(){function t(t,e){for(var n=Math.abs(r.x()(t[0],0)-e),i=0,o=0;o<t.length;o++)Math.abs(r.x()(t[o],o)-e)<n&&(n=Math.abs(r.x()(t[o],o)-e),i=o);return i}if(!l){var e=d3.mouse(this)[0]-o.left;u=[t(g,Math.round(n.invert(e)))],m()}}var y=d3.select(this);t.utils.initSVG(y);var b=t.utils.availableWidth(a,y,o),x=t.utils.availableHeight(s,y,o);
if(e.update=function(){y.call(e)},e.container=this,!g||!g.length)return t.utils.noData(e,y),e;y.selectAll(".nv-noData").remove();var w=r.y()(g[g.length-1],g.length-1);n=r.xScale(),i=r.yScale();var _=y.selectAll("g.nv-wrap.nv-sparklineplus").data([g]),$=_.enter().append("g").attr("class","nvd3 nv-wrap nv-sparklineplus"),k=$.append("g"),C=_.select("g");k.append("g").attr("class","nv-sparklineWrap"),k.append("g").attr("class","nv-valueWrap"),k.append("g").attr("class","nv-hoverArea"),_.attr("transform","translate("+o.left+","+o.top+")");var M=C.select(".nv-sparklineWrap");if(r.width(b).height(x),M.call(r),h){var D=C.select(".nv-valueWrap"),S=D.selectAll(".nv-currentValue").data([w]);S.enter().append("text").attr("class","nv-currentValue").attr("dx",p?-8:8).attr("dy",".9em").style("text-anchor",p?"end":"start"),S.attr("x",b+(p?o.right:0)).attr("y",f?function(t){return i(t)}:0).style("fill",r.color()(g[g.length-1],g.length-1)).text(d(w))}k.select(".nv-hoverArea").append("rect").on("mousemove",v).on("click",function(){l=!l}).on("mouseout",function(){u=[],m()}),C.select(".nv-hoverArea rect").attr("transform",function(t){return"translate("+-o.left+","+-o.top+")"}).attr("width",b+o.left+o.right).attr("height",x+o.top)}),v.renderEnd("sparklinePlus immediate"),e}var n,i,r=t.models.sparkline(),o={top:15,right:100,bottom:10,left:50},a=null,s=null,u=[],l=!1,c=d3.format(",r"),d=d3.format(",.2f"),h=!0,f=!0,p=!1,g=null,m=d3.dispatch("renderEnd"),v=t.utils.renderWatch(m);return e.dispatch=m,e.sparkline=r,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return a},set:function(t){a=t}},height:{get:function(){return s},set:function(t){s=t}},xTickFormat:{get:function(){return c},set:function(t){c=t}},yTickFormat:{get:function(){return d},set:function(t){d=t}},showLastValue:{get:function(){return h},set:function(t){h=t}},alignValue:{get:function(){return f},set:function(t){f=t}},rightAlignValue:{get:function(){return p},set:function(t){p=t}},noData:{get:function(){return g},set:function(t){g=t}},margin:{get:function(){return o},set:function(t){o.top=void 0!==t.top?t.top:o.top,o.right=void 0!==t.right?t.right:o.right,o.bottom=void 0!==t.bottom?t.bottom:o.bottom,o.left=void 0!==t.left?t.left:o.left}}}),t.utils.inheritOptions(e,r),t.utils.initOptions(e),e},t.models.stackedArea=function(){"use strict";function e(f){return w.reset(),w.models(y),f.each(function(f){var b=o-r.left-r.right,_=a-r.top-r.bottom;l=d3.select(this),t.utils.initSVG(l),n=y.xScale(),i=y.yScale();var $=f;f.forEach(function(t,e){t.seriesIndex=e,t.values=t.values.map(function(t,n){return t.index=n,t.seriesIndex=e,t})});var k=f.filter(function(t){return!t.disabled});f=d3.layout.stack().order(g).offset(p).values(function(t){return t.values}).x(c).y(d).out(function(t,e,n){t.display={y:n,y0:e}})(k);var C=l.selectAll("g.nv-wrap.nv-stackedarea").data([f]),M=C.enter().append("g").attr("class","nvd3 nv-wrap nv-stackedarea"),D=M.append("defs"),S=M.append("g"),T=C.select("g");S.append("g").attr("class","nv-areaWrap"),S.append("g").attr("class","nv-scatterWrap"),C.attr("transform","translate("+r.left+","+r.top+")"),0==y.forceY().length&&y.forceY().push(0),y.width(b).height(_).x(c).y(function(t){return void 0!==t.display?t.display.y+t.display.y0:void 0}).forceY([0]).color(f.map(function(t,e){return t.color=t.color||s(t,t.seriesIndex),t.color}));var A=T.select(".nv-scatterWrap").datum(f);A.call(y),D.append("clipPath").attr("id","nv-edge-clip-"+u).append("rect"),C.select("#nv-edge-clip-"+u+" rect").attr("width",b).attr("height",_),T.attr("clip-path",v?"url(#nv-edge-clip-"+u+")":"");var E=d3.svg.area().defined(h).x(function(t,e){return n(c(t,e))}).y0(function(t){return i(t.display.y0)}).y1(function(t){return i(t.display.y+t.display.y0)}).interpolate(m),O=d3.svg.area().defined(h).x(function(t,e){return n(c(t,e))}).y0(function(t){return i(t.display.y0)}).y1(function(t){return i(t.display.y0)}),N=T.select(".nv-areaWrap").selectAll("path.nv-area").data(function(t){return t});N.enter().append("path").attr("class",function(t,e){return"nv-area nv-area-"+e}).attr("d",function(t,e){return O(t.values,t.seriesIndex)}).on("mouseover",function(t,e){d3.select(this).classed("hover",!0),x.areaMouseover({point:t,series:t.key,pos:[d3.event.pageX,d3.event.pageY],seriesIndex:t.seriesIndex})}).on("mouseout",function(t,e){d3.select(this).classed("hover",!1),x.areaMouseout({point:t,series:t.key,pos:[d3.event.pageX,d3.event.pageY],seriesIndex:t.seriesIndex})}).on("click",function(t,e){d3.select(this).classed("hover",!1),x.areaClick({point:t,series:t.key,pos:[d3.event.pageX,d3.event.pageY],seriesIndex:t.seriesIndex})}),N.exit().remove(),N.style("fill",function(t,e){return t.color||s(t,t.seriesIndex)}).style("stroke",function(t,e){return t.color||s(t,t.seriesIndex)}),N.watchTransition(w,"stackedArea path").attr("d",function(t,e){return E(t.values,e)}),y.dispatch.on("elementMouseover.area",function(t){T.select(".nv-chart-"+u+" .nv-area-"+t.seriesIndex).classed("hover",!0)}),y.dispatch.on("elementMouseout.area",function(t){T.select(".nv-chart-"+u+" .nv-area-"+t.seriesIndex).classed("hover",!1)}),e.d3_stackedOffset_stackPercent=function(t){var e,n,i,r=t.length,o=t[0].length,a=[];for(n=0;o>n;++n){for(e=0,i=0;e<$.length;e++)i+=d($[e].values[n]);if(i)for(e=0;r>e;e++)t[e][n][1]/=i;else for(e=0;r>e;e++)t[e][n][1]=0}for(n=0;o>n;++n)a[n]=0;return a}}),w.renderEnd("stackedArea immediate"),e}var n,i,r={top:0,right:0,bottom:0,left:0},o=960,a=500,s=t.utils.defaultColor(),u=Math.floor(1e5*Math.random()),l=null,c=function(t){return t.x},d=function(t){return t.y},h=function(t,e){return!isNaN(d(t,e))&&null!==d(t,e)},f="stack",p="zero",g="default",m="linear",v=!1,y=t.models.scatter(),b=250,x=d3.dispatch("areaClick","areaMouseover","areaMouseout","renderEnd","elementClick","elementMouseover","elementMouseout");y.pointSize(2.2).pointDomain([2.2,2.2]);var w=t.utils.renderWatch(x,b);return e.dispatch=x,e.scatter=y,y.dispatch.on("elementClick",function(){x.elementClick.apply(this,arguments)}),y.dispatch.on("elementMouseover",function(){x.elementMouseover.apply(this,arguments)}),y.dispatch.on("elementMouseout",function(){x.elementMouseout.apply(this,arguments)}),e.interpolate=function(t){return arguments.length?(m=t,e):m},e.duration=function(t){return arguments.length?(b=t,w.reset(b),y.duration(b),e):b},e.dispatch=x,e.scatter=y,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return o},set:function(t){o=t}},height:{get:function(){return a},set:function(t){a=t}},defined:{get:function(){return h},set:function(t){h=t}},clipEdge:{get:function(){return v},set:function(t){v=t}},offset:{get:function(){return p},set:function(t){p=t}},order:{get:function(){return g},set:function(t){g=t}},interpolate:{get:function(){return m},set:function(t){m=t}},x:{get:function(){return c},set:function(t){c=d3.functor(t)}},y:{get:function(){return d},set:function(t){d=d3.functor(t)}},margin:{get:function(){return r},set:function(t){r.top=void 0!==t.top?t.top:r.top,r.right=void 0!==t.right?t.right:r.right,r.bottom=void 0!==t.bottom?t.bottom:r.bottom,r.left=void 0!==t.left?t.left:r.left}},color:{get:function(){return s},set:function(e){s=t.utils.getColor(e)}},style:{get:function(){return f},set:function(t){switch(f=t){case"stack":e.offset("zero"),e.order("default");break;case"stream":e.offset("wiggle"),e.order("inside-out");break;case"stream-center":e.offset("silhouette"),e.order("inside-out");break;case"expand":e.offset("expand"),e.order("default");break;case"stack_percent":e.offset(e.d3_stackedOffset_stackPercent),e.order("default")}}},duration:{get:function(){return b},set:function(t){b=t,w.reset(b),y.duration(b)}}}),t.utils.inheritOptions(e,y),t.utils.initOptions(e),e},t.models.stackedAreaChart=function(){"use strict";function e(c){return N.reset(),N.models(r),v&&N.models(o),y&&N.models(a),c.each(function(c){var C=d3.select(this),N=this;t.utils.initSVG(C);var H=t.utils.availableWidth(h,C,d),L=t.utils.availableHeight(f,C,d);if(e.update=function(){C.transition().duration(A).call(e)},e.container=this,$.setter(F(c),e.update).getter(P(c)).update(),$.disabled=c.map(function(t){return!!t.disabled}),!k){var z;k={};for(z in $)$[z]instanceof Array?k[z]=$[z].slice(0):k[z]=$[z]}if(!(c&&c.length&&c.filter(function(t){return t.values.length}).length))return t.utils.noData(e,C),e;C.selectAll(".nv-noData").remove(),n=r.xScale(),i=r.yScale();var j=C.selectAll("g.nv-wrap.nv-stackedAreaChart").data([c]),R=j.enter().append("g").attr("class","nvd3 nv-wrap nv-stackedAreaChart").append("g"),U=j.select("g");if(R.append("rect").style("opacity",0),R.append("g").attr("class","nv-x nv-axis"),R.append("g").attr("class","nv-y nv-axis"),R.append("g").attr("class","nv-stackedWrap"),R.append("g").attr("class","nv-legendWrap"),R.append("g").attr("class","nv-controlsWrap"),R.append("g").attr("class","nv-interactive"),U.select("rect").attr("width",H).attr("height",L),m){var q=g?H-D:H;s.width(q),U.select(".nv-legendWrap").datum(c).call(s),d.top!=s.height()&&(d.top=s.height(),L=t.utils.availableHeight(f,C,d)),U.select(".nv-legendWrap").attr("transform","translate("+(H-q)+","+-d.top+")")}if(g){var B=[{key:T.stacked||"Stacked",metaKey:"Stacked",disabled:"stack"!=r.style(),style:"stack"},{key:T.stream||"Stream",metaKey:"Stream",disabled:"stream"!=r.style(),style:"stream"},{key:T.expanded||"Expanded",metaKey:"Expanded",disabled:"expand"!=r.style(),style:"expand"},{key:T.stack_percent||"Stack %",metaKey:"Stack_Percent",disabled:"stack_percent"!=r.style(),style:"stack_percent"}];D=S.length/3*260,B=B.filter(function(t){return-1!==S.indexOf(t.metaKey)}),u.width(D).color(["#444","#444","#444"]),U.select(".nv-controlsWrap").datum(B).call(u),d.top!=Math.max(u.height(),s.height())&&(d.top=Math.max(u.height(),s.height()),L=t.utils.availableHeight(f,C,d)),U.select(".nv-controlsWrap").attr("transform","translate(0,"+-d.top+")")}j.attr("transform","translate("+d.left+","+d.top+")"),b&&U.select(".nv-y.nv-axis").attr("transform","translate("+H+",0)"),x&&(l.width(H).height(L).margin({left:d.left,top:d.top}).svgContainer(C).xScale(n),j.select(".nv-interactive").call(l)),r.width(H).height(L);var V=U.select(".nv-stackedWrap").datum(c);if(V.transition().call(r),v&&(o.scale(n)._ticks(t.utils.calcTicksX(H/100,c)).tickSize(-L,0),U.select(".nv-x.nv-axis").attr("transform","translate(0,"+L+")"),U.select(".nv-x.nv-axis").transition().duration(0).call(o)),y){var Y;if(Y="wiggle"===r.offset()?0:t.utils.calcTicksY(L/36,c),a.scale(i)._ticks(Y).tickSize(-H,0),"expand"===r.style()||"stack_percent"===r.style()){var G=a.tickFormat();E&&G===W||(E=G),a.tickFormat(W)}else E&&(a.tickFormat(E),E=null);U.select(".nv-y.nv-axis").transition().duration(0).call(a)}r.dispatch.on("areaClick.toggle",function(t){1===c.filter(function(t){return!t.disabled}).length?c.forEach(function(t){t.disabled=!1}):c.forEach(function(e,n){e.disabled=n!=t.seriesIndex}),$.disabled=c.map(function(t){return!!t.disabled}),M.stateChange($),e.update()}),s.dispatch.on("stateChange",function(t){for(var n in t)$[n]=t[n];M.stateChange($),e.update()}),u.dispatch.on("legendClick",function(t,n){t.disabled&&(B=B.map(function(t){return t.disabled=!0,t}),t.disabled=!1,r.style(t.style),$.style=r.style(),M.stateChange($),e.update())}),l.dispatch.on("elementMousemove",function(n){r.clearHighlights();var i,o,a,s=[],u=0;if(c.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(l,c){o=t.interactiveBisect(l.values,n.pointXValue,e.x());var d=l.values[o],h=e.y()(d,o);if(null!=h&&r.highlightPoint(c,o,!0),"undefined"!=typeof d){"undefined"==typeof i&&(i=d),"undefined"==typeof a&&(a=e.xScale()(e.x()(d,o)));var f="expand"==r.style()?d.display.y:e.y()(d,o);s.push({key:l.key,value:f,color:p(l,l.seriesIndex),stackedValue:d.display}),w&&"expand"!=r.style()&&(u+=f)}}),s.reverse(),s.length>2){var d=e.yScale().invert(n.mouseY),h=null;s.forEach(function(t,e){d=Math.abs(d);var n=Math.abs(t.stackedValue.y0),i=Math.abs(t.stackedValue.y);return d>=n&&i+n>=d?void(h=e):void 0}),null!=h&&(s[h].highlight=!0)}w&&"expand"!=r.style()&&s.length>=2&&s.push({key:_,value:u,total:!0});var f=e.x()(i,o),g=l.tooltip.valueFormatter();"expand"===r.style()||"stack_percent"===r.style()?(O||(O=g),g=d3.format(".1%")):O&&(g=O,O=null),l.tooltip.chartContainer(N.parentNode).valueFormatter(g).data({value:f,series:s})(),l.renderGuideLine(a)}),l.dispatch.on("elementMouseout",function(t){r.clearHighlights()}),M.on("changeState",function(t){"undefined"!=typeof t.disabled&&c.length===t.disabled.length&&(c.forEach(function(e,n){e.disabled=t.disabled[n]}),$.disabled=t.disabled),"undefined"!=typeof t.style&&(r.style(t.style),I=t.style),e.update()})}),N.renderEnd("stacked Area chart immediate"),e}var n,i,r=t.models.stackedArea(),o=t.models.axis(),a=t.models.axis(),s=t.models.legend(),u=t.models.legend(),l=t.interactiveGuideline(),c=t.models.tooltip(),d={top:30,right:25,bottom:50,left:60},h=null,f=null,p=t.utils.defaultColor(),g=!0,m=!0,v=!0,y=!0,b=!1,x=!1,w=!0,_="TOTAL",$=t.utils.state(),k=null,C=null,M=d3.dispatch("stateChange","changeState","renderEnd"),D=250,S=["Stacked","Stream","Expanded"],T={},A=250;$.style=r.style(),o.orient("bottom").tickPadding(7),a.orient(b?"right":"left"),c.headerFormatter(function(t,e){return o.tickFormat()(t,e)}).valueFormatter(function(t,e){return a.tickFormat()(t,e)}),l.tooltip.headerFormatter(function(t,e){return o.tickFormat()(t,e)}).valueFormatter(function(t,e){return a.tickFormat()(t,e)});var E=null,O=null;u.updateState(!1);var N=t.utils.renderWatch(M),I=r.style(),P=function(t){return function(){return{active:t.map(function(t){return!t.disabled}),style:r.style()}}},F=function(t){return function(e){void 0!==e.style&&(I=e.style),void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}},W=d3.format("%");return r.dispatch.on("elementMouseover.tooltip",function(t){t.point.x=r.x()(t.point),t.point.y=r.y()(t.point),c.data(t).hidden(!1)}),r.dispatch.on("elementMouseout.tooltip",function(t){c.hidden(!0)}),e.dispatch=M,e.stacked=r,e.legend=s,e.controls=u,e.xAxis=o,e.yAxis=a,e.interactiveLayer=l,e.tooltip=c,e.dispatch=M,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return h},set:function(t){h=t}},height:{get:function(){return f},set:function(t){f=t}},showLegend:{get:function(){return m},set:function(t){m=t}},showXAxis:{get:function(){return v},set:function(t){v=t}},showYAxis:{get:function(){return y},set:function(t){y=t}},defaultState:{get:function(){return k},set:function(t){k=t}},noData:{get:function(){return C},set:function(t){C=t}},showControls:{get:function(){return g},set:function(t){g=t}},controlLabels:{get:function(){return T},set:function(t){T=t}},controlOptions:{get:function(){return S},set:function(t){S=t}},showTotalInTooltip:{get:function(){return w},set:function(t){w=t}},totalLabel:{get:function(){return _},set:function(t){_=t}},margin:{get:function(){return d},set:function(t){d.top=void 0!==t.top?t.top:d.top,d.right=void 0!==t.right?t.right:d.right,d.bottom=void 0!==t.bottom?t.bottom:d.bottom,d.left=void 0!==t.left?t.left:d.left}},duration:{get:function(){return A},set:function(t){A=t,N.reset(A),r.duration(A),o.duration(A),a.duration(A)}},color:{get:function(){return p},set:function(e){p=t.utils.getColor(e),s.color(p),r.color(p)}},rightAlignYAxis:{get:function(){return b},set:function(t){b=t,a.orient(b?"right":"left")}},useInteractiveGuideline:{get:function(){return x},set:function(t){x=!!t,e.interactive(!t),e.useVoronoi(!t),r.scatter.interactive(!t)}}}),t.utils.inheritOptions(e,r),t.utils.initOptions(e),e},t.models.sunburst=function(){"use strict";function e(w){return x.reset(),w.each(function(x){function w(t){t.x0=t.x,t.dx0=t.dx}function _(t){var e=d3.interpolate(m.domain(),[t.x,t.x+t.dx]),n=d3.interpolate(v.domain(),[t.y,1]),i=d3.interpolate(v.range(),[t.y?20:0,M]);return function(t,r){return r?function(e){return b(t)}:function(r){return m.domain(e(r)),v.domain(n(r)).range(i(r)),b(t)}}}d=d3.select(this);var $,k=t.utils.availableWidth(a,d,o),C=t.utils.availableHeight(s,d,o),M=Math.min(k,C)/2;t.utils.initSVG(d);var D=d.selectAll(".nv-wrap.nv-sunburst").data(x),S=D.enter().append("g").attr("class","nvd3 nv-wrap nv-sunburst nv-chart-"+c),T=S.selectAll("nv-sunburst");e.update=function(){0===p?d.call(e):d.transition().duration(p).call(e)},e.container=this,D.attr("transform","translate("+k/2+","+C/2+")"),d.on("click",function(t,e){g.chartClick({data:t,index:e,pos:d3.event,id:c})}),v.range([0,M]),n=n||x,r=x[0],y.value(l[u]||l.count),$=T.data(y.nodes).enter().append("path").attr("d",b).style("fill",function(t){return t.color?t.color:h(f?(t.children?t:t.parent).name:t.name)}).style("stroke","#FFF").on("click",function(t){i!==n&&n!==t&&(i=n),n=t,$.transition().duration(p).attrTween("d",_(t))}).each(w).on("dblclick",function(t){i.parent==t&&$.transition().duration(p).attrTween("d",_(r))}).each(w).on("mouseover",function(t,e){d3.select(this).classed("hover",!0).style("opacity",.8),g.elementMouseover({data:t,color:d3.select(this).style("fill")})}).on("mouseout",function(t,e){d3.select(this).classed("hover",!1).style("opacity",1),g.elementMouseout({data:t})}).on("mousemove",function(t,e){g.elementMousemove({data:t})})}),x.renderEnd("sunburst immediate"),e}var n,i,r,o={top:0,right:0,bottom:0,left:0},a=null,s=null,u="count",l={count:function(t){return 1},size:function(t){return t.size}},c=Math.floor(1e4*Math.random()),d=null,h=t.utils.defaultColor(),f=!0,p=500,g=d3.dispatch("chartClick","elementClick","elementDblClick","elementMousemove","elementMouseover","elementMouseout","renderEnd"),m=d3.scale.linear().range([0,2*Math.PI]),v=d3.scale.sqrt(),y=d3.layout.partition().sort(null).value(function(t){return 1}),b=d3.svg.arc().startAngle(function(t){return Math.max(0,Math.min(2*Math.PI,m(t.x)))}).endAngle(function(t){return Math.max(0,Math.min(2*Math.PI,m(t.x+t.dx)))}).innerRadius(function(t){return Math.max(0,v(t.y))}).outerRadius(function(t){return Math.max(0,v(t.y+t.dy))}),x=t.utils.renderWatch(g);return e.dispatch=g,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return a},set:function(t){a=t}},height:{get:function(){return s},set:function(t){s=t}},mode:{get:function(){return u},set:function(t){u=t}},id:{get:function(){return c},set:function(t){c=t}},duration:{get:function(){return p},set:function(t){p=t}},groupColorByParent:{get:function(){return f},set:function(t){f=!!t}},margin:{get:function(){return o},set:function(t){o.top=void 0!=t.top?t.top:o.top,o.right=void 0!=t.right?t.right:o.right,o.bottom=void 0!=t.bottom?t.bottom:o.bottom,o.left=void 0!=t.left?t.left:o.left}},color:{get:function(){return h},set:function(e){h=t.utils.getColor(e)}}}),t.utils.initOptions(e),e},t.models.sunburstChart=function(){"use strict";function e(i){return h.reset(),h.models(n),i.each(function(i){var s=d3.select(this);t.utils.initSVG(s);var u=t.utils.availableWidth(o,s,r),l=t.utils.availableHeight(a,s,r);if(e.update=function(){0===c?s.call(e):s.transition().duration(c).call(e)},e.container=this,!i||!i.length)return t.utils.noData(e,s),e;s.selectAll(".nv-noData").remove();var d=s.selectAll("g.nv-wrap.nv-sunburstChart").data(i),h=d.enter().append("g").attr("class","nvd3 nv-wrap nv-sunburstChart").append("g"),f=d.select("g");h.append("g").attr("class","nv-sunburstWrap"),d.attr("transform","translate("+r.left+","+r.top+")"),n.width(u).height(l);var p=f.select(".nv-sunburstWrap").datum(i);d3.transition(p).call(n)}),h.renderEnd("sunburstChart immediate"),e}var n=t.models.sunburst(),i=t.models.tooltip(),r={top:30,right:20,bottom:20,left:20},o=null,a=null,s=t.utils.defaultColor(),u=(Math.round(1e5*Math.random()),null),l=null,c=250,d=d3.dispatch("stateChange","changeState","renderEnd");i.duration(0);var h=t.utils.renderWatch(d);return i.headerEnabled(!1).valueFormatter(function(t,e){return t}),n.dispatch.on("elementMouseover.tooltip",function(t){t.series={key:t.data.name,value:t.data.size,color:t.color},i.data(t).hidden(!1)}),n.dispatch.on("elementMouseout.tooltip",function(t){i.hidden(!0)}),n.dispatch.on("elementMousemove.tooltip",function(t){i()}),e.dispatch=d,e.sunburst=n,e.tooltip=i,e.options=t.utils.optionsFunc.bind(e),e._options=Object.create({},{noData:{get:function(){return l},set:function(t){l=t}},defaultState:{get:function(){return u},set:function(t){u=t}},color:{get:function(){return s},set:function(t){s=t,n.color(s)}},duration:{get:function(){return c},set:function(t){c=t,h.reset(c),n.duration(c)}},margin:{get:function(){return r},set:function(t){r.top=void 0!==t.top?t.top:r.top,r.right=void 0!==t.right?t.right:r.right,r.bottom=void 0!==t.bottom?t.bottom:r.bottom,r.left=void 0!==t.left?t.left:r.left}}}),t.utils.inheritOptions(e,n),t.utils.initOptions(e),e},t.version="1.8.2"}();
//# sourceMappingURL=../maps/scripts/vendor-f2493b506f.js.map
